callback topic

Callbacks

Callbacks used in the Win32 API.

Typedefs

BFFCALLBACK = Int32 Function(Pointer<NativeType> hwnd, Uint32 uMsg, IntPtr lParam, IntPtr lpData) callback
Receives event notifications from the Active Directory Domain Services container browser dialog box.
DLGPROC = IntPtr Function(Pointer<NativeType> param0, Uint32 param1, IntPtr param2, IntPtr param3) callback
An application-defined callback function used with the CreateDialog and DialogBox families of functions.
DRAWSTATEPROC = Int32 Function(Pointer<NativeType> hdc, IntPtr lData, IntPtr wData, Int32 cx, Int32 cy) callback
An application-defined callback function that renders a complex image for the DrawState function.
DTT_CALLBACK_PROC = Int32 Function(Pointer<NativeType> hdc, Pointer<Utf16> pszText, Int32 cchText, Pointer<RECT> prc, Uint32 dwFlags, IntPtr lParam) callback
ENUMRESNAMEPROC = Int32 Function(Pointer<NativeType> hModule, Pointer<Utf16> lpType, Pointer<Utf16> lpName, IntPtr lParam) callback
An application-defined callback function used with the EnumResourceNames and EnumResourceNamesEx functions.
ENUMRESTYPEPROC = Int32 Function(Pointer<NativeType> hModule, Pointer<Utf16> lpType, IntPtr lParam) callback
An application-defined callback function used with the EnumResourceTypes and EnumResourceTypesEx functions.
FARPROC = Pointer<NativeType> callback
FONTENUMPROC = Int32 Function(Pointer<LOGFONT> param0, Pointer<TEXTMETRIC> param1, Uint32 param2, IntPtr param3) callback
An application defined callback function used with the EnumFontFamilies function.
GRAYSTRINGPROC = Int32 Function(Pointer<NativeType> param0, IntPtr param1, Int32 param2) callback
An application-defined callback function used with the GrayString function.
HOOKPROC = IntPtr Function(Int32 code, IntPtr wParam, IntPtr lParam) callback
An application-defined or library-defined callback function used with the SetWindowsHookEx function.
LPCCHOOKPROC = IntPtr Function(Pointer<NativeType> param0, Uint32 param1, IntPtr param2, IntPtr param3) callback
Receives messages or notifications intended for the default dialog box procedure of the Color dialog box.
LPCFHOOKPROC = IntPtr Function(Pointer<NativeType> param0, Uint32 param1, IntPtr param2, IntPtr param3) callback
Receives messages or notifications intended for the default dialog box procedure of the Font dialog box.
LPEXCEPFINO_DEFERRED_FILLIN = Int32 Function(Pointer<EXCEPINFO> pExcepInfo) callback
LPFRHOOKPROC = IntPtr Function(Pointer<NativeType> param0, Uint32 param1, IntPtr param2, IntPtr param3) callback
Receives messages or notifications intended for the default dialog box procedure of the Find or Replace dialog box.
LPHANDLER_FUNCTION = Void Function(Uint32 dwControl) callback
An application-defined callback function used with the RegisterServiceCtrlHandler function.
LPHANDLER_FUNCTION_EX = Uint32 Function(Uint32 dwControl, Uint32 dwEventType, Pointer<NativeType> lpEventData, Pointer<NativeType> lpContext) callback
An application-defined callback function used with the RegisterServiceCtrlHandlerEx function.
LPOCNCHKPROC = Int32 Function(IntPtr param0, IntPtr param1, Pointer<NativeType> param2) callback
LPOCNCONNPROC = IntPtr Function(IntPtr param0, Pointer<Utf16> param1, Pointer<Utf16> param2, Pointer<NativeType> param3) callback
LPOCNDSCPROC = Void Function(IntPtr param0, IntPtr param1, Pointer<NativeType> param2) callback
LPOFNHOOKPROC = IntPtr Function(Pointer<NativeType> param0, Uint32 param1, IntPtr param2, IntPtr param3) callback
Receives notification messages sent from the dialog box.
LPOVERLAPPED_COMPLETION_ROUTINE = Void Function(Uint32 dwErrorCode, Uint32 dwNumberOfBytesTransfered, Pointer<OVERLAPPED> lpOverlapped) callback
An application-defined callback function used with the ReadFileEx and WriteFileEx functions.
LPPROGRESS_ROUTINE = Uint32 Function(Int64 totalFileSize, Int64 totalBytesTransferred, Int64 streamSize, Int64 streamBytesTransferred, Uint32 dwStreamNumber, Uint32 dwCallbackReason, Pointer<NativeType> hSourceFile, Pointer<NativeType> hDestinationFile, Pointer<NativeType> lpData) callback
An application-defined callback function used with the CopyFileEx, MoveFileTransacted, and MoveFileWithProgress functions.
LPSERVICE_MAIN_FUNCTION = Void Function(Uint32 dwNumServicesArgs, Pointer<Pointer<Utf16>> lpServiceArgVectors) callback
The entry point for a service.
LPTHREAD_START_ROUTINE = Uint32 Function(Pointer<NativeType> lpThreadParameter) callback
An application-defined function that serves as the starting address for a thread.
MagImageScalingCallback = Int32 Function(Pointer<NativeType> hwnd, Pointer<NativeType> srcdata, MAGIMAGEHEADER srcheader, Pointer<NativeType> destdata, MAGIMAGEHEADER destheader, RECT unclipped, RECT clipped, Pointer<NativeType> dirty) callback
Prototype for a callback function that implements a custom transform for image scaling.
MIDIINPROC = Void Function(HMIDIIN hMidiIn, UINT wMsg, DWORD_PTR dwInstance, DWORD_PTR dwParam1, DWORD_PTR dwParam2) callback
An application-defined callback function for handling incoming MIDI messages.
MIDIOUTPROC = Void Function(HMIDIOUT hmo, UINT wMsg, DWORD_PTR dwInstance, DWORD_PTR dwParam1, DWORD_PTR dwParam2) callback
An application-defined callback function for handling outgoing MIDI messages.
MONITORENUMPROC = Int32 Function(Pointer<NativeType> param0, Pointer<NativeType> param1, Pointer<RECT> param2, IntPtr param3) callback
An application-defined callback function that is called by the EnumDisplayMonitors function.
NEARPROC = Pointer<NativeType> callback
PENUM_PAGE_FILE_CALLBACK = Int32 Function(Pointer<NativeType> pContext, Pointer<ENUM_PAGE_FILE_INFORMATION> pPageFileInfo, Pointer<Utf16> lpFilename) callback
An application-defined callback function used with the EnumPageFiles function.
PFN_AUTHENTICATION_CALLBACK_EX = Int32 Function(Pointer<NativeType> pvParam, Pointer<BLUETOOTH_AUTHENTICATION_CALLBACK_PARAMS> pAuthCallbackParams) callback
An application-defined callback function used in conjunction with the BluetoothRegisterForAuthenticationEx function.
PFN_BLUETOOTH_ENUM_ATTRIBUTES_CALLBACK = Int32 Function(Uint32 uAttribId, Pointer<Uint8> pValueStream, Uint32 cbStreamSize, Pointer<NativeType> pvParam) callback
An application-defined callback function that is called once for each attribute found in the pSDPStream parameter passed to the BluetoothSdpEnumAttributes function call.
PFN_DEVICE_CALLBACK = Int32 Function(Pointer<NativeType> pvParam, Pointer<BLUETOOTH_DEVICE_INFO> pDevice) callback
An application-defined callback function used in association with selecting Bluetooth devices.
PFN_SC_NOTIFY_CALLBACK = Void Function(Pointer<NativeType> pParameter) callback
PFNBLUETOOTH_GATT_EVENT_CALLBACK = Void Function(Int32 eventType, Pointer<NativeType> eventOutParameter, Pointer<NativeType> context) callback
Profile drivers implement a Bluetooth GATT event callback to be called whenever the value of a specific characteristic changes.
PFTASKDIALOGCALLBACK = Int32 Function(Pointer<NativeType> hwnd, Uint32 msg, IntPtr wParam, IntPtr lParam, IntPtr lpRefData) callback
An application-defined function used with the TaskDialogIndirect function.
PHANDLER_ROUTINE = Int32 Function(Uint32 ctrlType) callback
An application-defined function used with the SetConsoleCtrlHandler function.
PROC = Pointer<NativeType> callback
PSYM_ENUMERATESYMBOLS_CALLBACK = Int32 Function(Pointer<SYMBOL_INFO> pSymInfo, Uint32 symbolSize, Pointer<NativeType> userContext) callback
Used with the SymEnumSymbols, SymEnumTypes, and SymEnumTypesByName functions.
SENDASYNCPROC = Void Function(Pointer<NativeType> param0, Uint32 param1, IntPtr param2, IntPtr param3) callback
An application-defined callback function used with the SendMessageCallback function.
SPNOTIFYCALLBACK = Void Function(IntPtr wParam, IntPtr lParam) callback
SUBCLASSPROC = IntPtr Function(Pointer<NativeType> hWnd, Uint32 uMsg, IntPtr wParam, IntPtr lParam, IntPtr uIdSubclass, IntPtr dwRefData) callback
Defines the prototype for the callback function used by RemoveWindowSubclass and SetWindowSubclass.
TIMERPROC = Void Function(Pointer<NativeType> param0, Uint32 param1, IntPtr param2, Uint32 param3) callback
An application-defined callback function that processes WM_TIMER messages.
WLAN_NOTIFICATION_CALLBACK = Void Function(Pointer<L2_NOTIFICATION_DATA> param0, Pointer<NativeType> param1) callback
Defines the type of notification callback function.
WNDENUMPROC = Int32 Function(Pointer<NativeType> param0, IntPtr param1) callback
An application-defined callback function used with the EnumWindows or EnumDesktopWindows function.
WNDPROC = IntPtr Function(Pointer<NativeType> param0, Uint32 param1, IntPtr param2, IntPtr param3) callback
An application-defined callback function that processes messages sent to a window.