comctl32 topic

Common Controls Library

Implements a wide variety of standard Windows controls, such as File Open, Save, and Save As dialogs, progress bars, and list views. It creates and manages the windows for these UI elements, places various graphic elements within them, and collects user input.

Functions

DefSubclassProc(HWND hWnd, int uMsg, WPARAM wParam, LPARAM lParam) LRESULT comctl32
Calls the next handler in a window's subclass chain.
DrawStatusText(HDC hDC, Pointer<RECT> lprc, PCWSTR pszText, int uFlags) → void comctl32
Draws the specified text in the style of a status window with borders.
ImageList_Destroy(HIMAGELIST? himl) bool comctl32
Destroys an image list.
InitCommonControlsEx(Pointer<INITCOMMONCONTROLSEX> picce) bool comctl32
Ensures that the common control DLL (Comctl32.dll) is loaded, and registers specific common control classes from the DLL.
RemoveWindowSubclass(HWND hWnd, Pointer<NativeFunction<SUBCLASSPROC>> pfnSubclass, int uIdSubclass) bool comctl32
Removes a subclass callback from a window.
SetWindowSubclass(HWND hWnd, Pointer<NativeFunction<SUBCLASSPROC>> pfnSubclass, int uIdSubclass, int dwRefData) bool comctl32
Installs or updates a window subclass callback.
TaskDialog(HWND? hwndOwner, HINSTANCE? hInstance, PCWSTR? pszWindowTitle, PCWSTR? pszMainInstruction, PCWSTR? pszContent, TASKDIALOG_COMMON_BUTTON_FLAGS dwCommonButtons, PCWSTR? pszIcon, Pointer<Int32>? pnButton) → void comctl32
Creates, displays, and operates a task dialog.
TaskDialogIndirect(Pointer<TASKDIALOGCONFIG> pTaskConfig, Pointer<Int32>? pnButton, Pointer<Int32>? pnRadioButton, Pointer<Int32>? pfVerificationFlagChecked) → void comctl32
Creates, displays, and operates a task dialog.