crypt32 topic

Cryptographic API

Application programming interface that enables application developers to add authentication, encoding, and encryption to Windows-based applications.

Functions

CryptProtectData(Pointer<CRYPT_INTEGER_BLOB> pDataIn, PCWSTR? szDataDescr, Pointer<CRYPT_INTEGER_BLOB>? pOptionalEntropy, Pointer<CRYPTPROTECT_PROMPTSTRUCT>? pPromptStruct, int dwFlags, Pointer<CRYPT_INTEGER_BLOB> pDataOut) Win32Result<bool> crypt32
Performs encryption on the data in a DATA_BLOB structure.
CryptProtectMemory(Pointer<NativeType> pDataIn, int cbDataIn, int dwFlags) Win32Result<bool> crypt32
Encrypts memory to prevent others from viewing sensitive information in your process.
CryptUnprotectData(Pointer<CRYPT_INTEGER_BLOB> pDataIn, Pointer<Pointer<Utf16>>? ppszDataDescr, Pointer<CRYPT_INTEGER_BLOB>? pOptionalEntropy, Pointer<CRYPTPROTECT_PROMPTSTRUCT>? pPromptStruct, int dwFlags, Pointer<CRYPT_INTEGER_BLOB> pDataOut) Win32Result<bool> crypt32
Decrypts and does an integrity check of the data in a DATA_BLOB structure.
CryptUnprotectMemory(Pointer<NativeType> pDataIn, int cbDataIn, int dwFlags) Win32Result<bool> crypt32
Decrypts memory that was encrypted using the CryptProtectMemory function.
CryptUpdateProtectedState(PSID? pOldSid, PCWSTR? pwszOldPassword, int dwFlags, Pointer<Uint32>? pdwSuccessCount, Pointer<Uint32>? pdwFailureCount) Win32Result<bool> crypt32
Migrates the current user's master keys after the user's security identifier (SID) has changed.