dbghelp topic

Debug Help Library

DbgHelp contains a set of debugging support routines that allow you to work with executable images in the portable executable (PE) format.

Functions

SymCleanup(HANDLE hProcess) Win32Result<bool> dbghelp
Deallocates all resources associated with the process handle.
SymEnumSymbols(HANDLE hProcess, int baseOfDll, PCWSTR? mask, Pointer<NativeFunction<PSYM_ENUMERATESYMBOLS_CALLBACK>> enumSymbolsCallback, Pointer<NativeType>? userContext) Win32Result<bool> dbghelp
Enumerates all symbols in a process.
SymFromAddr(HANDLE hProcess, int address, Pointer<Uint64>? displacement, Pointer<SYMBOL_INFO> symbol) Win32Result<bool> dbghelp
Retrieves symbol information for the specified address.
SymFromToken(HANDLE hProcess, int base, int token, Pointer<SYMBOL_INFO> symbol) Win32Result<bool> dbghelp
Retrieves symbol information for the specified managed code token.
SymGetExtendedOption(IMAGEHLP_EXTENDED_OPTIONS option) bool dbghelp
Gets whether the specified extended symbol option on or off.
SymInitialize(HANDLE hProcess, PCWSTR? userSearchPath, bool fInvadeProcess) Win32Result<bool> dbghelp
Initializes the symbol handler for a process.
SymLoadModuleEx(HANDLE hProcess, HANDLE? hFile, PCWSTR? imageName, PCWSTR? moduleName, int baseOfDll, int dllSize, Pointer<MODLOAD_DATA>? data, SYM_LOAD_FLAGS? flags) Win32Result<int> dbghelp
Loads the symbol table for the specified module.
SymSetExtendedOption(IMAGEHLP_EXTENDED_OPTIONS option, bool value) bool dbghelp
Turns the specified extended symbol option on or off.
SymSetOptions(int symOptions) int dbghelp
Sets the options mask.
SymSetParentWindow(HWND hwnd) Win32Result<bool> dbghelp
Sets the window that the caller will use to display a user interface.
SymSetScopeFromAddr(HANDLE hProcess, int address) Win32Result<bool> dbghelp
Sets the local scope to the symbol that matches the specified address.
SymSetScopeFromIndex(HANDLE hProcess, int baseOfDll, int index) Win32Result<bool> dbghelp
Sets the local scope to the symbol that matches the specified index.
SymSetScopeFromInlineContext(HANDLE hProcess, int address, int inlineContext) Win32Result<bool> dbghelp
Sets the local scope to the symbol that matches the specified address and inline context.
SymSetSearchPath(HANDLE hProcess, PCWSTR? searchPathA) Win32Result<bool> dbghelp
Sets the search path for the specified process.
SymUnloadModule(HANDLE hProcess, int baseOfDll) Win32Result<bool> dbghelp
Unloads the symbol table.
SymUnloadModule64(HANDLE hProcess, int baseOfDll) Win32Result<bool> dbghelp
Unloads the symbol table.
UnDecorateSymbolName(PCWSTR name, PWSTR outputString, int maxStringLength, int flags) Win32Result<int> dbghelp
Undecorates the specified decorated C++ symbol name.