dwmapi topic

Desktop Window Manager API

Desktop composition is performed by the Desktop Window Manager (DWM). Through desktop composition, DWM enables visual effects on the desktop as well as various features such as glass window frames, 3-D window transition animations, Windows Flip and Windows Flip3D, and high resolution support.

Functions

DwmEnableBlurBehindWindow(HWND hWnd, Pointer<DWM_BLURBEHIND> pBlurBehind) → void dwmapi
Enables the blur effect on a specified window.
DwmEnableMMCSS(bool fEnableMMCSS) → void dwmapi
Notifies the Desktop Window Manager (DWM) to opt in to or out of Multimedia Class Schedule Service (MMCSS) scheduling while the calling process is alive.
DwmExtendFrameIntoClientArea(HWND hWnd, Pointer<MARGINS> pMarInset) → void dwmapi
Extends the window frame into the client area.
DwmFlush() → void dwmapi
Issues a flush call that blocks the caller until the next present, when all of the Microsoft DirectX surface updates that are currently outstanding have been made.
DwmGetColorizationColor(Pointer<Uint32> pcrColorization, Pointer<Int32> pfOpaqueBlend) → void dwmapi
Retrieves the current color used for Desktop Window Manager (DWM) glass composition.
DwmGetTransportAttributes(Pointer<Int32> pfIsRemoting, Pointer<Int32> pfIsConnected, Pointer<Uint32> pDwGeneration) → void dwmapi
Retrieves transport attributes.
DwmGetWindowAttribute(HWND hwnd, DWMWINDOWATTRIBUTE dwAttribute, Pointer<NativeType> pvAttribute, int cbAttribute) → void dwmapi
Retrieves the current value of a specified Desktop Window Manager (DWM) attribute applied to a window.
DwmInvalidateIconicBitmaps(HWND hwnd) → void dwmapi
Called by an application to indicate that all previously provided iconic bitmaps from a window, both thumbnails and peek representations, should be refreshed.
DwmRenderGesture(GESTURE_TYPE gt, int cContacts, Pointer<Uint32> pdwPointerID, Pointer<POINT> pPoints) → void dwmapi
Notifies Desktop Window Manager (DWM) that a touch contact has been recognized as a gesture, and that DWM should draw feedback for that gesture.
DwmSetWindowAttribute(HWND hwnd, DWMWINDOWATTRIBUTE dwAttribute, Pointer<NativeType> pvAttribute, int cbAttribute) → void dwmapi
Sets the value of Desktop Window Manager (DWM) non-client rendering attributes for a window.
DwmShowContact(int dwPointerID, DWM_SHOWCONTACT eShowContact) → void dwmapi
Called by an app or framework to specify the visual feedback type to draw in response to a particular touch or pen contact.