dxva2 topic

DirectX Video Acceleration API

DirectX Video Acceleration (DXVA) is an API and a corresponding DDI for using hardware acceleration to speed up video processing. Software codecs and software video processors can use DXVA to offload certain CPU-intensive operations to the GPU. For example, a software decoder can offload the inverse discrete cosine transform (iDCT) to the GPU.

Functions

DestroyPhysicalMonitor(HANDLE hMonitor) Win32Result<bool> dxva2
Closes a handle to a physical monitor.
DestroyPhysicalMonitors(int dwPhysicalMonitorArraySize, Pointer<PHYSICAL_MONITOR> pPhysicalMonitorArray) Win32Result<bool> dxva2
Closes an array of physical monitor handles.
GetMonitorBrightness(HANDLE hMonitor, Pointer<Uint32> pdwMinimumBrightness, Pointer<Uint32> pdwCurrentBrightness, Pointer<Uint32> pdwMaximumBrightness) Win32Result<int> dxva2
Retrieves a monitor's minimum, maximum, and current brightness settings.
GetMonitorCapabilities(HANDLE hMonitor, Pointer<Uint32> pdwMonitorCapabilities, Pointer<Uint32> pdwSupportedColorTemperatures) int dxva2
Retrieves the configuration capabilities of a monitor.
GetMonitorColorTemperature(HANDLE hMonitor, Pointer<Int32> pctCurrentColorTemperature) Win32Result<int> dxva2
Retrieves a monitor's current color temperature.
GetMonitorContrast(HANDLE hMonitor, Pointer<Uint32> pdwMinimumContrast, Pointer<Uint32> pdwCurrentContrast, Pointer<Uint32> pdwMaximumContrast) Win32Result<int> dxva2
Retrieves a monitor's minimum, maximum, and current contrast settings.
GetMonitorDisplayAreaPosition(HANDLE hMonitor, MC_POSITION_TYPE ptPositionType, Pointer<Uint32> pdwMinimumPosition, Pointer<Uint32> pdwCurrentPosition, Pointer<Uint32> pdwMaximumPosition) Win32Result<int> dxva2
Retrieves a monitor's minimum, maximum, and current horizontal or vertical position.
GetMonitorDisplayAreaSize(HANDLE hMonitor, MC_SIZE_TYPE stSizeType, Pointer<Uint32> pdwMinimumWidthOrHeight, Pointer<Uint32> pdwCurrentWidthOrHeight, Pointer<Uint32> pdwMaximumWidthOrHeight) Win32Result<int> dxva2
Retrieves a monitor's minimum, maximum, and current width or height.
GetMonitorRedGreenOrBlueDrive(HANDLE hMonitor, MC_DRIVE_TYPE dtDriveType, Pointer<Uint32> pdwMinimumDrive, Pointer<Uint32> pdwCurrentDrive, Pointer<Uint32> pdwMaximumDrive) Win32Result<int> dxva2
Retrieves a monitor's red, green, or blue drive value.
GetMonitorRedGreenOrBlueGain(HANDLE hMonitor, MC_GAIN_TYPE gtGainType, Pointer<Uint32> pdwMinimumGain, Pointer<Uint32> pdwCurrentGain, Pointer<Uint32> pdwMaximumGain) Win32Result<int> dxva2
Retrieves a monitor's red, green, or blue gain value.
GetMonitorTechnologyType(HANDLE hMonitor, Pointer<Int32> pdtyDisplayTechnologyType) Win32Result<int> dxva2
Retrieves the type of technology used by a monitor.
GetNumberOfPhysicalMonitorsFromHMONITOR(HMONITOR hMonitor, Pointer<Uint32> pdwNumberOfPhysicalMonitors) Win32Result<bool> dxva2
Retrieves the number of physical monitors associated with an HMONITOR monitor handle.
GetPhysicalMonitorsFromHMONITOR(HMONITOR hMonitor, int dwPhysicalMonitorArraySize, Pointer<PHYSICAL_MONITOR> pPhysicalMonitorArray) Win32Result<bool> dxva2
Retrieves the physical monitors associated with an HMONITOR monitor handle.
SaveCurrentMonitorSettings(HANDLE hMonitor) Win32Result<int> dxva2
Saves the current monitor settings to the display's nonvolatile storage.
SetMonitorBrightness(HANDLE hMonitor, int dwNewBrightness) Win32Result<int> dxva2
Sets a monitor's brightness value.
SetMonitorColorTemperature(HANDLE hMonitor, MC_COLOR_TEMPERATURE ctCurrentColorTemperature) Win32Result<int> dxva2
Sets a monitor's color temperature.
SetMonitorContrast(HANDLE hMonitor, int dwNewContrast) Win32Result<int> dxva2
Sets a monitor's contrast value.
SetMonitorDisplayAreaPosition(HANDLE hMonitor, MC_POSITION_TYPE ptPositionType, int dwNewPosition) Win32Result<int> dxva2
Sets the horizontal or vertical position of a monitor's display area.
SetMonitorDisplayAreaSize(HANDLE hMonitor, MC_SIZE_TYPE stSizeType, int dwNewDisplayAreaWidthOrHeight) Win32Result<int> dxva2
Sets the width or height of a monitor's display area.
SetMonitorRedGreenOrBlueDrive(HANDLE hMonitor, MC_DRIVE_TYPE dtDriveType, int dwNewDrive) int dxva2
Sets a monitor's red, green, or blue drive value.
SetMonitorRedGreenOrBlueGain(HANDLE hMonitor, MC_GAIN_TYPE gtGainType, int dwNewGain) int dxva2
Sets a monitor's red, green, or blue gain value.