magnification topic

Magnification API

The Magnification API enables applications to magnify the entire screen or portions of the screen, and to apply color effects.

Functions

MagGetColorEffect(HWND hwnd, Pointer<MAGCOLOREFFECT> pEffect) bool magnification
Gets the color transformation matrix for a magnifier control.
MagGetFullscreenColorEffect(Pointer<MAGCOLOREFFECT> pEffect) bool magnification
Retrieves the color transformation matrix associated with the full-screen magnifier.
MagGetFullscreenTransform(Pointer<Float> pMagLevel, Pointer<Int32> pxOffset, Pointer<Int32> pyOffset) bool magnification
Retrieves the magnification settings for the full-screen magnifier.
MagGetImageScalingCallback(HWND hwnd) Pointer<NativeFunction<MagImageScalingCallback>> magnification
Retrieves the registered callback function that implements a custom transform for image scaling.
MagGetInputTransform(Pointer<Int32> pfEnabled, Pointer<RECT> pRectSource, Pointer<RECT> pRectDest) bool magnification
Retrieves the current input transformation for pen and touch input, represented as a source rectangle and a destination rectangle.
MagGetWindowFilterList(HWND hwnd, Pointer<Uint32> pdwFilterMode, int count, Pointer<Pointer<NativeType>> pHWND) int magnification
Retrieves the list of windows that are magnified or excluded from magnification.
MagGetWindowSource(HWND hwnd, Pointer<RECT> pRect) bool magnification
Gets the rectangle of the area that is being magnified.
MagGetWindowTransform(HWND hwnd, Pointer<MAGTRANSFORM> pTransform) bool magnification
Retrieves the transformation matrix associated with a magnifier control.
MagInitialize() bool magnification
Creates and initializes the magnifier run-time objects.
MagSetColorEffect(HWND hwnd, Pointer<MAGCOLOREFFECT> pEffect) bool magnification
Sets the color transformation matrix for a magnifier control.
MagSetFullscreenColorEffect(Pointer<MAGCOLOREFFECT> pEffect) bool magnification
Changes the color transformation matrix associated with the full-screen magnifier.
MagSetFullscreenTransform(double magLevel, int xOffset, int yOffset) bool magnification
Changes the magnification settings for the full-screen magnifier.
MagSetImageScalingCallback(HWND hwnd, Pointer<NativeFunction<MagImageScalingCallback>> callback) bool magnification
Sets the callback function for external image filtering and scaling.
MagSetInputTransform(bool fEnabled, Pointer<RECT> pRectSource, Pointer<RECT> pRectDest) Win32Result<bool> magnification
Sets the current active input transformation for pen and touch input, represented as a source rectangle and a destination rectangle.
MagSetWindowFilterList(HWND hwnd, MW_FILTERMODE dwFilterMode, int count, Pointer<Pointer<NativeType>> pHWND) bool magnification
Sets the list of windows to be magnified or the list of windows to be excluded from magnification.
MagSetWindowSource(HWND hwnd, RECT rect) bool magnification
Sets the source rectangle for the magnification window.
MagSetWindowTransform(HWND hwnd, Pointer<MAGTRANSFORM> pTransform) bool magnification
Sets the transformation matrix for a magnifier control.
MagShowSystemCursor(bool fShowCursor) bool magnification
Shows or hides the system cursor.
MagUninitialize() bool magnification
Destroys the magnifier run-time objects.