netapi32 topic

Network Management API

The network management functions provide the ability to manage user accounts and network resources.

Functions

NetFreeAadJoinInformation(Pointer<DSREG_JOIN_INFO>? pJoinInfo) → void netapi32
Frees the memory allocated for the specified DSREG_JOIN_INFO structure, which contains join information for a tenant and which you retrieved by calling the NetGetAadJoinInformation function.
NetGetAadJoinInformation(PCWSTR? pcszTenantId) Pointer<DSREG_JOIN_INFO> netapi32
Retrieves the join information for the specified tenant.