ntdll topic

Native API

The Native API is the interface used by user-mode components of the operating system that must run without support from Win32 or other API subsystems.

Functions

NtQuerySystemInformation(SYSTEM_INFORMATION_CLASS systemInformationClass, Pointer<NativeType> systemInformation, int systemInformationLength, Pointer<Uint32> returnLength) NTSTATUS ntdll
Retrieves the specified system information.
RtlGetVersion(Pointer<OSVERSIONINFO> lpVersionInformation) NTSTATUS ntdll
Gets version information about the currently running operating system.