ole32 topic

OLE/COM APIs

Provides the Component Object Model (COM), as well as Object Linking and Embedding (OLE).

Functions

CLSIDFromProgID(PCWSTR lpszProgID) Pointer<GUID> ole32
Looks up a CLSID in the registry, given a ProgID.
CLSIDFromProgIDEx(PCWSTR lpszProgID) Pointer<GUID> ole32
Triggers automatic installation if the COMClassStore policy is enabled.
CLSIDFromString(PCWSTR lpsz) Pointer<GUID> ole32
Converts a string generated by the StringFromCLSID function back into the original CLSID.
CoAddRefServerProcess() int ole32
Increments a global per-process reference count.
CoCreateGuid() Pointer<GUID> ole32
Creates a GUID, a unique 128-bit integer used for CLSIDs and interface identifiers.
CoCreateInstance<T extends IUnknown>(Pointer<GUID> rclsid, IUnknown? pUnkOuter, CLSCTX dwClsContext) → T ole32
Creates a single uninitialized object of the class associated with a specified CLSID.
CoDecrementMTAUsage(CO_MTA_USAGE_COOKIE cookie) → void ole32
Releases the increment made by a previous call to the CoIncrementMTAUsage function.
CoGetApartmentType(Pointer<Int32> pAptType, Pointer<Int32> pAptQualifier) → void ole32
Returns the current apartment type and type qualifier.
CoGetClassObject<T extends IUnknown>(Pointer<GUID> rclsid, CLSCTX dwClsContext) → T ole32
Provides a pointer to an interface on a class object associated with a specified CLSID.
CoGetCurrentProcess() int ole32
Returns a value that is unique to the current thread.
CoGetMalloc(int dwMemContext) IMalloc? ole32
Retrieves a pointer to the default OLE task memory allocator (which supports the system implementation of the IMalloc interface) so applications can call its methods to manage memory.
CoIncrementMTAUsage() CO_MTA_USAGE_COOKIE ole32
Keeps MTA support active when no MTA threads are running.
CoInitializeEx(COINIT dwCoInit) HRESULT ole32
Initializes the COM library for use by the calling thread, sets the thread's concurrency model, and creates a new apartment for the thread if one is required.
CoInitializeSecurity(PSECURITY_DESCRIPTOR? pSecDesc, int cAuthSvc, Pointer<SOLE_AUTHENTICATION_SERVICE>? asAuthSvc, RPC_C_AUTHN_LEVEL dwAuthnLevel, RPC_C_IMP_LEVEL dwImpLevel, Pointer<NativeType>? pAuthList, EOLE_AUTHENTICATION_CAPABILITIES dwCapabilities) → void ole32
Registers security and sets the default security values for the process.
CoSetProxyBlanket(IUnknown? pProxy, int dwAuthnSvc, int dwAuthzSvc, PCWSTR? pServerPrincName, RPC_C_AUTHN_LEVEL dwAuthnLevel, RPC_C_IMP_LEVEL dwImpLevel, Pointer<NativeType>? pAuthInfo, EOLE_AUTHENTICATION_CAPABILITIES dwCapabilities) → void ole32
Sets the authentication information that will be used to make calls on the specified proxy.
CoTaskMemAlloc(int cb) Pointer<NativeType> ole32
Allocates a block of task memory in the same way that IMalloc.alloc does.
CoTaskMemFree(Pointer<NativeType>? pv) → void ole32
Frees a block of task memory previously allocated through a call to the CoTaskMemAlloc or CoTaskMemRealloc function.
CoTaskMemRealloc(Pointer<NativeType>? pv, int cb) Pointer<NativeType> ole32
Changes the size of a previously allocated block of task memory.
CoUninitialize() → void ole32
Closes the COM library on the current thread, unloads all DLLs loaded by the thread, frees any other resources that the thread maintains, and forces all RPC connections on the thread to close.
CoWaitForMultipleHandles(int dwFlags, int dwTimeout, int cHandles, Pointer<Pointer<NativeType>> pHandles) int ole32
Waits for specified handles to be signaled or for a specified timeout period to elapse.
CoWaitForMultipleObjects(int dwFlags, int dwTimeout, int cHandles, Pointer<Pointer<NativeType>> pHandles) int ole32
A replacement for CoWaitForMultipleHandles.
CreateStreamOnHGlobal(HGLOBAL? hGlobal, bool fDeleteOnRelease) IStream? ole32
Creates a stream object that uses an HGLOBAL memory handle to store the stream contents.
GetClassFile(PCWSTR szFilename) Pointer<GUID> ole32
Returns the CLSID associated with the specified file name.
GetHGlobalFromStream(IStream? pstm) HGLOBAL ole32
Retrieves the global memory handle to a stream that was created through a call to the CreateStreamOnHGlobal function.
IIDFromString(PCWSTR lpsz) Pointer<GUID> ole32
Converts a string generated by the StringFromIID function back into the original interface identifier (IID).
OleInitialize() → void ole32
Initializes the COM library on the current apartment and identifies the concurrency model as single-thread apartment (STA).
OleUninitialize() → void ole32
Closes the COM library on the apartment, releases any class factories, other COM objects, or servers held by the apartment, disables RPC on the apartment, and frees any resources the apartment maintains.
ProgIDFromCLSID(Pointer<GUID> clsid) PWSTR ole32
Retrieves the ProgID for a given CLSID.
PropVariantClear(Pointer<PROPVARIANT> pvar) → void ole32
Frees all elements that can be freed in a given PROPVARIANT structure.
PropVariantCopy(Pointer<PROPVARIANT> pvarDest, Pointer<PROPVARIANT> pvarSrc) → void ole32
Copies the contents of one PROPVARIANT structure to another.
PropVariantInit(Pointer<PROPVARIANT> pvar) → void ole32
Initializes a PROPVARIANT structure.
StringFromCLSID(Pointer<GUID> rclsid) PWSTR ole32
Converts a CLSID into a string of printable characters.
StringFromGUID2(Pointer<GUID> rguid, PWSTR lpsz, int cchMax) int ole32
Converts a globally unique identifier (GUID) into a string of printable characters.
StringFromIID(Pointer<GUID> rclsid) PWSTR ole32
Converts an interface identifier into a string of printable characters.