oleaut32 topic

OLE Automation API

OLE Automation APIs.

Functions

DosDateTimeToVariantTime(int wDosDate, int wDosTime, Pointer<Double> pvtime) int oleaut32
Converts the MS-DOS representation of time to the date and time representation stored in a variant.
GetActiveObject(Pointer<GUID> rclsid, Pointer<VTablePointer> ppunk) → void oleaut32
Retrieves a pointer to a running object that has been registered with OLE.
SafeArrayAccessData(Pointer<SAFEARRAY> psa, Pointer<Pointer<NativeType>> ppvData) → void oleaut32
Increments the lock count of an array, and retrieves a pointer to the array data.
SafeArrayAddRef(Pointer<SAFEARRAY> psa, Pointer<Pointer<NativeType>> ppDataToRelease) → void oleaut32
Increases the pinning reference count of the descriptor for the specified safe array by one, and may increase the pinning reference count of the data for the specified safe array by one if that data was dynamically allocated, as determined by the descriptor of the safe array.
SafeArrayAllocData(Pointer<SAFEARRAY> psa) → void oleaut32
Allocates memory for a safe array, based on a descriptor created with SafeArrayAllocDescriptor.
SafeArrayAllocDescriptor(int cDims) Pointer<SAFEARRAY> oleaut32
Allocates memory for a safe array descriptor.
SafeArrayAllocDescriptorEx(VARENUM vt, int cDims) Pointer<SAFEARRAY> oleaut32
Creates a safe array descriptor for an array of any valid variant type, including VT_RECORD, without allocating the array data.
SafeArrayCopy(Pointer<SAFEARRAY> psa) Pointer<SAFEARRAY> oleaut32
Creates a copy of an existing safe array.
SafeArrayCopyData(Pointer<SAFEARRAY> psaSource, Pointer<SAFEARRAY> psaTarget) → void oleaut32
Copies the source array to the specified target array after releasing any resources in the target array.
SafeArrayCreate(VARENUM vt, int cDims, Pointer<SAFEARRAYBOUND> rgsabound) Pointer<SAFEARRAY> oleaut32
Creates a new array descriptor, allocates and initializes the data for the array, and returns a pointer to the new array descriptor.
SafeArrayCreateEx(VARENUM vt, int cDims, Pointer<SAFEARRAYBOUND> rgsabound, Pointer<NativeType> pvExtra) Pointer<SAFEARRAY> oleaut32
Creates and returns a safe array descriptor from the specified VARTYPE, number of dimensions and bounds.
SafeArrayCreateVector(VARENUM vt, int lLbound, int cElements) Pointer<SAFEARRAY> oleaut32
Creates a one-dimensional array.
SafeArrayCreateVectorEx(VARENUM vt, int lLbound, int cElements, Pointer<NativeType> pvExtra) Pointer<SAFEARRAY> oleaut32
Creates and returns a one-dimensional safe array of the specified VARTYPE and bounds.
SafeArrayDestroy(Pointer<SAFEARRAY> psa) → void oleaut32
Destroys an existing array descriptor and all of the data in the array.
SafeArrayDestroyData(Pointer<SAFEARRAY> psa) → void oleaut32
Destroys all the data in the specified safe array.
SafeArrayDestroyDescriptor(Pointer<SAFEARRAY> psa) → void oleaut32
Destroys the descriptor of the specified safe array.
SafeArrayGetDim(Pointer<SAFEARRAY> psa) int oleaut32
Gets the number of dimensions in the array.
SafeArrayGetElement(Pointer<SAFEARRAY> psa, Pointer<Int32> rgIndices, Pointer<NativeType> pv) → void oleaut32
Retrieves a single element of the array.
SafeArrayGetElemsize(Pointer<SAFEARRAY> psa) int oleaut32
Gets the size of an element.
SafeArrayGetIID(Pointer<SAFEARRAY> psa) Pointer<GUID> oleaut32
Gets the GUID of the interface contained within the specified safe array.
SafeArrayGetLBound(Pointer<SAFEARRAY> psa, int nDim) int oleaut32
Gets the lower bound for any dimension of the specified safe array.
SafeArrayGetRecordInfo(Pointer<SAFEARRAY> psa) IRecordInfo? oleaut32
Retrieves the IRecordInfo interface of the UDT contained in the specified safe array.
SafeArrayGetUBound(Pointer<SAFEARRAY> psa, int nDim) int oleaut32
Gets the upper bound for any dimension of the specified safe array.
SafeArrayGetVartype(Pointer<SAFEARRAY> psa) VARENUM oleaut32
Gets the VARTYPE stored in the specified safe array.
SafeArrayLock(Pointer<SAFEARRAY> psa) → void oleaut32
Increments the lock count of an array, and places a pointer to the array data in pvData of the array descriptor.
SafeArrayPtrOfIndex(Pointer<SAFEARRAY> psa, Pointer<Int32> rgIndices, Pointer<Pointer<NativeType>> ppvData) → void oleaut32
Gets a pointer to an array element.
SafeArrayPutElement(Pointer<SAFEARRAY> psa, Pointer<Int32> rgIndices, Pointer<NativeType> pv) → void oleaut32
Stores the data element at the specified location in the array.
SafeArrayRedim(Pointer<SAFEARRAY> psa, Pointer<SAFEARRAYBOUND> psaboundNew) → void oleaut32
Changes the right-most (least significant) bound of the specified safe array.
SafeArrayReleaseData(Pointer<NativeType> pData) → void oleaut32
Decreases the pinning reference count for the specified safe array data by one.
SafeArrayReleaseDescriptor(Pointer<SAFEARRAY> psa) → void oleaut32
Decreases the pinning reference count for the descriptor of the specified safe array by one.
SafeArraySetIID(Pointer<SAFEARRAY> psa, Pointer<GUID> guid) → void oleaut32
Sets the GUID of the interface for the specified safe array.
SafeArraySetRecordInfo(Pointer<SAFEARRAY> psa, IRecordInfo? prinfo) → void oleaut32
Sets the record info in the specified safe array.
SafeArrayUnaccessData(Pointer<SAFEARRAY> psa) → void oleaut32
Decrements the lock count of an array, and invalidates the pointer retrieved by SafeArrayAccessData.
SafeArrayUnlock(Pointer<SAFEARRAY> psa) → void oleaut32
Decrements the lock count of an array so it can be freed or resized.
SysAllocString(PCWSTR? psz) BSTR oleaut32
Allocates a new string and copies the passed string into it.
SysAllocStringByteLen(PCSTR? psz, int len) BSTR oleaut32
Takes an ANSI string as input, and returns a BSTR that contains an ANSI string.
SysAllocStringLen(PCWSTR? strIn, int ui) BSTR oleaut32
Allocates a new string, copies the specified number of characters from the passed string, and appends a null-terminating character.
SysFreeString(BSTR? bstrString) → void oleaut32
Deallocates a string allocated previously by SysAllocString, SysAllocStringByteLen, SysReAllocString, SysAllocStringLen, or SysReAllocStringLen.
SysReAllocString(Pointer<Pointer<Utf16>> pbstr, PCWSTR? psz) int oleaut32
Reallocates a previously allocated string to be the size of a second string and copies the second string into the reallocated memory.
SysReAllocStringLen(Pointer<Pointer<Utf16>> pbstr, PCWSTR? psz, int len) int oleaut32
Creates a new BSTR containing a specified number of characters from an old BSTR, and frees the old BSTR.
SysReleaseString(BSTR bstrString) → void oleaut32
Decreases the pinning reference count for the specified string by one.
SysStringByteLen(BSTR? bstr) int oleaut32
Returns the length (in bytes) of a BSTR.
SysStringLen(BSTR? pbstr) int oleaut32
Returns the length of a BSTR.
VarBstrCat(BSTR bstrLeft, BSTR bstrRight) BSTR oleaut32
Concatenates two variants of type BSTR and returns the resulting BSTR.
VarBstrCmp(BSTR bstrLeft, BSTR bstrRight, int lcid, int dwFlags) → void oleaut32
Compares two variants of type BSTR.
VariantChangeType(Pointer<VARIANT> pvargDest, Pointer<VARIANT> pvarSrc, VAR_CHANGE_FLAGS wFlags, VARENUM vt) → void oleaut32
Converts a variant from one type to another.
VariantClear(Pointer<VARIANT> pvarg) → void oleaut32
Clears a variant.
VariantCopy(Pointer<VARIANT> pvargDest, Pointer<VARIANT> pvargSrc) → void oleaut32
Frees the destination variant and makes a copy of the source variant.
VariantInit(Pointer<VARIANT> pvarg) → void oleaut32
Initializes a variant.
VariantTimeToDosDateTime(double vtime, Pointer<Uint16> pwDosDate, Pointer<Uint16> pwDosTime) int oleaut32
Converts the variant representation of a date and time to MS-DOS date and time values.
VariantTimeToSystemTime(double vtime, Pointer<SYSTEMTIME> lpSystemTime) int oleaut32
Converts the variant representation of time to system time values.