onecore topic

OneCore API

APIs associated with the OneCore effort.

Functions

GetCommPorts(Pointer<Uint32> lpPortNumbers, int uPortNumbersCount, Pointer<Uint32> puPortNumbersFound) int onecore
Gets an array that contains the well-formed COM ports.
GetIntegratedDisplaySize() double onecore
Retrieves the best estimate of the diagonal size of the built-in screen, in inches.
GetServiceDirectory(SERVICE_STATUS_HANDLE hServiceStatus, SERVICE_DIRECTORY_TYPE eDirectoryType, PWSTR? lpPathBuffer, int cchPathBufferLength, Pointer<Uint32> lpcchRequiredBufferLength) int onecore
Returns a path for a per-service filesystem location for a service to read and/or write state to.
GetServiceRegistryStateKey(SERVICE_STATUS_HANDLE serviceStatusHandle, SERVICE_REGISTRY_STATE_TYPE stateType, int accessMask, Pointer<Pointer<NativeType>> serviceStateKey) int onecore
Returns a handle for a registry key for a service to read and/or write state to.
GetSharedServiceDirectory(SC_HANDLE serviceHandle, SERVICE_SHARED_DIRECTORY_TYPE directoryType, PWSTR? pathBuffer, int pathBufferLength, Pointer<Uint32> requiredBufferLength) int onecore
Returns a path for a per-service filesystem location for a service and associated programs to read and/or write state to.
GetSharedServiceRegistryStateKey(SC_HANDLE serviceHandle, SERVICE_SHARED_REGISTRY_STATE_TYPE stateType, int accessMask, Pointer<Pointer<NativeType>> serviceStateKey) int onecore
Returns a handle for a registry key for a service and associated programs to read and/or write state to.
IsApiSetImplemented(PCSTR contract) bool onecore
Tests if a specified API set is present on the computer.
OpenCommPort(int uPortNumber, int dwDesiredAccess, int dwFlagsAndAttributes) HANDLE onecore
Attempts to open a communication device.