psapi topic

Process Status API

Obtains information about processes and device drivers.

Functions

EmptyWorkingSet(HANDLE hProcess) Win32Result<bool> psapi
Removes as many pages as possible from the working set of the specified process.
EnumDeviceDrivers(Pointer<Pointer<NativeType>> lpImageBase, int cb, Pointer<Uint32> lpcbNeeded) Win32Result<bool> psapi
Retrieves the load address for each device driver in the system.
EnumPageFiles(Pointer<NativeFunction<PENUM_PAGE_FILE_CALLBACK>> pCallBackRoutine, Pointer<NativeType> pContext) Win32Result<bool> psapi
Calls the callback routine for each installed pagefile in the system.
EnumProcesses(Pointer<Uint32> lpidProcess, int cb, Pointer<Uint32> lpcbNeeded) Win32Result<bool> psapi
Retrieves the process identifier for each process object in the system.
EnumProcessModules(HANDLE hProcess, Pointer<Pointer<NativeType>> lphModule, int cb, Pointer<Uint32> lpcbNeeded) Win32Result<bool> psapi
Retrieves a handle for each module in the specified process.
EnumProcessModulesEx(HANDLE hProcess, Pointer<Pointer<NativeType>> lphModule, int cb, Pointer<Uint32> lpcbNeeded, ENUM_PROCESS_MODULES_EX_FLAGS dwFilterFlag) Win32Result<bool> psapi
Retrieves a handle for each module in the specified process that meets the specified filter criteria.
GetDeviceDriverBaseName(Pointer<NativeType> imageBase, PWSTR lpBaseName, int nSize) Win32Result<int> psapi
Retrieves the base name of the specified device driver.
GetDeviceDriverFileName(Pointer<NativeType> imageBase, PWSTR lpFilename, int nSize) Win32Result<int> psapi
Retrieves the path available for the specified device driver.
GetMappedFileName(HANDLE hProcess, Pointer<NativeType> lpv, PWSTR lpFilename, int nSize) Win32Result<int> psapi
Checks whether the specified address is within a memory-mapped file in the address space of the specified process.
GetModuleBaseName(HANDLE hProcess, HMODULE? hModule, PWSTR lpBaseName, int nSize) Win32Result<int> psapi
Retrieves the base name of the specified module.
GetModuleFileNameEx(HANDLE? hProcess, HMODULE? hModule, PWSTR lpFilename, int nSize) Win32Result<int> psapi
Retrieves the fully qualified path for the file containing the specified module.
GetModuleInformation(HANDLE hProcess, HMODULE hModule, Pointer<MODULEINFO> lpmodinfo, int cb) Win32Result<bool> psapi
Retrieves information about the specified module in the MODULEINFO structure.
GetPerformanceInfo(Pointer<PERFORMANCE_INFORMATION> pPerformanceInformation, int cb) Win32Result<bool> psapi
Retrieves the performance values contained in the PERFORMANCE_INFORMATION structure.
GetProcessImageFileName(HANDLE hProcess, PWSTR lpImageFileName, int nSize) Win32Result<int> psapi
Retrieves the name of the executable file for the specified process.
GetProcessMemoryInfo(HANDLE process, Pointer<PROCESS_MEMORY_COUNTERS> ppsmemCounters, int cb) Win32Result<bool> psapi
Retrieves information about the memory usage of the specified process.