shell32 topic

Windows Shell APIs

Functions provided by the Windows desktop shell, including file associations, known paths, installed programs and the taskbar.

Functions

CommandLineToArgv(PCWSTR lpCmdLine, Pointer<Int32> pNumArgs) Win32Result<Pointer<Pointer<Utf16>>> shell32
Parses a Unicode command line string and returns an array of pointers to the command line arguments, along with a count of such arguments, in a way that is similar to the standard C run-time argv and argc values.
DragAcceptFiles(HWND hWnd, bool fAccept) → void shell32
Registers whether a window accepts dropped files.
DragFinish(HDROP hDrop) → void shell32
Releases memory that the system allocated for use in transferring file names to the application.
DragQueryFile(HDROP hDrop, int iFile, PWSTR? lpszFile, int cch) int shell32
Retrieves the names of dropped files that result from a successful drag-and-drop operation.
ExtractAssociatedIcon(PWSTR pszIconPath, Pointer<Uint16> piIcon) HICON shell32
Gets a handle to an icon stored as a resource in a file or an icon stored in a file's associated executable file.
FindExecutable(PCWSTR lpFile, PCWSTR? lpDirectory, PWSTR lpResult) HINSTANCE shell32
Retrieves the name of and handle to the executable (.exe) file associated with a specific document file.
SHBrowseForFolder(Pointer<BROWSEINFO> lpbi) Pointer<ITEMIDLIST> shell32
Displays a dialog box that enables the user to select a Shell folder.
SHCreateItemFromParsingName<T extends IUnknown>(PCWSTR pszPath, IBindCtx? pbc) → T shell32
Creates and initializes a Shell item object from a parsing name.
Shell_NotifyIcon(NOTIFY_ICON_MESSAGE dwMessage, Pointer<NOTIFYICONDATA> lpData) bool shell32
Sends a message to the taskbar's status area.
ShellAbout(HWND? hWnd, PCWSTR szApp, PCWSTR? szOtherStuff, HICON? hIcon) int shell32
Displays a ShellAbout dialog box.
ShellExecute(HWND? hwnd, PCWSTR? lpOperation, PCWSTR lpFile, PCWSTR? lpParameters, PCWSTR? lpDirectory, SHOW_WINDOW_CMD nShowCmd) HINSTANCE shell32
Performs an operation on a specified file.
ShellExecuteEx(Pointer<SHELLEXECUTEINFO> pExecInfo) Win32Result<bool> shell32
Performs an operation on a specified file.
SHEmptyRecycleBin(HWND? hwnd, PCWSTR? pszRootPath, int dwFlags) → void shell32
Empties the Recycle Bin on the specified drive.
SHFileOperation(Pointer<SHFILEOPSTRUCT> lpFileOp) Win32Result<int> shell32
Copies, moves, renames, or deletes a file system object.
SHFreeNameMappings(HANDLE? hNameMappings) → void shell32
Frees a file name mapping object that was retrieved by the SHFileOperation function.
SHGetDesktopFolder() IShellFolder? shell32
Retrieves the IShellFolder interface for the desktop folder, which is the root of the Shell's namespace.
SHGetDiskFreeSpaceEx(PCWSTR pszDirectoryName, Pointer<Uint64>? pulFreeBytesAvailableToCaller, Pointer<Uint64>? pulTotalNumberOfBytes, Pointer<Uint64>? pulTotalNumberOfFreeBytes) bool shell32
Retrieves disk space information for a disk volume.
SHGetDriveMedia(PCWSTR pszDrive) int shell32
Returns the type of media that is in the given drive.
SHGetFileInfo(PCWSTR pszPath, FILE_FLAGS_AND_ATTRIBUTES dwFileAttributes, Pointer<SHFILEINFO>? psfi, int cbFileInfo, SHGFI_FLAGS uFlags) int shell32
Retrieves information about an object in the file system, such as a file, folder, directory, or drive root.
SHGetFolderPath(int csidl, HANDLE? hToken, int dwFlags, PWSTR pszPath) → void shell32
Deprecated.
SHGetKnownFolderPath(Pointer<GUID> rfid, KNOWN_FOLDER_FLAG dwFlags, HANDLE? hToken) PWSTR shell32
Retrieves the full path of a known folder identified by the folder's KNOWNFOLDERID.
SHGetLocalizedName(PCWSTR pszPath, PWSTR pszResModule, int cch, Pointer<Int32> pidsRes) → void shell32
Retrieves the localized name of a file in a Shell folder.
SHGetPathFromIDList(Pointer<ITEMIDLIST> pidl, PWSTR pszPath) bool shell32
Converts an item identifier list to a file system path.
SHQueryRecycleBin(PCWSTR? pszRootPath, Pointer<SHQUERYRBINFO> pSHQueryRBInfo) → void shell32
Retrieves the size of the Recycle Bin and the number of items in it, for a specified drive.