uxtheme topic

User Theming APIs

Handles user experience theming and visual styles.

Functions

CloseThemeData(HTHEME hTheme) → void uxtheme
Closes the theme data handle.
DrawThemeBackground(HTHEME hTheme, HDC hdc, int iPartId, int iStateId, Pointer<RECT> pRect, Pointer<RECT>? pClipRect) → void uxtheme
Draws the border and fill defined by the visual style for the specified control part.
DrawThemeEdge(HTHEME hTheme, HDC hdc, int iPartId, int iStateId, Pointer<RECT> pDestRect, DRAWEDGE_FLAGS uEdge, DRAW_EDGE_FLAGS uFlags, Pointer<RECT>? pContentRect) → void uxtheme
Draws one or more edges defined by the visual style of a rectangle.
DrawThemeIcon(HTHEME hTheme, HDC hdc, int iPartId, int iStateId, Pointer<RECT> pRect, HIMAGELIST himl, int iImageIndex) → void uxtheme
Draws an image from an image list with the icon effect defined by the visual style.
DrawThemeParentBackground(HWND hwnd, HDC hdc, Pointer<RECT>? prc) → void uxtheme
Draws the part of a parent control that is covered by a partially-transparent or alpha-blended child control.
DrawThemeParentBackgroundEx(HWND hwnd, HDC hdc, DRAW_THEME_PARENT_BACKGROUND_FLAGS dwFlags, Pointer<RECT>? prc) → void uxtheme
Used by partially-transparent or alpha-blended child controls to draw the part of their parent in front of which they appear.
DrawThemeTextEx(HTHEME hTheme, HDC hdc, int iPartId, int iStateId, PCWSTR pszText, int cchText, DRAW_TEXT_FORMAT dwTextFlags, Pointer<RECT> pRect, Pointer<DTTOPTS>? pOptions) → void uxtheme
Draws text using the color and font defined by the visual style.
EnableThemeDialogTexture(HWND hwnd, int dwFlags) → void uxtheme
Enables or disables the visual style of the background of a dialog window.
GetCurrentThemeName(PWSTR pszThemeFileName, int cchMaxNameChars, PWSTR? pszColorBuff, int cchMaxColorChars, PWSTR? pszSizeBuff, int cchMaxSizeChars) → void uxtheme
Retrieves the name of the current visual style, and optionally retrieves the color scheme name and size name.
GetThemeMetric(HTHEME hTheme, HDC? hdc, int iPartId, int iStateId, THEME_PROPERTY_SYMBOL_ID iPropId) → int uxtheme
Retrieves the value of a metric property.
GetThemePartSize(HTHEME hTheme, HDC? hdc, int iPartId, int iStateId, Pointer<RECT>? prc, THEMESIZE eSize) → Pointer<SIZE> uxtheme
Calculates the original size of the part defined by a visual style.
GetThemeRect(HTHEME hTheme, int iPartId, int iStateId, int iPropId) → Pointer<RECT> uxtheme
Retrieves the value of a RECT property.
GetThemeSysColor(HTHEME? hTheme, int iColorId) → COLORREF uxtheme
Retrieves the value of a system color.
GetThemeSysColorBrush(HTHEME? hTheme, THEME_PROPERTY_SYMBOL_ID iColorId) → HBRUSH uxtheme
Retrieves a system color brush.
GetThemeSysFont(HTHEME? hTheme, THEME_PROPERTY_SYMBOL_ID iFontId) → Pointer<LOGFONT> uxtheme
Retrieves the LOGFONT of a system font.
GetThemeSysSize(HTHEME? hTheme, int iSizeId) → int uxtheme
Retrieves the value of a system size metric from theme data.
GetWindowTheme(HWND hwnd) → HTHEME uxtheme
Retrieves a theme handle to a window that has visual styles applied.
IsAppThemed() → bool uxtheme
Reports whether the current application's user interface displays using visual styles.
IsCompositionActive() → bool uxtheme
Determines whether Desktop Window Manager (DWM) composition effects are available to the theme.
IsThemeActive() → bool uxtheme
Tests if a visual style for the current application is active.
IsThemeBackgroundPartiallyTransparent(HTHEME hTheme, int iPartId, int iStateId) → bool uxtheme
Retrieves whether the background specified by the visual style has transparent pieces or alpha-blended pieces.
IsThemeDialogTextureEnabled(HWND hwnd) → bool uxtheme
Reports whether a specified dialog window supports background texturing.
IsThemePartDefined(HTHEME hTheme, int iPartId, int iStateId) → bool uxtheme
Retrieves whether a visual style has defined parameters for the specified part and state.
OpenThemeData(HWND? hwnd, PCWSTR pszClassList) → HTHEME uxtheme
Opens the theme data for a window and its associated class.
OpenThemeDataEx(HWND? hwnd, PCWSTR pszClassList, OPEN_THEME_DATA_FLAGS dwFlags) → HTHEME uxtheme
Opens the theme data associated with a window for specified theme classes.
OpenThemeDataForDpi(HWND? hwnd, PCWSTR pszClassList, int dpi) → HTHEME uxtheme
A variant of OpenThemeData that opens a theme handle associated with a specific DPI.
SetThemeAppProperties(SET_THEME_APP_PROPERTIES_FLAGS dwFlags) → void uxtheme
Sets the flags that determine how visual styles are implemented in the calling application.
SetWindowTheme(HWND hwnd, PCWSTR? pszSubAppName, PCWSTR? pszSubIdList) → void uxtheme
Causes a window to use a different set of visual style information than its class normally uses.
SetWindowThemeAttribute(HWND hwnd, WINDOWTHEMEATTRIBUTETYPE eAttribute, Pointer<NativeType> pvAttribute, int cbAttribute) → void uxtheme
Sets attributes to control how visual styles are applied to a specified window.