winmm topic

Windows Multimedia API

Microsoft Windows multimedia support enables applications to use sound and video.

Functions

mciGetDeviceID(PCWSTR pszDevice) int winmm
Retrieves the device identifier corresponding to the name of an open device.
mciGetDeviceIDFromElementID(int dwElementID, PCWSTR lpstrType) int winmm
Retrieves the MCI device identifier corresponding to an element identifier.
mciGetErrorString(int mcierr, PWSTR pszText, int cchText) bool winmm
Retrieves a string that describes the specified MCI error code.
mciSendCommand(int mciId, int uMsg, int? dwParam1, int? dwParam2) int winmm
Sends a command message to the specified MCI device.
mciSendString(PCWSTR lpstrCommand, PWSTR? lpstrReturnString, int uReturnLength, HWND? hwndCallback) int winmm
Sends a command string to an MCI device.
midiConnect(HMIDI hmi, HMIDIOUT hmo) int winmm
Connects a MIDI input device to a MIDI thru or output device, or connects a MIDI thru device to a MIDI output device.
midiDisconnect(HMIDI hmi, HMIDIOUT hmo) int winmm
Disconnects a MIDI input device from a MIDI thru or output device, or disconnects a MIDI thru device from a MIDI output device.
midiInAddBuffer(HMIDIIN hmi, Pointer<MIDIHDR> pmh, int cbmh) int winmm
Sends an input buffer to a specified opened MIDI input device.
midiInClose(HMIDIIN hmi) int winmm
Closes the specified MIDI input device.
midiInGetDevCaps(int uDeviceID, Pointer<MIDIINCAPS> pmic, int cbmic) int winmm
Determines the capabilities of a specified MIDI input device.
midiInGetErrorText(int mmrError, PWSTR pszText, int cchText) int winmm
Retrieves a textual description for an error identified by the specified error code.
midiInGetID(HMIDIIN hmi, Pointer<Uint32> puDeviceID) int winmm
Gets the device identifier for the given MIDI input device.
midiInGetNumDevs() int winmm
Retrieves the number of MIDI input devices in the system.
midiInMessage(HMIDIIN? hmi, int uMsg, int? dw1, int? dw2) int winmm
Sends a message to the MIDI device driver.
midiInOpen(Pointer<Pointer<NativeType>> phmi, int uDeviceID, int? dwCallback, int? dwInstance, MIDI_WAVE_OPEN_TYPE fdwOpen) int winmm
Opens a specified MIDI input device.
midiInPrepareHeader(HMIDIIN hmi, Pointer<MIDIHDR> pmh, int cbmh) int winmm
Prepares a buffer for MIDI input.
midiInReset(HMIDIIN hmi) int winmm
Stops input on a given MIDI input device.
midiInStart(HMIDIIN hmi) int winmm
Starts MIDI input on the specified MIDI input device.
midiInStop(HMIDIIN hmi) int winmm
Stops MIDI input on the specified MIDI input device.
midiInUnprepareHeader(HMIDIIN hmi, Pointer<MIDIHDR> pmh, int cbmh) int winmm
Cleans up the preparation performed by the midiInPrepareHeader function.
midiOutCacheDrumPatches(HMIDIOUT hmo, int uPatch, Pointer<Uint16> pwkya, int fuCache) int winmm
Requests that an internal MIDI synthesizer device preload and cache a specified set of key-based percussion patches.
midiOutCachePatches(HMIDIOUT hmo, int uBank, Pointer<Uint16> pwpa, int fuCache) int winmm
Requests that an internal MIDI synthesizer device preload and cache a specified set of patches.
midiOutClose(HMIDIOUT hmo) int winmm
Closes the specified MIDI output device.
midiOutGetDevCaps(int uDeviceID, Pointer<MIDIOUTCAPS> pmoc, int cbmoc) int winmm
Queries a specified MIDI output device to determine its capabilities.
midiOutGetErrorText(int mmrError, PWSTR pszText, int cchText) int winmm
Retrieves a textual description for an error identified by the specified error code.
midiOutGetID(HMIDIOUT hmo, Pointer<Uint32> puDeviceID) int winmm
Retrieves the device identifier for the given MIDI output device.
midiOutGetNumDevs() int winmm
Retrieves the number of MIDI output devices present in the system.
midiOutGetVolume(HMIDIOUT? hmo, Pointer<Uint32> pdwVolume) int winmm
Retrieves the current volume setting of a MIDI output device.
midiOutLongMsg(HMIDIOUT hmo, Pointer<MIDIHDR> pmh, int cbmh) int winmm
Sends a system-exclusive MIDI message to the specified MIDI output device.
midiOutMessage(HMIDIOUT? hmo, int uMsg, int? dw1, int? dw2) int winmm
Sends a message to the MIDI device drivers.
midiOutOpen(Pointer<Pointer<NativeType>> phmo, int uDeviceID, int? dwCallback, int? dwInstance, MIDI_WAVE_OPEN_TYPE fdwOpen) int winmm
Opens a MIDI output device for playback.
midiOutPrepareHeader(HMIDIOUT hmo, Pointer<MIDIHDR> pmh, int cbmh) int winmm
Prepares a MIDI system-exclusive or stream buffer for output.
midiOutReset(HMIDIOUT hmo) int winmm
Turns off all notes on all MIDI channels for the specified MIDI output device.
midiOutSetVolume(HMIDIOUT? hmo, int dwVolume) int winmm
Sets the volume of a MIDI output device.
midiOutShortMsg(HMIDIOUT hmo, int dwMsg) int winmm
Sends a short MIDI message to the specified MIDI output device.
midiOutUnprepareHeader(HMIDIOUT hmo, Pointer<MIDIHDR> pmh, int cbmh) int winmm
Cleans up the preparation performed by the midiOutPrepareHeader function.
PlaySound(PCWSTR? pszSound, HMODULE? hmod, SND_FLAGS fdwSound) bool winmm
Plays a sound specified by the given file name, resource, or system event.
timeGetTime() int winmm
Retrieves the system time, in milliseconds.
waveInAddBuffer(HWAVEIN hwi, Pointer<WAVEHDR> pwh, int cbwh) int winmm
Sends an input buffer to the given waveform-audio input device.
waveInClose(HWAVEIN hwi) int winmm
Closes the given waveform-audio input device.
waveInGetDevCaps(int uDeviceID, Pointer<WAVEINCAPS> pwic, int cbwic) int winmm
Retrieves the capabilities of a given waveform-audio input device.
waveInGetErrorText(int mmrError, PWSTR pszText, int cchText) int winmm
Retrieves a textual description of the error identified by the given error number.
waveInGetID(HWAVEIN hwi, Pointer<Uint32> puDeviceID) int winmm
Gets the device identifier for the given waveform-audio input device.
waveInGetNumDevs() int winmm
Returns the number of waveform-audio input devices present in the system.
waveInGetPosition(HWAVEIN hwi, Pointer<MMTIME> pmmt, int cbmmt) int winmm
Retrieves the current input position of the given waveform-audio input device.
waveInMessage(HWAVEIN? hwi, int uMsg, int? dw1, int? dw2) int winmm
Sends messages to the waveform-audio input device drivers.
waveInOpen(Pointer<Pointer<NativeType>>? phwi, int uDeviceID, Pointer<WAVEFORMATEX> pwfx, int? dwCallback, int? dwInstance, MIDI_WAVE_OPEN_TYPE fdwOpen) int winmm
Opens the given waveform-audio input device for recording.
waveInPrepareHeader(HWAVEIN hwi, Pointer<WAVEHDR> pwh, int cbwh) int winmm
Prepares a buffer for waveform-audio input.
waveInReset(HWAVEIN hwi) int winmm
Stops input on the given waveform-audio input device and resets the current position to zero.
waveInStart(HWAVEIN hwi) int winmm
Starts input on the given waveform-audio input device.
waveInStop(HWAVEIN hwi) int winmm
Stops waveform-audio input.
waveInUnprepareHeader(HWAVEIN hwi, Pointer<WAVEHDR> pwh, int cbwh) int winmm
Cleans up the preparation performed by the waveInPrepareHeader function.
waveOutClose(HWAVEOUT hwo) int winmm
Closes the given waveform-audio output device.
waveOutGetDevCaps(int uDeviceID, Pointer<WAVEOUTCAPS> pwoc, int cbwoc) int winmm
Retrieves the capabilities of a given waveform-audio output device.
waveOutGetErrorText(int mmrError, PWSTR pszText, int cchText) int winmm
Retrieves a textual description of the error identified by the given error number.
waveOutGetID(HWAVEOUT hwo, Pointer<Uint32> puDeviceID) int winmm
Retrieves the device identifier for the given waveform-audio output device.
waveOutGetNumDevs() int winmm
Retrieves the number of waveform-audio output devices present in the system.
waveOutGetPitch(HWAVEOUT hwo, Pointer<Uint32> pdwPitch) int winmm
Retrieves the current pitch setting for the specified waveform-audio output device.
waveOutGetPlaybackRate(HWAVEOUT hwo, Pointer<Uint32> pdwRate) int winmm
Retrieves the current playback rate for the specified waveform-audio output device.
waveOutGetPosition(HWAVEOUT hwo, Pointer<MMTIME> pmmt, int cbmmt) int winmm
Retrieves the current playback position of the given waveform-audio output device.
waveOutGetVolume(HWAVEOUT? hwo, Pointer<Uint32> pdwVolume) int winmm
Retrieves the current volume level of the specified waveform-audio output device.
waveOutMessage(HWAVEOUT? hwo, int uMsg, int dw1, int dw2) int winmm
Sends messages to the waveform-audio output device drivers.
waveOutOpen(Pointer<Pointer<NativeType>>? phwo, int uDeviceID, Pointer<WAVEFORMATEX> pwfx, int? dwCallback, int? dwInstance, MIDI_WAVE_OPEN_TYPE fdwOpen) int winmm
Opens the given waveform-audio output device for playback.
waveOutPause(HWAVEOUT hwo) int winmm
Pauses playback on the given waveform-audio output device.
waveOutPrepareHeader(HWAVEOUT hwo, Pointer<WAVEHDR> pwh, int cbwh) int winmm
Prepares a waveform-audio data block for playback.
waveOutReset(HWAVEOUT hwo) int winmm
Stops playback on the given waveform-audio output device and resets the current position to zero.
waveOutRestart(HWAVEOUT hwo) int winmm
Resumes playback on a paused waveform-audio output device.
waveOutSetPitch(HWAVEOUT hwo, int dwPitch) int winmm
Sets the pitch for the specified waveform-audio output device.
waveOutSetPlaybackRate(HWAVEOUT hwo, int dwRate) int winmm
Sets the playback rate for the specified waveform-audio output device.
waveOutSetVolume(HWAVEOUT? hwo, int dwVolume) int winmm
Sets the volume level of the specified waveform-audio output device.
waveOutUnprepareHeader(HWAVEOUT hwo, Pointer<WAVEHDR> pwh, int cbwh) int winmm
Cleans up the preparation performed by the waveOutPrepareHeader function.
waveOutWrite(HWAVEOUT hwo, Pointer<WAVEHDR> pwh, int cbwh) int winmm
Sends a data block to the given waveform-audio output device.