wlanapi topic

Wireless LAN API

The Native Wifi application programming interface (API) functions have two purposes: to manage wireless network profiles and to manage wireless network connections. The API elements are exposed by the Auto Configuration Module (ACM). The exposed connection and disconnection API elements can be used to override the automatic configuration logic.

Functions

WlanAllocateMemory(int dwMemorySize) Win32Result<Pointer<NativeType>> wlanapi
Allocates memory.
WlanCloseHandle(HANDLE hClientHandle) int wlanapi
Closes a connection to the server.
WlanConnect(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, Pointer<WLAN_CONNECTION_PARAMETERS> pConnectionParameters) int wlanapi
Attempts to connect to a specific network.
WlanDeleteProfile(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, PCWSTR strProfileName) int wlanapi
Deletes a wireless profile for a wireless interface on the local computer.
WlanDeviceServiceCommand(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, Pointer<GUID> pDeviceServiceGuid, int dwOpCode, int dwInBufferSize, Pointer<NativeType>? pInBuffer, int dwOutBufferSize, Pointer<NativeType>? pOutBuffer, Pointer<Uint32> pdwBytesReturned) int wlanapi
Allows an OEM or IHV component to communicate with a device service on a particular wireless LAN interface.
WlanDisconnect(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid) int wlanapi
Disconnects an interface from its current network.
WlanEnumInterfaces(HANDLE hClientHandle, Pointer<Pointer<WLAN_INTERFACE_INFO_LIST>> ppInterfaceList) int wlanapi
Enumerates all of the wireless LAN interfaces currently enabled on the local computer.
WlanExtractPsdIEDataList(HANDLE hClientHandle, int dwIeDataSize, Pointer<Uint8> pRawIeData, PCWSTR strFormat, Pointer<Pointer<WLAN_RAW_DATA_LIST>> ppPsdIEDataList) int wlanapi
Extracts the proximity service discovery (PSD) information element (IE) data list from raw IE data included in a beacon.
WlanFreeMemory(Pointer<NativeType> pMemory) → void wlanapi
Frees memory.
WlanGetAvailableNetworkList(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, int dwFlags, Pointer<Pointer<WLAN_AVAILABLE_NETWORK_LIST>> ppAvailableNetworkList) int wlanapi
Retrieves the list of available networks on a wireless LAN interface.
WlanGetFilterList(HANDLE hClientHandle, WLAN_FILTER_LIST_TYPE wlanFilterListType, Pointer<Pointer<DOT11_NETWORK_LIST>> ppNetworkList) int wlanapi
Retrieves a group policy or user permission list.
WlanGetInterfaceCapability(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, Pointer<Pointer<WLAN_INTERFACE_CAPABILITY>> ppCapability) int wlanapi
Retrieves the capabilities of an interface.
WlanGetNetworkBssList(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, Pointer<DOT11_SSID>? pDot11Ssid, DOT11_BSS_TYPE dot11BssType, bool bSecurityEnabled, Pointer<Pointer<WLAN_BSS_LIST>> ppWlanBssList) int wlanapi
Retrieves a list of the basic service set (BSS) entries of the wireless network or networks on a given wireless LAN interface.
WlanGetProfile(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, PCWSTR strProfileName, Pointer<Pointer<Utf16>> pstrProfileXml, Pointer<Uint32>? pdwFlags, Pointer<Uint32>? pdwGrantedAccess) int wlanapi
Retrieves all information about a specified wireless profile.
WlanGetProfileCustomUserData(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, PCWSTR strProfileName, Pointer<Uint32> pdwDataSize, Pointer<Pointer<Uint8>> ppData) int wlanapi
Gets the custom user data associated with a wireless profile.
WlanGetProfileList(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, Pointer<Pointer<WLAN_PROFILE_INFO_LIST>> ppProfileList) int wlanapi
Retrieves the list of profiles.
WlanGetSecuritySettings(HANDLE hClientHandle, WLAN_SECURABLE_OBJECT securableObject, Pointer<Int32>? pValueType, Pointer<Pointer<Utf16>> pstrCurrentSDDL, Pointer<Uint32> pdwGrantedAccess) int wlanapi
Gets the security settings associated with a configurable object.
WlanGetSupportedDeviceServices(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, Pointer<Pointer<WLAN_DEVICE_SERVICE_GUID_LIST>> ppDevSvcGuidList) int wlanapi
Retrieves a list of the supported device services on a given wireless LAN interface.
WlanHostedNetworkForceStart(HANDLE hClientHandle, Pointer<Int32>? pFailReason) int wlanapi
Transitions the wireless Hosted Network to the wlan_hosted_network_active state without associating the request with the application's calling handle.
WlanHostedNetworkForceStop(HANDLE hClientHandle, Pointer<Int32>? pFailReason) int wlanapi
Transitions the wireless Hosted Network to the wlan_hosted_network_idle without associating the request with the application's calling handle.
WlanHostedNetworkInitSettings(HANDLE hClientHandle, Pointer<Int32>? pFailReason) int wlanapi
Configures and persists to storage the network connection settings (SSID and maximum number of peers, for example) on the wireless Hosted Network if these settings are not already configured.
WlanHostedNetworkQueryProperty(HANDLE hClientHandle, WLAN_HOSTED_NETWORK_OPCODE opCode, Pointer<Uint32> pdwDataSize, Pointer<Pointer<NativeType>> ppvData, Pointer<Int32> pWlanOpcodeValueType) int wlanapi
Queries the current static properties of the wireless Hosted Network.
WlanHostedNetworkQuerySecondaryKey(HANDLE hClientHandle, Pointer<Uint32> pdwKeyLength, Pointer<Pointer<Uint8>> ppucKeyData, Pointer<Int32> pbIsPassPhrase, Pointer<Int32> pbPersistent, Pointer<Int32>? pFailReason) int wlanapi
Queries the secondary security key that is configured to be used by the wireless Hosted Network.
WlanHostedNetworkQueryStatus(HANDLE hClientHandle, Pointer<Pointer<WLAN_HOSTED_NETWORK_STATUS>> ppWlanHostedNetworkStatus) int wlanapi
Queries the current status of the wireless Hosted Network.
WlanHostedNetworkRefreshSecuritySettings(HANDLE hClientHandle, Pointer<Int32>? pFailReason) int wlanapi
Refreshes the configurable and auto-generated parts of the wireless Hosted Network security settings.
WlanHostedNetworkSetProperty(HANDLE hClientHandle, WLAN_HOSTED_NETWORK_OPCODE opCode, int dwDataSize, Pointer<NativeType> pvData, Pointer<Int32>? pFailReason) int wlanapi
Sets static properties of the wireless Hosted Network.
WlanHostedNetworkSetSecondaryKey(HANDLE hClientHandle, int dwKeyLength, Pointer<Uint8> pucKeyData, bool bIsPassPhrase, bool bPersistent, Pointer<Int32>? pFailReason) int wlanapi
Configures the secondary security key that will be used by the wireless Hosted Network.
WlanHostedNetworkStartUsing(HANDLE hClientHandle, Pointer<Int32>? pFailReason) int wlanapi
Starts the wireless Hosted Network.
WlanHostedNetworkStopUsing(HANDLE hClientHandle, Pointer<Int32>? pFailReason) int wlanapi
Stops the wireless Hosted Network.
WlanIhvControl(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, WLAN_IHV_CONTROL_TYPE type, int dwInBufferSize, Pointer<NativeType> pInBuffer, int dwOutBufferSize, Pointer<NativeType>? pOutBuffer, Pointer<Uint32> pdwBytesReturned) int wlanapi
Provides a mechanism for independent hardware vendor (IHV) control of WLAN drivers or services.
WlanOpenHandle(int dwClientVersion, Pointer<Uint32> pdwNegotiatedVersion, Pointer<Pointer<NativeType>> phClientHandle) int wlanapi
Opens a connection to the server.
WlanQueryAutoConfigParameter(HANDLE hClientHandle, WLAN_AUTOCONF_OPCODE opCode, Pointer<Uint32> pdwDataSize, Pointer<Pointer<NativeType>> ppData, Pointer<Int32>? pWlanOpcodeValueType) int wlanapi
Queries for the parameters of the auto configuration service.
WlanQueryInterface(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, WLAN_INTF_OPCODE opCode, Pointer<Uint32> pdwDataSize, Pointer<Pointer<NativeType>> ppData, Pointer<Int32>? pWlanOpcodeValueType) int wlanapi
Queries various parameters of a specified interface.
WlanReasonCodeToString(int dwReasonCode, int dwBufferSize, PCWSTR pStringBuffer) int wlanapi
Retrieves a string that describes a specified reason code.
WlanRegisterDeviceServiceNotification(HANDLE hClientHandle, Pointer<WLAN_DEVICE_SERVICE_GUID_LIST>? pDevSvcGuidList) int wlanapi
Allows user mode clients with admin privileges, or User-Mode Driver Framework (UMDF) drivers, to register for unsolicited notifications corresponding to device services that they're interested in.
WlanRegisterNotification(HANDLE hClientHandle, WLAN_NOTIFICATION_SOURCES dwNotifSource, bool bIgnoreDuplicate, Pointer<NativeFunction<WLAN_NOTIFICATION_CALLBACK>>? funcCallback, Pointer<NativeType>? pCallbackContext, Pointer<Uint32>? pdwPrevNotifSource) int wlanapi
Used to register and unregister notifications on all wireless interfaces.
WlanRegisterVirtualStationNotification(HANDLE hClientHandle, bool bRegister) int wlanapi
Used to register and unregister notifications on a virtual station.
WlanRenameProfile(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, PCWSTR strOldProfileName, PCWSTR strNewProfileName) int wlanapi
Renames the specified profile.
WlanSaveTemporaryProfile(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, PCWSTR strProfileName, PCWSTR? strAllUserProfileSecurity, int dwFlags, bool bOverWrite) int wlanapi
Saves a temporary profile to the profile store.
WlanScan(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, Pointer<DOT11_SSID>? pDot11Ssid, Pointer<WLAN_RAW_DATA>? pIeData) int wlanapi
Requests a scan for available networks on the indicated interface.
WlanSetAutoConfigParameter(HANDLE hClientHandle, WLAN_AUTOCONF_OPCODE opCode, int dwDataSize, Pointer<NativeType> pData) int wlanapi
Sets parameters for the automatic configuration service.
WlanSetFilterList(HANDLE hClientHandle, WLAN_FILTER_LIST_TYPE wlanFilterListType, Pointer<DOT11_NETWORK_LIST>? pNetworkList) int wlanapi
Sets the permit/deny list.
WlanSetInterface(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, WLAN_INTF_OPCODE opCode, int dwDataSize, Pointer<NativeType> pData) int wlanapi
Sets user-configurable parameters.
WlanSetProfile(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, int dwFlags, PCWSTR strProfileXml, PCWSTR? strAllUserProfileSecurity, bool bOverwrite, Pointer<Uint32> pdwReasonCode) int wlanapi
Sets the content of a specific profile.
WlanSetProfileCustomUserData(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, PCWSTR strProfileName, int dwDataSize, Pointer<Uint8> pData) int wlanapi
Sets the custom user data associated with a profile.
WlanSetProfileEapUserData(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, PCWSTR strProfileName, EAP_METHOD_TYPE eapType, WLAN_SET_EAPHOST_FLAGS dwFlags, int dwEapUserDataSize, Pointer<Uint8>? pbEapUserData) int wlanapi
Sets the Extensible Authentication Protocol (EAP) user credentials as specified by raw EAP data.
WlanSetProfileEapXmlUserData(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, PCWSTR strProfileName, WLAN_SET_EAPHOST_FLAGS dwFlags, PCWSTR strEapXmlUserData) int wlanapi
Sets the Extensible Authentication Protocol (EAP) user credentials as specified by an XML string.
WlanSetProfileList(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, int dwItems, Pointer<Pointer<Utf16>> strProfileNames) int wlanapi
Sets the preference order of profiles.
WlanSetProfilePosition(HANDLE hClientHandle, Pointer<GUID> pInterfaceGuid, PCWSTR strProfileName, int dwPosition) int wlanapi
Sets the position of a single, specified profile in the preference list.
WlanSetPsdIEDataList(HANDLE hClientHandle, PCWSTR? strFormat, Pointer<WLAN_RAW_DATA_LIST>? pPsdIEDataList) int wlanapi
Sets the proximity service discovery (PSD) information element (IE) data list.
WlanSetSecuritySettings(HANDLE hClientHandle, WLAN_SECURABLE_OBJECT securableObject, PCWSTR strModifiedSDDL) int wlanapi
Sets the security settings for a configurable object.