xinput topic
Game Controller APIs
XInput Game Controller API enables applications to receive input from the Xbox Controller for Windows.
Functions
-
XInputEnable(
bool enable) → void xinput - Sets the reporting state of XInput.
-
XInputGetAudioDeviceIds(
int dwUserIndex, PWSTR? pRenderDeviceId, Pointer< xinputUint32> ? pRenderCount, PWSTR? pCaptureDeviceId, Pointer<Uint32> ? pCaptureCount) → int - Retrieves the sound rendering and sound capture audio device IDs that are associated with the headset connected to the specified controller.
-
XInputGetBatteryInformation(
int dwUserIndex, BATTERY_DEVTYPE devType, Pointer< xinputXINPUT_BATTERY_INFORMATION> pBatteryInformation) → int - Retrieves the battery type and charge status of a wireless controller.
-
XInputGetCapabilities(
int dwUserIndex, XINPUT_FLAG dwFlags, Pointer< xinputXINPUT_CAPABILITIES> pCapabilities) → int - Retrieves the capabilities and features of a connected controller.
-
XInputGetKeystroke(
int dwUserIndex, Pointer< xinputXINPUT_KEYSTROKE> pKeystroke) → int - Retrieves a gamepad input event.
-
XInputGetState(
int dwUserIndex, Pointer< xinputXINPUT_STATE> pState) → int - Retrieves the current state of the specified controller.
-
XInputSetState(
int dwUserIndex, Pointer< xinputXINPUT_VIBRATION> pVibration) → int - Sends data to a connected controller.