ADDJOB_INFO_1 class base struct

Identifies a print job as well as the directory and file in which an application can store that job.

To learn more, see learn.microsoft.com/windows/win32/printdocs/addjob-info-1.

Inheritance
Implemented types
Available extensions

Constructors

ADDJOB_INFO_1()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
JobId int
A handle to the print job.
getter/setter pair
Path PWSTR
Pointer to a null-terminated string that contains the path and file name that the application can use to store the print job.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<ADDJOB_INFO_1>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited