ADDRINFO class base struct

Used by the GetAddrInfoW function to hold host address information.

To learn more, see learn.microsoft.com/windows/win32/api/ws2def/ns-ws2def-addrinfow.

Inheritance
Implemented types
Available extensions

Constructors

ADDRINFO()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
ai_addr Pointer<SOCKADDR>
A pointer to a sockaddr structure.
getter/setter pair
ai_addrlen int
The length, in bytes, of the buffer pointed to by the ai_addr member.
getter/setter pair
ai_canonname PWSTR
The canonical name for the host.
getter/setter pair
ai_family int
The address family.
getter/setter pair
ai_flags int
Flags that indicate options used in the GetAddrInfoW function.
getter/setter pair
ai_next Pointer<ADDRINFO>
A pointer to the next structure in a linked list.
getter/setter pair
ai_protocol int
The protocol type.
getter/setter pair
ai_socktype int
The socket type.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<ADDRINFO>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited