ALTTABINFO class base struct

Contains status information for the application-switching (ALT+TAB) window.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-alttabinfo.

Inheritance
Implemented types
Available extensions

Constructors

ALTTABINFO()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
cbSize ↔ int
The size of the struct in bytes.
getter/setter pair
cColumns ↔ int
The number of columns in the window.
getter/setter pair
cItems ↔ int
The number of items in the window.
getter/setter pair
cRows ↔ int
The number of rows in the window.
getter/setter pair
cxItem ↔ int
The width of each icon in the application-switching window.
getter/setter pair
cyItem ↔ int
The height of each icon in the application-switching window.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iColFocus ↔ int
The column of the item that has the focus.
getter/setter pair
iRowFocus ↔ int
The row of the item that has the focus.
getter/setter pair
ptStart ↔ POINT
The top-left corner of the first icon.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) → Pointer<ALTTABINFO>
Allocates native memory and copies the contents of this struct into it.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited