APPX_CAPABILITY_INTERNET_CLIENT_SERVER top-level constant

APPX_CAPABILITIES const APPX_CAPABILITY_INTERNET_CLIENT_SERVER

Your Internet connection, including incoming unsolicited connections from the Internet – the app can send information to or from your computer through a firewall.

Implementation

const APPX_CAPABILITY_INTERNET_CLIENT_SERVER = APPX_CAPABILITIES(2);