ARRAYDESC class base struct

Describes an array, its element type, and its dimension.

To learn more, see learn.microsoft.com/windows/win32/api/oaidl/ns-oaidl-arraydesc.

Inheritance
Implemented types
Available extensions

Constructors

ARRAYDESC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
cDims int
The dimension count.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rgbounds Array<SAFEARRAYBOUND>
A variable-length array containing one element for each dimension.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tdescElem TYPEDESC
The element type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<ARRAYDESC>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited