AddJob function winspool
Adds a print job to the list of print jobs that can be scheduled by the print spooler.
The function retrieves the name of the file you can use to store the job.
To learn more, see learn.microsoft.com/windows/win32/printdocs/addjob.
Implementation
@pragma('vm:prefer-inline')
bool AddJob(
PRINTER_HANDLE hPrinter,
int level,
Pointer<Uint8>? pData,
int cbBuf,
Pointer<Uint32> pcbNeeded,
) => _AddJob(hPrinter, level, pData ?? nullptr, cbBuf, pcbNeeded) != FALSE;