BITMAPV5HEADER class base struct

The BITMAPV5HEADER structure is the bitmap information header file. It is an extended version of the BITMAPINFOHEADER structure.

Inheritance
Implemented types
Available extensions

Constructors

BITMAPV5HEADER()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bV5AlphaMask int
getter/setter pair
bV5BitCount int
getter/setter pair
bV5BlueMask int
getter/setter pair
bV5ClrImportant int
getter/setter pair
bV5ClrUsed int
getter/setter pair
bV5Compression int
getter/setter pair
bV5CSType int
getter/setter pair
bV5Endpoints CIEXYZTRIPLE
getter/setter pair
bV5GammaBlue int
getter/setter pair
bV5GammaGreen int
getter/setter pair
bV5GammaRed int
getter/setter pair
bV5GreenMask int
getter/setter pair
bV5Height int
getter/setter pair
bV5Intent int
getter/setter pair
bV5Planes int
getter/setter pair
bV5ProfileData int
getter/setter pair
bV5ProfileSize int
getter/setter pair
bV5RedMask int
getter/setter pair
bV5Reserved int
getter/setter pair
bV5Size int
getter/setter pair
bV5SizeImage int
getter/setter pair
bV5Width int
getter/setter pair
bV5XPelsPerMeter int
getter/setter pair
bV5YPelsPerMeter int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited