BTH_DEVICE_INFO class base struct

Stores information about a Bluetooth device.

To learn more, see learn.microsoft.com/windows/win32/api/bthdef/ns-bthdef-bth_device_info.

Inheritance
Implemented types
Available extensions

Constructors

BTH_DEVICE_INFO()

Properties

address int
Address of the remote Bluetooth device.
getter/setter pair
address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
classOfDevice int
Bit field that describes the device class of device (COD) of the remote device.
getter/setter pair
flags int
A combination of one or more of the flags listed in the following table.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name Array<Int8>
Name of the remote Bluetooth device, as reported by the device, encoded in UTF8.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<BTH_DEVICE_INFO>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited