BTH_QUERY_DEVICE class base struct

Used when querying for the presence of a Bluetooth device.

To learn more, see learn.microsoft.com/windows/win32/api/ws2bth/ns-ws2bth-bth_query_device.

Inheritance
Implemented types
Available extensions
Annotations

Constructors

BTH_QUERY_DEVICE()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
LAP int
Reserved.
getter/setter pair
length int
Requested length of the inquiry, in seconds.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<BTH_QUERY_DEVICE>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited