BTH_SET_SERVICE class base struct

Provides service information for the specified Bluetooth service.

To learn more, see learn.microsoft.com/windows/win32/api/ws2bth/ns-ws2bth-bth_set_service.

Inheritance
Implemented types
Available extensions
Annotations

Constructors

BTH_SET_SERVICE()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
fCodService int
Class of device (COD) information.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pRecord Array<Uint8>
SDP record, as defined by the Bluetooth specification.
getter/setter pair
pRecordHandle Pointer<Pointer<NativeType>>
Handle to the SDP record.
getter/setter pair
pSdpVersion Pointer<Uint32>
Version of the SDP.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ulRecordLength int
Size, in bytes, of pRecord.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<BTH_SET_SERVICE>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited