CACHE_DESCRIPTOR class base struct

Describes the cache attributes.

To learn more, see learn.microsoft.com/windows/win32/api/winnt/ns-winnt-cache_descriptor.

Inheritance
Implemented types
Available extensions

Constructors

CACHE_DESCRIPTOR()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
Associativity int
The cache associativity.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
Level int
getter/setter pair
LineSize int
The cache line size, in bytes.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Size int
The cache size, in bytes.
getter/setter pair
Type PROCESSOR_CACHE_TYPE
The cache type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<CACHE_DESCRIPTOR>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited