CHOOSECOLOR class base struct

Contains information the ChooseColor function uses to initialize the Color dialog box.

To learn more, see learn.microsoft.com/windows/win32/api/commdlg/ns-commdlg-choosecolorw.

Inheritance
Implemented types
Available extensions

Constructors

CHOOSECOLOR()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
Flags CHOOSECOLOR_FLAGS
A set of bit flags that you can use to initialize the Color dialog box.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hInstance HWND
If the CC_ENABLETEMPLATEHANDLE flag is set in the Flags member, hInstance is a handle to a memory object containing a dialog box template.
getter/setter pair
hwndOwner HWND
A handle to the window that owns the dialog box.
getter/setter pair
lCustData LPARAM
Application-defined data that the system passes to the hook procedure identified by the lpfnHook member.
getter/setter pair
lpCustColors Pointer<Uint32>
A pointer to an array of 16 values that contain red, green, blue (RGB) values for the custom color boxes in the dialog box.
getter/setter pair
lpfnHook Pointer<NativeFunction<LPCCHOOKPROC>>
A pointer to a CCHookProc hook procedure that can process messages intended for the dialog box.
getter/setter pair
lpTemplateName PWSTR
The name of the dialog box template resource in the module identified by the hInstance member.
getter/setter pair
lStructSize int
The length, in bytes, of the structure.
getter/setter pair
rgbResult COLORREF
If the CC_RGBINIT flag is set, rgbResult specifies the color initially selected when the dialog box is created.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<CHOOSECOLOR>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited