CHOOSEFONT class base struct

Contains information that the ChooseFont function uses to initialize the Font dialog box.

After the user closes the dialog box, the system returns information about the user's selection in this structure.

To learn more, see learn.microsoft.com/windows/win32/api/commdlg/ns-commdlg-choosefontw.

Inheritance
Implemented types
Available extensions

Constructors

CHOOSEFONT()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
Flags CHOOSEFONT_FLAGS
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hDC HDC
This member is ignored by the ChooseFont function.
getter/setter pair
hInstance HINSTANCE
If the CF_ENABLETEMPLATEHANDLE flag is set in the Flags member, hInstance is a handle to a memory object containing a dialog box template.
getter/setter pair
hwndOwner HWND
A handle to the window that owns the dialog box.
getter/setter pair
iPointSize int
The size of the selected font, in units of 1/10 of a point.
getter/setter pair
lCustData LPARAM
Application-defined data that the system passes to the hook procedure identified by the lpfnHook member.
getter/setter pair
lpfnHook Pointer<NativeFunction<LPCFHOOKPROC>>
A pointer to a CFHookProc hook procedure that can process messages intended for the dialog box.
getter/setter pair
lpLogFont Pointer<LOGFONT>
A pointer to a LOGFONT structure.
getter/setter pair
lpszStyle PWSTR
The style data.
getter/setter pair
lpTemplateName PWSTR
The name of the dialog box template resource in the module identified by the hInstance member.
getter/setter pair
lStructSize int
The length of the structure, in bytes.
getter/setter pair
MISSING_ALIGNMENT__ int
getter/setter pair
nFontType CHOOSEFONT_FONT_TYPE
getter/setter pair
nSizeMax int
The maximum point size a user can select.
getter/setter pair
nSizeMin int
The minimum point size a user can select.
getter/setter pair
rgbColors COLORREF
If the CF_EFFECTS flag is set, rgbColors specifies the initial text color.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<CHOOSEFONT>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited