COMDLG_FILTERSPEC class base struct

Used generically to filter elements.

To learn more, see learn.microsoft.com/windows/win32/api/shtypes/ns-shtypes-comdlg_filterspec.

Inheritance
Implemented types
Available extensions

Constructors

COMDLG_FILTERSPEC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
pszName PWSTR
A pointer to a buffer that contains the friendly name of the filter.
getter/setter pair
pszSpec PWSTR
A pointer to a buffer that contains the filter pattern.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<COMDLG_FILTERSPEC>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited