COMMPROP class base struct

Contains information about a communications driver.

To learn more, see learn.microsoft.com/windows/win32/api/winbase/ns-winbase-commprop.

Inheritance
Implemented types
Available extensions

Constructors

COMMPROP()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwCurrentRxQueue int
The size of the driver's internal input buffer, in bytes.
getter/setter pair
dwCurrentTxQueue int
The size of the driver's internal output buffer, in bytes.
getter/setter pair
dwMaxBaud int
The maximum allowable baud rate, in bits per second (bps).
getter/setter pair
dwMaxRxQueue int
The maximum size of the driver's internal input buffer, in bytes.
getter/setter pair
dwMaxTxQueue int
The maximum size of the driver's internal output buffer, in bytes.
getter/setter pair
dwProvCapabilities int
A bitmask indicating the capabilities offered by the provider.
getter/setter pair
dwProvSpec1 int
Any provider-specific data.
getter/setter pair
dwProvSpec2 int
Any provider-specific data.
getter/setter pair
dwProvSubType int
The communications-provider type.
getter/setter pair
dwServiceMask int
A bitmask indicating which services are implemented by this provider.
getter/setter pair
dwSettableBaud int
The baud rates that can be used.
getter/setter pair
dwSettableParams int
A bitmask indicating the communications parameters that can be changed.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wcProvChar String
Any provider-specific data.
getter/setter pair
wPacketLength int
The size of the entire data packet, regardless of the amount of data requested, in bytes.
getter/setter pair
wPacketVersion int
The version of the structure.
getter/setter pair
wSettableData int
A bitmask indicating the number of data bits that can be set.
getter/setter pair
wSettableStopParity COMMPROP_STOP_PARITY
A bitmask indicating the stop bit and parity settings that can be selected.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<COMMPROP>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited