CONNECTDATA class base struct

Describes a connection that exists to a given connection point.

To learn more, see learn.microsoft.com/windows/win32/api/ocidl/ns-ocidl-connectdata.

Inheritance
Implemented types
Available extensions

Constructors

CONNECTDATA()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwCookie int
Connection where this value is the same token that is returned originally from calls to IConnectionPoint::Advise.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pUnk IUnknown?
A pointer to the IUnknown interface on a connected advisory sink.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<CONNECTDATA>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited