CONSOLE_SELECTION_INFO class base struct

Contains information for a console selection.

To learn more, see learn.microsoft.com/windows/console/console-selection-info-str.

Inheritance
Implemented types
Available extensions

Constructors

CONSOLE_SELECTION_INFO()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwFlags int
The selection indicator.
getter/setter pair
dwSelectionAnchor COORD
A COORD structure that specifies the selection anchor, in characters.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
srSelection SMALL_RECT
A SMALL_RECT structure that specifies the selection rectangle.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<CONSOLE_SELECTION_INFO>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited