CRYPTPROTECT_PROMPTSTRUCT class base struct

Provides the text of a prompt and information about when and where that prompt is to be displayed when using the CryptProtectData and CryptUnprotectData functions.

To learn more, see learn.microsoft.com/windows/win32/api/dpapi/ns-dpapi-cryptprotect_promptstruct.

Inheritance
Implemented types
Available extensions

Constructors

CRYPTPROTECT_PROMPTSTRUCT()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
cbSize int
The size of the struct in bytes.
getter/setter pair
dwPromptFlags int
DWORD flags that indicate when prompts to the user are to be displayed.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hwndApp HWND
Window handle to the parent window.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
szPrompt PWSTR
A string containing the text of a prompt to be displayed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<CRYPTPROTECT_PROMPTSTRUCT>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited