CWPSTRUCT class base struct

Defines the message parameters passed to a WH_CALLWNDPROC hook procedure, CallWndProc.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-cwpstruct.

Inheritance
Implemented types
Available extensions

Constructors

CWPSTRUCT()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
hwnd HWND
A handle to the window to receive the message.
getter/setter pair
lParam LPARAM
Additional information about the message.
getter/setter pair
message int
The message.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wParam WPARAM
Additional information about the message.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<CWPSTRUCT>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited