Chord function gdi32
Draws a chord (a region bounded by the intersection of an ellipse and a line segment, called a secant).
The chord is outlined by using the current pen and filled by using the current brush.
To learn more, see learn.microsoft.com/windows/win32/api/wingdi/nf-wingdi-chord.
Implementation
@pragma('vm:prefer-inline')
bool Chord(
HDC hdc,
int x1,
int y1,
int x2,
int y2,
int x3,
int y3,
int x4,
int y4,
) => _Chord(hdc, x1, y1, x2, y2, x3, y3, x4, y4) != FALSE;