ClearCommBreak function kernel32
Restores character transmission for a specified communications device and places the transmission line in a nonbreak state.
To learn more, see learn.microsoft.com/windows/win32/api/winbase/nf-winbase-clearcommbreak.
Implementation
Win32Result<bool> ClearCommBreak(HANDLE hFile) {
resolveGetLastError();
final result_ = _ClearCommBreak(hFile);
return .new(value: result_ != FALSE, error: GetLastError());
}