CloseSpoolFileHandle function winspool

bool CloseSpoolFileHandle(
  1. PRINTER_HANDLE hPrinter,
  2. HANDLE hSpoolFile
)

Closes a handle to a spool file associated with the print job currently submitted by the application.

To learn more, see learn.microsoft.com/windows/win32/printdocs/closespoolfilehandle.

Implementation

@pragma('vm:prefer-inline')
bool CloseSpoolFileHandle(PRINTER_HANDLE hPrinter, HANDLE hSpoolFile) =>
    _CloseSpoolFileHandle(hPrinter, hSpoolFile) != FALSE;