ComInterface class abstract interface com

Base interface for all COM types that participate in the companion system.

This abstraction enables type-safe COM activation and casting by associating Dart interface types with metadata and construction logic at runtime.

Each COM interface type is paired with a ComCompanion, which provides:

  • The interface IID
  • A constructor that wraps a raw vtable pointer

Companions may be either:

  • Predefined by the library (for built-in Win32 / COM interfaces)
  • Registered by user code for custom or third-party interfaces

This system is used by functions such as:

  • createInstance<T>()
  • CoCreateInstance<T>()
  • CoGetClassObject<T>()
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

register<T extends ComInterface>(ComCompanion<T> companion) → void
Registers a ComCompanion for the COM interface type T.
unregister<T extends ComInterface>() → void
Unregisters the companion associated with the COM interface type T.