dmLogPixels property

  1. @Uint16()
int dmLogPixels
getter/setter pair

For displays, specifies the number of logical pixels per inch of a display device and should be equal to the ulLogPixels member of the GDIINFO structure.

Implementation

@Uint16()
external int dmLogPixels;