DEVMODE_0_0 class sealed struct

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dmCopies int
getter/setter pair
dmDefaultSource int
getter/setter pair
dmOrientation int
getter/setter pair
dmPaperLength int
getter/setter pair
dmPaperSize int
getter/setter pair
dmPaperWidth int
getter/setter pair
dmPrintQuality int
getter/setter pair
dmScale int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<DEVMODE_0_0>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited