Contains information about a logical volume.
To learn more, see learn.microsoft.com/windows/win32/api/dbt/ns-dbt-dev_broadcast_volume.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - dbcv_devicetype ↔ int
-
Set to DBT_DEVTYP_VOLUME (2).
getter/setter pair
- dbcv_flags ↔ DEV_BROADCAST_VOLUME_FLAGS
-
getter/setter pair
- dbcv_reserved ↔ int
-
getter/setter pair
- dbcv_size ↔ int
-
The size of this structure, in bytes.
getter/setter pair
- dbcv_unitmask ↔ int
-
The logical unit mask identifying one or more logical units.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< DEV_BROADCAST_VOLUME> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited