DISPLAYCONFIG_2DREGION class base struct

Represents a point or an offset in a two-dimensional space.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/ns-wingdi-displayconfig_2dregion.

Inheritance
Implemented types
Available extensions

Constructors

DISPLAYCONFIG_2DREGION()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
cx int
The horizontal component of the point or offset.
getter/setter pair
cy int
The vertical component of the point or offset.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<DISPLAYCONFIG_2DREGION>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited