DISPLAYCONFIG_PATH_INFO class base struct

Used to describe a single path from a target to a source.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/ns-wingdi-displayconfig_path_info.

Inheritance
Implemented types
Available extensions

Constructors

DISPLAYCONFIG_PATH_INFO()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
flags int
A bitwise OR of flag values that indicates the state of the path.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceInfo DISPLAYCONFIG_PATH_SOURCE_INFO
A DISPLAYCONFIG_PATH_SOURCE_INFO structure that contains the source information for the path.
getter/setter pair
targetInfo DISPLAYCONFIG_PATH_TARGET_INFO
A DISPLAYCONFIG_PATH_TARGET_INFO structure that contains the target information for the path.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<DISPLAYCONFIG_PATH_INFO>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited