DISPLAYCONFIG_PATH_SOURCE_INFO class base struct

Contains source information for a single path.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/ns-wingdi-displayconfig_path_source_info.

Inheritance
Implemented types
Available extensions

Properties

adapterId LUID
The identifier of the adapter that this source information relates to.
getter/setter pair
address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
Anonymous DISPLAYCONFIG_PATH_SOURCE_INFO_0
getter/setter pair
Anonymous DISPLAYCONFIG_PATH_SOURCE_INFO_0_0

Available on DISPLAYCONFIG_PATH_SOURCE_INFO, provided by the DISPLAYCONFIG_PATH_SOURCE_INFO_0_Extension extension

getter/setter pair
bitfield int

Available on DISPLAYCONFIG_PATH_SOURCE_INFO, provided by the DISPLAYCONFIG_PATH_SOURCE_INFO_0_0_Extension extension

getter/setter pair
cloneGroupId int

Available on DISPLAYCONFIG_PATH_SOURCE_INFO, provided by the DISPLAYCONFIG_PATH_SOURCE_INFO_0_0_Extension extension

getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
The source identifier on the specified adapter that this path relates to.
getter/setter pair
modeInfoIdx int

Available on DISPLAYCONFIG_PATH_SOURCE_INFO, provided by the DISPLAYCONFIG_PATH_SOURCE_INFO_0_Extension extension

getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceModeInfoIdx int

Available on DISPLAYCONFIG_PATH_SOURCE_INFO, provided by the DISPLAYCONFIG_PATH_SOURCE_INFO_0_0_Extension extension

getter/setter pair
statusFlags int
A bitwise OR of flag values that indicates the status of the source.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<DISPLAYCONFIG_PATH_SOURCE_INFO>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited