DISPLAYCONFIG_RATIONAL class base struct

Describes a fractional value that represents vertical and horizontal frequencies of a video mode (that is, vertical sync and horizontal sync).

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/ns-wingdi-displayconfig_rational.

Inheritance
Implemented types
Available extensions

Constructors

DISPLAYCONFIG_RATIONAL()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
Denominator int
The denominator of the frequency fraction.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
Numerator int
The numerator of the frequency fraction.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<DISPLAYCONFIG_RATIONAL>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited