DISPLAYCONFIG_TARGET_MODE class base struct

Describes a display path target mode.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/ns-wingdi-displayconfig_target_mode.

Inheritance
Implemented types
Available extensions

Constructors

DISPLAYCONFIG_TARGET_MODE()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetVideoSignalInfo DISPLAYCONFIG_VIDEO_SIGNAL_INFO
A DISPLAYCONFIG_VIDEO_SIGNAL_INFO structure that contains a detailed description of the current target mode.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<DISPLAYCONFIG_TARGET_MODE>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited