DISPLAYCONFIG_VIDEO_SIGNAL_INFO class base struct

Contains information about the video signal for a display.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/ns-wingdi-displayconfig_video_signal_info.

Inheritance
Implemented types
Available extensions

Properties

activeSize DISPLAYCONFIG_2DREGION
A DISPLAYCONFIG_2DREGION structure that specifies the width and height (in pixels) of the active portion of the video signal.
getter/setter pair
AdditionalSignalInfo DISPLAYCONFIG_VIDEO_SIGNAL_INFO_0_0

Available on DISPLAYCONFIG_VIDEO_SIGNAL_INFO, provided by the DISPLAYCONFIG_VIDEO_SIGNAL_INFO_0_Extension extension

getter/setter pair
address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
Anonymous DISPLAYCONFIG_VIDEO_SIGNAL_INFO_0
getter/setter pair
bitfield int

Available on DISPLAYCONFIG_VIDEO_SIGNAL_INFO, provided by the DISPLAYCONFIG_VIDEO_SIGNAL_INFO_0_0_Extension extension

getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hSyncFreq DISPLAYCONFIG_RATIONAL
A DISPLAYCONFIG_RATIONAL structure that represents horizontal sync.
getter/setter pair
pixelRate int
The pixel clock rate.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanLineOrdering DISPLAYCONFIG_SCANLINE_ORDERING
The scan-line ordering (for example, progressive or interlaced) of the video signal.
getter/setter pair
totalSize DISPLAYCONFIG_2DREGION
A DISPLAYCONFIG_2DREGION structure that specifies the width and height (in pixels) of the entire video signal.
getter/setter pair
videoStandard int

Available on DISPLAYCONFIG_VIDEO_SIGNAL_INFO, provided by the DISPLAYCONFIG_VIDEO_SIGNAL_INFO_0_0_Extension extension

getter/setter pair
videoStandard int

Available on DISPLAYCONFIG_VIDEO_SIGNAL_INFO, provided by the DISPLAYCONFIG_VIDEO_SIGNAL_INFO_0_Extension extension

getter/setter pair
vSyncFreq DISPLAYCONFIG_RATIONAL
A DISPLAYCONFIG_RATIONAL structure that represents vertical sync.
getter/setter pair
vSyncFreqDivider int

Available on DISPLAYCONFIG_VIDEO_SIGNAL_INFO, provided by the DISPLAYCONFIG_VIDEO_SIGNAL_INFO_0_0_Extension extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<DISPLAYCONFIG_VIDEO_SIGNAL_INFO>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited