DLGTEMPLATE class base struct

Defines the dimensions and style of a dialog box.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-dlgtemplate.

Inheritance
Implemented types
Available extensions
Annotations

Constructors

DLGTEMPLATE()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
cdit int
The number of items in the dialog box.
getter/setter pair
cx int
The width, in dialog box units, of the dialog box.
getter/setter pair
cy int
The height, in dialog box units, of the dialog box.
getter/setter pair
dwExtendedStyle int
The extended styles for a window.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style int
The style of the dialog box.
getter/setter pair
x int
The x-coordinate, in dialog box units, of the upper-left corner of the dialog box.
getter/setter pair
y int
The y-coordinate, in dialog box units, of the upper-left corner of the dialog box.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<DLGTEMPLATE>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited