DLLVERSIONINFO class base struct

Receives DLL-specific version information.

To learn more, see learn.microsoft.com/windows/win32/api/shlwapi/ns-shlwapi-dllversioninfo.

Inheritance
Implemented types
Available extensions

Constructors

DLLVERSIONINFO()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
cbSize int
The size of the struct in bytes.
getter/setter pair
dwBuildNumber int
The build number of the DLL.
getter/setter pair
dwMajorVersion int
The major version of the DLL.
getter/setter pair
dwMinorVersion int
The minor version of the DLL.
getter/setter pair
dwPlatformID int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<DLLVERSIONINFO>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited