DSREG_USER_INFO class base struct

Contains information about a user account that is used to join a device to Microsoft Azure Active Directory.

To learn more, see learn.microsoft.com/windows/win32/api/lmjoin/ns-lmjoin-dsreg_user_info.

Inheritance
Implemented types
Available extensions

Constructors

DSREG_USER_INFO()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
pszUserEmail PWSTR
The email address of the user.
getter/setter pair
pszUserKeyId PWSTR
The identifier of the Microsoft Passport key that is provisioned for the user.
getter/setter pair
pszUserKeyName PWSTR
The name of the Microsoft Passport key that is provisioned for the user.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<DSREG_USER_INFO>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited