DTBGOPTS class base struct

Defines the options for the DrawThemeBackgroundEx function.

To learn more, see learn.microsoft.com/windows/win32/api/uxtheme/ns-uxtheme-dtbgopts.

Inheritance
Implemented types
Available extensions

Constructors

DTBGOPTS()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwFlags int
Flags that specify the selected options.
getter/setter pair
dwSize int
Size of the structure.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rcClip RECT
A RECT that specifies the bounding rectangle of the clip region.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<DTBGOPTS>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited