DTTOPTS class base struct

Defines the options for the DrawThemeTextEx function.

To learn more, see learn.microsoft.com/windows/win32/api/uxtheme/ns-uxtheme-dttopts.

Inheritance
Implemented types
Available extensions

Constructors

DTTOPTS()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
crBorder ↔ COLORREF
Specifies the color of the outline that will be drawn around the text.
getter/setter pair
crShadow ↔ COLORREF
Specifies the color of the shadow that will be drawn behind the text.
getter/setter pair
crText ↔ COLORREF
Specifies the color of the text that will be drawn.
getter/setter pair
dwFlags ↔ DTTOPTS_FLAGS
A combination of flags that specify whether certain values of the DTTOPTS structure have been specified, and how to interpret these values.
getter/setter pair
dwSize ↔ int
Size of the structure.
getter/setter pair
fApplyOverlay ↔ bool
If [TRUE], text will be drawn on top of the shadow and outline effects.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iBorderSize ↔ int
Specifies the radius of the outline that will be drawn around the text.
getter/setter pair
iColorPropId ↔ int
Specifies an alternate color property to use when drawing text.
getter/setter pair
iFontPropId ↔ int
Specifies an alternate font property to use when drawing text.
getter/setter pair
iGlowSize ↔ int
Specifies the size of a glow that will be drawn on the background prior to any text being drawn.
getter/setter pair
iStateId ↔ int
Specifies an alternate state to use.
getter/setter pair
iTextShadowType ↔ int
getter/setter pair
lParam ↔ LPARAM
Parameter for callback back function specified by pfnDrawTextCallback.
getter/setter pair
pfnDrawTextCallback ↔ Pointer<NativeFunction<DTT_CALLBACK_PROC>>
Pointer to callback function for DrawThemeTextEx.
getter/setter pair
ptShadowOffset ↔ POINT
Specifies the amount of offset, in logical coordinates, between the shadow and the text.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) → Pointer<DTTOPTS>
Allocates native memory and copies the contents of this struct into it.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited