DeletePrinterData function winspool

int DeletePrinterData(
  1. PRINTER_HANDLE hPrinter,
  2. PCWSTR pValueName
)

Deletes specified configuration data for a printer.

A printers configuration data consists of a set of named and typed values. The DeletePrinterData function deletes one of these values, specified by its value name.

To learn more, see learn.microsoft.com/windows/win32/printdocs/deleteprinterdata.

Implementation

@pragma('vm:prefer-inline')
int DeletePrinterData(PRINTER_HANDLE hPrinter, PCWSTR pValueName) =>
    _DeletePrinterData(hPrinter, pValueName);