DrawEscape function gdi32

int DrawEscape(
  1. HDC hdc,
  2. int iEscape,
  3. int cjIn,
  4. PCSTR? lpIn,
)

Provides drawing capabilities of the specified video display that are not directly available through the graphics device interface (GDI).

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/nf-wingdi-drawescape.

Implementation

@pragma('vm:prefer-inline')
int DrawEscape(HDC hdc, int iEscape, int cjIn, PCSTR? lpIn) =>
    _DrawEscape(hdc, iEscape, cjIn, lpIn ?? nullptr);