ENUMLOGFONTEX class base struct

Contains information about an enumerated font.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/ns-wingdi-enumlogfontexw.

Inheritance
Implemented types
Available extensions

Constructors

ENUMLOGFONTEX()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
elfFullName String
The unique name of the font.
getter/setter pair
elfLogFont LOGFONT
A LOGFONT structure that contains values defining the font attributes.
getter/setter pair
elfScript String
The script, that is, the character set, of the font.
getter/setter pair
elfStyle String
The style of the font.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<ENUMLOGFONTEX>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited