Contains information about a pagefile.
To learn more, see learn.microsoft.com/windows/win32/api/psapi/ns-psapi-enum_page_file_information.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - cb ↔ int
-
The size of this structure, in bytes.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- PeakUsage ↔ int
-
The peak pagefile usage, in pages.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- TotalInUse ↔ int
-
The current pagefile usage, in pages.
getter/setter pair
- TotalSize ↔ int
-
The total size of the pagefile, in pages.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< ENUM_PAGE_FILE_INFORMATION> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited