EN_ERRSPACE top-level constant

int const EN_ERRSPACE

Sent when an edit control cannot allocate enough memory to meet a specific request.

The parent window of the edit control receives this notification code through a WM_COMMAND message.

To learn more, see learn.microsoft.com/windows/win32/Controls/en-errspace.

Implementation

const EN_ERRSPACE = 1280;