EVENTMSG class base struct

Contains information about a hardware message sent to the system message queue.

This structure is used to store message information for the JournalPlaybackProc callback function.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-eventmsg.

Inheritance
Implemented types
Available extensions

Constructors

EVENTMSG()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
hwnd HWND
A handle to the window to which the message was posted.
getter/setter pair
message int
The message.
getter/setter pair
paramH int
Additional information about the message.
getter/setter pair
paramL int
Additional information about the message.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time int
The time at which the message was posted.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<EVENTMSG>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited