EndPath function gdi32

bool EndPath(
  1. HDC hdc
)

Closes a path bracket and selects the path defined by the bracket into the specified device context.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/nf-wingdi-endpath.

Implementation

@pragma('vm:prefer-inline')
bool EndPath(HDC hdc) => _EndPath(hdc) != FALSE;