EnumDisplaySettings function user32

bool EnumDisplaySettings(
  1. PCWSTR? lpszDeviceName,
  2. ENUM_DISPLAY_SETTINGS_MODE iModeNum,
  3. Pointer<DEVMODE> lpDevMode
)

Retrieves information about one of the graphics modes for a display device.

To retrieve information for all the graphics modes of a display device, make a series of calls to this function.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-enumdisplaysettingsw.

Implementation

@pragma('vm:prefer-inline')
bool EnumDisplaySettings(
  PCWSTR? lpszDeviceName,
  ENUM_DISPLAY_SETTINGS_MODE iModeNum,
  Pointer<DEVMODE> lpDevMode,
) =>
    _EnumDisplaySettings(lpszDeviceName ?? nullptr, iModeNum, lpDevMode) !=
    FALSE;