EnumDisplaySettingsEx function user32

bool EnumDisplaySettingsEx(
  1. PCWSTR? lpszDeviceName,
  2. ENUM_DISPLAY_SETTINGS_MODE iModeNum,
  3. Pointer<DEVMODE> lpDevMode,
  4. ENUM_DISPLAY_SETTINGS_FLAGS dwFlags,
)

Retrieves information about one of the graphics modes for a display device.

To retrieve information for all the graphics modes for a display device, make a series of calls to this function.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-enumdisplaysettingsexw.

Implementation

@pragma('vm:prefer-inline')
bool EnumDisplaySettingsEx(
  PCWSTR? lpszDeviceName,
  ENUM_DISPLAY_SETTINGS_MODE iModeNum,
  Pointer<DEVMODE> lpDevMode,
  ENUM_DISPLAY_SETTINGS_FLAGS dwFlags,
) =>
    _EnumDisplaySettingsEx(
      lpszDeviceName ?? nullptr,
      iModeNum,
      lpDevMode,
      dwFlags,
    ) !=
    FALSE;