EnumFontFamiliesEx function gdi32

int EnumFontFamiliesEx(
  1. HDC hdc,
  2. Pointer<LOGFONT> lpLogfont,
  3. Pointer<NativeFunction<FONTENUMPROC>> lpProc,
  4. LPARAM lParam,
  5. int dwFlags,
)

Enumerates all uniquely-named fonts in the system that match the font characteristics specified by the LOGFONT structure.

EnumFontFamiliesEx enumerates fonts based on typeface name, character set, or both.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/nf-wingdi-enumfontfamiliesexw.

Implementation

@pragma('vm:prefer-inline')
int EnumFontFamiliesEx(
  HDC hdc,
  Pointer<LOGFONT> lpLogfont,
  Pointer<NativeFunction<FONTENUMPROC>> lpProc,
  LPARAM lParam,
  int dwFlags,
) => _EnumFontFamiliesEx(hdc, lpLogfont, lpProc, lParam, dwFlags);