ExtTextOut function gdi32

bool ExtTextOut(
  1. HDC hdc,
  2. int x,
  3. int y,
  4. ETO_OPTIONS options,
  5. Pointer<RECT>? lprect,
  6. PCWSTR? lpString,
  7. int c,
  8. Pointer<Int32>? lpDx,
)

Draws text using the currently selected font, background color, and text color.

You can optionally provide dimensions to be used for clipping, opaquing, or both.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/nf-wingdi-exttextoutw.

Implementation

@pragma('vm:prefer-inline')
bool ExtTextOut(
  HDC hdc,
  int x,
  int y,
  ETO_OPTIONS options,
  Pointer<RECT>? lprect,
  PCWSTR? lpString,
  int c,
  Pointer<Int32>? lpDx,
) =>
    _ExtTextOut(
      hdc,
      x,
      y,
      options,
      lprect ?? nullptr,
      lpString ?? nullptr,
      c,
      lpDx ?? nullptr,
    ) !=
    FALSE;