ExtractAssociatedIcon function shell32
Gets a handle to an icon stored as a resource in a file or an icon stored in a file's associated executable file.
HICON ExtractAssociatedIconW(
HINSTANCE hInst,
LPWSTR pszIconPath,
WORD *piIcon
);
Implementation
int ExtractAssociatedIcon(
int hInst,
Pointer<Utf16> pszIconPath,
Pointer<Uint16> piIcon,
) => _ExtractAssociatedIcon(hInst, pszIconPath, piIcon);