FDAP_BOTTOM top-level constant
FDAP
const FDAP_BOTTOM
The place is added to the bottom of the default list.
Implementation
const FDAP_BOTTOM = FDAP(0);
The place is added to the bottom of the default list.
const FDAP_BOTTOM = FDAP(0);