FD_SET class base struct

Used by Windows Sockets (Winsock) functions and service providers to place sockets into a set.

To learn more, see learn.microsoft.com/windows/win32/api/winsock/nf-winsock-fd_set.

Inheritance
Implemented types
Available extensions

Constructors

FD_SET()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
fd_array Array<IntPtr>
getter/setter pair
fd_count int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<FD_SET>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited