toNative method

Pointer<FD_SET> toNative({
  1. Allocator allocator = adaptiveCalloc,
})

Allocates native memory and copies the contents of this struct into it.

The returned pointer refers to newly allocated memory. The caller is responsible for freeing it, unless a scoped allocator (such as Arena) is used, in which case the allocator manages the lifetime.

Implementation

Pointer<FD_SET> toNative({Allocator allocator = adaptiveCalloc}) =>
    allocator()..ref = this;