FINDMSGSTRING top-level constant

String const FINDMSGSTRING

A Find or Replace dialog box sends the FINDMSGSTRING registered message to the window procedure of its owner window when the user clicks the Find Next, Replace, or Replace All button, or closes the dialog box.

To learn more, see learn.microsoft.com/windows/win32/dlgbox/findmsgstring.

Implementation

const FINDMSGSTRING = 'commdlg_FindReplace';