FOCUS_EVENT_RECORD class base struct

Describes a focus event in a console INPUT_RECORD structure.

These events are used internally and should be ignored.

To learn more, see learn.microsoft.com/windows/console/focus-event-record-str.

Inheritance
Implemented types
Available extensions

Constructors

FOCUS_EVENT_RECORD()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bSetFocus bool
Reserved.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<FOCUS_EVENT_RECORD>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited