FSCTL_TXFS_CREATE_MINIVERSION top-level constant

int const FSCTL_TXFS_CREATE_MINIVERSION

Creates a new miniversion for the specified file.

Miniversions allow you to refer to a snapshot of the file during a transaction. Miniversions are discarded when a transaction is committed or rolled back.

To learn more, see learn.microsoft.com/windows/win32/api/winioctl/ni-winioctl-fsctl_txfs_create_miniversion.

Implementation

const FSCTL_TXFS_CREATE_MINIVERSION = 622972;