FUT_GENERIC top-level constant

FILE_USAGE_TYPE const FUT_GENERIC

The file is open in the process for an unspecified action or an action that does not readily fit into the other two categories.

Implementation

const FUT_GENERIC = FILE_USAGE_TYPE(2);