FindNextPrinterChangeNotification function winspool

bool FindNextPrinterChangeNotification(
  1. FINDPRINTERCHANGENOTIFICATION_HANDLE hChange,
  2. Pointer<Uint32>? pdwChange,
  3. Pointer<Pointer<NativeType>>? ppPrinterNotifyInfo
)

Retrieves information about the most recent change notification for a change notification object associated with a printer or print server.

To learn more, see learn.microsoft.com/windows/win32/printdocs/findnextprinterchangenotification.

Implementation

@pragma('vm:prefer-inline')
bool FindNextPrinterChangeNotification(
  FINDPRINTERCHANGENOTIFICATION_HANDLE hChange,
  Pointer<Uint32>? pdwChange,
  Pointer<Pointer>? ppPrinterNotifyInfo,
) =>
    _FindNextPrinterChangeNotification(
      hChange,
      pdwChange ?? nullptr,
      nullptr,
      ppPrinterNotifyInfo ?? nullptr,
    ) !=
    FALSE;