FreeMemoryJobObject function kernel32

void FreeMemoryJobObject(
  1. Pointer<NativeType> buffer
)

Frees memory that a function related to job objects allocated.

Functions related to job objects that allocate memory include QueryIoRateControlInformationJobObject.

To learn more, see learn.microsoft.com/windows/win32/api/jobapi2/nf-jobapi2-freememoryjobobject.

Implementation

@pragma('vm:prefer-inline')
void FreeMemoryJobObject(Pointer buffer) => _FreeMemoryJobObject(buffer);