GetAsyncKeyState function user32

int GetAsyncKeyState(
  1. int vKey
)

Determines whether a key is up or down at the time the function is called, and whether the key was pressed after a previous call to GetAsyncKeyState.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-getasynckeystate.

Implementation

@pragma('vm:prefer-inline')
int GetAsyncKeyState(int vKey) => _GetAsyncKeyState(vKey);