GetClipboardFormatName function user32
Retrieves from the clipboard the name of the specified registered format.
The function copies the name to the specified buffer.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-getclipboardformatnamew.
Implementation
Win32Result<int> GetClipboardFormatName(
int format,
PWSTR lpszFormatName,
int cchMaxCount,
) {
resolveGetLastError();
final result_ = _GetClipboardFormatName(format, lpszFormatName, cchMaxCount);
return .new(value: result_, error: GetLastError());
}