GetDIBits function gdi32

int GetDIBits(
  1. HDC hdc,
  2. HBITMAP hbm,
  3. int start,
  4. int cLines,
  5. Pointer<NativeType>? lpvBits,
  6. Pointer<BITMAPINFO> lpbmi,
  7. DIB_USAGE usage,
)

Retrieves the bits of the specified compatible bitmap and copies them into a buffer as a DIB using the specified format.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/nf-wingdi-getdibits.

Implementation

@pragma('vm:prefer-inline')
int GetDIBits(
  HDC hdc,
  HBITMAP hbm,
  int start,
  int cLines,
  Pointer? lpvBits,
  Pointer<BITMAPINFO> lpbmi,
  DIB_USAGE usage,
) => _GetDIBits(hdc, hbm, start, cLines, lpvBits ?? nullptr, lpbmi, usage);