GetNearestColor function gdi32

COLORREF GetNearestColor(
  1. HDC hdc,
  2. COLORREF color
)

Retrieves a color value identifying a color from the system palette that will be displayed when the specified color value is used.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/nf-wingdi-getnearestcolor.

Implementation

@pragma('vm:prefer-inline')
COLORREF GetNearestColor(HDC hdc, COLORREF color) =>
    COLORREF(_GetNearestColor(hdc, color));