GetOpenFileName function comdlg32

bool GetOpenFileName(
  1. Pointer<OPENFILENAME> param0
)

Creates an Open dialog box that lets the user specify the drive, directory, and the name of a file or set of files to be opened.

To learn more, see learn.microsoft.com/windows/win32/api/commdlg/nf-commdlg-getopenfilenamew.

Implementation

@pragma('vm:prefer-inline')
bool GetOpenFileName(Pointer<OPENFILENAME> param0) =>
    _GetOpenFileName(param0) != FALSE;