GetPointerInfoHistory function user32

Win32Result<bool> GetPointerInfoHistory(
  1. int pointerId,
  2. Pointer<Uint32> entriesCount,
  3. Pointer<POINTER_INFO>? pointerInfo
)

Gets the information associated with the individual inputs, if any, that were coalesced into the current message for the specified pointer.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-getpointerinfohistory.

Implementation

Win32Result<bool> GetPointerInfoHistory(
  int pointerId,
  Pointer<Uint32> entriesCount,
  Pointer<POINTER_INFO>? pointerInfo,
) {
  final result_ = GetPointerInfoHistory_Wrapper(
    pointerId,
    entriesCount,
    pointerInfo ?? nullptr,
  );
  return Win32Result(value: result_.value.i32 != FALSE, error: result_.error);
}