GetPointerPenInfoHistory function user32

Win32Result<bool> GetPointerPenInfoHistory(
  1. int pointerId,
  2. Pointer<Uint32> entriesCount,
  3. Pointer<POINTER_PEN_INFO>? penInfo
)

Gets the pen-based information associated with the individual inputs, if any, that were coalesced into the current message for the specified pointer (of type PT_PEN).

To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-getpointerpeninfohistory.

Implementation

Win32Result<bool> GetPointerPenInfoHistory(
  int pointerId,
  Pointer<Uint32> entriesCount,
  Pointer<POINTER_PEN_INFO>? penInfo,
) {
  resolveGetLastError();
  final result_ = _GetPointerPenInfoHistory(
    pointerId,
    entriesCount,
    penInfo ?? nullptr,
  );
  return .new(value: result_ != FALSE, error: GetLastError());
}