GetSaveFileName function comdlg32

bool GetSaveFileName(
  1. Pointer<OPENFILENAME> param0
)

Creates a Save dialog box that lets the user specify the drive, directory, and name of a file to save.

To learn more, see learn.microsoft.com/windows/win32/api/commdlg/nf-commdlg-getsavefilenamew.

Implementation

@pragma('vm:prefer-inline')
bool GetSaveFileName(Pointer<OPENFILENAME> param0) =>
    _GetSaveFileName(param0) != FALSE;