GetUpdateRect function user32

bool GetUpdateRect(
  1. HWND hWnd,
  2. Pointer<RECT>? lpRect,
  3. bool bErase
)

Retrieves the coordinates of the smallest rectangle that completely encloses the update region of the specified window.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-getupdaterect.

Implementation

@pragma('vm:prefer-inline')
bool GetUpdateRect(HWND hWnd, Pointer<RECT>? lpRect, bool bErase) =>
    _GetUpdateRect(hWnd, lpRect ?? nullptr, bErase ? TRUE : FALSE) != FALSE;