HARDWAREINPUT class base struct

Contains information about a simulated message generated by an input device other than a keyboard or mouse.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-hardwareinput.

Inheritance
Implemented types
Available extensions

Constructors

HARDWAREINPUT()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uMsg int
The message generated by the input hardware.
getter/setter pair
wParamH int
The high-order word of the lParam parameter for uMsg.
getter/setter pair
wParamL int
The low-order word of the lParam parameter for uMsg.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<HARDWAREINPUT>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited