IAppxBlockMapFile class com

Represents a file in the block map.

To learn more, see learn.microsoft.com/windows/win32/api/appxpackaging/nn-appxpackaging-iappxblockmapfile.

Inheritance
Implemented types

Constructors

IAppxBlockMapFile(VTablePointer ptr)
Creates a new instance of IAppxBlockMapFile from a VTablePointer.
IAppxBlockMapFile.from(IUnknown interface)
Creates a new instance of IAppxBlockMapFile from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getBlocks() IAppxBlockMapBlocksEnumerator?
Retrieves an enumerator for traversing the blocks of a file listed in the block map.
getLocalFileHeaderSize() int
Retrieves the size of the zip local file header of the associated zip file item.
getName() PWSTR
Retrieves the name of the associated zip file item.
getUncompressedSize() int
Retrieves the uncompressed size of the associated zip file item.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override
validateFileHash(IStream? fileStream) bool
Validates the content of a file against the hashes stored in the block elements for this block map file.

Operators

operator ==(Object other) bool
The equality operator.
inherited