IAppxManifestHostRuntimeDependenciesEnumerator class com

Inheritance
Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getCurrent() IAppxManifestHostRuntimeDependency?
Throws a WindowsException on failure.
getHasCurrent() bool
Throws a WindowsException on failure.
moveNext() bool
Throws a WindowsException on failure.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited