IAppxManifestMainPackageDependenciesEnumerator class com

Enumerates <MainPackageDependency> elements from an app manifest.

To learn more, see learn.microsoft.com/windows/win32/api/appxpackaging/nn-appxpackaging-iappxmanifestmainpackagedependenciesenumerator.

Inheritance
Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getCurrent() IAppxManifestMainPackageDependency?
Gets the <MainPackageDependency> element at the current position of the enumerator.
getHasCurrent() bool
Determines whether there is a <MainPackageDependency> element at the current position of the enumerator.
moveNext() bool
Advances the position of the enumerator to the next <MainPackageDependency> element.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited