IAppxManifestReader class com

Represents an object model of the package manifest that provides methods to access manifest elements and attributes.

To learn more, see learn.microsoft.com/windows/win32/api/appxpackaging/nn-appxpackaging-iappxmanifestreader.

Inheritance
Implemented types
Implementers

Constructors

IAppxManifestReader(VTablePointer ptr)
Creates a new instance of IAppxManifestReader from a VTablePointer.
IAppxManifestReader.from(IUnknown interface)
Creates a new instance of IAppxManifestReader from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getApplications() IAppxManifestApplicationsEnumerator?
Gets an enumerator that iterates through the applications defined in the manifest.
getCapabilities() APPX_CAPABILITIES
Gets the list of capabilities requested by the package.
getDeviceCapabilities() IAppxManifestDeviceCapabilitiesEnumerator?
Gets an enumerator that iterates through the device capabilities defined in the manifest.
getPackageDependencies() IAppxManifestPackageDependenciesEnumerator?
Gets an enumerator that iterates through dependencies defined in the manifest.
getPackageId() IAppxManifestPackageId?
Gets the package identifier defined in the manifest.
getPrerequisite(PCWSTR name) int
Gets the specified prerequisite as defined in the package manifest.
getProperties() IAppxManifestProperties?
Gets the properties of the package as defined in the manifest.
getResources() IAppxManifestResourcesEnumerator?
Gets an enumerator that iterates through the resources defined in the manifest.
getStream() IStream?
Gets the raw XML parsed and read by the manifest reader.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited