IAppxManifestReader5 class com

Represents an object model of the package manifest that provides methods to access manifest elements and attributes.

To learn more, see learn.microsoft.com/windows/win32/api/appxpackaging/nn-appxpackaging-iappxmanifestreader5.

Inheritance
Implemented types

Constructors

IAppxManifestReader5(VTablePointer ptr)
Creates a new instance of IAppxManifestReader5 from a VTablePointer.
IAppxManifestReader5.from(IUnknown interface)
Creates a new instance of IAppxManifestReader5 from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getMainPackageDependencies() IAppxManifestMainPackageDependenciesEnumerator?
Gets a main package dependencies enumerator.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited