IAppxPackageWriter class com

Provides a write-only object model for app packages.

To learn more, see learn.microsoft.com/windows/win32/api/appxpackaging/nn-appxpackaging-iappxpackagewriter.

Inheritance
Implemented types

Constructors

IAppxPackageWriter(VTablePointer ptr)
Creates a new instance of IAppxPackageWriter from a VTablePointer.
IAppxPackageWriter.from(IUnknown interface)
Creates a new instance of IAppxPackageWriter from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addPayloadFile(PCWSTR fileName, PCWSTR contentType, APPX_COMPRESSION_OPTION compressionOption, IStream? inputStream) → void
Adds a new payload file to the app package.
addRef() int
Increments the reference count of this COM object.
inherited
close(IStream? manifest) → void
Writes footprint files at the end of the app package, and closes the package writer object's output stream.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited