IAudioClock class com

Enables a client to monitor a stream's data rate and the current position in the stream.

To learn more, see learn.microsoft.com/windows/win32/api/audioclient/nn-audioclient-iaudioclock.

Inheritance
Implemented types

Constructors

IAudioClock(VTablePointer ptr)
Creates a new instance of IAudioClock from a VTablePointer.
IAudioClock.from(IUnknown interface)
Creates a new instance of IAudioClock from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getCharacteristics() int
Reserved for future use.
getFrequency() int
Gets the device frequency.
getPosition(Pointer<Uint64> pu64Position, Pointer<Uint64>? pu64QPCPosition) → void
Gets the current device position.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited