IAudioSessionControl class com

The IAudioSessionControl interface enables a client to configure the control parameters for an audio session and to monitor events in the session. The IAudioClient::Initialize method initializes a stream object and assigns the stream to an audio session. The client obtains a reference to the IAudioSessionControl interface on a stream object by calling the IAudioClient::GetService method with parameter riid set to REFIID IID_IAudioSessionControl.

Inheritance
Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
ptr ↔ Pointer<COMObject>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() → int
Increments the reference count for an interface pointer to a COM object.
inherited
detach() → void
Detaches the object from the Finalizer.
inherited
getDisplayName(Pointer<Pointer<Utf16>> pRetVal) → int
getGroupingParam(Pointer<GUID> pRetVal) → int
getIconPath(Pointer<Pointer<Utf16>> pRetVal) → int
getState(Pointer<Int32> pRetVal) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface(Pointer<GUID> riid, Pointer<Pointer<NativeType>> ppvObject) → int
Queries a COM object for a pointer to one of its interface; identifying the interface by a reference to its interface identifier (IID).
inherited
registerAudioSessionNotification(Pointer<COMObject> NewNotifications) → int
release() → int
Decrements the reference count for an interface on a COM object.
inherited
setDisplayName(Pointer<Utf16> Value, Pointer<GUID> EventContext) → int
setGroupingParam(Pointer<GUID> Override, Pointer<GUID> EventContext) → int
setIconPath(Pointer<Utf16> Value, Pointer<GUID> EventContext) → int
toInterface(String iid) → Pointer<COMObject>
Cast an existing COM object to a specified interface.
inherited
toString() → String
A string representation of this object.
inherited
unregisterAudioSessionNotification(Pointer<COMObject> NewNotifications) → int

Operators

operator ==(Object other) → bool
The equality operator.
inherited