IAudioSessionControl2 class com

The IAudioSessionControl2 interface can be used by a client to get information about the audio session.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
ptr ↔ Pointer<COMObject>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() → int
Increments the reference count for an interface pointer to a COM object.
inherited
detach() → void
Detaches the object from the Finalizer.
inherited
getDisplayName(Pointer<Pointer<Utf16>> pRetVal) → int
inherited
getGroupingParam(Pointer<GUID> pRetVal) → int
inherited
getIconPath(Pointer<Pointer<Utf16>> pRetVal) → int
inherited
getProcessId(Pointer<Uint32> pRetVal) → int
getSessionIdentifier(Pointer<Pointer<Utf16>> pRetVal) → int
getSessionInstanceIdentifier(Pointer<Pointer<Utf16>> pRetVal) → int
getState(Pointer<Int32> pRetVal) → int
inherited
isSystemSoundsSession() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface(Pointer<GUID> riid, Pointer<Pointer<NativeType>> ppvObject) → int
Queries a COM object for a pointer to one of its interface; identifying the interface by a reference to its interface identifier (IID).
inherited
registerAudioSessionNotification(Pointer<COMObject> NewNotifications) → int
inherited
release() → int
Decrements the reference count for an interface on a COM object.
inherited
setDisplayName(Pointer<Utf16> Value, Pointer<GUID> EventContext) → int
inherited
setDuckingPreference(int optOut) → int
setGroupingParam(Pointer<GUID> Override, Pointer<GUID> EventContext) → int
inherited
setIconPath(Pointer<Utf16> Value, Pointer<GUID> EventContext) → int
inherited
toInterface(String iid) → Pointer<COMObject>
Cast an existing COM object to a specified interface.
inherited
toString() → String
A string representation of this object.
inherited
unregisterAudioSessionNotification(Pointer<COMObject> NewNotifications) → int
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited