IAudioSessionEnumerator class com

Enumerates audio sessions on an audio device.

To learn more, see learn.microsoft.com/windows/win32/api/audiopolicy/nn-audiopolicy-iaudiosessionenumerator.

Inheritance
Implemented types

Constructors

IAudioSessionEnumerator(VTablePointer ptr)
Creates a new instance of IAudioSessionEnumerator from a VTablePointer.
IAudioSessionEnumerator.from(IUnknown interface)
Creates a new instance of IAudioSessionEnumerator from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getCount() int
Gets the total number of audio sessions that are open on the audio device.
getSession(int sessionCount) IAudioSessionControl?
Gets the audio session specified by an audio session number.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited