IAudioSessionManager2 class com

Enables an application to manage submixes for the audio device.

To learn more, see learn.microsoft.com/windows/win32/api/audiopolicy/nn-audiopolicy-iaudiosessionmanager2.

Inheritance
Implemented types

Constructors

IAudioSessionManager2(VTablePointer ptr)
Creates a new instance of IAudioSessionManager2 from a VTablePointer.
IAudioSessionManager2.from(IUnknown interface)
Creates a new instance of IAudioSessionManager2 from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getAudioSessionControl(Pointer<GUID>? audioSessionGuid, int streamFlags) IAudioSessionControl?
Retrieves an audio session control.
inherited
getSessionEnumerator() IAudioSessionEnumerator?
Gets a pointer to the audio session enumerator object.
getSimpleAudioVolume(Pointer<GUID>? audioSessionGuid, int streamFlags) ISimpleAudioVolume?
Retrieves a simple audio volume control.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
registerDuckNotification(PCWSTR sessionID, IAudioVolumeDuckNotification? duckNotification) → void
Registers the application with the session manager to receive ducking notifications.
registerSessionNotification(IAudioSessionNotification? sessionNotification) → void
Registers the application to receive a notification when a session is created.
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override
unregisterDuckNotification(IAudioVolumeDuckNotification? duckNotification) → void
Deletes a previous registration by the application to receive notifications.
unregisterSessionNotification(IAudioSessionNotification? sessionNotification) → void
Deletes the registration to receive a notification when a session is created.

Operators

operator ==(Object other) bool
The equality operator.
inherited