IClassFactory class com

Enables a class of objects to be created.

To learn more, see learn.microsoft.com/windows/win32/api/unknwn/nn-unknwn-iclassfactory.

Inheritance
Implemented types

Constructors

IClassFactory(VTablePointer ptr)
Creates a new instance of IClassFactory from a VTablePointer.
IClassFactory.from(IUnknown interface)
Creates a new instance of IClassFactory from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
createInstance<T extends IUnknown>(IUnknown? pUnkOuter) → T
Creates an uninitialized object.
lockServer(bool fLock) → void
Locks an object application open in memory.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited