IConnectionPoint class com

Supports connection points for connectable objects.

Inheritance

Constructors

IConnectionPoint(Pointer<COMObject> ptr)
IConnectionPoint.from(IUnknown interface)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
ptr ↔ Pointer<COMObject>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() → int
Increments the reference count for an interface pointer to a COM object.
inherited
advise(Pointer<COMObject> pUnkSink, Pointer<Uint32> pdwCookie) → int
detach() → void
Detaches the object from the Finalizer.
inherited
enumConnections(Pointer<Pointer<COMObject>> ppEnum) → int
getConnectionInterface(Pointer<GUID> pIID) → int
getConnectionPointContainer(Pointer<Pointer<COMObject>> ppCPC) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface(Pointer<GUID> riid, Pointer<Pointer<NativeType>> ppvObject) → int
Queries a COM object for a pointer to one of its interface; identifying the interface by a reference to its interface identifier (IID).
inherited
release() → int
Decrements the reference count for an interface on a COM object.
inherited
toInterface(String iid) → Pointer<COMObject>
Cast an existing COM object to a specified interface.
inherited
toString() → String
A string representation of this object.
inherited
unadvise(int dwCookie) → int

Operators

operator ==(Object other) → bool
The equality operator.
inherited