IDesktopWallpaper class com

Provides methods for managing the desktop wallpaper.

To learn more, see learn.microsoft.com/windows/win32/api/shobjidl_core/nn-shobjidl_core-idesktopwallpaper.

Inheritance
Implemented types

Constructors

IDesktopWallpaper(VTablePointer ptr)
Creates a new instance of IDesktopWallpaper from a VTablePointer.
IDesktopWallpaper.from(IUnknown interface)
Creates a new instance of IDesktopWallpaper from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
advanceSlideshow(PCWSTR monitorID, DESKTOP_SLIDESHOW_DIRECTION direction) → void
Switches the wallpaper on a specified monitor to the next image in the slideshow.
enable(bool enable) → void
Enables or disables the desktop background.
getBackgroundColor() COLORREF
Retrieves the color that is visible on the desktop when no image is displayed or when the desktop background has been disabled.
getMonitorDevicePathAt(int monitorIndex) PWSTR
Retrieves the unique ID of one of the system's monitors.
getMonitorDevicePathCount() int
Retrieves the number of monitors that are associated with the system.
getMonitorRECT(PCWSTR monitorID) Pointer<RECT>
Retrieves the display rectangle of the specified monitor.
getPosition() DESKTOP_WALLPAPER_POSITION
Retrieves the current display value for the desktop background image.
getSlideshow() IShellItemArray?
Gets the path to the directory where the slideshow images are stored.
getSlideshowOptions(Pointer<Int32> options, Pointer<Uint32> slideshowTick) → void
Gets the current desktop wallpaper slideshow settings for shuffle and timing.
getStatus() DESKTOP_SLIDESHOW_STATE
Gets the current status of the slideshow.
getWallpaper(PCWSTR monitorID) PWSTR
Gets the current desktop wallpaper.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
setBackgroundColor(COLORREF color) → void
Sets the color that is visible on the desktop when no image is displayed or when the desktop background has been disabled.
setPosition(DESKTOP_WALLPAPER_POSITION position) → void
Sets the display option for the desktop wallpaper image, determining whether the image should be centered, tiled, or stretched.
setSlideshow(IShellItemArray? items) → void
Specifies the images to use for the desktop wallpaper slideshow.
setSlideshowOptions(DESKTOP_SLIDESHOW_OPTIONS options, int slideshowTick) → void
Sets the desktop wallpaper slideshow settings for shuffle and timing.
setWallpaper(PCWSTR monitorID, PCWSTR wallpaper) → void
Sets the desktop wallpaper.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited