IEnumIDList class com

Exposes a standard set of methods used to enumerate the pointers to item identifier lists (PIDLs) of the items in a Shell folder.

To learn more, see learn.microsoft.com/windows/win32/api/shobjidl_core/nn-shobjidl_core-ienumidlist.

Inheritance
Implemented types

Constructors

IEnumIDList(VTablePointer ptr)
Creates a new instance of IEnumIDList from a VTablePointer.
IEnumIDList.from(IUnknown interface)
Creates a new instance of IEnumIDList from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
clone(Pointer<VTablePointer> ppenum) HRESULT
Creates a new item enumeration object with the same contents and state as the current one.
next(int celt, Pointer<Pointer<ITEMIDLIST>> rgelt, Pointer<Uint32>? pceltFetched) HRESULT
Retrieves the specified number of item identifiers in the enumeration sequence and advances the current position by the number of items retrieved.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
reset() HRESULT
Returns to the beginning of the enumeration sequence.
skip(int celt) HRESULT
Skips the specified number of elements in the enumeration sequence.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited