IEnumNetworks class com

A standard enumerator for networks.

It enumerates all networks available on the local machine. This interface can be obtained from the INetworkListManager interface.

To learn more, see learn.microsoft.com/windows/win32/api/netlistmgr/nn-netlistmgr-ienumnetworks.

Inheritance
Implemented types

Constructors

IEnumNetworks(VTablePointer ptr)
Creates a new instance of IEnumNetworks from a VTablePointer.
IEnumNetworks.from(IUnknown interface)
Creates a new instance of IEnumNetworks from an existing interface.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
newEnum → IEnumVARIANT?
Returns an automation enumerator object that you can use to iterate through the IEnumNetworks collection.
no setter
ptr → VTablePointer
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() → int
Increments the reference count of this COM object.
inherited
clone() → IEnumNetworks?
Creates an enumerator that contains the same enumeration state as the enumerator currently in use.
getIDsOfNames(Pointer<GUID> riid, Pointer<Pointer<Utf16>> rgszNames, int cNames, int lcid, Pointer<Int32> rgDispId) → void
Maps a single member and an optional set of argument names to a corresponding set of integer DISPIDs, which can be used on subsequent calls to Invoke.
inherited
getTypeInfo(int iTInfo, int lcid) → ITypeInfo?
Retrieves the type information for an object, which can then be used to get the type information for an interface.
inherited
getTypeInfoCount() → int
Retrieves the number of type information interfaces that an object provides (either 0 or 1).
inherited
invoke(int dispIdMember, Pointer<GUID> riid, int lcid, DISPATCH_FLAGS wFlags, Pointer<DISPPARAMS> pDispParams, Pointer<VARIANT>? pVarResult, Pointer<EXCEPINFO>? pExcepInfo, Pointer<Uint32>? puArgErr) → void
Provides access to properties and methods exposed by an object.
inherited
next(int celt, Pointer<VTablePointer> rgelt, Pointer<Uint32>? pceltFetched) → void
Gets the next specified number of elements in the enumeration sequence.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() → int
Decrements the reference count of this COM object.
inherited
reset() → void
Resets the enumeration sequence to the beginning.
skip(int celt) → void
Skips over the next specified number of elements in the enumeration sequence.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited