IEnumResources class com
Exposes resource enumeration methods.
To learn more, see learn.microsoft.com/windows/win32/api/shobjidl_core/nn-shobjidl_core-ienumresources.
- Inheritance
- Implemented types
Constructors
- IEnumResources(VTablePointer ptr)
- Creates a new instance of IEnumResources from a VTablePointer.
- IEnumResources.from(IUnknown interface)
-
Creates a new instance of IEnumResources from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
clone(
) → IEnumResources? - Clones a resource enumerator.
-
next(
int celt, Pointer< SHELL_ITEM_RESOURCE> psir, Pointer<Uint32> pceltFetched) → void - Gets the next SHELL_ITEM_RESOURCE structure.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
reset(
) → void - Resets the enumeration index to 0.
-
skip(
int celt) → void - Skips a specified number of resources.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited