IFileDialogEvents class com

Exposes methods that allow notification of events within a common file dialog.

To learn more, see learn.microsoft.com/windows/win32/api/shobjidl_core/nn-shobjidl_core-ifiledialogevents.

Inheritance
Implemented types

Constructors

IFileDialogEvents(VTablePointer ptr)
Creates a new instance of IFileDialogEvents from a VTablePointer.
IFileDialogEvents.from(IUnknown interface)
Creates a new instance of IFileDialogEvents from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onFileOk(IFileDialog? pfd) → void
Called just before the dialog is about to return with a result.
onFolderChange(IFileDialog? pfd) → void
Called when the user navigates to a new folder.
onFolderChanging(IFileDialog? pfd, IShellItem? psiFolder) → void
Called before IFileDialogEvents.onFolderChange.
onOverwrite(IFileDialog? pfd, IShellItem? psi) FDE_OVERWRITE_RESPONSE
Called from the save dialog when the user chooses to overwrite a file.
onSelectionChange(IFileDialog? pfd) → void
Called when the user changes the selection in the dialog's view.
onShareViolation(IFileDialog? pfd, IShellItem? psi) FDE_SHAREVIOLATION_RESPONSE
Enables an application to respond to sharing violations that arise from Open or Save operations.
onTypeChange(IFileDialog? pfd) → void
Called when the dialog is opened to notify the application of the initial chosen filetype.
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited