IFileIsInUse class com

Exposes methods that can be called to get information on or close a file that is in use by another application.

To learn more, see learn.microsoft.com/windows/win32/api/shobjidl_core/nn-shobjidl_core-ifileisinuse.

Inheritance
Implemented types

Constructors

IFileIsInUse(VTablePointer ptr)
Creates a new instance of IFileIsInUse from a VTablePointer.
IFileIsInUse.from(IUnknown interface)
Creates a new instance of IFileIsInUse from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
closeFile() → void
Closes the file currently in use.
getAppName() PWSTR
Retrieves the name of the application that is using the file.
getCapabilities() int
Determines whether the file can be closed and whether the UI is capable of switching to the window of the application that is using the file.
getSwitchToHWND() HWND
Retrieves the handle of the top-level window of the application that is using the file.
getUsage() FILE_USAGE_TYPE
Gets a value that indicates how the file in use is being used.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited