IFileSaveDialog class com

Extends the IFileDialog interface by adding methods specific to the save dialog, which include those that provide support for the collection of metadata to be persisted with the file.

To learn more, see learn.microsoft.com/windows/win32/api/shobjidl_core/nn-shobjidl_core-ifilesavedialog.

Inheritance
Implemented types

Constructors

IFileSaveDialog(VTablePointer ptr)
Creates a new instance of IFileSaveDialog from a VTablePointer.
IFileSaveDialog.from(IUnknown interface)
Creates a new instance of IFileSaveDialog from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addPlace(IShellItem? psi, FDAP fdap) → void
Adds a folder to the list of places available for the user to open or save items.
inherited
addRef() int
Increments the reference count of this COM object.
inherited
advise(IFileDialogEvents? pfde) int
Assigns an event handler that listens for events coming from the dialog.
inherited
applyProperties(IShellItem? psi, IPropertyStore? pStore, HWND hwnd, IFileOperationProgressSink? pSink) → void
Applies a set of properties to an item using the Shell's copy engine.
clearClientData() → void
Instructs the dialog to clear all persisted state information.
inherited
close(HRESULT hr) → void
Closes the dialog.
inherited
getCurrentSelection() IShellItem?
Gets the user's current selection in the dialog.
inherited
getFileName() PWSTR
Retrieves the text currently entered in the dialog's File name edit box.
inherited
getFileTypeIndex() int
Gets the currently selected file type.
inherited
getFolder() IShellItem?
Gets either the folder currently selected in the dialog, or, if the dialog is not currently displayed, the folder that is to be selected when the dialog is opened.
inherited
getOptions() FILEOPENDIALOGOPTIONS
Gets the current flags that are set to control dialog behavior.
inherited
getProperties() IPropertyStore?
Retrieves the set of property values for a saved item or an item in the process of being saved.
getResult() IShellItem?
Gets the choice that the user made in the dialog.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
setClientGuid(Pointer<GUID> guid) → void
Enables a calling application to associate a GUID with a dialog's persisted state.
inherited
setCollectedProperties(IPropertyDescriptionList? pList, bool fAppendDefault) → void
Specifies which properties will be collected in the save dialog.
setDefaultExtension(PCWSTR pszDefaultExtension) → void
Sets the default extension to be added to file names.
inherited
setDefaultFolder(IShellItem? psi) → void
Sets the folder used as a default if there is not a recently used folder value available.
inherited
setFileName(PCWSTR pszName) → void
Sets the file name that appears in the File name edit box when that dialog box is opened.
inherited
setFileNameLabel(PCWSTR pszLabel) → void
Sets the text of the label next to the file name edit box.
inherited
setFileTypeIndex(int iFileType) → void
Sets the file type that appears as selected in the dialog.
inherited
setFileTypes(int cFileTypes, Pointer<COMDLG_FILTERSPEC> rgFilterSpec) → void
Sets the file types that the dialog can open or save.
inherited
setFilter(IShellItemFilter? pFilter) → void
SetFilter is no longer available for use as of Windows 7.
inherited
setFolder(IShellItem? psi) → void
Sets a folder that is always selected when the dialog is opened, regardless of previous user action.
inherited
setOkButtonLabel(PCWSTR pszText) → void
Sets the text of the Open or Save button.
inherited
setOptions(FILEOPENDIALOGOPTIONS fos) → void
Sets flags to control the behavior of the dialog.
inherited
setProperties(IPropertyStore? pStore) → void
Provides a property store that defines the default values to be used for the item being saved.
setSaveAsItem(IShellItem? psi) → void
Sets an item to be used as the initial entry in a Save As dialog.
setTitle(PCWSTR pszTitle) → void
Sets the title of the dialog.
inherited
show(HWND? hwndOwner) → void
Launches the modal window.
inherited
toString() String
A string representation of this object.
override
unadvise(int dwCookie) → void
Removes an event handler that was attached through the IFileDialog.advise method.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited