setProperties method
Provides a property store that defines the default values to be used for the item being saved.
Throws a WindowsException on failure.
To learn more, see learn.microsoft.com/windows/win32/api/shobjidl_core/nf-shobjidl_core-ifilesavedialog-setproperties.
Implementation
@pragma('vm:prefer-inline')
void setProperties(IPropertyStore? pStore) {
final hr$ = HRESULT(_SetPropertiesFn(ptr, pStore?.ptr ?? nullptr));
if (hr$.isError) throw WindowsException(hr$);
}