IMMDevice class com

Encapsulates the generic features of a multimedia device resource.

To learn more, see learn.microsoft.com/windows/win32/api/mmdeviceapi/nn-mmdeviceapi-immdevice.

Inheritance
Implemented types

Constructors

IMMDevice(VTablePointer ptr)
Creates a new instance of IMMDevice from a VTablePointer.
IMMDevice.from(IUnknown interface)
Creates a new instance of IMMDevice from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

activate<T extends IUnknown>(CLSCTX dwClsCtx, Pointer<PROPVARIANT>? pActivationParams) → T
Creates a COM object with the specified interface.
addRef() int
Increments the reference count of this COM object.
inherited
getId() PWSTR
Retrieves an endpoint ID string that identifies the audio endpoint device.
getState() DEVICE_STATE
Retrieves the current device state.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openPropertyStore(STGM stgmAccess) IPropertyStore?
Retrieves an interface to the device's property store.
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited