IMMDeviceCollection class com
Represents a collection of multimedia device resources.
To learn more, see learn.microsoft.com/windows/win32/api/mmdeviceapi/nn-mmdeviceapi-immdevicecollection.
- Inheritance
- Implemented types
Constructors
- IMMDeviceCollection(VTablePointer ptr)
- Creates a new instance of IMMDeviceCollection from a VTablePointer.
- IMMDeviceCollection.from(IUnknown interface)
-
Creates a new instance of IMMDeviceCollection from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
getCount(
) → int - Retrieves a count of the devices in the device collection.
-
item(
int nDevice) → IMMDevice? - Retrieves a pointer to the specified item in the device collection.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited