unregisterEndpointNotificationCallback method

void unregisterEndpointNotificationCallback(
  1. IMMNotificationClient? pClient
)

Deletes the registration of a notification interface that the client registered in a previous call to the IMMDeviceEnumerator.registerEndpointNotificationCallback method.

Throws a WindowsException on failure.

To learn more, see learn.microsoft.com/windows/win32/api/mmdeviceapi/nf-mmdeviceapi-immdeviceenumerator-unregisterendpointnotificationcallback.

Implementation

@pragma('vm:prefer-inline')
void unregisterEndpointNotificationCallback(IMMNotificationClient? pClient) {
  final hr$ = HRESULT(
    _UnregisterEndpointNotificationCallbackFn(ptr, pClient?.ptr ?? nullptr),
  );
  if (hr$.isError) throw WindowsException(hr$);
}