IMMEndpoint class com

Represents an audio endpoint device.

To learn more, see learn.microsoft.com/windows/win32/api/mmdeviceapi/nn-mmdeviceapi-immendpoint.

Inheritance
Implemented types

Constructors

IMMEndpoint(VTablePointer ptr)
Creates a new instance of IMMEndpoint from a VTablePointer.
IMMEndpoint.from(IUnknown interface)
Creates a new instance of IMMEndpoint from an existing interface.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
ptr → VTablePointer
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() → int
Increments the reference count of this COM object.
inherited
getDataFlow() → EDataFlow
Indicates whether the audio endpoint device is a rendering device or a capture device.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() → int
Decrements the reference count of this COM object.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited