getInterfaceImplProps method
Gets a pointer to the metadata tokens for the Type that implements the specified method, and for the interface that declares that method.
Throws a WindowsException on failure.
To learn more, see learn.microsoft.com/windows/win32/api/rometadataapi/nf-rometadataapi-imetadataimport-getinterfaceimplprops.
Implementation
@pragma('vm:prefer-inline')
void getInterfaceImplProps(
int iiImpl,
Pointer<Uint32> pClass,
Pointer<Uint32> ptkIface,
) {
final hr$ = HRESULT(
_GetInterfaceImplPropsFn(ptr, iiImpl, pClass, ptkIface),
);
if (hr$.isError) throw WindowsException(hr$);
}