IModalWindow class com

Exposes a method that represents a modal window.

To learn more, see learn.microsoft.com/windows/win32/api/shobjidl_core/nn-shobjidl_core-imodalwindow.

Inheritance
Implemented types
Implementers

Constructors

IModalWindow(VTablePointer ptr)
Creates a new instance of IModalWindow from a VTablePointer.
IModalWindow.from(IUnknown interface)
Creates a new instance of IModalWindow from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
show(HWND? hwndOwner) → void
Launches the modal window.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited