IMoniker class com

Enables you to use a moniker object, which contains information that uniquely identifies a COM object.

To learn more, see learn.microsoft.com/windows/win32/api/objidl/nn-objidl-imoniker.

Inheritance
Implemented types

Constructors

IMoniker(VTablePointer ptr)
Creates a new instance of IMoniker from a VTablePointer.
IMoniker.from(IUnknown interface)
Creates a new instance of IMoniker from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
bindToObject<T extends IUnknown>(IBindCtx? pbc, IMoniker? pmkToLeft) → T
Binds to the specified object.
bindToStorage<T extends IUnknown>(IBindCtx? pbc, IMoniker? pmkToLeft) → T
Binds to the storage for the specified object.
commonPrefixWith(IMoniker? pmkOther) IMoniker?
Creates a new moniker based on the prefix that this moniker has in common with the specified moniker.
composeWith(IMoniker? pmkRight, bool fOnlyIfNotGeneric) IMoniker?
Creates a new composite moniker by combining the current moniker with the specified moniker.
enum$(bool fForward) IEnumMoniker?
Retrieves a pointer to an enumerator for the components of a composite moniker.
getClassID() Pointer<GUID>
Retrieves the class identifier (CLSID) of the object.
inherited
getDisplayName(IBindCtx? pbc, IMoniker? pmkToLeft) PWSTR
Retrieves the display name for the moniker.
getSizeMax() int
Retrieves the size of the stream needed to save the object.
inherited
getTimeOfLastChange(IBindCtx? pbc, IMoniker? pmkToLeft) Pointer<FILETIME>
Retrieves the time at which the object identified by this moniker was last changed.
hash() int
Creates a hash value using the internal state of the moniker.
override
inverse() IMoniker?
Creates a moniker that is the inverse of this moniker.
isDirty() HRESULT
Determines whether an object has changed since it was last saved to its stream.
inherited
isEqual(IMoniker? pmkOtherMoniker) HRESULT
Determines whether this moniker is identical to the specified moniker.
isRunning(IBindCtx? pbc, IMoniker? pmkToLeft, IMoniker? pmkNewlyRunning) → void
Determines whether the object identified by this moniker is currently loaded and running.
isSystemMoniker() int
Determines whether this moniker is one of the system-provided moniker classes.
load(IStream? pStm) → void
Initializes an object from the stream where it was saved previously.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseDisplayName(IBindCtx? pbc, IMoniker? pmkToLeft, PCWSTR pszDisplayName, Pointer<Uint32> pchEaten, Pointer<VTablePointer> ppmkOut) → void
Converts a display name into a moniker.
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
reduce(IBindCtx? pbc, int dwReduceHowFar, Pointer<VTablePointer> ppmkToLeft, Pointer<VTablePointer> ppmkReduced) → void
Reduces a moniker to its simplest form.
relativePathTo(IMoniker? pmkOther) IMoniker?
Creates a relative moniker between this moniker and the specified moniker.
release() int
Decrements the reference count of this COM object.
inherited
save(IStream? pStm, bool fClearDirty) → void
Saves an object to the specified stream.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited