Carries information used to load common control classes from the dynamic-link library (DLL).
This structure is used with the InitCommonControlsEx function.
To learn more, see learn.microsoft.com/windows/win32/api/commctrl/ns-commctrl-initcommoncontrolsex.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - dwICC ↔ INITCOMMONCONTROLSEX_ICC
-
getter/setter pair
- dwSize ↔ int
-
The size of the structure, in bytes.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< INITCOMMONCONTROLSEX> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited