IP_ADAPTER_INDEX_MAP class base struct

Stores the interface index associated with a network adapter with IPv4 enabled together with the name of the network adapter.

To learn more, see learn.microsoft.com/windows/win32/api/ipexport/ns-ipexport-ip_adapter_index_map.

Inheritance
Implemented types
Available extensions

Constructors

IP_ADAPTER_INDEX_MAP()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
Index int
The interface index associated with the network adapter.
getter/setter pair
Name String
A string that contains the name of the adapter.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<IP_ADAPTER_INDEX_MAP>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited