IP_ADDRESS_STRING class base struct

Stores an IPv4 address in dotted decimal notation.

To learn more, see learn.microsoft.com/windows/win32/api/iptypes/ns-iptypes-ip_address_string.

Inheritance
Implemented types
Available extensions

Constructors

IP_ADDRESS_STRING()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
String$ Array<Int8>
A character string that represents an IPv4 address or an IPv4 subnet mask in dotted decimal notation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<IP_ADDRESS_STRING>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited