IPersistFile class com
Enables an object to be loaded from or saved to a disk file, rather than a storage object or stream.
To learn more, see learn.microsoft.com/windows/win32/api/objidl/nn-objidl-ipersistfile.
- Inheritance
- Implemented types
Constructors
- IPersistFile(VTablePointer ptr)
- Creates a new instance of IPersistFile from a VTablePointer.
- IPersistFile.from(IUnknown interface)
-
Creates a new instance of IPersistFile from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
getClassID(
) → Pointer< GUID> -
Retrieves the class identifier (CLSID) of the object.
inherited
-
getCurFile(
) → PWSTR - Retrieves the current name of the file associated with the object.
-
isDirty(
) → HRESULT - Determines whether an object has changed since it was last saved to its current file.
-
load(
PCWSTR pszFileName, STGM dwMode) → void - Opens the specified file and initializes an object from the file contents.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
save(
PCWSTR pszFileName, bool fRemember) → void - Saves a copy of the object to the specified file.
-
saveCompleted(
PCWSTR pszFileName) → void - Notifies the object that it can write to its file.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited