IPersistStream class com

Enables the saving and loading of objects that use a simple serial stream for their storage needs.

To learn more, see learn.microsoft.com/windows/win32/api/objidl/nn-objidl-ipersiststream.

Inheritance
Implemented types
Implementers

Constructors

IPersistStream(VTablePointer ptr)
Creates a new instance of IPersistStream from a VTablePointer.
IPersistStream.from(IUnknown interface)
Creates a new instance of IPersistStream from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getClassID() Pointer<GUID>
Retrieves the class identifier (CLSID) of the object.
inherited
getSizeMax() int
Retrieves the size of the stream needed to save the object.
isDirty() HRESULT
Determines whether an object has changed since it was last saved to its stream.
load(IStream? pStm) → void
Initializes an object from the stream where it was saved previously.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
save(IStream? pStm, bool fClearDirty) → void
Saves an object to the specified stream.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited