IPortableDeviceValuesCollection class com

Holds a collection of zero-based indexed IPortableDeviceValues interfaces.

To learn more, see learn.microsoft.com/windows/win32/wpd_sdk/iportabledevicevaluescollection.

Inheritance
Implemented types

Constructors

IPortableDeviceValuesCollection(VTablePointer ptr)
Creates a new instance of IPortableDeviceValuesCollection from a VTablePointer.
IPortableDeviceValuesCollection.from(IUnknown interface)
Creates a new instance of IPortableDeviceValuesCollection from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(IPortableDeviceValues? pValues) → void
IPortableDeviceValuesCollection::Add method - The Add method adds an item to the collection.
addRef() int
Increments the reference count of this COM object.
inherited
clear() → void
Releases all items from the collection.
getAt(int dwIndex) IPortableDeviceValues?
IPortableDeviceValuesCollection::GetAt method - The GetAt method retrieves an item from the collection by a zero-based index.
getCount(Pointer<Uint32> pcElems) → void
IPortableDeviceValuesCollection::GetCount method - The GetCount method retrieves the number of items in the collection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
removeAt(int dwIndex) → void
IPortableDeviceValuesCollection::RemoveAt method - The RemoveAt method removes the element stored at the location specified by the given index.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited