IShellFolder class com

Exposed by all Shell namespace folder objects, its methods are used to manage folders.

To learn more, see learn.microsoft.com/windows/win32/api/shobjidl_core/nn-shobjidl_core-ishellfolder.

Inheritance
Implemented types

Constructors

IShellFolder(VTablePointer ptr)
Creates a new instance of IShellFolder from a VTablePointer.
IShellFolder.from(IUnknown interface)
Creates a new instance of IShellFolder from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
bindToObject<T extends IUnknown>(Pointer<ITEMIDLIST> pidl, IBindCtx? pbc) → T
Retrieves a handler, typically the Shell folder object that implements IShellFolder for a particular item.
bindToStorage<T extends IUnknown>(Pointer<ITEMIDLIST> pidl, IBindCtx? pbc) → T
Requests a pointer to an object's storage interface.
compareIDs(LPARAM lParam, Pointer<ITEMIDLIST> pidl1, Pointer<ITEMIDLIST> pidl2) HRESULT
Determines the relative order of two file objects or folders, given their item identifier lists.
createViewObject<T extends IUnknown>(HWND hwndOwner) → T
Requests an object that can be used to obtain information from or interact with a folder object.
enumObjects(HWND hwnd, int grfFlags, Pointer<VTablePointer> ppenumIDList) HRESULT
Enables a client to determine the contents of a folder by creating an item identifier enumeration object and returning its IEnumIDList interface.
getAttributesOf(int cidl, Pointer<Pointer<ITEMIDLIST>> apidl, Pointer<Uint32> rgfInOut) → void
Gets the attributes of one or more file or folder objects contained in the object represented by IShellFolder.
getDisplayNameOf(Pointer<ITEMIDLIST> pidl, SHGDNF uFlags) Pointer<STRRET>
Retrieves the display name for the specified file object or subfolder.
getUIObjectOf<T extends IUnknown>(HWND hwndOwner, int cidl, Pointer<Pointer<ITEMIDLIST>> apidl) → T
Gets an object that can be used to carry out actions on the specified file objects or folders.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseDisplayName(HWND hwnd, IBindCtx? pbc, PCWSTR pszDisplayName, Pointer<Pointer<ITEMIDLIST>> ppidl, Pointer<Uint32> pdwAttributes) → void
Translates the display name of a file object or a folder into an item identifier list.
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
setNameOf(HWND? hwnd, Pointer<ITEMIDLIST> pidl, PCWSTR pszName, SHGDNF uFlags, Pointer<Pointer<ITEMIDLIST>>? ppidlOut) → void
Sets the display name of a file object or subfolder, changing the item identifier in the process.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited