IShellItem class com
Exposes methods that retrieve information about a Shell item.
IShellItem and IShellItem2 are the preferred representations of items in any new code.
To learn more, see learn.microsoft.com/windows/win32/api/shobjidl_core/nn-shobjidl_core-ishellitem.
- Inheritance
- Implemented types
- Implementers
Constructors
- IShellItem(VTablePointer ptr)
- Creates a new instance of IShellItem from a VTablePointer.
- IShellItem.from(IUnknown interface)
-
Creates a new instance of IShellItem from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
bindToHandler<
T extends IUnknown> (IBindCtx? pbc, Pointer< GUID> bhid) → T - Binds to a handler for an item as specified by the handler ID value (BHID).
-
compare(
IShellItem? psi, int hint) → int - Compares two IShellItem objects.
-
getAttributes(
SFGAO_FLAGS sfgaoMask) → SFGAO_FLAGS - Gets a requested set of attributes of the IShellItem object.
-
getDisplayName(
SIGDN sigdnName) → PWSTR - Gets the display name of the IShellItem object.
-
getParent(
) → IShellItem? - Gets the parent of an IShellItem object.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited