IShellLinkDataList class com

Exposes methods that allow an application to attach extra data blocks to a Shell link.

These methods add, copy, or remove data blocks.

To learn more, see learn.microsoft.com/windows/win32/api/shobjidl_core/nn-shobjidl_core-ishelllinkdatalist.

Inheritance
Implemented types

Constructors

IShellLinkDataList(VTablePointer ptr)
Creates a new instance of IShellLinkDataList from a VTablePointer.
IShellLinkDataList.from(IUnknown interface)
Creates a new instance of IShellLinkDataList from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addDataBlock(Pointer<NativeType> pDataBlock) → void
Adds a data block to a link.
addRef() int
Increments the reference count of this COM object.
inherited
copyDataBlock(int dwSig, Pointer<Pointer<NativeType>> ppDataBlock) → void
Retrieves a copy of a link's data block.
getFlags() int
Gets the current option settings.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
removeDataBlock(int dwSig) → void
Removes a data block from a link.
setFlags(int dwFlags) → void
Sets the current option settings.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited