IShellService class com

Exposes one method that declares ownership when a service component implementing a certain interface is shared among multiple clients, such as Windows Internet Explorer and Windows Explorer.

To learn more, see learn.microsoft.com/windows/win32/api/shdeprecated/nn-shdeprecated-ishellservice.

Inheritance
Implemented types

Constructors

IShellService(VTablePointer ptr)
Creates a new instance of IShellService from a VTablePointer.
IShellService.from(IUnknown interface)
Creates a new instance of IShellService from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
setOwner(IUnknown? punkOwner) → void
Declares an owner reference to the service object.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited