ISimpleAudioVolume class com

Enables a client to control the master volume level of an audio session.

To learn more, see learn.microsoft.com/windows/win32/api/audioclient/nn-audioclient-isimpleaudiovolume.

Inheritance
Implemented types

Constructors

ISimpleAudioVolume(VTablePointer ptr)
Creates a new instance of ISimpleAudioVolume from a VTablePointer.
ISimpleAudioVolume.from(IUnknown interface)
Creates a new instance of ISimpleAudioVolume from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getMasterVolume() double
Retrieves the client volume level for the audio session.
getMute() bool
Retrieves the current muting state for the audio session.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
setMasterVolume(double fLevel, Pointer<GUID> eventContext) → void
Sets the master volume level for the audio session.
setMute(bool bMute, Pointer<GUID> eventContext) → void
Sets the muting state for the audio session.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited