ISpNotifySource class com

Provides a mechanism for a notification but no information on the events that caused the notification.

To learn more, see learn.microsoft.com/previous-versions/windows/desktop/ms717961(v=vs.85).

Inheritance
Implemented types
Implementers

Constructors

ISpNotifySource(VTablePointer ptr)
Creates a new instance of ISpNotifySource from a VTablePointer.
ISpNotifySource.from(IUnknown interface)
Creates a new instance of ISpNotifySource from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getNotifyEventHandle() HANDLE
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
setNotifyCallbackFunction(Pointer<Pointer<NativeFunction<SPNOTIFYCALLBACK>>> pfnCallback, WPARAM wParam, LPARAM lParam) → void
Throws a WindowsException on failure.
setNotifyCallbackInterface(ISpNotifyCallback? pSpCallback, WPARAM wParam, LPARAM lParam) → void
Throws a WindowsException on failure.
setNotifySink(ISpNotifySink? pNotifySink) → void
Throws a WindowsException on failure.
setNotifyWin32Event() → void
Throws a WindowsException on failure.
setNotifyWindowMessage(HWND hWnd, int msg, WPARAM wParam, LPARAM lParam) → void
Throws a WindowsException on failure.
toString() String
A string representation of this object.
override
waitForNotifyEvent(int dwMilliseconds) → void
Throws a WindowsException on failure.

Operators

operator ==(Object other) bool
The equality operator.
inherited