ISpVoice class com

Enables an application to perform text synthesis operations.

To learn more, see learn.microsoft.com/previous-versions/windows/desktop/ms719576(v=vs.85).

Inheritance
Implemented types

Constructors

ISpVoice(VTablePointer ptr)
Creates a new instance of ISpVoice from a VTablePointer.
ISpVoice.from(IUnknown interface)
Creates a new instance of ISpVoice from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
displayUI(HWND hwndParent, PCWSTR pszTitle, PCWSTR pszTypeOfUI, Pointer<NativeType> pvExtraData, int cbExtraData) → void
Throws a WindowsException on failure.
getAlertBoundary(Pointer<Int32> peBoundary) → void
Throws a WindowsException on failure.
getEvents(int ulCount, Pointer<SPEVENT> pEventArray, Pointer<Uint32> pulFetched) → void
Throws a WindowsException on failure.
inherited
getInfo(Pointer<SPEVENTSOURCEINFO> pInfo) → void
Throws a WindowsException on failure.
inherited
getNotifyEventHandle() HANDLE
inherited
getOutputObjectToken() ISpObjectToken?
Throws a WindowsException on failure.
getOutputStream() ISpStreamFormat?
Throws a WindowsException on failure.
getPriority(Pointer<Int32> pePriority) → void
Throws a WindowsException on failure.
getRate(Pointer<Int32> pRateAdjust) → void
Throws a WindowsException on failure.
getStatus(Pointer<SPVOICESTATUS> pStatus, Pointer<Pointer<Utf16>> ppszLastBookmark) → void
Throws a WindowsException on failure.
getSyncSpeakTimeout(Pointer<Uint32> pmsTimeout) → void
Throws a WindowsException on failure.
getVoice() ISpObjectToken?
Throws a WindowsException on failure.
getVolume(Pointer<Uint16> pusVolume) → void
Throws a WindowsException on failure.
isUISupported(PCWSTR pszTypeOfUI, Pointer<NativeType> pvExtraData, int cbExtraData, Pointer<Int32> pfSupported) → void
Throws a WindowsException on failure.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
Throws a WindowsException on failure.
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
resume() → void
Throws a WindowsException on failure.
setAlertBoundary(SPEVENTENUM eBoundary) → void
Throws a WindowsException on failure.
setInterest(int ullEventInterest, int ullQueuedInterest) → void
Throws a WindowsException on failure.
inherited
setNotifyCallbackFunction(Pointer<Pointer<NativeFunction<SPNOTIFYCALLBACK>>> pfnCallback, WPARAM wParam, LPARAM lParam) → void
Throws a WindowsException on failure.
inherited
setNotifyCallbackInterface(ISpNotifyCallback? pSpCallback, WPARAM wParam, LPARAM lParam) → void
Throws a WindowsException on failure.
inherited
setNotifySink(ISpNotifySink? pNotifySink) → void
Throws a WindowsException on failure.
inherited
setNotifyWin32Event() → void
Throws a WindowsException on failure.
inherited
setNotifyWindowMessage(HWND hWnd, int msg, WPARAM wParam, LPARAM lParam) → void
Throws a WindowsException on failure.
inherited
setOutput(IUnknown? pUnkOutput, bool fAllowFormatChanges) → void
Throws a WindowsException on failure.
setPriority(SPVPRIORITY ePriority) → void
Throws a WindowsException on failure.
setRate(int rateAdjust) → void
Throws a WindowsException on failure.
setSyncSpeakTimeout(int msTimeout) → void
Throws a WindowsException on failure.
setVoice(ISpObjectToken? pToken) → void
Throws a WindowsException on failure.
setVolume(int usVolume) → void
Throws a WindowsException on failure.
skip(PCWSTR pItemType, int lNumItems, Pointer<Uint32> pulNumSkipped) → void
Throws a WindowsException on failure.
speak(PCWSTR? pwcs, int dwFlags, Pointer<Uint32>? pulStreamNumber) → void
Throws a WindowsException on failure.
speakCompleteEvent() HANDLE
speakStream(IStream? pStream, int dwFlags, Pointer<Uint32>? pulStreamNumber) → void
Throws a WindowsException on failure.
toString() String
A string representation of this object.
override
waitForNotifyEvent(int dwMilliseconds) → void
Throws a WindowsException on failure.
inherited
waitUntilDone(int msTimeout) → void
Throws a WindowsException on failure.

Operators

operator ==(Object other) bool
The equality operator.
inherited