ISpeechAudioFormat class com

Inheritance
Implemented types

Constructors

ISpeechAudioFormat(VTablePointer ptr)
Creates a new instance of ISpeechAudioFormat from a VTablePointer.
ISpeechAudioFormat.from(IUnknown interface)
Creates a new instance of ISpeechAudioFormat from an existing interface.
factory

Properties

guid BSTR
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type SpeechAudioFormatType
getter/setter pair

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getIDsOfNames(Pointer<GUID> riid, Pointer<Pointer<Utf16>> rgszNames, int cNames, int lcid, Pointer<Int32> rgDispId) → void
Maps a single member and an optional set of argument names to a corresponding set of integer DISPIDs, which can be used on subsequent calls to Invoke.
inherited
getTypeInfo(int iTInfo, int lcid) ITypeInfo?
Retrieves the type information for an object, which can then be used to get the type information for an interface.
inherited
getTypeInfoCount() int
Retrieves the number of type information interfaces that an object provides (either 0 or 1).
inherited
getWaveFormatEx() ISpeechWaveFormatEx?
Throws a WindowsException on failure.
invoke(int dispIdMember, Pointer<GUID> riid, int lcid, DISPATCH_FLAGS wFlags, Pointer<DISPPARAMS> pDispParams, Pointer<VARIANT>? pVarResult, Pointer<EXCEPINFO>? pExcepInfo, Pointer<Uint32>? puArgErr) → void
Provides access to properties and methods exposed by an object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
setWaveFormatEx(ISpeechWaveFormatEx? speechWaveFormatEx) → void
Throws a WindowsException on failure.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited