ISpeechDataKey class com

Inheritance
Implemented types

Constructors

ISpeechDataKey(VTablePointer ptr)
Creates a new instance of ISpeechDataKey from a VTablePointer.
ISpeechDataKey.from(IUnknown interface)
Creates a new instance of ISpeechDataKey from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
createKey(BSTR subKeyName) ISpeechDataKey?
Throws a WindowsException on failure.
deleteKey(BSTR subKeyName) → void
Throws a WindowsException on failure.
deleteValue(BSTR valueName) → void
Throws a WindowsException on failure.
enumKeys(int index) BSTR
Throws a WindowsException on failure.
enumValues(int index) BSTR
Throws a WindowsException on failure.
getBinaryValue(BSTR valueName) Pointer<VARIANT>
Throws a WindowsException on failure.
getIDsOfNames(Pointer<GUID> riid, Pointer<Pointer<Utf16>> rgszNames, int cNames, int lcid, Pointer<Int32> rgDispId) → void
Maps a single member and an optional set of argument names to a corresponding set of integer DISPIDs, which can be used on subsequent calls to Invoke.
inherited
getLongValue(BSTR valueName) int
Throws a WindowsException on failure.
getStringValue(BSTR valueName) BSTR
Throws a WindowsException on failure.
getTypeInfo(int iTInfo, int lcid) ITypeInfo?
Retrieves the type information for an object, which can then be used to get the type information for an interface.
inherited
getTypeInfoCount() int
Retrieves the number of type information interfaces that an object provides (either 0 or 1).
inherited
invoke(int dispIdMember, Pointer<GUID> riid, int lcid, DISPATCH_FLAGS wFlags, Pointer<DISPPARAMS> pDispParams, Pointer<VARIANT>? pVarResult, Pointer<EXCEPINFO>? pExcepInfo, Pointer<Uint32>? puArgErr) → void
Provides access to properties and methods exposed by an object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openKey(BSTR subKeyName) ISpeechDataKey?
Throws a WindowsException on failure.
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
setBinaryValue(BSTR valueName, VARIANT value) → void
Throws a WindowsException on failure.
setLongValue(BSTR valueName, int value) → void
Throws a WindowsException on failure.
setStringValue(BSTR valueName, BSTR value) → void
Throws a WindowsException on failure.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited