ISpeechVoice class com

Inheritance
Implemented types

Constructors

ISpeechVoice(VTablePointer ptr)
Creates a new instance of ISpeechVoice from a VTablePointer.
ISpeechVoice.from(IUnknown interface)
Creates a new instance of ISpeechVoice from an existing interface.
factory

Properties

alertBoundary SpeechVoiceEvents
getter/setter pair
allowAudioOutputFormatChangesOnNextSet bool
getter/setter pair
audioOutput ISpeechObjectToken?
no setter
audioOutputStream ISpeechBaseStream?
no setter
eventInterests SpeechVoiceEvents
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
priority SpeechVoicePriority
getter/setter pair
ptr VTablePointer
finalinherited
rate int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ISpeechVoiceStatus?
no setter
synchronousSpeakTimeout int
getter/setter pair
voice ISpeechObjectToken?
no setter
volume int
getter/setter pair

Methods

addRef() int
Increments the reference count of this COM object.
inherited
displayUI(int hWndParent, BSTR title, BSTR typeOfUI, Pointer<VARIANT> extraData) → void
Throws a WindowsException on failure.
getAudioOutputs(BSTR requiredAttributes, BSTR optionalAttributes) ISpeechObjectTokens?
Throws a WindowsException on failure.
getIDsOfNames(Pointer<GUID> riid, Pointer<Pointer<Utf16>> rgszNames, int cNames, int lcid, Pointer<Int32> rgDispId) → void
Maps a single member and an optional set of argument names to a corresponding set of integer DISPIDs, which can be used on subsequent calls to Invoke.
inherited
getTypeInfo(int iTInfo, int lcid) ITypeInfo?
Retrieves the type information for an object, which can then be used to get the type information for an interface.
inherited
getTypeInfoCount() int
Retrieves the number of type information interfaces that an object provides (either 0 or 1).
inherited
getVoices(BSTR requiredAttributes, BSTR optionalAttributes) ISpeechObjectTokens?
Throws a WindowsException on failure.
invoke(int dispIdMember, Pointer<GUID> riid, int lcid, DISPATCH_FLAGS wFlags, Pointer<DISPPARAMS> pDispParams, Pointer<VARIANT>? pVarResult, Pointer<EXCEPINFO>? pExcepInfo, Pointer<Uint32>? puArgErr) → void
Provides access to properties and methods exposed by an object.
inherited
isUISupported(BSTR typeOfUI, Pointer<VARIANT> extraData) bool
Throws a WindowsException on failure.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
Throws a WindowsException on failure.
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
resume() → void
Throws a WindowsException on failure.
setAudioOutput(ISpeechObjectToken? audioOutput) → void
Throws a WindowsException on failure.
setAudioOutputStream(ISpeechBaseStream? audioOutputStream) → void
Throws a WindowsException on failure.
setVoice(ISpeechObjectToken? voice) → void
Throws a WindowsException on failure.
skip(BSTR type, int numItems) int
Throws a WindowsException on failure.
speak(BSTR text, SpeechVoiceSpeakFlags flags) int
Throws a WindowsException on failure.
speakCompleteEvent() int
Throws a WindowsException on failure.
speakStream(ISpeechBaseStream? stream, SpeechVoiceSpeakFlags flags) int
Throws a WindowsException on failure.
toString() String
A string representation of this object.
override
waitUntilDone(int msTimeout) bool
Throws a WindowsException on failure.

Operators

operator ==(Object other) bool
The equality operator.
inherited