ISpellCheckerChangedEventHandler class com
Allows the caller to create a handler for notifications that the state of the speller has changed.
To learn more, see learn.microsoft.com/windows/win32/api/spellcheck/nn-spellcheck-ispellcheckerchangedeventhandler.
- Inheritance
- Implemented types
Constructors
- ISpellCheckerChangedEventHandler(VTablePointer ptr)
- Creates a new instance of ISpellCheckerChangedEventHandler from a VTablePointer.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
invoke(
ISpellChecker? sender) → void - Receives the SpellCheckerChanged event.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited