IStream class com

Lets you read and write data to stream objects.

To learn more, see learn.microsoft.com/windows/win32/api/objidl/nn-objidl-istream.

Inheritance
Implemented types
Implementers

Constructors

IStream(VTablePointer ptr)
Creates a new instance of IStream from a VTablePointer.
IStream.from(IUnknown interface)
Creates a new instance of IStream from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
clone() IStream?
Creates a new stream object with its own seek pointer that references the same bytes as the original stream.
commit(STGC grfCommitFlags) → void
Ensures that any changes made to a stream object open in transacted mode are reflected in the parent storage.
copyTo(IStream? pstm, int cb, Pointer<Uint64>? pcbRead, Pointer<Uint64>? pcbWritten) → void
Copies a specified number of bytes from the current seek pointer in the stream to the current seek pointer in another stream.
lockRegion(int libOffset, int cb, LOCKTYPE dwLockType) → void
Restricts access to a specified range of bytes in the stream.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
read(Pointer<NativeType> pv, int cb, Pointer<Uint32>? pcbRead) HRESULT
Reads a specified number of bytes from the stream object into memory, starting at the current seek pointer.
inherited
release() int
Decrements the reference count of this COM object.
inherited
revert() → void
Discards all changes that have been made to a transacted stream since the last IStream.commit call.
seek(int dlibMove, STREAM_SEEK dwOrigin, Pointer<Uint64>? plibNewPosition) → void
Changes the seek pointer to a new location.
setSize(int libNewSize) → void
Changes the size of the stream object.
stat(Pointer<STATSTG> pstatstg, STATFLAG grfStatFlag) → void
Retrieves the STATSTG structure for this stream.
toString() String
A string representation of this object.
override
unlockRegion(int libOffset, int cb, int dwLockType) → void
Removes the access restriction on a range of bytes previously restricted with IStream.lockRegion.
write(Pointer<NativeType> pv, int cb, Pointer<Uint32>? pcbWritten) HRESULT
Writes a specified number of bytes into the stream object starting at the current seek pointer.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited