seek method

void seek(
  1. int dlibMove,
  2. STREAM_SEEK dwOrigin,
  3. Pointer<Uint64>? plibNewPosition
)

Changes the seek pointer to a new location.

The new location is relative to either the beginning of the stream, the end of the stream, or the current seek pointer.

Throws a WindowsException on failure.

To learn more, see learn.microsoft.com/windows/win32/api/objidl/nf-objidl-istream-seek.

Implementation

@pragma('vm:prefer-inline')
void seek(
  int dlibMove,
  STREAM_SEEK dwOrigin,
  Pointer<Uint64>? plibNewPosition,
) {
  final hr$ = HRESULT(
    _SeekFn(ptr, dlibMove, dwOrigin, plibNewPosition ?? nullptr),
  );
  if (hr$.isError) throw WindowsException(hr$);
}