ITypeLib class com

Represents a type library, the data that describes a set of objects.

To learn more, see learn.microsoft.com/windows/win32/api/oaidl/nn-oaidl-itypelib.

Inheritance
Implemented types

Constructors

ITypeLib(VTablePointer ptr)
Creates a new instance of ITypeLib from a VTablePointer.
ITypeLib.from(IUnknown interface)
Creates a new instance of ITypeLib from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
findName(PWSTR szNameBuf, int lHashVal, Pointer<VTablePointer> ppTInfo, Pointer<Int32> rgMemId, Pointer<Uint16> pcFound) → void
Finds occurrences of a type description in a type library.
getDocumentation(int index, Pointer<Pointer<Utf16>>? pBstrName, Pointer<Pointer<Utf16>>? pBstrDocString, Pointer<Uint32> pdwHelpContext, Pointer<Pointer<Utf16>>? pBstrHelpFile) → void
Retrieves the documentation string for the library, the complete Help file name and path, and the context identifier for the library Help topic in the Help file.
getLibAttr() Pointer<TLIBATTR>
Retrieves the structure that contains the library's attributes.
getTypeComp() ITypeComp?
Enables a client compiler to bind to the types, variables, constants, and global functions for a library.
getTypeInfo(int index) ITypeInfo?
Retrieves the specified type description in the library.
getTypeInfoCount() int
Provides the number of type descriptions that are in a type library.
getTypeInfoOfGuid(Pointer<GUID> guid) ITypeInfo?
Retrieves the type description that corresponds to the specified GUID.
getTypeInfoType(int index) TYPEKIND
Retrieves the type of a type description.
isName(PWSTR szNameBuf, int lHashVal, Pointer<Int32> pfName) → void
Indicates whether a passed-in string contains the name of a type or member described in the library.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
releaseTLibAttr(Pointer<TLIBATTR> pTLibAttr) → void
Releases the TLIBATTR originally obtained from GetLibAttr.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited