IUIAutomation6 class com

Extends the IUIAutomation5 interface to expose additional methods for controlling Microsoft UI Automation functionality.

To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomation6.

Inheritance
Implemented types

Constructors

IUIAutomation6(VTablePointer ptr)
Creates a new instance of IUIAutomation6 from a VTablePointer.
IUIAutomation6.from(IUnknown interface)
Creates a new instance of IUIAutomation6 from an existing interface.
factory

Properties

autoSetFocus bool
Specifies whether calls to UI Automation control pattern methods automatically set focus to the target element.
getter/setter pairinherited
coalesceEvents CoalesceEventsOptions
Gets or sets whether an accessible technology client receives all events, or a subset where duplicate events are detected and filtered.
getter/setter pair
connectionRecoveryBehavior ConnectionRecoveryBehaviorOptions
Indicates whether an accessible technology client adjusts provider request timeouts when the provider is non-responsive.
getter/setter pair
connectionTimeout int
Specifies the length of time that UI Automation will wait for a provider to respond to a client request for an automation element.
getter/setter pairinherited
contentViewCondition IUIAutomationCondition?
Retrieves a predefined IUIAutomationCondition interface that selects content elements.
no setterinherited
contentViewWalker IUIAutomationTreeWalker?
Retrieves an IUIAutomationTreeWalker interface used to discover content elements.
no setterinherited
controlViewCondition IUIAutomationCondition?
Retrieves a predefined IUIAutomationCondition interface that selects control elements.
no setterinherited
controlViewWalker IUIAutomationTreeWalker?
Retrieves an IUIAutomationTreeWalker interface used to discover control elements.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
proxyFactoryMapping IUIAutomationProxyFactoryMapping?
Retrieves an object that represents the mapping of Window classnames and associated data to individual proxy factories.
no setterinherited
ptr VTablePointer
finalinherited
rawViewCondition IUIAutomationCondition?
Retrieves a predefined IUIAutomationCondition interface that selects all UI elements in an unfiltered view.
no setterinherited
rawViewWalker IUIAutomationTreeWalker?
Retrieves a tree walker object used to traverse an unfiltered view of the Microsoft UI Automation tree.
no setterinherited
reservedMixedAttributeValue IUnknown?
Retrieves a static token object representing a text attribute that is a mixed attribute.
no setterinherited
reservedNotSupportedValue IUnknown?
Retrieves a static token object representing a property or text attribute that is not supported.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionTimeout int
Specifies the length of time that UI Automation will wait for a provider to respond to a client request for information about an automation element.
getter/setter pairinherited

Methods

addActiveTextPositionChangedEventHandler(IUIAutomationElement? element, TreeScope scope, IUIAutomationCacheRequest? cacheRequest, IUIAutomationActiveTextPositionChangedEventHandler? handler) → void
Registers a method that handles when the active text position changes.
addAutomationEventHandler(UIA_EVENT_ID eventId, IUIAutomationElement? element, TreeScope scope, IUIAutomationCacheRequest? cacheRequest, IUIAutomationEventHandler? handler) → void
Registers a method that handles Microsoft UI Automation events.
inherited
addChangesEventHandler(IUIAutomationElement? element, TreeScope scope, Pointer<Int32> changeTypes, int changesCount, IUIAutomationCacheRequest? pCacheRequest, IUIAutomationChangesEventHandler? handler) → void
Registers a method that handles change events.
inherited
addEventHandlerGroup(IUIAutomationElement? element, IUIAutomationEventHandlerGroup? handlerGroup) → void
Registers a collection of event handler methods specified with the CreateEventHandlerGroup.
addFocusChangedEventHandler(IUIAutomationCacheRequest? cacheRequest, IUIAutomationFocusChangedEventHandler? handler) → void
Registers a method that handles focus-changed events.
inherited
addNotificationEventHandler(IUIAutomationElement? element, TreeScope scope, IUIAutomationCacheRequest? cacheRequest, IUIAutomationNotificationEventHandler? handler) → void
Registers a method that handles notification events.
inherited
addPropertyChangedEventHandler(IUIAutomationElement? element, TreeScope scope, IUIAutomationCacheRequest? cacheRequest, IUIAutomationPropertyChangedEventHandler? handler, Pointer<SAFEARRAY> propertyArray) → void
Registers a method that handles and array of property-changed events.
inherited
addPropertyChangedEventHandlerNativeArray(IUIAutomationElement? element, TreeScope scope, IUIAutomationCacheRequest? cacheRequest, IUIAutomationPropertyChangedEventHandler? handler, Pointer<Int32> propertyArray, int propertyCount) → void
Registers a method that handles a native array of property-changed events.
inherited
addRef() int
Increments the reference count of this COM object.
inherited
addStructureChangedEventHandler(IUIAutomationElement? element, TreeScope scope, IUIAutomationCacheRequest? cacheRequest, IUIAutomationStructureChangedEventHandler? handler) → void
Registers a method that handles structure-changed events.
inherited
addTextEditTextChangedEventHandler(IUIAutomationElement? element, TreeScope scope, TextEditChangeType textEditChangeType, IUIAutomationCacheRequest? cacheRequest, IUIAutomationTextEditTextChangedEventHandler? handler) → void
Registers a method that handles programmatic text-edit events.
inherited
checkNotSupported(VARIANT value) bool
Checks a provided VARIANT to see if it contains the Not Supported identifier.
inherited
compareElements(IUIAutomationElement? el1, IUIAutomationElement? el2) bool
Compares two UI Automation elements to determine whether they represent the same underlying UI element.
inherited
compareRuntimeIds(Pointer<SAFEARRAY> runtimeId1, Pointer<SAFEARRAY> runtimeId2) bool
Compares two integer arrays containing run-time identifiers (IDs) to determine whether their content is the same and they belong to the same UI element.
inherited
createAndCondition(IUIAutomationCondition? condition1, IUIAutomationCondition? condition2) IUIAutomationCondition?
Creates a condition that selects elements that match both of two conditions.
inherited
createAndConditionFromArray(Pointer<SAFEARRAY> conditions) IUIAutomationCondition?
Creates a condition that selects elements based on multiple conditions, all of which must be true.
inherited
createAndConditionFromNativeArray(Pointer<VTablePointer> conditions, int conditionCount) IUIAutomationCondition?
Creates a condition that selects elements from a native array, based on multiple conditions that must all be true.
inherited
createCacheRequest() IUIAutomationCacheRequest?
Creates a cache request.
inherited
createEventHandlerGroup() IUIAutomationEventHandlerGroup?
Registers one or more event listeners in a single method call.
createFalseCondition() IUIAutomationCondition?
Creates a condition that is always false.
inherited
createNotCondition(IUIAutomationCondition? condition) IUIAutomationCondition?
Creates a condition that is the negative of a specified condition.
inherited
createOrCondition(IUIAutomationCondition? condition1, IUIAutomationCondition? condition2) IUIAutomationCondition?
Creates a combination of two conditions where a match exists if either of the conditions is true.
inherited
createOrConditionFromArray(Pointer<SAFEARRAY> conditions) IUIAutomationCondition?
Creates a combination of two or more conditions where a match exists if any of the conditions is true.
inherited
createOrConditionFromNativeArray(Pointer<VTablePointer> conditions, int conditionCount) IUIAutomationCondition?
Creates a combination of two or more conditions where a match exists if any one of the conditions is true.
inherited
createPropertyCondition(UIA_PROPERTY_ID propertyId, VARIANT value) IUIAutomationCondition?
Creates a condition that selects elements that have a property with the specified value.
inherited
createPropertyConditionEx(UIA_PROPERTY_ID propertyId, VARIANT value, PropertyConditionFlags flags) IUIAutomationCondition?
Creates a condition that selects elements that have a property with the specified value, using optional flags.
inherited
createProxyFactoryEntry(IUIAutomationProxyFactory? factory) IUIAutomationProxyFactoryEntry?
Creates a new instance of a proxy factory object.
inherited
createTreeWalker(IUIAutomationCondition? pCondition) IUIAutomationTreeWalker?
Retrieves a tree walker object that can be used to traverse the Microsoft UI Automation tree.
inherited
createTrueCondition() IUIAutomationCondition?
Retrieves a predefined condition that selects all elements.
inherited
elementFromHandle(HWND hwnd) IUIAutomationElement?
Retrieves a UI Automation element for the specified window.
inherited
elementFromHandleBuildCache(HWND hwnd, IUIAutomationCacheRequest? cacheRequest) IUIAutomationElement?
Retrieves a UI Automation element for the specified window, prefetches the requested properties and control patterns, and stores the prefetched items in the cache.
inherited
elementFromIAccessible(IAccessible? accessible, int childId) IUIAutomationElement?
Retrieves a UI Automation element for the specified accessible object from a Microsoft Active Accessibility server.
inherited
elementFromIAccessibleBuildCache(IAccessible? accessible, int childId, IUIAutomationCacheRequest? cacheRequest) IUIAutomationElement?
Retrieves a UI Automation element for the specified accessible object from a Microsoft Active Accessibility server, prefetches the requested properties and control patterns, and stores the prefetched items in the cache.
inherited
elementFromPoint(POINT pt) IUIAutomationElement?
Retrieves the UI Automation element at the specified point on the desktop.
inherited
elementFromPointBuildCache(POINT pt, IUIAutomationCacheRequest? cacheRequest) IUIAutomationElement?
Retrieves the UI Automation element at the specified point on the desktop, prefetches the requested properties and control patterns, and stores the prefetched items in the cache.
inherited
getFocusedElement() IUIAutomationElement?
Retrieves the UI Automation element that has the input focus.
inherited
getFocusedElementBuildCache(IUIAutomationCacheRequest? cacheRequest) IUIAutomationElement?
Retrieves the UI Automation element that has the input focus, prefetches the requested properties and control patterns, and stores the prefetched items in the cache.
inherited
getPatternProgrammaticName(UIA_PATTERN_ID pattern) BSTR
Retrieves the registered programmatic name of a control pattern.
inherited
getPropertyProgrammaticName(UIA_PROPERTY_ID property) BSTR
Retrieves the registered programmatic name of a property.
inherited
getRootElement() IUIAutomationElement?
Retrieves the UI Automation element that represents the desktop.
inherited
getRootElementBuildCache(IUIAutomationCacheRequest? cacheRequest) IUIAutomationElement?
Retrieves the UI Automation element that represents the desktop, prefetches the requested properties and control patterns, and stores the prefetched items in the cache.
inherited
intNativeArrayToSafeArray(Pointer<Int32> array, int arrayCount) Pointer<SAFEARRAY>
Converts an array of integers to a SAFEARRAY.
inherited
intSafeArrayToNativeArray(Pointer<SAFEARRAY> intArray, Pointer<Pointer<Int32>> array, Pointer<Int32> arrayCount) → void
Converts a SAFEARRAY of integers to an array.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pollForPotentialSupportedPatterns(IUIAutomationElement? pElement, Pointer<Pointer<SAFEARRAY>> patternIds, Pointer<Pointer<SAFEARRAY>> patternNames) → void
Retrieves the control patterns that might be supported on a UI Automation element.
inherited
pollForPotentialSupportedProperties(IUIAutomationElement? pElement, Pointer<Pointer<SAFEARRAY>> propertyIds, Pointer<Pointer<SAFEARRAY>> propertyNames) → void
Retrieves the properties that might be supported on a UI Automation element.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
rectToVariant(RECT rc) Pointer<VARIANT>
Creates a VARIANT that contains the coordinates of a rectangle.
inherited
release() int
Decrements the reference count of this COM object.
inherited
removeActiveTextPositionChangedEventHandler(IUIAutomationElement? element, IUIAutomationActiveTextPositionChangedEventHandler? handler) → void
Removes an active text position changed event handler.
removeAllEventHandlers() → void
Removes all registered Microsoft UI Automation event handlers.
inherited
removeAutomationEventHandler(UIA_EVENT_ID eventId, IUIAutomationElement? element, IUIAutomationEventHandler? handler) → void
Removes the specified UI Automation event handler.
inherited
removeChangesEventHandler(IUIAutomationElement? element, IUIAutomationChangesEventHandler? handler) → void
Removes a changes event handler.
inherited
removeEventHandlerGroup(IUIAutomationElement? element, IUIAutomationEventHandlerGroup? handlerGroup) → void
Asynchronously removes the specified UI Automation event handler group.
removeFocusChangedEventHandler(IUIAutomationFocusChangedEventHandler? handler) → void
Removes a focus-changed event handler.
inherited
removeNotificationEventHandler(IUIAutomationElement? element, IUIAutomationNotificationEventHandler? handler) → void
Removes a notification event handler.
inherited
removePropertyChangedEventHandler(IUIAutomationElement? element, IUIAutomationPropertyChangedEventHandler? handler) → void
Removes a property-changed event handler.
inherited
removeStructureChangedEventHandler(IUIAutomationElement? element, IUIAutomationStructureChangedEventHandler? handler) → void
Removes a structure-changed event handler.
inherited
removeTextEditTextChangedEventHandler(IUIAutomationElement? element, IUIAutomationTextEditTextChangedEventHandler? handler) → void
Removes a programmatic text-edit event handler.
inherited
safeArrayToRectNativeArray(Pointer<SAFEARRAY> rects, Pointer<Pointer<RECT>> rectArray, Pointer<Int32> rectArrayCount) → void
Converts a SAFEARRAY containing rectangle coordinates to an array of type RECT.
inherited
toString() String
A string representation of this object.
override
variantToRect(VARIANT var$) Pointer<RECT>
Converts a VARIANT containing rectangle coordinates to a RECT.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited