IUIAutomationExpandCollapsePattern class com

Provides access to a control that can visually expand to display content, and collapse to hide content.

To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationexpandcollapsepattern.

Inheritance
Implemented types

Constructors

IUIAutomationExpandCollapsePattern(VTablePointer ptr)
Creates a new instance of IUIAutomationExpandCollapsePattern from a VTablePointer.
IUIAutomationExpandCollapsePattern.from(IUnknown interface)
Creates a new instance of IUIAutomationExpandCollapsePattern from an existing interface.
factory

Properties

cachedExpandCollapseState ExpandCollapseState
Retrieves a cached value that indicates the state, expanded or collapsed, of the element.
no setter
currentExpandCollapseState ExpandCollapseState
Retrieves a value that indicates the state, expanded or collapsed, of the element.
no setter
hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
collapse() → void
Hides all child nodes, controls, or content of the element.
expand() → void
Displays all child nodes, controls, or content of the element.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited