IUIAutomationItemContainerPattern class com
Exposes a method that retrieves an item from a container, such as a virtual list.
To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationitemcontainerpattern.
- Inheritance
- Implemented types
Constructors
- IUIAutomationItemContainerPattern(VTablePointer ptr)
- Creates a new instance of IUIAutomationItemContainerPattern from a VTablePointer.
- IUIAutomationItemContainerPattern.from(IUnknown interface)
-
Creates a new instance of IUIAutomationItemContainerPattern from an
existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
findItemByProperty(
IUIAutomationElement? pStartAfter, UIA_PROPERTY_ID propertyId, VARIANT value) → IUIAutomationElement? - Retrieves an element within a containing element, based on a specified property value.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited