IUIAutomationProxyFactory class com

Exposes properties and methods of an object that creates a Microsoft UI Automation provider for UI elements that do not have native support for UI Automation.

This interface is implemented by proxies.

To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationproxyfactory.

Inheritance
Implemented types

Constructors

IUIAutomationProxyFactory(VTablePointer ptr)
Creates a new instance of IUIAutomationProxyFactory from a VTablePointer.
IUIAutomationProxyFactory.from(IUnknown interface)
Creates a new instance of IUIAutomationProxyFactory from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
proxyFactoryId BSTR
Retrieves the identifier of the proxy factory.
no setter
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
createProvider(HWND hwnd, int idObject, int idChild) IRawElementProviderSimple?
Creates a proxy object that provides Microsoft UI Automation support for a UI element.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited