IUIAutomationProxyFactoryEntry class com

Represents a proxy factory in the table maintained by Microsoft UI Automation, and exposes properties and methods that can be used by client applications to interact with IUIAutomationProxyFactory objects.

To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationproxyfactoryentry.

Inheritance
Implemented types

Constructors

IUIAutomationProxyFactoryEntry(VTablePointer ptr)
Creates a new instance of IUIAutomationProxyFactoryEntry from a VTablePointer.
IUIAutomationProxyFactoryEntry.from(IUnknown interface)
Creates a new instance of IUIAutomationProxyFactoryEntry from an existing interface.
factory

Properties

allowSubstringMatch bool
Sets or retrieves a value that specifies whether the proxy allows substring matching.
getter/setter pair
canCheckBaseClass bool
Sets or retrieves a value that specifies whether the base class can be checked when searching for a proxy factory.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
needsAdviseEvents bool
Sets or retrieves a value that specifies whether the proxy must be notified when an application has registered for events.
getter/setter pair
proxyFactory IUIAutomationProxyFactory?
Retrieves the proxy factory associated with this entry.
no setter
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
className() BSTR
Sets or retrieves the name of the window class served by the proxy factory.
getWinEventsForAutomationEvent(UIA_EVENT_ID eventId, UIA_PROPERTY_ID propertyId) Pointer<SAFEARRAY>
Retrieves the list of WinEvents that are mapped to a specific Microsoft UI Automation event.
imageName() BSTR
Sets or retrieves the name of the image of the proxy factory.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
setClassName(PCWSTR className) → void
Sets or retrieves the name of the window class served by the proxy factory.
setImageName(PCWSTR imageName) → void
Sets or retrieves the name of the image of the proxy factory.
setWinEventsForAutomationEvent(UIA_EVENT_ID eventId, UIA_PROPERTY_ID propertyId, Pointer<SAFEARRAY> winEvents) → void
Maps Microsoft UI Automation events to WinEvents.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited