needsAdviseEvents property

bool get needsAdviseEvents

Sets or retrieves a value that specifies whether the proxy must be notified when an application has registered for events.

To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nf-uiautomationclient-iuiautomationproxyfactoryentry-get_needsadviseevents.

Implementation

bool get needsAdviseEvents {
  final adviseEvents = adaptiveCalloc<Int32>();
  final hr$ = HRESULT(_get_NeedsAdviseEventsFn(ptr, adviseEvents));
  if (hr$.isError) {
    free(adviseEvents);
    throw WindowsException(hr$);
  }
  final result$ = adviseEvents.value;
  free(adviseEvents);
  return result$ != FALSE;
}
set needsAdviseEvents (bool adviseEvents)

Implementation

set needsAdviseEvents(bool adviseEvents) {
  final hr$ = HRESULT(
    _put_NeedsAdviseEventsFn(ptr, adviseEvents ? TRUE : FALSE),
  );
  if (hr$.isError) throw WindowsException(hr$);
}