IUIAutomationScrollPattern class com

Provides access to a control that acts as a scrollable container for a collection of child elements.

To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationscrollpattern.

Inheritance
Implemented types

Constructors

IUIAutomationScrollPattern(VTablePointer ptr)
Creates a new instance of IUIAutomationScrollPattern from a VTablePointer.
IUIAutomationScrollPattern.from(IUnknown interface)
Creates a new instance of IUIAutomationScrollPattern from an existing interface.
factory

Properties

cachedHorizontallyScrollable bool
Retrieves a cached value that indicates whether the element can scroll horizontally.
no setter
cachedHorizontalScrollPercent double
Retrieves the cached horizontal scroll position.
no setter
cachedHorizontalViewSize double
Retrieves the cached horizontal size of the viewable region of a scrollable element.
no setter
cachedVerticallyScrollable bool
Retrieves a cached value that indicates whether the element can scroll vertically.
no setter
cachedVerticalScrollPercent double
Retrieves the cached vertical scroll position.
no setter
cachedVerticalViewSize double
Retrieves the cached vertical size of the viewable region of a scrollable element.
no setter
currentHorizontallyScrollable bool
Indicates whether the element can scroll horizontally.
no setter
currentHorizontalScrollPercent double
Retrieves the horizontal scroll position.
no setter
currentHorizontalViewSize double
Retrieves the horizontal size of the viewable region of a scrollable element.
no setter
currentVerticallyScrollable bool
Indicates whether the element can scroll vertically.
no setter
currentVerticalScrollPercent double
Retrieves the vertical scroll position.
no setter
currentVerticalViewSize double
Retrieves the vertical size of the viewable region of a scrollable element.
no setter
hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
scroll(ScrollAmount horizontalAmount, ScrollAmount verticalAmount) → void
Scrolls the visible region of the content area horizontally and vertically.
setScrollPercent(double horizontalPercent, double verticalPercent) → void
Sets the horizontal and vertical scroll positions as a percentage of the total content area within the UI Automation element.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited