cachedCanSelectMultiple property
bool
get
cachedCanSelectMultiple
Retrieves a cached value that indicates whether more than one item in the container can be selected at one time.
To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nf-uiautomationclient-iuiautomationselectionpattern-get_cachedcanselectmultiple.
Implementation
bool get cachedCanSelectMultiple {
final retVal = adaptiveCalloc<Int32>();
final hr$ = HRESULT(_get_CachedCanSelectMultipleFn(ptr, retVal));
if (hr$.isError) {
free(retVal);
throw WindowsException(hr$);
}
final result$ = retVal.value;
free(retVal);
return result$ != FALSE;
}