IUIAutomationTableItemPattern class com

Provides access to a child element in a container that supports IUIAutomationTablePattern.

To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationtableitempattern.

Inheritance
Implemented types

Constructors

IUIAutomationTableItemPattern(VTablePointer ptr)
Creates a new instance of IUIAutomationTableItemPattern from a VTablePointer.
IUIAutomationTableItemPattern.from(IUnknown interface)
Creates a new instance of IUIAutomationTableItemPattern from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getCachedColumnHeaderItems() IUIAutomationElementArray?
Retrieves the cached column headers associated with a table item or cell.
getCachedRowHeaderItems() IUIAutomationElementArray?
Retrieves the cached row headers associated with a table item or cell.
getCurrentColumnHeaderItems() IUIAutomationElementArray?
Retrieves the column headers associated with a table item or cell.
getCurrentRowHeaderItems() IUIAutomationElementArray?
Retrieves the row headers associated with a table item or cell.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited