IUIAutomationTextPattern class com

Provides access to a control that contains text.

To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationtextpattern.

Inheritance
Implemented types
Implementers

Constructors

IUIAutomationTextPattern(VTablePointer ptr)
Creates a new instance of IUIAutomationTextPattern from a VTablePointer.
IUIAutomationTextPattern.from(IUnknown interface)
Creates a new instance of IUIAutomationTextPattern from an existing interface.
factory

Properties

documentRange IUIAutomationTextRange?
Retrieves a text range that encloses the main text of a document.
no setter
hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedTextSelection SupportedTextSelection
Retrieves a value that specifies the type of text selection that is supported by the control.
no setter

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getSelection() IUIAutomationTextRangeArray?
Retrieves a collection of text ranges that represents the currently selected text in a text-based control.
getVisibleRanges() IUIAutomationTextRangeArray?
Retrieves an array of disjoint text ranges from a text-based control where each text range represents a contiguous span of visible text.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
rangeFromChild(IUIAutomationElement? child) IUIAutomationTextRange?
Retrieves a text range enclosing a child element such as an image, hyperlink, Microsoft Excel spreadsheet, or other embedded object.
rangeFromPoint(POINT pt) IUIAutomationTextRange?
Retrieves the degenerate (empty) text range nearest to the specified screen coordinates.
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited