IUIAutomationTextPattern2 class com

Extends the IUIAutomationTextPattern interface.

To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationtextpattern2.

Inheritance
Implemented types

Constructors

IUIAutomationTextPattern2(VTablePointer ptr)
Creates a new instance of IUIAutomationTextPattern2 from a VTablePointer.
IUIAutomationTextPattern2.from(IUnknown interface)
Creates a new instance of IUIAutomationTextPattern2 from an existing interface.
factory

Properties

documentRange IUIAutomationTextRange?
Retrieves a text range that encloses the main text of a document.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedTextSelection SupportedTextSelection
Retrieves a value that specifies the type of text selection that is supported by the control.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getCaretRange(Pointer<Int32> isActive, Pointer<VTablePointer> range) → void
Retrieves a zero-length text range at the location of the caret that belongs to the text-based control.
getSelection() IUIAutomationTextRangeArray?
Retrieves a collection of text ranges that represents the currently selected text in a text-based control.
inherited
getVisibleRanges() IUIAutomationTextRangeArray?
Retrieves an array of disjoint text ranges from a text-based control where each text range represents a contiguous span of visible text.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
rangeFromAnnotation(IUIAutomationElement? annotation) IUIAutomationTextRange?
Retrieves a text range containing the text that is the target of the annotation associated with the specified annotation element.
rangeFromChild(IUIAutomationElement? child) IUIAutomationTextRange?
Retrieves a text range enclosing a child element such as an image, hyperlink, Microsoft Excel spreadsheet, or other embedded object.
inherited
rangeFromPoint(POINT pt) IUIAutomationTextRange?
Retrieves the degenerate (empty) text range nearest to the specified screen coordinates.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited