IUIAutomationTextRangeArray class com

Represents a collection of IUIAutomationTextRange objects.

To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationtextrangearray.

Inheritance
Implemented types

Constructors

IUIAutomationTextRangeArray(VTablePointer ptr)
Creates a new instance of IUIAutomationTextRangeArray from a VTablePointer.
IUIAutomationTextRangeArray.from(IUnknown interface)
Creates a new instance of IUIAutomationTextRangeArray from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
Retrieves the number of text ranges in the collection.
no setter
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getElement(int index) IUIAutomationTextRange?
Retrieves a text range from the collection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited