IUIAutomationTransformPattern class com

Provides access to a control that can be moved, resized, or rotated.

To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationtransformpattern.

Inheritance
Implemented types
Implementers

Constructors

IUIAutomationTransformPattern(VTablePointer ptr)
Creates a new instance of IUIAutomationTransformPattern from a VTablePointer.
IUIAutomationTransformPattern.from(IUnknown interface)
Creates a new instance of IUIAutomationTransformPattern from an existing interface.
factory

Properties

cachedCanMove bool
Retrieves a cached value that indicates whether the element can be moved.
no setter
cachedCanResize bool
Retrieves a cached value that indicates whether the element can be resized.
no setter
cachedCanRotate bool
Retrieves a cached value that indicates whether the element can be rotated.
no setter
currentCanMove bool
Indicates whether the element can be moved.
no setter
currentCanResize bool
Indicates whether the element can be resized.
no setter
currentCanRotate bool
Indicates whether the element can be rotated.
no setter
hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
move(double x, double y) → void
Moves the UI Automation element.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
resize(double width, double height) → void
Resizes the UI Automation element.
rotate(double degrees) → void
Rotates the UI Automation element.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited