IUIAutomationVirtualizedItemPattern class com

Represents a virtualized item, which is an item that is represented by a placeholder automation element in the Microsoft UI Automation tree.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
ptr ↔ Pointer<COMObject>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() → int
Increments the reference count for an interface pointer to a COM object.
inherited
detach() → void
Detaches the object from the Finalizer.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface(Pointer<GUID> riid, Pointer<Pointer<NativeType>> ppvObject) → int
Queries a COM object for a pointer to one of its interface; identifying the interface by a reference to its interface identifier (IID).
inherited
realize() → int
release() → int
Decrements the reference count for an interface on a COM object.
inherited
toInterface(String iid) → Pointer<COMObject>
Cast an existing COM object to a specified interface.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited