IWbemLocator class com

Use the IWbemLocator interface to obtain the initial namespace pointer to the IWbemServices interface for WMI on a specific host computer.

To learn more, see learn.microsoft.com/windows/win32/api/wbemcli/nn-wbemcli-iwbemlocator.

Inheritance
Implemented types

Constructors

IWbemLocator(VTablePointer ptr)
Creates a new instance of IWbemLocator from a VTablePointer.
IWbemLocator.from(IUnknown interface)
Creates a new instance of IWbemLocator from an existing interface.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
ptr → VTablePointer
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() → int
Increments the reference count of this COM object.
inherited
connectServer(BSTR strNetworkResource, BSTR strUser, BSTR strPassword, BSTR strLocale, int lSecurityFlags, BSTR strAuthority, IWbemContext? pCtx) → IWbemServices?
Creates a connection through DCOM to a WMI namespace on the computer specified in the strNetworkResource parameter.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() → int
Decrements the reference count of this COM object.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited