IWebAuthenticationCoreManagerInterop class com

Inheritance
Implemented types

Constructors

IWebAuthenticationCoreManagerInterop(VTablePointer ptr)
Creates a new instance of IWebAuthenticationCoreManagerInterop from a VTablePointer.
IWebAuthenticationCoreManagerInterop.from(IUnknown interface)
Creates a new instance of IWebAuthenticationCoreManagerInterop from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getIids(Pointer<Uint32> iidCount, Pointer<Pointer<GUID>> iids) → void
Gets the interfaces that are implemented by the current Windows Runtime class.
inherited
getRuntimeClassName() HSTRING
Gets the fully qualified name of the current Windows Runtime object.
inherited
getTrustLevel() TrustLevel
Gets the trust level of the current Windows Runtime object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
requestTokenForWindowAsync<T extends IUnknown>(HWND appWindow, IInspectable? request) → T
Asynchronously requests a token from a web account provider.
requestTokenWithWebAccountForWindowAsync<T extends IUnknown>(HWND appWindow, IInspectable? request, IInspectable? webAccount) → T
Asynchronously requests a token from a web account provider.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited