IWinHttpRequest class com

Provides all of the nonevent methods for Microsoft Windows HTTP Services (WinHTTP).

To learn more, see learn.microsoft.com/windows/win32/WinHttp/iwinhttprequest-interface.

Inheritance
Implemented types

Constructors

IWinHttpRequest(VTablePointer ptr)
Creates a new instance of IWinHttpRequest from a VTablePointer.
IWinHttpRequest.from(IUnknown interface)
Creates a new instance of IWinHttpRequest from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
responseBody Pointer<VARIANT>
Retrieves the response entity body as an array of unsigned bytes.
no setter
responseStream Pointer<VARIANT>
Retrieves the response entity body as an IStream.
no setter
responseText BSTR
Retrieves the response entity body as text.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
Retrieves the HTTP status code from the last response.
no setter
statusText BSTR
Retrieves the HTTP status text.
no setter

Methods

abort() → void
Aborts a WinHTTP Send method.
addRef() int
Increments the reference count of this COM object.
inherited
getAllResponseHeaders() BSTR
Retrieves all HTTP response headers.
getIDsOfNames(Pointer<GUID> riid, Pointer<Pointer<Utf16>> rgszNames, int cNames, int lcid, Pointer<Int32> rgDispId) → void
Maps a single member and an optional set of argument names to a corresponding set of integer DISPIDs, which can be used on subsequent calls to Invoke.
inherited
getResponseHeader(BSTR header) BSTR
Retrieves the HTTP response headers.
getTypeInfo(int iTInfo, int lcid) ITypeInfo?
Retrieves the type information for an object, which can then be used to get the type information for an interface.
inherited
getTypeInfoCount() int
Retrieves the number of type information interfaces that an object provides (either 0 or 1).
inherited
invoke(int dispIdMember, Pointer<GUID> riid, int lcid, DISPATCH_FLAGS wFlags, Pointer<DISPPARAMS> pDispParams, Pointer<VARIANT>? pVarResult, Pointer<EXCEPINFO>? pExcepInfo, Pointer<Uint32>? puArgErr) → void
Provides access to properties and methods exposed by an object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(BSTR method, BSTR url, VARIANT async) → void
Opens an HTTP connection to an HTTP resource.
option(WinHttpRequestOption option) Pointer<VARIANT>
Sets or retrieves a Microsoft Windows HTTP Services (WinHTTP) option value.
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
send(VARIANT body) → void
Sends an HTTP request to an HTTP server.
setAutoLogonPolicy(WinHttpRequestAutoLogonPolicy autoLogonPolicy) → void
Sets the current Automatic Logon Policy.
setClientCertificate(BSTR clientCertificate) → void
Selects a client certificate to send to a Secure Hypertext Transfer Protocol (HTTPS) server.
setCredentials(BSTR userName, BSTR password, int flags) → void
Sets credentials to be used with an HTTP server, whether it is a proxy server or an originating server.
setOption(WinHttpRequestOption option, VARIANT value) → void
Sets or retrieves a Microsoft Windows HTTP Services (WinHTTP) option value.
setProxy(int proxySetting, VARIANT proxyServer, VARIANT bypassList) → void
Sets proxy server information.
setRequestHeader(BSTR header, BSTR value) → void
Adds, changes, or deletes an HTTP request header.
setTimeouts(int resolveTimeout, int connectTimeout, int sendTimeout, int receiveTimeout) → void
Specifies the individual time-out components of a send/receive operation, in milliseconds.
toString() String
A string representation of this object.
override
waitForResponse(VARIANT timeout) bool
Waits for an asynchronous Send method to complete, with optional time-out value, in seconds.

Operators

operator ==(Object other) bool
The equality operator.
inherited