InSendMessage function user32

bool InSendMessage()

Determines whether the current window procedure is processing a message that was sent from another thread (in the same process or a different process) by a call to the SendMessage function.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-insendmessage.

Implementation

@pragma('vm:prefer-inline')
bool InSendMessage() => _InSendMessage() != FALSE;