InSendMessageEx function user32

int InSendMessageEx()

Determines whether the current window procedure is processing a message that was sent from another thread (in the same process or a different process).

To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-insendmessageex.

Implementation

@pragma('vm:prefer-inline')
int InSendMessageEx() => _InSendMessageEx(nullptr);