InvertRect function user32

bool InvertRect(
  1. HDC hDC,
  2. Pointer<RECT> lprc
)

Inverts a rectangle in a window by performing a logical NOT operation on the color values for each pixel in the rectangle's interior.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-invertrect.

Implementation

@pragma('vm:prefer-inline')
bool InvertRect(HDC hDC, Pointer<RECT> lprc) => _InvertRect(hDC, lprc) != FALSE;