KEYBDINPUT class base struct

Contains information about a simulated keyboard event.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-keybdinput.

Inheritance
Implemented types
Available extensions

Constructors

KEYBDINPUT()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwExtraInfo int
An additional value associated with the keystroke.
getter/setter pair
dwFlags KEYBD_EVENT_FLAGS
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time int
The time stamp for the event, in milliseconds.
getter/setter pair
wScan int
A hardware scan code for the key.
getter/setter pair
wVk VIRTUAL_KEY
A virtual-key code.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<KEYBDINPUT>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited