LPFRHOOKPROC typedef callback

LPFRHOOKPROC = IntPtr Function(Pointer<NativeType> param0, Uint32 param1, IntPtr param2, IntPtr param3)

Receives messages or notifications intended for the default dialog box procedure of the Find or Replace dialog box.

To learn more, see learn.microsoft.com/windows/win32/api/commdlg/nc-commdlg-lpfrhookproc.

Implementation

typedef LPFRHOOKPROC =
    IntPtr Function(
      Pointer param0,
      Uint32 param1,
      IntPtr param2,
      IntPtr param3,
    );