LUID class base struct

An opaque structure that specifies an identifier that is guaranteed to be unique on the local machine.

To learn more, see learn.microsoft.com/windows/win32/api/ntdef/ns-ntdef-luid.

Inheritance
Implemented types
Available extensions

Constructors

LUID()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
HighPart int
getter/setter pair
LowPart int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<LUID>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited