MAGIMAGEHEADER class base struct

Inheritance
Implemented types
Available extensions

Constructors

MAGIMAGEHEADER()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
cbSize int
The size of the struct in bytes.
getter/setter pair
format GUID
A WICPixelFormatGUID (declared in wincodec.h) that specifies the pixel format of the image.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
The height of the image.
getter/setter pair
offset int
The offset of the start of the image data from the beginning of the file.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stride int
The stride, or number of bytes in a row of the image.
getter/setter pair
width int
The width of the image.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<MAGIMAGEHEADER>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited