MARGINS class base struct

Returned by the GetThemeMargins function to define the margins of windows that have visual styles applied.

To learn more, see learn.microsoft.com/windows/win32/api/uxtheme/ns-uxtheme-margins.

Inheritance
Implemented types
Available extensions

Constructors

MARGINS()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
cxLeftWidth int
Width of the left border that retains its size.
getter/setter pair
cxRightWidth int
Width of the right border that retains its size.
getter/setter pair
cyBottomHeight int
Height of the bottom border that retains its size.
getter/setter pair
cyTopHeight int
Height of the top border that retains its size.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<MARGINS>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited