MCI_PLAY_PARMS class base struct

Contains positioning information for the MCI_PLAY command.

To learn more, see learn.microsoft.com/windows/win32/Multimedia/mci-play-parms.

Inheritance
Implemented types
Available extensions
Annotations

Constructors

MCI_PLAY_PARMS()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwCallback int
The low-order word specifies a window handle used for the MCI_NOTIFY flag.
getter/setter pair
dwFrom int
Position to play from.
getter/setter pair
dwTo int
Position to play to.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<MCI_PLAY_PARMS>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited