MENUBARINFO class base struct

Contains menu bar information.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-menubarinfo.

Inheritance
Implemented types
Available extensions

Constructors

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bitfield int
getter/setter pair
cbSize int
The size of the struct in bytes.
getter/setter pair
fBarFocused int
getter/setter pair
fFocused int
getter/setter pair
fUnused int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hMenu HMENU
A handle to the menu bar or popup menu.
getter/setter pair
hwndMenu HWND
A handle to the submenu.
getter/setter pair
rcBar RECT
The coordinates of the menu bar, popup menu, or menu item.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<MENUBARINFO>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited