MIDIHDR class base struct

Defines the header used to identify a MIDI system-exclusive or stream buffer.

To learn more, see learn.microsoft.com/windows/win32/api/mmeapi/ns-mmeapi-midihdr.

Inheritance
Implemented types
Available extensions
Annotations

Constructors

MIDIHDR()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwBufferLength int
Size of the buffer.
getter/setter pair
dwBytesRecorded int
Actual amount of data in the buffer.
getter/setter pair
dwFlags int
Flags giving information about the buffer.
getter/setter pair
dwOffset int
Offset into the buffer when a callback is performed.
getter/setter pair
dwUser int
Custom user data.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lpData PSTR
Pointer to MIDI data.
getter/setter pair
lpNext Pointer<MIDIHDR>
Reserved; do not use.
getter/setter pair
reserved int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<MIDIHDR>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited