MIDIINCAPS class base struct

Describes the capabilities of a MIDI input device.

To learn more, see learn.microsoft.com/windows/win32/api/mmeapi/ns-mmeapi-midiincapsw.

Inheritance
Implemented types
Available extensions
Annotations

Constructors

MIDIINCAPS()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwSupport int
Reserved; must be zero.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
szPname String
Product name in a string.
getter/setter pair
vDriverVersion int
Version number of the device driver for the MIDI input device.
getter/setter pair
wMid int
Manufacturer identifier of the device driver for the MIDI input device.
getter/setter pair
wPid int
Product identifier of the MIDI input device.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<MIDIINCAPS>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited