Describes the capabilities of a MIDI output device.
To learn more, see learn.microsoft.com/windows/win32/api/mmeapi/ns-mmeapi-midioutcapsw.
- Inheritance
- Implemented types
- Available extensions
- Annotations
-
- @Packed(1)
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - dwSupport ↔ int
-
Optional functionality supported by the device.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- szPname ↔ String
-
Product name in a string.
getter/setter pair
- vDriverVersion ↔ int
-
Version number of the device driver for the MIDI output device.
getter/setter pair
- wChannelMask ↔ int
-
Channels that an internal synthesizer device responds to, where the least
significant bit refers to channel 0 and the most significant bit to
channel 15.
getter/setter pair
- wMid ↔ int
-
Manufacturer identifier of the device driver for the MIDI output device.
getter/setter pair
- wNotes ↔ int
-
Maximum number of simultaneous notes that can be played by an internal
synthesizer device.
getter/setter pair
- wPid ↔ int
-
Product identifier of the MIDI output device.
getter/setter pair
- wTechnology ↔ int
-
Type of the MIDI output device.
getter/setter pair
- wVoices ↔ int
-
Number of voices supported by an internal synthesizer device.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< MIDIOUTCAPS> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited