MIDISTRMBUFFVER class base struct

Contains version information for a long MIDI event of the MEVT_VERSION type.

To learn more, see learn.microsoft.com/windows/win32/api/mmeapi/ns-mmeapi-midistrmbuffver.

Inheritance
Implemented types
Available extensions
Annotations

Constructors

MIDISTRMBUFFVER()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwMid int
Manufacturer identifier.
getter/setter pair
dwOEMVersion int
OEM version of the stream.
getter/setter pair
dwVersion int
Version of the stream.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<MIDISTRMBUFFVER>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited