MMTIME_0 class sealed union

Inheritance
Implemented types
Available extensions
Annotations

Properties

address Pointer<T>

Available on T, provided by the UnionAddress extension

The memory address of the underlying data.
no setter
cb int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
midi MMTIME_0_1
getter/setter pair
ms int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sample int
getter/setter pair
smpte MMTIME_0_0
getter/setter pair
ticks int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<MMTIME_0>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited