MMTIME_0_0 class sealed struct

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dummy int
getter/setter pair
fps int
getter/setter pair
frame int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hour int
getter/setter pair
min int
getter/setter pair
pad Array<Uint8>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sec int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<MMTIME_0_0>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited