MM_MIM_MOREDATA top-level constant

int const MM_MIM_MOREDATA

The MM_MIM_MOREDATA message is sent to a callback window when a MIDI message is received by a MIDI input device but the application is not processing MIM_DATA messages fast enough to keep up with the input device driver.

To learn more, see learn.microsoft.com/windows/win32/Multimedia/mm-mim-moredata.

Implementation

const MM_MIM_MOREDATA = 972;