Contains module data.
To learn more, see learn.microsoft.com/windows/win32/api/dbghelp/ns-dbghelp-modload_data.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
data
↔ Pointer<
NativeType> -
The data.
getter/setter pair
- flags ↔ int
-
This member is unused.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size ↔ int
-
The size of the data buffer, in bytes.
getter/setter pair
- ssig ↔ MODLOAD_DATA_TYPE
-
getter/setter pair
- ssize ↔ int
-
The size of this structure, in bytes.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< MODLOAD_DATA> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited