MODULEINFO class base struct

Contains the module load address, size, and entry point.

To learn more, see learn.microsoft.com/windows/win32/api/psapi/ns-psapi-moduleinfo.

Inheritance
Implemented types
Available extensions

Constructors

MODULEINFO()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
EntryPoint Pointer<NativeType>
The entry point of the module.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lpBaseOfDll Pointer<NativeType>
The load address of the module.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
SizeOfImage int
The size of the linear space that the module occupies, in bytes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<MODULEINFO>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited