MOUSEHOOKSTRUCTEX class base struct

Contains information about a mouse event passed to a WH_MOUSE hook procedure, MouseProc.

This is an extension of the MOUSEHOOKSTRUCT structure that includes information about wheel movement or the use of the X button.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-mousehookstructex.

Inheritance
Implemented types
Available extensions

Constructors

MOUSEHOOKSTRUCTEX()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
Base MOUSEHOOKSTRUCT
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mouseData int
If the message is WM_MOUSEWHEEL, the HIWORD of this member is the wheel delta.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<MOUSEHOOKSTRUCTEX>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited