Describes a mouse input event in a console INPUT_RECORD structure.
To learn more, see learn.microsoft.com/windows/console/mouse-event-record-str.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - dwButtonState ↔ int
-
The status of the mouse buttons.
getter/setter pair
- dwControlKeyState ↔ int
-
The state of the control keys.
getter/setter pair
- dwEventFlags ↔ int
-
The type of mouse event.
getter/setter pair
- dwMousePosition ↔ COORD
-
A
COORDstructure that contains the location of the cursor, in terms of the console screen buffer's character-cell coordinates.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< MOUSE_EVENT_RECORD> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited