MapVirtualKeyEx function user32

int MapVirtualKeyEx(
  1. int uCode,
  2. MAP_VIRTUAL_KEY_TYPE uMapType,
  3. HKL? dwhkl
)

Translates (maps) a virtual-key code into a scan code or character value, or translates a scan code into a virtual-key code.

The function translates the codes using the input language and an input locale identifier.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-mapvirtualkeyexw.

Implementation

@pragma('vm:prefer-inline')
int MapVirtualKeyEx(int uCode, MAP_VIRTUAL_KEY_TYPE uMapType, HKL? dwhkl) =>
    _MapVirtualKeyEx(uCode, uMapType, dwhkl ?? nullptr);