MapWindowPoints function user32

int MapWindowPoints(
  1. HWND? hWndFrom,
  2. HWND? hWndTo,
  3. Pointer<POINT> lpPoints,
  4. int cPoints,
)

Converts (maps) a set of points from a coordinate space relative to one window to a coordinate space relative to another window.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-mapwindowpoints.

Implementation

@pragma('vm:prefer-inline')
int MapWindowPoints(
  HWND? hWndFrom,
  HWND? hWndTo,
  Pointer<POINT> lpPoints,
  int cPoints,
) =>
    _MapWindowPoints(hWndFrom ?? nullptr, hWndTo ?? nullptr, lpPoints, cPoints);