NCCALCSIZE_PARAMS class base struct

Contains information that an application can use while processing the WM_NCCALCSIZE message to calculate the size, position, and valid contents of the client area of a window.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-nccalcsize_params.

Inheritance
Implemented types
Available extensions

Constructors

NCCALCSIZE_PARAMS()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
lppos Pointer<WINDOWPOS>
A pointer to a WINDOWPOS structure that contains the size and position values specified in the operation that moved or resized the window.
getter/setter pair
rgrc Array<RECT>
An array of rectangles.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<NCCALCSIZE_PARAMS>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited