NotifyWinEvent function user32

void NotifyWinEvent(
  1. int event,
  2. HWND hwnd,
  3. int idObject,
  4. int idChild,
)

Signals the system that a predefined event occurred.

If any client applications have registered a hook function for the event, the system calls the client's hook function.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-notifywinevent.

Implementation

@pragma('vm:prefer-inline')
void NotifyWinEvent(int event, HWND hwnd, int idObject, int idChild) =>
    _NotifyWinEvent(event, hwnd, idObject, idChild);