PALETTEENTRY class base struct

Specifies the color and usage of an entry in a logical palette.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/ns-wingdi-paletteentry.

Inheritance
Implemented types
Available extensions

Constructors

PALETTEENTRY()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
peBlue int
The blue intensity value for the palette entry.
getter/setter pair
peFlags int
The alpha intensity value for the palette entry.
getter/setter pair
peGreen int
The green intensity value for the palette entry.
getter/setter pair
peRed int
The red intensity value for the palette entry.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<PALETTEENTRY>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited