PHYSICAL_MONITOR class base struct

Contains a handle and text description corresponding to a physical monitor.

To learn more, see learn.microsoft.com/windows/win32/api/physicalmonitorenumerationapi/ns-physicalmonitorenumerationapi-physical_monitor.

Inheritance
Implemented types
Available extensions
Annotations

Constructors

PHYSICAL_MONITOR()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
hPhysicalMonitor HANDLE
Handle to the physical monitor.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
szPhysicalMonitorDescription String
Text description of the physical monitor.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<PHYSICAL_MONITOR>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited