POINTER_TOUCH_INFO class base struct

Defines basic touch information common to all pointer types.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-pointer_touch_info.

Inheritance
Implemented types
Available extensions

Constructors

POINTER_TOUCH_INFO()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
orientation int
A pointer orientation, with a value between 0 and 359, where 0 indicates a touch pointer aligned with the x-axis and pointing from left to right; increasing values indicate degrees of rotation in the clockwise direction.
getter/setter pair
pointerInfo POINTER_INFO
An embedded POINTER_INFO header structure.
getter/setter pair
pressure int
A pen pressure normalized to a range between 0 and 1024.
getter/setter pair
rcContact RECT
The predicted screen coordinates of the contact area, in pixels.
getter/setter pair
rcContactRaw RECT
The raw screen coordinates of the contact area, in pixels.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
touchFlags int
Currently none.
getter/setter pair
touchMask int
Indicates which of the optional fields contain valid values.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<POINTER_TOUCH_INFO>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited