POINTL class base struct

Defines the x- and y-coordinates of a point.

To learn more, see learn.microsoft.com/windows/win32/api/windef/ns-windef-pointl.

Inheritance
Implemented types
Available extensions

Constructors

POINTL()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x int
Specifies the x-coordinate of the point.
getter/setter pair
y int
Specifies the y-coordinate of the point.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<POINTL>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited