PRINTER_DEFAULTS class base struct

Specifies the default data type, environment, initialization data, and access rights for a printer.

To learn more, see learn.microsoft.com/windows/win32/printdocs/printer-defaults.

Inheritance
Implemented types
Available extensions

Constructors

PRINTER_DEFAULTS()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
DesiredAccess PRINTER_ACCESS_RIGHTS
Specifies desired access rights for a printer.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pDatatype PWSTR
Pointer to a null-terminated string that specifies the default data type for a printer.
getter/setter pair
pDevMode Pointer<DEVMODE>
Pointer to a DEVMODE structure that identifies the default environment and initialization data for a printer.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<PRINTER_DEFAULTS>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited