PRINTER_INFO_1 class base struct

Specifies general printer information.

To learn more, see learn.microsoft.com/windows/win32/printdocs/printer-info-1.

Inheritance
Implemented types
Available extensions

Constructors

PRINTER_INFO_1()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
Flags int
Specifies information about the returned data.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pComment PWSTR
Pointer to a null-terminated string that contains additional data describing the structure.
getter/setter pair
pDescription PWSTR
Pointer to a null-terminated string that describes the contents of the structure.
getter/setter pair
pName PWSTR
Pointer to a null-terminated string that names the contents of the structure.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<PRINTER_INFO_1>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited