PRINTER_INFO_3 class base struct

Specifies printer security information.

To learn more, see learn.microsoft.com/windows/win32/printdocs/printer-info-3.

Inheritance
Implemented types
Available extensions

Constructors

PRINTER_INFO_3()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
pSecurityDescriptor PSECURITY_DESCRIPTOR
Pointer to a SECURITY_DESCRIPTOR structure that specifies a printer's security information.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<PRINTER_INFO_3>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited