PRINTER_INFO_6 class base struct

Specifies the status value of a printer.

To learn more, see learn.microsoft.com/windows/win32/printdocs/printer-info-6.

Inheritance
Implemented types
Available extensions

Constructors

PRINTER_INFO_6()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwStatus int
The printer status.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<PRINTER_INFO_6>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited