NotifyData property
A union of data information based on the Type and Field members.
Implementation
external PRINTER_NOTIFY_INFO_DATA_0 NotifyData;
A union of data information based on the Type and Field members.
external PRINTER_NOTIFY_INFO_DATA_0 NotifyData;