PRINTER_OPTIONS class base struct

Represents printer options.

To learn more, see learn.microsoft.com/windows/win32/printdocs/printer-options.

Inheritance
Implemented types
Available extensions

Constructors

PRINTER_OPTIONS()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
cbSize int
The size of the struct in bytes.
getter/setter pair
dwFlags PRINTER_OPTION_FLAGS
A set of PRINTER_OPTION_FLAGS that specifies how the handle to a printer returned by OpenPrinter2 will be used by other functions.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<PRINTER_OPTIONS>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited