PRINT_EXECUTION_DATA class base struct

Contains the execution context of the printer driver that calls GetPrintExecutionData.

To learn more, see learn.microsoft.com/windows/win32/printdocs/print-execution-data.

Inheritance
Implemented types
Available extensions

Constructors

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
clientAppPID int
If the value of context is PRINT_EXECUTION_CONTEXT_WOW64, clientAppPID identifies the client application on whose behalf the splwow64.exe process loaded the printer driver.
getter/setter pair
context PRINT_EXECUTION_CONTEXT
The PRINT_EXECUTION_CONTEXT value that represents the current execution context of the printer driver.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<PRINT_EXECUTION_DATA>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited