PROPSPEC class base struct

Used by many of the methods of IPropertyStorage to specify a property either by its property identifier (ID) or the associated string name.

To learn more, see learn.microsoft.com/windows/win32/api/propidlbase/ns-propidlbase-propspec.

Inheritance
Implemented types
Available extensions

Constructors

PROPSPEC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
Anonymous PROPSPEC_0
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lpwstr PWSTR

Available on PROPSPEC, provided by the PROPSPEC_0_Extension extension

getter/setter pair
propid int

Available on PROPSPEC, provided by the PROPSPEC_0_Extension extension

getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ulKind PROPSPEC_KIND
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<PROPSPEC>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited