PWSTR extension type
A strongly-typed wrapper around a Win32 PWSTR.
PWSTR represents a mutable, null-terminated UTF-16 string commonly used by
Win32 APIs.
Properties
- address → int
-
Access to the raw pointer value.
On 32-bit systems, the upper 32-bits of the result are 0.
no setterinherited
- byteLength → int
-
The length of this string in bytes, excluding the terminating NUL
character.
no setter
- hashCode → int
-
The hash code for a Pointer only depends on its address.
no setterinherited
- isEmpty → bool
-
Whether this string is empty.
no setter
- length → int
-
The number of UTF-16 code units in this string, excluding the terminating
NUL character.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cast<
U extends NativeType> () → Pointer< U> -
Reinterprets the address of this pointer as the address of a
U.inherited -
copy(
{Allocator allocator = adaptiveCalloc}) → PWSTR - Creates a deep copy of this string into newly allocated native memory.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setString(
String string) → int -
Writes the given Dart
stringinto this buffer as UTF-16 code units. -
toDartString(
{int? length}) → String - Converts this PWSTR to a Dart string.
-
toDartStringList(
int maxLength) → List< String> - Decodes a double-NUL-terminated UTF-16 string array.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
Equality for Pointers only depends on their address.
inherited