PhysicalToLogicalPointForPerMonitorDPI function user32

bool PhysicalToLogicalPointForPerMonitorDPI(
  1. HWND? hWnd,
  2. Pointer<POINT> lpPoint
)

Converts a point in a window from physical coordinates into logical coordinates, regardless of the dots per inch (dpi) awareness of the caller.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-physicaltologicalpointforpermonitordpi.

Implementation

@pragma('vm:prefer-inline')
bool PhysicalToLogicalPointForPerMonitorDPI(
  HWND? hWnd,
  Pointer<POINT> lpPoint,
) => _PhysicalToLogicalPointForPerMonitorDPI(hWnd ?? nullptr, lpPoint) != FALSE;