Describes the format of the raw input from a Human Interface Device (HID).
To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-rawhid.
- Inheritance
- Implemented types
- Available extensions
Constructors
- RAWHID()
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
bRawData
↔ Array<
Uint8> -
The raw input data, as an array of bytes.
getter/setter pair
- dwCount ↔ int
-
The number of HID inputs in bRawData.
getter/setter pair
- dwSizeHid ↔ int
-
The size, in bytes, of each HID input in bRawData.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< RAWHID> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited