RAWINPUTDEVICELIST class base struct

Contains information about a raw input device.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-rawinputdevicelist.

Inheritance
Implemented types
Available extensions

Constructors

RAWINPUTDEVICELIST()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwType RID_DEVICE_INFO_TYPE
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hDevice HANDLE
A handle to the raw input device.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<RAWINPUTDEVICELIST>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited