RAWKEYBOARD class base struct

Contains information about the state of the keyboard.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-rawkeyboard.

Inheritance
Implemented types
Available extensions

Constructors

RAWKEYBOARD()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
ExtraInformation int
The device-specific additional information for the event.
getter/setter pair
Flags int
Flags for scan code information.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
MakeCode int
Specifies the scan code associated with a key press.
getter/setter pair
Message int
The corresponding legacy keyboard window message, for example WM_KEYDOWN, WM_SYSKEYDOWN, and so forth.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
VKey int
The corresponding legacy virtual-key code.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<RAWKEYBOARD>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited