RAWMOUSE class base struct

Contains information about the state of the mouse.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-rawmouse.

Inheritance
Implemented types
Available extensions

Constructors

RAWMOUSE()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
Anonymous RAWMOUSE_0
getter/setter pair
Anonymous RAWMOUSE_0_0

Available on RAWMOUSE, provided by the RAWMOUSE_0_Extension extension

getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lLastX int
The motion in the X direction.
getter/setter pair
lLastY int
The motion in the Y direction.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ulButtons int

Available on RAWMOUSE, provided by the RAWMOUSE_0_Extension extension

getter/setter pair
ulExtraInformation int
The device-specific additional information for the event.
getter/setter pair
ulRawButtons int
The raw state of the mouse buttons.
getter/setter pair
usButtonData int

Available on RAWMOUSE, provided by the RAWMOUSE_0_0_Extension extension

getter/setter pair
usButtonFlags int

Available on RAWMOUSE, provided by the RAWMOUSE_0_0_Extension extension

getter/setter pair
usFlags MOUSE_STATE
The mouse state.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<RAWMOUSE>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited