RECT class base struct

Defines a rectangle by the coordinates of its upper-left and lower-right corners.

To learn more, see learn.microsoft.com/windows/win32/api/windef/ns-windef-rect.

Inheritance
Implemented types
Available extensions

Constructors

RECT()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bottom int
Specifies the y-coordinate of the lower-right corner of the rectangle.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
left int
Specifies the x-coordinate of the upper-left corner of the rectangle.
getter/setter pair
Specifies the x-coordinate of the lower-right corner of the rectangle.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top int
Specifies the y-coordinate of the upper-left corner of the rectangle.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<RECT>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited