RGBQUAD class base struct

Describes a color consisting of relative intensities of red, green, and blue.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/ns-wingdi-rgbquad.

Inheritance
Implemented types
Available extensions

Constructors

RGBQUAD()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
rgbBlue ↔ int
The intensity of blue in the color.
getter/setter pair
rgbGreen ↔ int
The intensity of green in the color.
getter/setter pair
rgbRed ↔ int
The intensity of red in the color.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) → Pointer<RGBQUAD>
Allocates native memory and copies the contents of this struct into it.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited