Rectangle function gdi32

bool Rectangle(
  1. HDC hdc,
  2. int left,
  3. int top,
  4. int right,
  5. int bottom,
)

Draws a rectangle.

The rectangle is outlined by using the current pen and filled by using the current brush.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/nf-wingdi-rectangle.

Implementation

@pragma('vm:prefer-inline')
bool Rectangle(HDC hdc, int left, int top, int right, int bottom) =>
    _Rectangle(hdc, left, top, right, bottom) != FALSE;