ReleaseCapture function user32

Win32Result<bool> ReleaseCapture()

Releases the mouse capture from a window in the current thread and restores normal mouse input processing.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-releasecapture.

Implementation

Win32Result<bool> ReleaseCapture() {
  resolveGetLastError();
  final result_ = _ReleaseCapture();
  return .new(value: result_ != FALSE, error: GetLastError());
}