ResetPrinter function winspool
Specifies the data type and device mode values to be used for printing documents submitted by the StartDocPrinter function.
These values can be overridden by using the SetJob function after document printing has started.
To learn more, see learn.microsoft.com/windows/win32/printdocs/resetprinter.
Implementation
@pragma('vm:prefer-inline')
bool ResetPrinter(
PRINTER_HANDLE hPrinter,
Pointer<PRINTER_DEFAULTS>? pDefault,
) => _ResetPrinter(hPrinter, pDefault ?? nullptr) != FALSE;