SAFEARRAY class base struct

Represents a safe array.

To learn more, see learn.microsoft.com/windows/win32/api/oaidl/ns-oaidl-safearray.

Inheritance
Implemented types
Available extensions

Constructors

SAFEARRAY()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
cbElements int
The size of an array element.
getter/setter pair
cDims int
The number of dimensions.
getter/setter pair
cLocks int
The number of times the array has been locked without a corresponding unlock.
getter/setter pair
fFeatures ADVANCED_FEATURE_FLAGS
Flags.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pvData Pointer<NativeType>
The data.
getter/setter pair
rgsabound Array<SAFEARRAYBOUND>
One bound for each dimension.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<SAFEARRAY>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited