SCROLLBARINFO class base struct

Contains scroll bar information.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-scrollbarinfo.

Inheritance
Implemented types
Available extensions

Constructors

SCROLLBARINFO()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
cbSize int
The size of the struct in bytes.
getter/setter pair
dxyLineButton int
Height or width of the thumb.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rcScrollBar RECT
Coordinates of the scroll bar as specified in a RECT structure.
getter/setter pair
reserved int
getter/setter pair
rgstate Array<Uint32>
An array of DWORD elements.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xyThumbBottom int
Position of the bottom or right of the thumb.
getter/setter pair
xyThumbTop int
Position of the top or left of the thumb.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<SCROLLBARINFO>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited