SCardWriteCache function winscard

int SCardWriteCache(
  1. int hContext,
  2. Pointer<GUID> cardIdentifier,
  3. int freshnessCounter,
  4. PCWSTR lookupName,
  5. Pointer<Uint8> data,
  6. int dataLen,
)

Writes a name-value pair from a smart card to the global cache maintained by the Smart Card Resource Manager.

To learn more, see learn.microsoft.com/windows/win32/api/winscard/nf-winscard-scardwritecachew.

Implementation

@pragma('vm:prefer-inline')
int SCardWriteCache(
  int hContext,
  Pointer<GUID> cardIdentifier,
  int freshnessCounter,
  PCWSTR lookupName,
  Pointer<Uint8> data,
  int dataLen,
) => _SCardWriteCache(
  hContext,
  cardIdentifier,
  freshnessCounter,
  lookupName,
  data,
  dataLen,
);