SDP_ELEMENT_DATA_0 class sealed union

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the UnionAddress extension

The memory address of the underlying data.
no setter
alternative SDP_ELEMENT_DATA_0_3
getter/setter pair
booleanVal int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
int128 SDP_LARGE_INTEGER_16
getter/setter pair
int16 int
getter/setter pair
int32 int
getter/setter pair
int64 int
getter/setter pair
int8 CHAR
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence SDP_ELEMENT_DATA_0_2
getter/setter pair
string SDP_ELEMENT_DATA_0_0
getter/setter pair
uint128 SDP_ULARGE_INTEGER_16
getter/setter pair
uint16 int
getter/setter pair
uint32 int
getter/setter pair
uint64 int
getter/setter pair
uint8 int
getter/setter pair
url SDP_ELEMENT_DATA_0_1
getter/setter pair
uuid128 GUID
getter/setter pair
uuid16 int
getter/setter pair
uuid32 int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<SDP_ELEMENT_DATA_0>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited