SERVICE_NOTIFY_2 class base struct

Represents service status notification information.

To learn more, see learn.microsoft.com/windows/win32/api/winsvc/ns-winsvc-service_notify_2w.

Inheritance
Implemented types
Available extensions

Constructors

SERVICE_NOTIFY_2()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwNotificationStatus int
A value that indicates the notification status.
getter/setter pair
dwNotificationTriggered int
If dwNotificationStatus is ERROR_SUCCESS, this member contains a bitmask of the notifications that triggered this call to the callback function.
getter/setter pair
dwVersion int
The structure version.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pContext Pointer<NativeType>
Any user-defined data to be passed to the callback function.
getter/setter pair
pfnNotifyCallback Pointer<NativeFunction<PFN_SC_NOTIFY_CALLBACK>>
A pointer to the callback function.
getter/setter pair
pszServiceNames PWSTR
If dwNotificationStatus is ERROR_SUCCESS and the notification is SERVICE_NOTIFY_CREATED or SERVICE_NOTIFY_DELETED, this member is valid and it is a MULTI_SZ string that contains one or more service names.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ServiceStatus SERVICE_STATUS_PROCESS
A SERVICE_STATUS_PROCESS structure that contains the service status information.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<SERVICE_NOTIFY_2>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited