pszServiceNames property

PWSTR get pszServiceNames

If dwNotificationStatus is ERROR_SUCCESS and the notification is SERVICE_NOTIFY_CREATED or SERVICE_NOTIFY_DELETED, this member is valid and it is a MULTI_SZ string that contains one or more service names.

Implementation

PWSTR get pszServiceNames => PWSTR(_pszServiceNames);
set pszServiceNames (PWSTR value)

Implementation

set pszServiceNames(PWSTR value) => _pszServiceNames = value;