SERVICE_TABLE_ENTRY class base struct

Specifies the ServiceMain function for a service that can run in the calling process.

It is used by the StartServiceCtrlDispatcher function.

To learn more, see learn.microsoft.com/windows/win32/api/winsvc/ns-winsvc-service_table_entryw.

Inheritance
Implemented types
Available extensions

Constructors

SERVICE_TABLE_ENTRY()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
lpServiceName PWSTR
The name of a service to be run in this service process.
getter/setter pair
lpServiceProc Pointer<NativeFunction<LPSERVICE_MAIN_FUNCTION>>
A pointer to a ServiceMain function.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<SERVICE_TABLE_ENTRY>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited