SERVICE_TIMECHANGE_INFO class base struct

Contains system time change settings.

To learn more, see learn.microsoft.com/windows/win32/api/winsvc/ns-winsvc-service_timechange_info.

Inheritance
Implemented types
Available extensions

Constructors

SERVICE_TIMECHANGE_INFO()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
liNewTime int
The new system time.
getter/setter pair
liOldTime int
The previous system time.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<SERVICE_TIMECHANGE_INFO>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited