SMALL_RECT class base struct

Defines the coordinates of the upper left and lower right corners of a rectangle.

To learn more, see learn.microsoft.com/windows/console/small-rect-str.

Inheritance
Implemented types
Available extensions

Constructors

SMALL_RECT()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
Bottom int
The y-coordinate of the lower right corner of the rectangle.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
Left int
The x-coordinate of the upper left corner of the rectangle.
getter/setter pair
The x-coordinate of the lower right corner of the rectangle.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Top int
The y-coordinate of the upper left corner of the rectangle.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<SMALL_RECT>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited