SOCKADDR class base struct

Varies depending on the protocol selected.

To learn more, see learn.microsoft.com/windows/win32/api/winsock/ns-winsock-sockaddr.

Inheritance
Implemented types
Available extensions

Constructors

SOCKADDR()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sa_data ↔ Array<Int8>
getter/setter pair
sa_family ↔ ADDRESS_FAMILY
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) → Pointer<SOCKADDR>
Allocates native memory and copies the contents of this struct into it.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited