SOCKET_ADDRESS class base struct

Stores protocol-specific address information.

To learn more, see learn.microsoft.com/windows/win32/api/ws2def/ns-ws2def-socket_address.

Inheritance
Implemented types
Available extensions

Constructors

SOCKET_ADDRESS()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
iSockaddrLength int
The length, in bytes, of the socket address.
getter/setter pair
lpSockaddr Pointer<SOCKADDR>
A pointer to a socket address represented as a SOCKADDR structure.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<SOCKET_ADDRESS>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited