SPEVENT class base struct

Inheritance
Implemented types
Available extensions

Constructors

SPEVENT()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bitfield int
getter/setter pair
eEventId int
getter/setter pair
elParamType int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lParam LPARAM
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ullAudioStreamOffset int
getter/setter pair
ulStreamNum int
getter/setter pair
wParam WPARAM
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<SPEVENT>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited