SP_DEVICE_INTERFACE_DATA class base struct

Defines a device interface in a device information set.

To learn more, see learn.microsoft.com/windows/win32/api/setupapi/ns-setupapi-sp_device_interface_data.

Inheritance
Implemented types
Available extensions

Constructors

SP_DEVICE_INTERFACE_DATA()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
cbSize int
The size of the struct in bytes.
getter/setter pair
Flags int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
InterfaceClassGuid GUID
The GUID for the class to which the device interface belongs.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<SP_DEVICE_INTERFACE_DATA>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited