STARTUPINFO class base struct

Specifies the window station, desktop, standard handles, and appearance of the main window for a process at creation time.

Inheritance
Implemented types
Available extensions

Constructors

STARTUPINFO()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
cb ↔ int
getter/setter pair
cbReserved2 ↔ int
getter/setter pair
dwFillAttribute ↔ int
getter/setter pair
dwFlags ↔ int
getter/setter pair
dwX ↔ int
getter/setter pair
dwXCountChars ↔ int
getter/setter pair
dwXSize ↔ int
getter/setter pair
dwY ↔ int
getter/setter pair
dwYCountChars ↔ int
getter/setter pair
dwYSize ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hStdError ↔ int
getter/setter pair
hStdInput ↔ int
getter/setter pair
hStdOutput ↔ int
getter/setter pair
lpDesktop ↔ Pointer<Utf16>
getter/setter pair
lpReserved ↔ Pointer<Utf16>
getter/setter pair
lpReserved2 ↔ Pointer<Uint8>
getter/setter pair
lpTitle ↔ Pointer<Utf16>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wShowWindow ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited