SYSTEM_POWER_STATUS class base struct

Contains information about the power status of the system.

To learn more, see learn.microsoft.com/windows/win32/api/winbase/ns-winbase-system_power_status.

Inheritance
Implemented types
Available extensions

Constructors

SYSTEM_POWER_STATUS()

Properties

ACLineStatus int
getter/setter pair
address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
BatteryFlag int
The battery charge status.
getter/setter pair
BatteryFullLifeTime int
The number of seconds of battery life when at full charge, or –1 if full battery lifetime is unknown or if the device is connected to AC power.
getter/setter pair
BatteryLifePercent int
The percentage of full battery charge remaining.
getter/setter pair
BatteryLifeTime int
The number of seconds of battery life remaining, or –1 if remaining seconds are unknown or if the device is connected to AC power.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
SystemStatusFlag int
The status of battery saver.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<SYSTEM_POWER_STATUS>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited