- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - BasePriority ↔ int
-
getter/setter pair
- HandleCount ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- ImageName ↔ UNICODE_STRING
-
getter/setter pair
- NextEntryOffset ↔ int
-
getter/setter pair
- NumberOfThreads ↔ int
-
getter/setter pair
- PagefileUsage ↔ int
-
getter/setter pair
- PeakPagefileUsage ↔ int
-
getter/setter pair
- PeakVirtualSize ↔ int
-
getter/setter pair
- PeakWorkingSetSize ↔ int
-
getter/setter pair
- PrivatePageCount ↔ int
-
getter/setter pair
- QuotaNonPagedPoolUsage ↔ int
-
getter/setter pair
- QuotaPagedPoolUsage ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- SessionId ↔ int
-
getter/setter pair
- UniqueProcessId ↔ HANDLE
-
getter/setter pair
- VirtualSize ↔ int
-
getter/setter pair
- WorkingSetSize ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< SYSTEM_PROCESS_INFORMATION> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited