SafeArrayCreate function oleaut32
Creates a new array descriptor, allocates and initializes the data for the array, and returns a pointer to the new array descriptor.
To learn more, see learn.microsoft.com/windows/win32/api/oleauto/nf-oleauto-safearraycreate.
Implementation
@pragma('vm:prefer-inline')
Pointer<SAFEARRAY> SafeArrayCreate(
VARENUM vt,
int cDims,
Pointer<SAFEARRAYBOUND> rgsabound,
) => _SafeArrayCreate(vt, cDims, rgsabound);