SetBkColor function gdi32

COLORREF SetBkColor(
  1. HDC hdc,
  2. COLORREF color
)

Sets the current background color to the specified color value, or to the nearest physical color if the device cannot represent the specified color value.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/nf-wingdi-setbkcolor.

Implementation

@pragma('vm:prefer-inline')
COLORREF SetBkColor(HDC hdc, COLORREF color) =>
    COLORREF(_SetBkColor(hdc, color));