SetBkMode function gdi32

int SetBkMode(
  1. HDC hdc,
  2. BACKGROUND_MODE mode
)

Sets the background mix mode of the specified device context.

The background mix mode is used with text, hatched brushes, and pen styles that are not solid lines.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/nf-wingdi-setbkmode.

Implementation

@pragma('vm:prefer-inline')
int SetBkMode(HDC hdc, BACKGROUND_MODE mode) => _SetBkMode(hdc, mode);