SetClipboardViewer function user32
Adds the specified window to the chain of clipboard viewers.
Clipboard viewer windows receive a WM_DRAWCLIPBOARD message whenever the content of the clipboard changes. This function is used for backward compatibility with earlier versions of Windows.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-setclipboardviewer.
Implementation
Win32Result<HWND> SetClipboardViewer(HWND hWndNewViewer) {
final result_ = SetClipboardViewer_Wrapper(hWndNewViewer);
return .new(value: .new(result_.value.ptr), error: result_.error);
}