SetScrollInfo function user32

int SetScrollInfo(
  1. HWND hwnd,
  2. SCROLLBAR_CONSTANTS nBar,
  3. Pointer<SCROLLINFO> lpsi,
  4. bool redraw,
)

Sets the parameters of a scroll bar, including the minimum and maximum scrolling positions, the page size, and the position of the scroll box (thumb).

The function also redraws the scroll bar, if requested.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-setscrollinfo.

Implementation

@pragma('vm:prefer-inline')
int SetScrollInfo(
  HWND hwnd,
  SCROLLBAR_CONSTANTS nBar,
  Pointer<SCROLLINFO> lpsi,
  bool redraw,
) => _SetScrollInfo(hwnd, nBar, lpsi, redraw ? TRUE : FALSE);