SetWindowExtEx function gdi32

bool SetWindowExtEx(
  1. HDC hdc,
  2. int x,
  3. int y,
  4. Pointer<SIZE>? lpsz,
)

Sets the horizontal and vertical extents of the window for a device context by using the specified values.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/nf-wingdi-setwindowextex.

Implementation

@pragma('vm:prefer-inline')
bool SetWindowExtEx(HDC hdc, int x, int y, Pointer<SIZE>? lpsz) =>
    _SetWindowExtEx(hdc, x, y, lpsz ?? nullptr) != FALSE;