SetWindowTheme function uxtheme

void SetWindowTheme(
  1. HWND hwnd,
  2. PCWSTR? pszSubAppName,
  3. PCWSTR? pszSubIdList
)

Causes a window to use a different set of visual style information than its class normally uses.

Throws a WindowsException on failure.

To learn more, see learn.microsoft.com/windows/win32/api/uxtheme/nf-uxtheme-setwindowtheme.

Implementation

@pragma('vm:prefer-inline')
void SetWindowTheme(HWND hwnd, PCWSTR? pszSubAppName, PCWSTR? pszSubIdList) {
  final hr$ = HRESULT(
    _SetWindowTheme(hwnd, pszSubAppName ?? nullptr, pszSubIdList ?? nullptr),
  );
  if (hr$.isError) throw WindowsException(hr$);
}