TASKDIALOGCONFIG_0 class sealed union

Inheritance
Implemented types
Available extensions
Annotations

Properties

address Pointer<T>

Available on T, provided by the UnionAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
hMainIcon HICON
getter/setter pair
pszMainIcon PWSTR
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<TASKDIALOGCONFIG_0>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited