TIMEVAL class base struct

Used to specify a time interval.

It is associated with the Berkeley Software Distribution (BSD) Time.h header file.

To learn more, see learn.microsoft.com/windows/win32/api/winsock/ns-winsock-timeval.

Inheritance
Implemented types
Available extensions

Constructors

TIMEVAL()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tv_sec int
Time interval, in seconds.
getter/setter pair
tv_usec int
Time interval, in microseconds.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<TIMEVAL>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited