TOKEN_ELEVATION class base struct

Indicates whether a token has elevated privileges.

To learn more, see learn.microsoft.com/windows/win32/api/winnt/ns-winnt-token_elevation.

Inheritance
Implemented types
Available extensions

Constructors

TOKEN_ELEVATION()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
TokenIsElevated int
A nonzero value if the token has elevated privileges; otherwise, a zero value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<TOKEN_ELEVATION>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited