TPMPARAMS class base struct

Contains extended parameters for the TrackPopupMenuEx function.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-tpmparams.

Inheritance
Implemented types
Available extensions

Constructors

TPMPARAMS()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
cbSize int
The size of the struct in bytes.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rcExclude RECT
The rectangle to be excluded when positioning the window, in screen coordinates.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<TPMPARAMS>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited