TYPEDESC class base struct

Describes the type of a variable, the return type of a function, or the type of a function parameter.

To learn more, see learn.microsoft.com/windows/win32/api/oaidl/ns-oaidl-typedesc.

Inheritance
Implemented types
Available extensions

Constructors

TYPEDESC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
Anonymous TYPEDESC_0
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hreftype int

Available on TYPEDESC, provided by the TYPEDESC_0_Extension extension

getter/setter pair
lpadesc Pointer<ARRAYDESC>

Available on TYPEDESC, provided by the TYPEDESC_0_Extension extension

getter/setter pair
lptdesc Pointer<TYPEDESC>

Available on TYPEDESC, provided by the TYPEDESC_0_Extension extension

getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vt VARENUM
The variant type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<TYPEDESC>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited