TranslateMessage function user32
Translates virtual-key messages into character messages.
The character messages are posted to the calling thread's message queue, to be read the next time the thread calls the GetMessage or PeekMessage function.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-translatemessage.
Implementation
@pragma('vm:prefer-inline')
bool TranslateMessage(Pointer<MSG> lpMsg) => _TranslateMessage(lpMsg) != FALSE;