TransmitCommChar function kernel32

Win32Result<bool> TransmitCommChar(
  1. HANDLE hFile,
  2. CHAR cChar
)

Transmits a specified character ahead of any pending data in the output buffer of the specified communications device.

To learn more, see learn.microsoft.com/windows/win32/api/winbase/nf-winbase-transmitcommchar.

Implementation

Win32Result<bool> TransmitCommChar(HANDLE hFile, CHAR cChar) {
  resolveGetLastError();
  final result_ = _TransmitCommChar(hFile, cChar);
  return .new(value: result_ != FALSE, error: GetLastError());
}