UIA_PROPERTY_ID extension type enum
- on
- Implemented types
- Available extensions
Constructors
- UIA_PROPERTY_ID(int _)
-
const
Properties
-
address
→ Pointer<
Never> -
Available on int, provided by the IntAddress extension
The memory address of the underlying data.no setter - bitLength → int
-
Returns the minimum number of bits required to store this integer.
no setterinherited
- hashCode → int
-
Returns a hash code for a numerical value.
no setterinherited
- isEven → bool
-
Returns true if and only if this integer is even.
no setterinherited
- isFinite → bool
-
Whether this number is finite.
no setterinherited
- isInfinite → bool
-
Whether this number is positive infinity or negative infinity.
no setterinherited
- isNaN → bool
-
Whether this number is a Not-a-Number value.
no setterinherited
- isNegative → bool
-
Whether this number is negative.
no setterinherited
- isOdd → bool
-
Returns true if and only if this integer is odd.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sign → int
-
Returns the sign of this integer.
no setterinherited
- toJS → JSNumber
-
Available on num, provided by the NumToJSExtension extension
Converts this num to a JSNumber.no setter
Methods
-
abs(
) → int -
Returns the absolute value of this integer.
inherited
-
ceil(
) → int -
Returns
this.inherited -
ceilToDouble(
) → double -
Returns
this.toDouble().inherited -
clamp(
num lowerLimit, num upperLimit) → num -
Returns this num clamped to be in the range
lowerLimit-upperLimit.inherited -
compareTo(
num other) → int -
Compares this to
other.inherited -
floor(
) → int -
Returns
this.inherited -
floorToDouble(
) → double -
Returns
this.toDouble().inherited -
gcd(
int other) → int -
Returns the greatest common divisor of this integer and
other.inherited -
modInverse(
int modulus) → int -
Returns the modular multiplicative inverse of this integer
modulo
modulus.inherited -
modPow(
int exponent, int modulus) → int -
Returns this integer to the power of
exponentmodulomodulus.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remainder(
num other) → num -
The remainder of the truncating division of
thisbyother.inherited -
round(
) → int -
Returns
this.inherited -
roundToDouble(
) → double -
Returns
this.toDouble().inherited -
toDouble(
) → double -
This number as a double.
inherited
-
toHexString(
int bits) → String -
Available on int, provided by the HexConversion extension
Converts an integer value to a nicely-formatted hexadecimal equivalent. -
toInt(
) → int -
Truncates this num to an integer and returns the result as an int.
inherited
-
toRadixString(
int radix) → String -
Converts this int to a string representation in the given
radix.inherited -
toSigned(
int width) → int -
Returns the least significant
widthbits of this integer, extending the highest retained bit to the sign. This is the same as truncating the value to fit inwidthbits using an signed 2-s complement representation. The returned value has the same bit value in all positions higher thanwidth.inherited -
toString(
) → String -
Returns a string representation of this integer.
inherited
-
toStringAsExponential(
[int? fractionDigits]) → String -
An exponential string-representation of this number.
inherited
-
toStringAsFixed(
int fractionDigits) → String -
A decimal-point string-representation of this number.
inherited
-
toStringAsPrecision(
int precision) → String -
A string representation with
precisionsignificant digits.inherited -
toUnsigned(
int width) → int -
Returns the least significant
widthbits of this integer as a non-negative number (i.e. unsigned representation). The returned value has zeros in all bit positions higher thanwidth.inherited -
truncate(
) → int -
Returns
this.inherited -
truncateToDouble(
) → double -
Returns
this.toDouble().inherited
Operators
-
operator %(
num other) → num -
Euclidean modulo of this number by
other.inherited -
operator &(
int other) → int -
Bit-wise and operator.
inherited
-
operator *(
num other) → num -
Multiplies this number by
other.inherited -
operator +(
num other) → num -
Adds
otherto this number.inherited -
operator -(
num other) → num -
Subtracts
otherfrom this number.inherited -
operator /(
num other) → double -
Divides this number by
other.inherited -
operator <(
num other) → bool -
Whether this number is numerically smaller than
other.inherited -
operator <<(
int shiftAmount) → int -
Shift the bits of this integer to the left by
shiftAmount.inherited -
operator <=(
num other) → bool -
Whether this number is numerically smaller than or equal to
other.inherited -
operator ==(
Object other) → bool -
Test whether this value is numerically equal to
other.inherited -
operator >(
num other) → bool -
Whether this number is numerically greater than
other.inherited -
operator >=(
num other) → bool -
Whether this number is numerically greater than or equal to
other.inherited -
operator >>(
int shiftAmount) → int -
Shift the bits of this integer to the right by
shiftAmount.inherited -
operator >>>(
int shiftAmount) → int -
Bitwise unsigned right shift by
shiftAmountbits.inherited -
operator ^(
int other) → int -
Bit-wise exclusive-or operator.
inherited
-
operator unary-(
) → int -
Return the negative value of this integer.
inherited
-
operator |(
int other) → int -
Bit-wise or operator.
inherited
-
operator ~(
) → int -
The bit-wise negate operator.
inherited
-
operator ~/(
num other) → int -
Truncating division operator.
inherited
Constants
- UIA_AcceleratorKeyPropertyId → const int
- UIA_AccessKeyPropertyId → const int
- UIA_AnnotationAnnotationTypeIdPropertyId → const UIA_PROPERTY_ID
- UIA_AnnotationAnnotationTypeNamePropertyId → const UIA_PROPERTY_ID
- UIA_AnnotationAuthorPropertyId → const int
- UIA_AnnotationDateTimePropertyId → const int
- UIA_AnnotationObjectsPropertyId → const int
- UIA_AnnotationTargetPropertyId → const int
- UIA_AnnotationTypesPropertyId → const int
- UIA_AriaPropertiesPropertyId → const int
- UIA_AriaRolePropertyId → const int
- UIA_AutomationIdPropertyId → const int
- UIA_BoundingRectanglePropertyId → const int
- UIA_CenterPointPropertyId → const int
- UIA_ClassNamePropertyId → const int
- UIA_ClickablePointPropertyId → const int
- UIA_ControllerForPropertyId → const int
- UIA_ControlTypePropertyId → const int
- UIA_CulturePropertyId → const int
- UIA_DescribedByPropertyId → const int
- UIA_DockDockPositionPropertyId → const int
- UIA_DragDropEffectPropertyId → const int
- UIA_DragDropEffectsPropertyId → const int
- UIA_DragGrabbedItemsPropertyId → const int
- UIA_DragIsGrabbedPropertyId → const int
- UIA_DropTargetDropTargetEffectPropertyId → const UIA_PROPERTY_ID
- UIA_DropTargetDropTargetEffectsPropertyId → const UIA_PROPERTY_ID
- UIA_ExpandCollapseExpandCollapseStatePropertyId → const UIA_PROPERTY_ID
- UIA_FillColorPropertyId → const int
- UIA_FillTypePropertyId → const int
- UIA_FlowsFromPropertyId → const int
- UIA_FlowsToPropertyId → const int
- UIA_FrameworkIdPropertyId → const int
- UIA_FullDescriptionPropertyId → const int
- UIA_GridColumnCountPropertyId → const int
- UIA_GridItemColumnPropertyId → const int
- UIA_GridItemColumnSpanPropertyId → const int
- UIA_GridItemContainingGridPropertyId → const int
- UIA_GridItemRowPropertyId → const int
- UIA_GridItemRowSpanPropertyId → const int
- UIA_GridRowCountPropertyId → const int
- UIA_HasKeyboardFocusPropertyId → const int
- UIA_HeadingLevelPropertyId → const int
- UIA_HelpTextPropertyId → const int
- UIA_IsAnnotationPatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsContentElementPropertyId → const int
- UIA_IsControlElementPropertyId → const int
- UIA_IsDataValidForFormPropertyId → const int
- UIA_IsDialogPropertyId → const int
- UIA_IsDockPatternAvailablePropertyId → const int
- UIA_IsDragPatternAvailablePropertyId → const int
- UIA_IsDropTargetPatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsEnabledPropertyId → const int
- UIA_IsExpandCollapsePatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsGridItemPatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsGridPatternAvailablePropertyId → const int
- UIA_IsInvokePatternAvailablePropertyId → const int
- UIA_IsItemContainerPatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsKeyboardFocusablePropertyId → const int
- UIA_IsLegacyIAccessiblePatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsMultipleViewPatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsObjectModelPatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsOffscreenPropertyId → const int
- UIA_IsPasswordPropertyId → const int
- UIA_IsPeripheralPropertyId → const int
- UIA_IsRangeValuePatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsRequiredForFormPropertyId → const int
- UIA_IsScrollItemPatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsScrollPatternAvailablePropertyId → const int
- UIA_IsSelectionItemPatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsSelectionPattern2AvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsSelectionPatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsSpreadsheetItemPatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsSpreadsheetPatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsStylesPatternAvailablePropertyId → const int
- UIA_IsSynchronizedInputPatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsTableItemPatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsTablePatternAvailablePropertyId → const int
- UIA_IsTextChildPatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsTextEditPatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsTextPattern2AvailablePropertyId → const int
- UIA_IsTextPatternAvailablePropertyId → const int
- UIA_IsTogglePatternAvailablePropertyId → const int
- UIA_IsTransformPattern2AvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsTransformPatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsValuePatternAvailablePropertyId → const int
- UIA_IsVirtualizedItemPatternAvailablePropertyId → const UIA_PROPERTY_ID
- UIA_IsWindowPatternAvailablePropertyId → const int
- UIA_ItemStatusPropertyId → const int
- UIA_ItemTypePropertyId → const int
- UIA_LabeledByPropertyId → const int
- UIA_LandmarkTypePropertyId → const int
- UIA_LegacyIAccessibleChildIdPropertyId → const int
- UIA_LegacyIAccessibleDefaultActionPropertyId → const UIA_PROPERTY_ID
- UIA_LegacyIAccessibleDescriptionPropertyId → const UIA_PROPERTY_ID
- UIA_LegacyIAccessibleHelpPropertyId → const int
- UIA_LegacyIAccessibleKeyboardShortcutPropertyId → const UIA_PROPERTY_ID
- UIA_LegacyIAccessibleNamePropertyId → const int
- UIA_LegacyIAccessibleRolePropertyId → const int
- UIA_LegacyIAccessibleSelectionPropertyId → const UIA_PROPERTY_ID
- UIA_LegacyIAccessibleStatePropertyId → const int
- UIA_LegacyIAccessibleValuePropertyId → const int
- UIA_LevelPropertyId → const int
- UIA_LiveSettingPropertyId → const int
- UIA_LocalizedControlTypePropertyId → const int
- UIA_LocalizedLandmarkTypePropertyId → const int
- UIA_MultipleViewCurrentViewPropertyId → const int
- UIA_MultipleViewSupportedViewsPropertyId → const UIA_PROPERTY_ID
- UIA_NamePropertyId → const int
- UIA_NativeWindowHandlePropertyId → const int
- UIA_OptimizeForVisualContentPropertyId → const int
- UIA_OrientationPropertyId → const int
- UIA_OutlineColorPropertyId → const int
- UIA_OutlineThicknessPropertyId → const int
- UIA_PositionInSetPropertyId → const int
- UIA_ProcessIdPropertyId → const int
- UIA_ProviderDescriptionPropertyId → const int
- UIA_RangeValueIsReadOnlyPropertyId → const int
- UIA_RangeValueLargeChangePropertyId → const int
- UIA_RangeValueMaximumPropertyId → const int
- UIA_RangeValueMinimumPropertyId → const int
- UIA_RangeValueSmallChangePropertyId → const int
- UIA_RangeValueValuePropertyId → const int
- UIA_RotationPropertyId → const int
- UIA_RuntimeIdPropertyId → const int
- UIA_ScrollHorizontallyScrollablePropertyId → const UIA_PROPERTY_ID
- UIA_ScrollHorizontalScrollPercentPropertyId → const UIA_PROPERTY_ID
- UIA_ScrollHorizontalViewSizePropertyId → const int
- UIA_ScrollVerticallyScrollablePropertyId → const UIA_PROPERTY_ID
- UIA_ScrollVerticalScrollPercentPropertyId → const UIA_PROPERTY_ID
- UIA_ScrollVerticalViewSizePropertyId → const int
- UIA_Selection2CurrentSelectedItemPropertyId → const UIA_PROPERTY_ID
- UIA_Selection2FirstSelectedItemPropertyId → const UIA_PROPERTY_ID
- UIA_Selection2ItemCountPropertyId → const int
- UIA_Selection2LastSelectedItemPropertyId → const UIA_PROPERTY_ID
- UIA_SelectionCanSelectMultiplePropertyId → const UIA_PROPERTY_ID
- UIA_SelectionIsSelectionRequiredPropertyId → const UIA_PROPERTY_ID
- UIA_SelectionItemIsSelectedPropertyId → const int
- UIA_SelectionItemSelectionContainerPropertyId → const UIA_PROPERTY_ID
- UIA_SelectionSelectionPropertyId → const int
- UIA_SizeOfSetPropertyId → const int
- UIA_SizePropertyId → const int
- UIA_SpreadsheetItemAnnotationObjectsPropertyId → const UIA_PROPERTY_ID
- UIA_SpreadsheetItemAnnotationTypesPropertyId → const UIA_PROPERTY_ID
- UIA_SpreadsheetItemFormulaPropertyId → const int
- UIA_StylesExtendedPropertiesPropertyId → const int
- UIA_StylesFillColorPropertyId → const int
- UIA_StylesFillPatternColorPropertyId → const int
- UIA_StylesFillPatternStylePropertyId → const int
- UIA_StylesShapePropertyId → const int
- UIA_StylesStyleIdPropertyId → const int
- UIA_StylesStyleNamePropertyId → const int
- UIA_TableColumnHeadersPropertyId → const int
- UIA_TableItemColumnHeaderItemsPropertyId → const UIA_PROPERTY_ID
- UIA_TableItemRowHeaderItemsPropertyId → const int
- UIA_TableRowHeadersPropertyId → const int
- UIA_TableRowOrColumnMajorPropertyId → const int
- UIA_ToggleToggleStatePropertyId → const int
- UIA_Transform2CanZoomPropertyId → const int
- UIA_Transform2ZoomLevelPropertyId → const int
- UIA_Transform2ZoomMaximumPropertyId → const int
- UIA_Transform2ZoomMinimumPropertyId → const int
- UIA_TransformCanMovePropertyId → const int
- UIA_TransformCanResizePropertyId → const int
- UIA_TransformCanRotatePropertyId → const int
- UIA_ValueIsReadOnlyPropertyId → const int
- UIA_ValueValuePropertyId → const int
- UIA_VisualEffectsPropertyId → const int
- UIA_WindowCanMaximizePropertyId → const int
- UIA_WindowCanMinimizePropertyId → const int
- UIA_WindowIsModalPropertyId → const int
- UIA_WindowIsTopmostPropertyId → const int
- UIA_WindowWindowInteractionStatePropertyId → const UIA_PROPERTY_ID
- UIA_WindowWindowVisualStatePropertyId → const int