UNICODE_STRING class base struct

Used by various Local Security Authority (LSA) functions to specify a Unicode string.

To learn more, see learn.microsoft.com/windows/win32/api/subauth/ns-subauth-unicode_string.

Inheritance
Implemented types
Available extensions

Constructors

UNICODE_STRING()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
Buffer PWSTR
Pointer to a wide-character string.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
Length int
Specifies the length, in bytes, of the string pointed to by the Buffer member, not including the terminating NULL character, if any.
getter/setter pair
MaximumLength int
Specifies the total size, in bytes, of memory allocated for Buffer.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<UNICODE_STRING>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited