UiaChangeInfo class base struct

Contains data about a UI Automation change that occurred.

To learn more, see learn.microsoft.com/windows/win32/api/uiautomationcore/ns-uiautomationcore-uiachangeinfo.

Inheritance
Implemented types
Available extensions

Constructors

UiaChangeInfo()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
extraInfo VARIANT
Detailed information about the change that occurred.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
payload VARIANT
Information about the type of change that occurred.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uiaId int
Identifies the type of change info.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<UiaChangeInfo>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited