UserEnabled top-level constant
MACHINE_ATTRIBUTES
const UserEnabled
The specified architecture of code can run in user mode.
Implementation
const UserEnabled = MACHINE_ATTRIBUTES(1);
The specified architecture of code can run in user mode.
const UserEnabled = MACHINE_ATTRIBUTES(1);