VS_FIXEDFILEINFO class base struct

Contains version information for a file.

This information is language and code page independent.

To learn more, see learn.microsoft.com/windows/win32/api/verrsrc/ns-verrsrc-vs_fixedfileinfo.

Inheritance
Implemented types
Available extensions

Constructors

VS_FIXEDFILEINFO()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwFileDateLS int
The least significant 32 bits of the file's 64-bit binary creation date and time stamp.
getter/setter pair
dwFileDateMS int
The most significant 32 bits of the file's 64-bit binary creation date and time stamp.
getter/setter pair
dwFileFlags VS_FIXEDFILEINFO_FILE_FLAGS
getter/setter pair
dwFileFlagsMask int
Contains a bitmask that specifies the valid bits in dwFileFlags.
getter/setter pair
dwFileOS VS_FIXEDFILEINFO_FILE_OS
getter/setter pair
dwFileSubtype VS_FIXEDFILEINFO_FILE_SUBTYPE
The function of the file.
getter/setter pair
dwFileType VS_FIXEDFILEINFO_FILE_TYPE
getter/setter pair
dwFileVersionLS int
The least significant 32 bits of the file's binary version number.
getter/setter pair
dwFileVersionMS int
The most significant 32 bits of the file's binary version number.
getter/setter pair
dwProductVersionLS int
The least significant 32 bits of the binary version number of the product with which this file was distributed.
getter/setter pair
dwProductVersionMS int
The most significant 32 bits of the binary version number of the product with which this file was distributed.
getter/setter pair
dwSignature int
Contains the value 0xFEEF04BD.
getter/setter pair
dwStrucVersion int
The binary version number of this structure.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<VS_FIXEDFILEINFO>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited