WAVEHDR class base struct

Defines the header used to identify a waveform-audio buffer.

To learn more, see learn.microsoft.com/windows/win32/api/mmeapi/ns-mmeapi-wavehdr.

Inheritance
Implemented types
Available extensions
Annotations

Constructors

WAVEHDR()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwBufferLength int
Length, in bytes, of the buffer.
getter/setter pair
dwBytesRecorded int
When the header is used in input, specifies how much data is in the buffer.
getter/setter pair
dwFlags int
A bitwise OR of zero or more flags.
getter/setter pair
dwLoops int
Number of times to play the loop.
getter/setter pair
dwUser int
User data.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lpData PSTR
Pointer to the waveform buffer.
getter/setter pair
lpNext Pointer<WAVEHDR>
Reserved.
getter/setter pair
reserved int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<WAVEHDR>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited