WAVEOUTCAPS class base struct

Describes the capabilities of a waveform-audio output device.

To learn more, see learn.microsoft.com/windows/win32/api/mmeapi/ns-mmeapi-waveoutcapsw.

Inheritance
Implemented types
Available extensions
Annotations

Constructors

WAVEOUTCAPS()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwFormats int
Standard formats that are supported.
getter/setter pair
dwSupport int
Optional functionality supported by the device.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
szPname String
Product name in a string.
getter/setter pair
vDriverVersion int
Version number of the device driver for the device.
getter/setter pair
wChannels int
Number specifying whether the device supports mono (1) or stereo (2) output.
getter/setter pair
wMid int
Manufacturer identifier for the device driver for the device.
getter/setter pair
wPid int
Product identifier for the device.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<WAVEOUTCAPS>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited