WLAN_AVAILABLE_NETWORK_LIST class base struct

The WLAN_AVAILABLE_NETWORK_LIST structure contains an array of information about available networks.

Inheritance
Implemented types
Available extensions

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwIndex ↔ int
getter/setter pair
dwNumberOfItems ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
Network ↔ Array<WLAN_AVAILABLE_NETWORK>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited