WLAN_BSS_LIST class base struct

Contains a list of basic service set (BSS) entries.

To learn more, see learn.microsoft.com/windows/win32/api/wlanapi/ns-wlanapi-wlan_bss_list.

Inheritance
Implemented types
Available extensions

Constructors

WLAN_BSS_LIST()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwNumberOfItems int
The number of items in the wlanBssEntries member.
getter/setter pair
dwTotalSize int
The total size of this structure, in bytes.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wlanBssEntries Array<WLAN_BSS_ENTRY>
An array of WLAN_BSS_ENTRY structures that contains information about a BSS.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<WLAN_BSS_LIST>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited