Contains an array of device service GUIDs.
To learn more, see learn.microsoft.com/windows/win32/api/wlanapi/ns-wlanapi-wlan_device_service_guid_list.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
DeviceService
↔ Array<
GUID> -
A pointer to an array containing
[GUID]s; each corresponds to a WLAN device service that the driver supports.getter/setter pair - dwIndex ↔ int
-
The index of the current item.
getter/setter pair
- dwNumberOfItems ↔ int
-
The number of items in the DeviceService argument.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< WLAN_DEVICE_SERVICE_GUID_LIST> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited