WLAN_DEVICE_SERVICE_NOTIFICATION_DATA class base struct

A structure that represents a device service notification.

To learn more, see learn.microsoft.com/windows/win32/api/wlanapi/ns-wlanapi-wlan_device_service_notification_data.

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
DataBlob Array<Uint8>
A pointer to an array containing BYTESs, representing the data blob.
getter/setter pair
DeviceService GUID
The [GUID] identifying the device service for this notification.
getter/setter pair
dwDataSize int
The size, in bytes, of the DataBlob member.
getter/setter pair
dwOpCode int
The opcode that identifies the operation under the device service for this notification.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<WLAN_DEVICE_SERVICE_NOTIFICATION_DATA>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited