Contains information about the status of the wireless Hosted Network.
To learn more, see learn.microsoft.com/windows/win32/api/wlanapi/ns-wlanapi-wlan_hosted_network_status.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - dot11PhyType ↔ DOT11_PHY_TYPE
-
The physical type of the network interface used by wireless Hosted
Network.
getter/setter pair
- dwNumberOfPeers ↔ int
-
The current number of authenticated peers on the wireless Hosted Network.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- HostedNetworkState ↔ WLAN_HOSTED_NETWORK_STATE
-
The current state of the wireless Hosted Network.
getter/setter pair
- IPDeviceID ↔ GUID
-
The actual network Device ID used for the wireless Hosted Network.
getter/setter pair
-
PeerList
↔ Array<
WLAN_HOSTED_NETWORK_PEER_STATE> -
An array of WLAN_HOSTED_NETWORK_PEER_STATE
structures describing each of the current peers on the wireless Hosted
Network.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ulChannelFrequency ↔ int
-
The channel frequency of the network interface used by wireless Hosted
Network.
getter/setter pair
-
wlanHostedNetworkBSSID
↔ Array<
Uint8> -
The BSSID used by the wireless Hosted Network in packets, beacons, and
probe responses.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< WLAN_HOSTED_NETWORK_STATUS> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited