WLAN_MSM_NOTIFICATION_DATA class base struct

Contains information about media specific module (MSM) connection related notifications.

To learn more, see learn.microsoft.com/windows/win32/api/wlanapi/ns-wlanapi-wlan_msm_notification_data.

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bFirstPeer bool
Indicates whether the peer is the first to join the ad hoc network created by the machine.
getter/setter pair
bLastPeer bool
Indicates whether the peer is the last to leave the ad hoc network created by the machine.
getter/setter pair
bSecurityEnabled bool
Indicates whether security is enabled for this connection.
getter/setter pair
dot11BssType DOT11_BSS_TYPE
A DOT11_BSS_TYPE value that indicates the BSS network type.
getter/setter pair
dot11MacAddr Array<Uint8>
A DOT11_MAC_ADDRESS that specifies the MAC address of the peer or access point.
getter/setter pair
dot11Ssid DOT11_SSID
A DOT11_SSID structure that contains the SSID of the association.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strProfileName String
The name of the profile used for the connection.
getter/setter pair
wlanConnectionMode WLAN_CONNECTION_MODE
A WLAN_CONNECTION_MODE value that specifies the mode of the connection.
getter/setter pair
wlanReasonCode int
A WLAN_REASON_CODE that indicates the reason for an operation failure.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<WLAN_MSM_NOTIFICATION_DATA>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited