toNative method

Pointer<WLAN_MSM_NOTIFICATION_DATA> toNative({
  1. Allocator allocator = adaptiveCalloc,
})

Allocates native memory and copies the contents of this struct into it.

The returned pointer refers to newly allocated memory. The caller is responsible for freeing it, unless a scoped allocator (such as Arena) is used, in which case the allocator manages the lifetime.

Implementation

Pointer<WLAN_MSM_NOTIFICATION_DATA> toNative({
  Allocator allocator = adaptiveCalloc,
}) => allocator()..ref = this;