WM_ASKCBFORMATNAME top-level constant
int
const WM_ASKCBFORMATNAME
Sent to the clipboard owner by a clipboard viewer window to request the name of a CF_OWNERDISPLAY clipboard format.
To learn more, see learn.microsoft.com/windows/win32/dataxchg/wm-askcbformatname.
Implementation
const WM_ASKCBFORMATNAME = 780;