WM_COPY top-level constant
int
const WM_COPY
An application sends the WM_COPY message to an edit control or combo box to copy the current selection to the clipboard in CF_TEXT format.
To learn more, see learn.microsoft.com/windows/win32/dataxchg/wm-copy.
Implementation
const WM_COPY = 769;