WM_SETREDRAW top-level constant

int const WM_SETREDRAW

You send the WM_SETREDRAW message to a window to allow changes in that window to be redrawn, or to prevent changes in that window from being redrawn.

To learn more, see learn.microsoft.com/windows/win32/gdi/wm-setredraw.

Implementation

const WM_SETREDRAW = 11;