WM_SYSKEYUP top-level constant

int const WM_SYSKEYUP

Posted to the window with the keyboard focus when the user releases a key that was pressed while the ALT key was held down.

To learn more, see learn.microsoft.com/windows/win32/inputdev/wm-syskeyup.

Implementation

const WM_SYSKEYUP = 261;