WTA_OPTIONS class base struct

Defines options that are used to set window visual style attributes.

To learn more, see learn.microsoft.com/windows/win32/api/uxtheme/ns-uxtheme-wta_options.

Inheritance
Implemented types
Available extensions

Constructors

WTA_OPTIONS()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwFlags int
A combination of flags that modify window visual style attributes.
getter/setter pair
dwMask int
A bitmask that describes how the values specified in dwFlags should be applied.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<WTA_OPTIONS>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited