WbemRefresher top-level property
Provides an entry point through which refreshable objects such as enumerators or refresher objects, can be refreshed.
{c71566f2-561e-11d1-ad87-00c04fd8fdff}.
To learn more, see learn.microsoft.com/windows/win32/api/wbemcli/nn-wbemcli-iwbemrefresher.
Implementation
final WbemRefresher = GUID.fromComponents(
0xc71566f2,
0x561e,
0x11d1,
.fromList(const [0xad, 0x87, 0x0, 0xc0, 0x4f, 0xd8, 0xfd, 0xff]),
);