WidenPath function gdi32

bool WidenPath(
  1. HDC hdc
)

Redefines the current path as the area that would be painted if the path were stroked using the pen currently selected into the given device context.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/nf-wingdi-widenpath.

Implementation

@pragma('vm:prefer-inline')
bool WidenPath(HDC hdc) => _WidenPath(hdc) != FALSE;