waveOutReset function winmm

int waveOutReset(
  1. HWAVEOUT hwo
)

Stops playback on the given waveform-audio output device and resets the current position to zero.

All pending playback buffers are marked as done (WHDR_DONE) and returned to the application.

To learn more, see learn.microsoft.com/windows/win32/api/mmeapi/nf-mmeapi-waveoutreset.

Implementation

@pragma('vm:prefer-inline')
int waveOutReset(HWAVEOUT hwo) => _waveOutReset(hwo);