ADDRINFO class base struct

The addrinfoW structure is used by the GetAddrInfoW function to hold host address information.

Inheritance
Implemented types
Available extensions

Constructors

ADDRINFO()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
ai_addr ↔ Pointer<SOCKADDR>
getter/setter pair
ai_addrlen ↔ int
getter/setter pair
ai_canonname ↔ Pointer<Utf16>
getter/setter pair
ai_family ↔ int
getter/setter pair
ai_flags ↔ int
getter/setter pair
ai_next ↔ Pointer<ADDRINFO>
getter/setter pair
ai_protocol ↔ int
getter/setter pair
ai_socktype ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited