com topic
Windows APIs that use the COM invocation model.
See COM documentation.
Classes
-
ComCompanion<T extends ComInterface>
com
-
Companion metadata for a specific COM interface type
T.
-
ComInterface
com
-
Base interface for all COM types that participate in the companion system.
-
IAccessible
com
-
Exposes methods and properties that make a user interface element and its
children accessible to client applications.
-
IAgileObject
com
-
Marks an interface as agile across apartments.
-
IApplicationActivationManager
com
-
Provides methods which activate Windows Store apps for the Launch, File, and
Protocol extensions.
-
IAppxBlockMapBlock
com
-
Provides a read-only object that represents an individual block within a
file contained in the block map file (AppxBlockMap.xml) for the App package.
-
IAppxBlockMapBlocksEnumerator
com
-
Enumerates the blocks from a block map in a single file.
-
IAppxBlockMapFile
com
-
Represents a file in the block map.
-
IAppxBlockMapFilesEnumerator
com
-
Enumerates the files from a block map.
-
IAppxBlockMapReader
com
-
Represents a read-only object model for block maps that provides access to
the file attributes and block hashes.
-
IAppxFactory
com
-
Creates objects for reading and writing app packages.
-
IAppxFile
com
-
Retrieves information about a payload or footprint file in a package.
-
IAppxFilesEnumerator
com
-
Enumerates the payload files in a package.
-
IAppxManifestApplication
com
-
Provides access to attribute values of the application.
-
IAppxManifestApplicationsEnumerator
com
-
Enumerates the applications defined in the package manifest.
-
IAppxManifestCapabilitiesEnumerator
com
-
-
IAppxManifestDeviceCapabilitiesEnumerator
com
-
Enumerates the device capabilities defined in the package manifest.
-
IAppxManifestDriverConstraint
com
-
-
IAppxManifestDriverConstraintsEnumerator
com
-
-
IAppxManifestDriverDependenciesEnumerator
com
-
-
IAppxManifestDriverDependency
com
-
-
IAppxManifestHostRuntimeDependenciesEnumerator
com
-
-
IAppxManifestHostRuntimeDependency
com
-
-
IAppxManifestHostRuntimeDependency2
com
-
-
IAppxManifestMainPackageDependenciesEnumerator
com
-
Enumerates <MainPackageDependency> elements from an app manifest.
-
IAppxManifestMainPackageDependency
com
-
Provides access to attribute values of the main package dependency.
-
IAppxManifestOptionalPackageInfo
com
-
Provides access to attribute values of the optional package information.
-
IAppxManifestOSPackageDependenciesEnumerator
com
-
-
IAppxManifestOSPackageDependency
com
-
-
IAppxManifestPackageDependenciesEnumerator
com
-
Enumerates the package dependencies defined in the package manifest.
-
IAppxManifestPackageDependency
com
-
Describes the dependency of one package on another package.
-
IAppxManifestPackageId
com
-
Provides access to the package identity.
-
IAppxManifestProperties
com
-
Provides read-only access to the properties section of a package manifest.
-
IAppxManifestQualifiedResource
com
-
-
IAppxManifestQualifiedResourcesEnumerator
com
-
-
IAppxManifestReader
com
-
Represents an object model of the package manifest that provides methods to
access manifest elements and attributes.
-
IAppxManifestReader2
com
-
Represents an object model of the package manifest that provides methods to
access manifest elements and attributes.
-
IAppxManifestReader3
com
-
Represents an object model of the package manifest that provides methods to
access manifest elements and attributes.
-
IAppxManifestReader4
com
-
Represents an object model of the package manifest that provides methods to
access manifest elements and attributes.
-
IAppxManifestReader5
com
-
Represents an object model of the package manifest that provides methods to
access manifest elements and attributes.
-
IAppxManifestReader6
com
-
Represents an object model of the package manifest that provides methods to
access manifest elements and attributes.
-
IAppxManifestReader7
com
-
-
IAppxManifestResourcesEnumerator
com
-
Enumerates the resources defined in the package manifest.
-
IAppxManifestTargetDeviceFamiliesEnumerator
com
-
-
IAppxManifestTargetDeviceFamily
com
-
Retrieves information about the target device family from the
AppxManifest.xml.
-
IAppxPackageReader
com
-
Provides a read-only object model for app packages.
-
IAppxPackageWriter
com
-
Provides a write-only object model for app packages.
-
IAudioCaptureClient
com
-
Enables a client to read input data from a capture endpoint buffer.
-
IAudioClient
com
-
Enables a client to create and initialize an audio stream between an audio
application and the audio engine (for a shared-mode stream) or the hardware
buffer of an audio endpoint device (for an exclusive-mode stream).
-
IAudioClient2
com
-
Derived from the IAudioClient interface, with a set of additional methods
that enable a Windows Audio Session API (WASAPI) audio client to do the
following: opt in for offloading, query stream properties, and get
information from the hardware that handles offloading.
-
IAudioClient3
com
-
Derived from the IAudioClient2 interface, with a set of additional methods
that enable a Windows Audio Session API (WASAPI) audio client to query for
the audio engine's supported periodicities and current periodicity as well
as request initialization of a shared audio stream with a specified
periodicity.
-
IAudioClientDuckingControl
com
-
Provides a method, SetDuckingOptionsForCurrentStream, that allows an app to
specify that the system shouldn't duck the audio of other streams when the
app's audio render stream is active.
-
IAudioClock
com
-
Enables a client to monitor a stream's data rate and the current position in
the stream.
-
IAudioClock2
com
-
Used to get the current device position.
-
IAudioClockAdjustment
com
-
Used to adjust the sample rate of a stream.
-
IAudioRenderClient
com
-
Enables a client to write output data to a rendering endpoint buffer.
-
IAudioSessionControl
com
-
Enables a client to configure the control parameters for an audio session
and to monitor events in the session.
-
IAudioSessionControl2
com
-
Can be used by a client to get information about the audio session.
-
IAudioSessionEnumerator
com
-
Enumerates audio sessions on an audio device.
-
IAudioSessionEvents
com
-
Provides notifications of session-related events such as changes in the
volume level, display name, and session state.
-
IAudioSessionManager
com
-
Enables a client to access the session controls and volume controls for both
cross-process and process-specific audio sessions.
-
IAudioSessionManager2
com
-
Enables an application to manage submixes for the audio device.
-
IAudioSessionNotification
com
-
Provides notification when an audio session is created.
-
IAudioStreamVolume
com
-
Enables a client to control and monitor the volume levels for all of the
channels in an audio stream.
-
IAudioVolumeDuckNotification
com
-
Used to by the system to send notifications about stream attenuation
changes.
-
IBindCtx
com
-
Provides access to a bind context, which is an object that stores
information about a particular moniker binding operation.
-
IChannelAudioVolume
com
-
Enables a client to control and monitor the volume levels for all of the
channels in the audio session that the stream belongs to.
-
IClassFactory
com
-
Enables a class of objects to be created.
-
IConnectionPoint
com
-
Supports connection points for connectable objects.
-
IConnectionPointContainer
com
-
Supports connection points for connectable objects.
-
IDesktopWallpaper
com
-
Provides methods for managing the desktop wallpaper.
-
IDispatch
com
-
Exposes objects, methods and properties to programming tools and other
applications that support Automation.
-
IEnumConnectionPoints
com
-
Enumerates connection points.
-
IEnumConnections
com
-
Enumerates the current connections for a connectable object.
-
IEnumIDList
com
-
Exposes a standard set of methods used to enumerate the pointers to item
identifier lists (PIDLs) of the items in a Shell folder.
-
IEnumMoniker
com
-
Enumerates the components of a moniker or the monikers in a table of
monikers.
-
IEnumNetworkConnections
com
-
Provides a standard enumerator for network connections.
-
IEnumNetworks
com
-
A standard enumerator for networks.
-
IEnumResources
com
-
Exposes resource enumeration methods.
-
IEnumShellItems
com
-
Exposes enumeration of IShellItem interfaces.
-
IEnumSpellingError
com
-
An enumeration of the spelling errors.
-
IEnumSpObjectTokens
com
-
-
IEnumSTATSTG
com
-
Enumerates an array of STATSTG structures.
-
IEnumString
com
-
Enumerates strings.
-
IEnumVARIANT
com
-
Provides a method for enumerating a collection of variants, including
heterogeneous collections of objects and intrinsic types.
-
IEnumWbemClassObject
com
-
Used to enumerate Common Information Model (CIM) objects and is similar to a
standard COM enumerator.
-
IErrorInfo
com
-
Provides detailed contextual error information.
-
IFileDialog
com
-
Exposes methods that initialize, show, and get results from the common file
dialog.
-
IFileDialog2
com
-
Extends the IFileDialog interface by providing methods that allow the caller
to name a specific, restricted location that can be browsed in the common
file dialog as well as to specify alternate text to display as a label on
the Cancel button.
-
IFileDialogCustomize
com
-
Exposes methods that allow an application to add controls to a common file
dialog.
-
IFileDialogEvents
com
-
Exposes methods that allow notification of events within a common file
dialog.
-
IFileIsInUse
com
-
Exposes methods that can be called to get information on or close a file
that is in use by another application.
-
IFileOpenDialog
com
-
Extends the IFileDialog interface by adding methods specific to the open
dialog.
-
IFileOperationProgressSink
com
-
Exposes methods that provide a rich notification system used by callers of
IFileOperation to monitor the details of the operations they are performing
through that interface.
-
IFileSaveDialog
com
-
Extends the IFileDialog interface by adding methods specific to the save
dialog, which include those that provide support for the collection of
metadata to be persisted with the file.
-
IInitializeWithWindow
com
-
Exposes a method through which a client can provide an owner window to a
Windows Runtime object used in a desktop application.
-
IInspectable
com
-
Provides functionality required for all Windows Runtime classes.
-
IKnownFolder
com
-
Exposes methods that allow an application to retrieve information about a
known folder's category, type, GUID, pointer to an item identifier list
(PIDL) value, redirection capabilities, and definition.
-
IKnownFolderManager
com
-
Exposes methods that create, enumerate or manage existing known folders.
-
IMalloc
com
-
Allocates, frees, and manages memory.
-
IMetaDataAssemblyImport
com
-
Provides methods to access and examine the contents of an assembly manifest.
-
IMetaDataDispenser
com
-
Provides methods to create a new metadata scope, or open an existing one.
-
IMetaDataDispenserEx
com
-
Extends the IMetaDataDispenser interface to provide the capability to
control how the metadata APIs operate on the current metadata scope.
-
IMetaDataImport
com
-
Provides methods for importing and manipulating existing metadata from a
portable executable (PE) file or other source, such as a type library or a
stand-alone, run-time metadata binary.
-
IMetaDataImport2
com
-
Extends the IMetaDataImport interface to provide the capability of working
with generic types.
-
IMetaDataTables
com
-
Provides methods for the storage and retrieval of metadata information in
tables.
-
IMetaDataTables2
com
-
Extends IMetaDataTables to include methods for working with metadata
streams.
-
IMMDevice
com
-
Encapsulates the generic features of a multimedia device resource.
-
IMMDeviceCollection
com
-
Represents a collection of multimedia device resources.
-
IMMDeviceEnumerator
com
-
Provides methods for enumerating multimedia device resources.
-
IMMEndpoint
com
-
Represents an audio endpoint device.
-
IMMNotificationClient
com
-
Provides notifications when an audio endpoint device is added or removed,
when the state or properties of an endpoint device change, or when there is
a change in the default role assigned to an endpoint device.
-
IModalWindow
com
-
Exposes a method that represents a modal window.
-
IMoniker
com
-
Enables you to use a moniker object, which contains information that
uniquely identifies a COM object.
-
INetwork
com
-
Represents a network on the local machine.
-
INetworkConnection
com
-
Represents a single network connection.
-
INetworkListManager
com
-
Provides a set of methods to perform network list management functions.
-
INetworkListManagerEvents
com
-
INetworkListManagerEvents is a message sink interface that a client
implements to get overall machine state related events.
-
IOptionDescription
com
-
Represents the description of a spell checker option.
-
IPersist
com
-
Provides the CLSID of an object that can be stored persistently in the
system.
-
IPersistFile
com
-
Enables an object to be loaded from or saved to a disk file, rather than a
storage object or stream.
-
IPersistMemory
com
-
Saves and loads objects from a stream.
-
IPersistStream
com
-
Enables the saving and loading of objects that use a simple serial stream
for their storage needs.
-
IPortableDeviceKeyCollection
com
-
Holds a collection of PROPERTYKEY values.
-
IPortableDevicePropVariantCollection
com
-
Holds a collection of indexed PROPVARIANT values of the same VARTYPE.
-
IPortableDeviceValues
com
-
Holds a collection of PROPERTYKEY/PROPVARIANT pairs.
-
IPortableDeviceValuesCollection
com
-
Holds a collection of zero-based indexed IPortableDeviceValues interfaces.
-
IPropertyDescriptionList
com
-
Exposes methods that extract information from a collection of property
descriptions presented as a list.
-
IPropertyStore
com
-
This interface exposes methods used to enumerate and manipulate property
values.
-
IProvideClassInfo
com
-
Provides access to the type information for an object's coclass entry in its
type library.
-
IRawElementProviderSimple
com
-
Defines methods and properties that expose simple UI elements.
-
IRecordInfo
com
-
Describes the structure of a particular UDT.
-
IRestrictedErrorInfo
com
-
Represents the details of an error, including restricted error information.
-
IRunningObjectTable
com
-
Manages access to the running object table (ROT), a globally accessible
look-up table on each workstation.
-
ISensor
com
-
Represents a sensor.
-
ISensorCollection
com
-
Represents a collection of sensors, such as all the sensors connected to a
computer.
-
ISensorDataReport
com
-
Represents a sensor data report.
-
ISensorEvents
com
-
You must implement if you want to receive sensor events.
-
ISensorManager
com
-
Provides methods for discovering and retrieving available sensors and a
method to request sensor manager events.
-
ISensorManagerEvents
com
-
For receiving sensor manager events.
-
ISequentialStream
com
-
Supports simplified sequential access to stream objects.
-
IShellFolder
com
-
Exposed by all Shell namespace folder objects, its methods are used to
manage folders.
-
IShellItem
com
-
Exposes methods that retrieve information about a Shell item.
-
IShellItem2
com
-
Extends IShellItem with methods that retrieve various property values of the
item.
-
IShellItemArray
com
-
Exposes methods that create and manipulate Shell item arrays.
-
IShellItemFilter
com
-
Exposed by a client to specify how to filter the enumeration of a Shell item
by a server application.
-
IShellItemImageFactory
com
-
Exposes a method to return either icons or thumbnails for Shell items.
-
IShellItemResources
com
-
Exposes methods to manipulate and query Shell item resources.
-
IShellLink
com
-
Exposes methods that create, modify, and resolve Shell links.
-
IShellLinkDataList
com
-
Exposes methods that allow an application to attach extra data blocks to a
Shell link.
-
IShellLinkDual
com
-
-
IShellService
com
-
Exposes one method that declares ownership when a service component
implementing a certain interface is shared among multiple clients, such as
Windows Internet Explorer and Windows Explorer.
-
ISimpleAudioVolume
com
-
Enables a client to control the master volume level of an audio session.
-
ISpDataKey
com
-
-
ISpeechAudioFormat
com
-
-
ISpeechBaseStream
com
-
Defines properties and methods for manipulating data streams.
-
ISpeechDataKey
com
-
-
ISpeechObjectToken
com
-
-
ISpeechObjectTokenCategory
com
-
-
ISpeechObjectTokens
com
-
Represents a collection of SpObjectToken objects.
-
ISpeechVoice
com
-
-
ISpeechVoiceStatus
com
-
Defines the types of information returned by the SpVoice.Status method.
-
ISpeechWaveFormatEx
com
-
-
ISpellChecker
com
-
Represents a particular spell checker for a particular language.
-
ISpellChecker2
com
-
Represents a particular spell checker for a particular language, with the
added ability to remove words from the added words dictionary, or from the
ignore list.
-
ISpellCheckerChangedEventHandler
com
-
Allows the caller to create a handler for notifications that the state of
the speller has changed.
-
ISpellCheckerFactory
com
-
A factory for instantiating a spell checker (ISpellChecker) as well as
providing functionality for determining which languages are supported.
-
ISpellingError
com
-
Provides information about a spelling error.
-
ISpEventSource
com
-
Provides the mechanism to filter and queue events.
-
ISpNotifyCallback
com
-
-
ISpNotifySink
com
-
-
ISpNotifySource
com
-
Provides a mechanism for a notification but no information on the events
that caused the notification.
-
ISpObjectToken
com
-
-
ISpObjectTokenCategory
com
-
-
ISpStreamFormat
com
-
-
ISpVoice
com
-
Enables an application to perform text synthesis operations.
-
IStorage
com
-
Supports the creation and management of structured storage objects.
-
IStream
com
-
Lets you read and write data to stream objects.
-
ISupportErrorInfo
com
-
Ensures that error information can be propagated up the call chain
correctly.
-
ITypeComp
com
-
Provides a fast way to access information that compilers need when binding
to and instantiating structures and interfaces.
-
ITypeInfo
com
-
Used for reading information about objects.
-
ITypeLib
com
-
Represents a type library, the data that describes a set of objects.
-
IUIAutomation
com
-
Exposes methods that enable Microsoft UI Automation client applications to
discover, access, and filter UI Automation elements.
-
IUIAutomation2
com
-
Extends the IUIAutomation interface to expose additional methods for
controlling Microsoft UI Automation functionality.
-
IUIAutomation3
com
-
Extends the IUIAutomation2 interface to expose additional methods for
controlling Microsoft UI Automation functionality.
-
IUIAutomation4
com
-
Extends the IUIAutomation3 interface to expose additional methods for
controlling Microsoft UI Automation functionality.
-
IUIAutomation5
com
-
Extends the IUIAutomation4 interface to expose additional methods for
controlling Microsoft UI Automation functionality.
-
IUIAutomation6
com
-
Extends the IUIAutomation5 interface to expose additional methods for
controlling Microsoft UI Automation functionality.
-
IUIAutomationActiveTextPositionChangedEventHandler
com
-
Exposes a method to handle Microsoft UI Automation events that occur when
the active text position changes.
-
IUIAutomationAndCondition
com
-
Exposes properties and methods that Microsoft UI Automation client
applications can use to retrieve information about an AND-based property
condition.
-
IUIAutomationAnnotationPattern
com
-
Provides access to the properties of an annotation in a document.
-
IUIAutomationBoolCondition
com
-
Represents a condition that can be either TRUE (selects all elements) or
FALSE (selects no elements).
-
IUIAutomationCacheRequest
com
-
Exposes properties and methods of a cache request.
-
IUIAutomationChangesEventHandler
com
-
Exposes a method to handle one or more Microsoft UI Automation change
events.
-
IUIAutomationCondition
com
-
This is the primary interface for conditions used in filtering when
searching for elements in the UI Automation tree.
-
IUIAutomationCustomNavigationPattern
com
-
Exposes a method to support access by a Microsoft UI Automation client to
controls that support a custom navigation order.
-
IUIAutomationDockPattern
com
-
Provides access to a control that enables child elements to be arranged
horizontally and vertically, relative to each other.
-
IUIAutomationDragPattern
com
-
Provides access to information exposed by a UI Automation provider for an
element that can be dragged as part of a drag-and-drop operation.
-
IUIAutomationDropTargetPattern
com
-
Provides access to drag-and-drop information exposed by a Microsoft UI
Automation provider for an element that can be the drop target of a
drag-and-drop operation.
-
IUIAutomationElement
com
-
Exposes methods and properties for a UI Automation element, which represents
a UI item.
-
IUIAutomationElement2
com
-
Extends the IUIAutomationElement interface.
-
IUIAutomationElement3
com
-
Extends the IUIAutomationElement2 interface.
-
IUIAutomationElement4
com
-
Extends the IUIAutomationElement3 interface.
-
IUIAutomationElement5
com
-
Extends the IUIAutomationElement4 interface to provide access to current and
cached landmark data.
-
IUIAutomationElement6
com
-
Extends the IUIAutomationElement5 interface to provide access to current and
cached full descriptions.
-
IUIAutomationElement7
com
-
Extends the IUIAutomationElement6 interface.
-
IUIAutomationElement8
com
-
Extends the IUIAutomationElement7 interface.
-
IUIAutomationElement9
com
-
Extends the IUIAutomationElement8 interface.
-
IUIAutomationElementArray
com
-
Represents a collection of UI Automation elements.
-
IUIAutomationEventHandler
com
-
Exposes a method to handle Microsoft UI Automation events.
-
IUIAutomationEventHandlerGroup
com
-
Exposes methods for adding one or more events to a collection for bulk
registration through the CreateEventHandlerGroup and AddEventHandlerGroup
methods defined in IUIAutomation6.
-
IUIAutomationExpandCollapsePattern
com
-
Provides access to a control that can visually expand to display content,
and collapse to hide content.
-
IUIAutomationFocusChangedEventHandler
com
-
Exposes a method to handle events that are raised when the keyboard focus
moves to another UI Automation element.
-
IUIAutomationGridItemPattern
com
-
Provides access to a child control in a grid-style container that supports
the IUIAutomationGridPattern interface.
-
IUIAutomationGridPattern
com
-
Provides access to a control that acts as a container for a collection of
child controls that are organized in a two-dimensional logical coordinate
system that can be traversed by row and column.
-
IUIAutomationInvokePattern
com
-
Exposes a method that enables a client application to invoke the action of a
control (typically a button).
-
IUIAutomationItemContainerPattern
com
-
Exposes a method that retrieves an item from a container, such as a virtual
list.
-
IUIAutomationLegacyIAccessiblePattern
com
-
Exposes methods and properties that enable Microsoft UI Automation clients
to retrieve UI information from Microsoft Active Accessibility (MSAA)
servers.
-
IUIAutomationMultipleViewPattern
com
-
Provides access to a control that can switch between multiple
representations of the same information or set of child controls.
-
IUIAutomationNotCondition
com
-
Represents a condition that is the negative of another condition.
-
IUIAutomationNotificationEventHandler
com
-
Exposes a method to handle Microsoft UI Automation notification events.
-
IUIAutomationObjectModelPattern
com
-
Provides access to the underlying object model implemented by a control or
application.
-
IUIAutomationOrCondition
com
-
Represents a condition made up of multiple conditions, at least one of which
must be true.
-
IUIAutomationPropertyChangedEventHandler
com
-
Exposes a method to handle Microsoft UI Automation events that occur when a
property is changed.
-
IUIAutomationPropertyCondition
com
-
Represents a condition based on a property value that is used to find UI
Automation elements.
-
IUIAutomationProxyFactory
com
-
Exposes properties and methods of an object that creates a Microsoft UI
Automation provider for UI elements that do not have native support for UI
Automation.
-
IUIAutomationProxyFactoryEntry
com
-
Represents a proxy factory in the table maintained by Microsoft UI
Automation, and exposes properties and methods that can be used by client
applications to interact with IUIAutomationProxyFactory objects.
-
IUIAutomationProxyFactoryMapping
com
-
Exposes properties and methods for a table of proxy factories.
-
IUIAutomationRangeValuePattern
com
-
Provides access to a control that presents a range of values.
-
IUIAutomationScrollItemPattern
com
-
Exposes a method that enables an item in a scrollable view to be placed in a
visible portion of the view.
-
IUIAutomationScrollPattern
com
-
Provides access to a control that acts as a scrollable container for a
collection of child elements.
-
IUIAutomationSelectionItemPattern
com
-
Provides access to the selectable child items of a container control that
supports IUIAutomationSelectionPattern.
-
IUIAutomationSelectionPattern
com
-
Provides access to a control that contains selectable child items.
-
IUIAutomationSelectionPattern2
com
-
Extends the IUIAutomationSelectionPattern interface to provide information
about selected items.
-
IUIAutomationSpreadsheetItemPattern
com
-
Enables a client application to retrieve information about an item (cell) in
a spreadsheet.
-
IUIAutomationSpreadsheetPattern
com
-
Enables a client application to access the items (cells) in a spreadsheet.
-
IUIAutomationStructureChangedEventHandler
com
-
Exposes a method to handle events that occur when the Microsoft UI
Automation tree structure is changed.
-
IUIAutomationStylesPattern
com
-
Enables Microsoft UI Automation clients to retrieve the visual styles
associated with an element in a document.
-
IUIAutomationSynchronizedInputPattern
com
-
Provides access to the keyboard or mouse input of a control.
-
IUIAutomationTableItemPattern
com
-
Provides access to a child element in a container that supports
IUIAutomationTablePattern.
-
IUIAutomationTablePattern
com
-
Provides access to a control that acts as a container for a collection of
child elements.
-
IUIAutomationTextChildPattern
com
-
Provides access a text-based control (or an object embedded in text) that is
a child or descendant of another text-based control.
-
IUIAutomationTextEditPattern
com
-
Provides access to a control that modifies text, for example a control that
performs auto-correction or enables input composition through an Input
Method Editor (IME).
-
IUIAutomationTextEditTextChangedEventHandler
com
-
Exposes a method to handle events that occur when Microsoft UI Automation
reports a text-changed event from text edit controls.
-
IUIAutomationTextPattern
com
-
Provides access to a control that contains text.
-
IUIAutomationTextPattern2
com
-
Extends the IUIAutomationTextPattern interface.
-
Provides access to a span of continuous text in a container that supports
the IUIAutomationTextPattern interface.
-
Extends the IUIAutomationTextRange interface to enable Microsoft UI
Automation clients to programmatically invoke context menus.
-
Extends the IUIAutomationTextRange2 interface to support faster access to
the underlying rich text data on a text range.
-
Represents a collection of IUIAutomationTextRange objects.
-
IUIAutomationTogglePattern
com
-
Provides access to a control that can cycle through a set of states, and
maintain a state after it is set.
-
IUIAutomationTransformPattern
com
-
Provides access to a control that can be moved, resized, or rotated.
-
IUIAutomationTransformPattern2
com
-
Extends the IUIAutomationTransformPattern interface to enable Microsoft UI
Automation clients to programmatically access the viewport zooming
functionality of a control.
-
IUIAutomationTreeWalker
com
-
Exposes properties and methods that UI Automation client applications use to
view and navigate the UI Automation elements on the desktop.
-
IUIAutomationValuePattern
com
-
Provides access to a control that contains a value that does not span a
range and that can be represented as a string.
-
IUIAutomationVirtualizedItemPattern
com
-
Represents a virtualized item, which is an item that is represented by a
placeholder automation element in the Microsoft UI Automation tree.
-
IUIAutomationWindowPattern
com
-
Provides access to the fundamental functionality of a window.
-
IUnknown
com
-
The foundational COM interface that provides methods for querying other
interfaces and managing the lifecycle of a COM object.
-
IUri
com
-
Exposes methods and properties used to parse and build Uniform Resource
Identifiers (URIs).
-
IVirtualDesktopManager
com
-
Exposes methods that enable an application to interact with groups of
windows that form virtual workspaces.
-
IWbemCallResult
com
-
Used for semisynchronous calls of the IWbemServices interface.
-
IWbemClassObject
com
-
Contains and manipulates both class definitions and class object instances.
-
IWbemConfigureRefresher
com
-
Used by client code to add enumerators, objects, and nested refreshers into
a refresher.
-
IWbemContext
com
-
Used to communicate additional context information to providers when
submitting IWbemServices calls to WMI.
-
IWbemHiPerfEnum
com
-
Used in refresher operations to provide rapid access to enumerations of
instance objects.
-
IWbemLocator
com
-
Use the IWbemLocator interface to obtain the initial namespace pointer to
the IWbemServices interface for WMI on a specific host computer.
-
IWbemObjectAccess
com
-
Provides access to the methods and properties of an object.
-
IWbemObjectSink
com
-
Creates a sink interface that can receive all types of notifications within
the WMI programming model.
-
IWbemQualifierSet
com
-
Acts as a container for the entire set of named qualifiers for a single
property or entire object (a class or instance).
-
IWbemRefresher
com
-
Provides an entry point through which refreshable objects such as
enumerators or refresher objects, can be refreshed.
-
IWbemServices
com
-
Used by clients and providers to access WMI services.
-
IWebAuthenticationCoreManagerInterop
com
-
Contains core methods for obtaining tokens from web account providers.
-
IWinHttpRequest
com
-
Provides all of the nonevent methods for Microsoft Windows HTTP Services
(WinHTTP).
Properties
-
isComInitialized
→ bool
com
-
Returns
true if the Component Object Model (COM) is initialized on the
current thread.
no setter
Functions
-
createInstance<T extends IUnknown>(GUID clsid)
→ T
com
-
Creates a COM object instance identified by
clsid and returns it as the
interface specified by T.