comctl32 topic
Common Controls Library
Implements a wide variety of standard Windows controls, such as File Open, Save, and Save As dialogs, progress bars, and list views. It creates and manages the windows for these UI elements, places various graphic elements within them, and collects user input.
Functions
-
DefSubclassProc(
HWND hWnd, int uMsg, WPARAM wParam, LPARAM lParam) → LRESULT comctl32 - Calls the next handler in a window's subclass chain.
-
DrawStatusText(
HDC hDC, Pointer< comctl32RECT> lprc, PCWSTR pszText, int uFlags) → void - Draws the specified text in the style of a status window with borders.
-
ImageList_Destroy(
HIMAGELIST? himl) → bool comctl32 - Destroys an image list.
-
InitCommonControlsEx(
Pointer< comctl32INITCOMMONCONTROLSEX> picce) → bool - Ensures that the common control DLL (Comctl32.dll) is loaded, and registers specific common control classes from the DLL.
-
RemoveWindowSubclass(
HWND hWnd, Pointer< comctl32NativeFunction< pfnSubclass, int uIdSubclass) → boolSUBCLASSPROC> > - Removes a subclass callback from a window.
-
SetWindowSubclass(
HWND hWnd, Pointer< comctl32NativeFunction< pfnSubclass, int uIdSubclass, int dwRefData) → boolSUBCLASSPROC> > - Installs or updates a window subclass callback.
-
TaskDialog(
HWND? hwndOwner, HINSTANCE? hInstance, PCWSTR? pszWindowTitle, PCWSTR? pszMainInstruction, PCWSTR? pszContent, TASKDIALOG_COMMON_BUTTON_FLAGS dwCommonButtons, PCWSTR? pszIcon, Pointer< comctl32Int32> ? pnButton) → void - Creates, displays, and operates a task dialog.
-
TaskDialogIndirect(
Pointer< comctl32TASKDIALOGCONFIG> pTaskConfig, Pointer<Int32> ? pnButton, Pointer<Int32> ? pnRadioButton, Pointer<Int32> ? pfVerificationFlagChecked) → void - Creates, displays, and operates a task dialog.