crypt32 topic
Cryptographic API
Application programming interface that enables application developers to add authentication, encoding, and encryption to Windows-based applications.
Functions
-
CryptProtectData(
Pointer< crypt32CRYPT_INTEGER_BLOB> pDataIn, PCWSTR? szDataDescr, Pointer<CRYPT_INTEGER_BLOB> ? pOptionalEntropy, Pointer<CRYPTPROTECT_PROMPTSTRUCT> ? pPromptStruct, int dwFlags, Pointer<CRYPT_INTEGER_BLOB> pDataOut) → Win32Result<bool> - Performs encryption on the data in a DATA_BLOB structure.
-
CryptProtectMemory(
Pointer< crypt32NativeType> pDataIn, int cbDataIn, int dwFlags) → Win32Result<bool> - Encrypts memory to prevent others from viewing sensitive information in your process.
-
CryptUnprotectData(
Pointer< crypt32CRYPT_INTEGER_BLOB> pDataIn, Pointer<Pointer< ? ppszDataDescr, Pointer<Utf16> >CRYPT_INTEGER_BLOB> ? pOptionalEntropy, Pointer<CRYPTPROTECT_PROMPTSTRUCT> ? pPromptStruct, int dwFlags, Pointer<CRYPT_INTEGER_BLOB> pDataOut) → Win32Result<bool> - Decrypts and does an integrity check of the data in a DATA_BLOB structure.
-
CryptUnprotectMemory(
Pointer< crypt32NativeType> pDataIn, int cbDataIn, int dwFlags) → Win32Result<bool> - Decrypts memory that was encrypted using the CryptProtectMemory function.
-
CryptUpdateProtectedState(
PSID? pOldSid, PCWSTR? pwszOldPassword, int dwFlags, Pointer< crypt32Uint32> ? pdwSuccessCount, Pointer<Uint32> ? pdwFailureCount) → Win32Result<bool> - Migrates the current user's master keys after the user's security identifier (SID) has changed.