netapi32 topic
Network Management API
The network management functions provide the ability to manage user accounts and network resources.
Functions
-
NetFreeAadJoinInformation(
Pointer< netapi32DSREG_JOIN_INFO> ? pJoinInfo) → void - Frees the memory allocated for the specified DSREG_JOIN_INFO structure, which contains join information for a tenant and which you retrieved by calling the NetGetAadJoinInformation function.
-
NetGetAadJoinInformation(
PCWSTR? pcszTenantId) → Pointer< netapi32DSREG_JOIN_INFO> - Retrieves the join information for the specified tenant.