ntdll topic
Native API
The Native API is the interface used by user-mode components of the operating system that must run without support from Win32 or other API subsystems.
Functions
-
NtQuerySystemInformation(
SYSTEM_INFORMATION_CLASS systemInformationClass, Pointer< ntdllNativeType> systemInformation, int systemInformationLength, Pointer<Uint32> returnLength) → NTSTATUS - Retrieves the specified system information.
-
RtlGetVersion(
Pointer< ntdllOSVERSIONINFO> lpVersionInformation) → NTSTATUS - Gets version information about the currently running operating system.