ole32 topic
OLE/COM APIs
Provides the Component Object Model (COM), as well as Object Linking and Embedding (OLE).
Functions
-
CLSIDFromProgID(
PCWSTR lpszProgID) → Pointer< ole32GUID> - Looks up a CLSID in the registry, given a ProgID.
-
CLSIDFromProgIDEx(
PCWSTR lpszProgID) → Pointer< ole32GUID> - Triggers automatic installation if the COMClassStore policy is enabled.
-
CLSIDFromString(
PCWSTR lpsz) → Pointer< ole32GUID> - Converts a string generated by the StringFromCLSID function back into the original CLSID.
-
CoAddRefServerProcess(
) → int ole32 - Increments a global per-process reference count.
-
CoCreateGuid(
) → Pointer< ole32GUID> - Creates a GUID, a unique 128-bit integer used for CLSIDs and interface identifiers.
-
CoCreateInstance<
T extends IUnknown> (Pointer< ole32GUID> rclsid, IUnknown? pUnkOuter, CLSCTX dwClsContext) → T - Creates a single uninitialized object of the class associated with a specified CLSID.
-
CoDecrementMTAUsage(
CO_MTA_USAGE_COOKIE cookie) → void ole32 - Releases the increment made by a previous call to the CoIncrementMTAUsage function.
-
CoGetApartmentType(
Pointer< ole32Int32> pAptType, Pointer<Int32> pAptQualifier) → void - Returns the current apartment type and type qualifier.
-
CoGetClassObject<
T extends IUnknown> (Pointer< ole32GUID> rclsid, CLSCTX dwClsContext) → T - Provides a pointer to an interface on a class object associated with a specified CLSID.
-
CoGetCurrentProcess(
) → int ole32 - Returns a value that is unique to the current thread.
-
CoGetMalloc(
int dwMemContext) → IMalloc? ole32 - Retrieves a pointer to the default OLE task memory allocator (which supports the system implementation of the IMalloc interface) so applications can call its methods to manage memory.
-
CoIncrementMTAUsage(
) → CO_MTA_USAGE_COOKIE ole32 - Keeps MTA support active when no MTA threads are running.
-
CoInitializeEx(
COINIT dwCoInit) → HRESULT ole32 - Initializes the COM library for use by the calling thread, sets the thread's concurrency model, and creates a new apartment for the thread if one is required.
-
CoInitializeSecurity(
PSECURITY_DESCRIPTOR? pSecDesc, int cAuthSvc, Pointer< ole32SOLE_AUTHENTICATION_SERVICE> ? asAuthSvc, RPC_C_AUTHN_LEVEL dwAuthnLevel, RPC_C_IMP_LEVEL dwImpLevel, Pointer<NativeType> ? pAuthList, EOLE_AUTHENTICATION_CAPABILITIES dwCapabilities) → void - Registers security and sets the default security values for the process.
-
CoSetProxyBlanket(
IUnknown? pProxy, int dwAuthnSvc, int dwAuthzSvc, PCWSTR? pServerPrincName, RPC_C_AUTHN_LEVEL dwAuthnLevel, RPC_C_IMP_LEVEL dwImpLevel, Pointer< ole32NativeType> ? pAuthInfo, EOLE_AUTHENTICATION_CAPABILITIES dwCapabilities) → void - Sets the authentication information that will be used to make calls on the specified proxy.
-
CoTaskMemAlloc(
int cb) → Pointer< ole32NativeType> -
Allocates a block of task memory in the same way that
IMalloc.allocdoes. -
CoTaskMemFree(
Pointer< ole32NativeType> ? pv) → void - Frees a block of task memory previously allocated through a call to the CoTaskMemAlloc or CoTaskMemRealloc function.
-
CoTaskMemRealloc(
Pointer< ole32NativeType> ? pv, int cb) → Pointer<NativeType> - Changes the size of a previously allocated block of task memory.
-
CoUninitialize(
) → void ole32 - Closes the COM library on the current thread, unloads all DLLs loaded by the thread, frees any other resources that the thread maintains, and forces all RPC connections on the thread to close.
-
CoWaitForMultipleHandles(
int dwFlags, int dwTimeout, int cHandles, Pointer< ole32Pointer< pHandles) → intNativeType> > - Waits for specified handles to be signaled or for a specified timeout period to elapse.
-
CoWaitForMultipleObjects(
int dwFlags, int dwTimeout, int cHandles, Pointer< ole32Pointer< pHandles) → intNativeType> > - A replacement for CoWaitForMultipleHandles.
-
CreateStreamOnHGlobal(
HGLOBAL? hGlobal, bool fDeleteOnRelease) → IStream? ole32 - Creates a stream object that uses an HGLOBAL memory handle to store the stream contents.
-
GetClassFile(
PCWSTR szFilename) → Pointer< ole32GUID> - Returns the CLSID associated with the specified file name.
-
GetHGlobalFromStream(
IStream? pstm) → HGLOBAL ole32 - Retrieves the global memory handle to a stream that was created through a call to the CreateStreamOnHGlobal function.
-
IIDFromString(
PCWSTR lpsz) → Pointer< ole32GUID> - Converts a string generated by the StringFromIID function back into the original interface identifier (IID).
-
OleInitialize(
) → void ole32 - Initializes the COM library on the current apartment and identifies the concurrency model as single-thread apartment (STA).
-
OleUninitialize(
) → void ole32 - Closes the COM library on the apartment, releases any class factories, other COM objects, or servers held by the apartment, disables RPC on the apartment, and frees any resources the apartment maintains.
-
ProgIDFromCLSID(
Pointer< ole32GUID> clsid) → PWSTR - Retrieves the ProgID for a given CLSID.
-
PropVariantClear(
Pointer< ole32PROPVARIANT> pvar) → void - Frees all elements that can be freed in a given PROPVARIANT structure.
-
PropVariantCopy(
Pointer< ole32PROPVARIANT> pvarDest, Pointer<PROPVARIANT> pvarSrc) → void - Copies the contents of one PROPVARIANT structure to another.
-
PropVariantInit(
Pointer< ole32PROPVARIANT> pvar) → void - Initializes a PROPVARIANT structure.
-
StringFromCLSID(
Pointer< ole32GUID> rclsid) → PWSTR - Converts a CLSID into a string of printable characters.
-
StringFromGUID2(
Pointer< ole32GUID> rguid, PWSTR lpsz, int cchMax) → int - Converts a globally unique identifier (GUID) into a string of printable characters.
-
StringFromIID(
Pointer< ole32GUID> rclsid) → PWSTR - Converts an interface identifier into a string of printable characters.