onecore topic
OneCore API
APIs associated with the OneCore effort.
Functions
-
GetCommPorts(
Pointer< onecoreUint32> lpPortNumbers, int uPortNumbersCount, Pointer<Uint32> puPortNumbersFound) → int - Gets an array that contains the well-formed COM ports.
-
GetIntegratedDisplaySize(
) → double onecore - Retrieves the best estimate of the diagonal size of the built-in screen, in inches.
-
GetServiceDirectory(
SERVICE_STATUS_HANDLE hServiceStatus, SERVICE_DIRECTORY_TYPE eDirectoryType, PWSTR? lpPathBuffer, int cchPathBufferLength, Pointer< onecoreUint32> lpcchRequiredBufferLength) → int - Returns a path for a per-service filesystem location for a service to read and/or write state to.
-
GetServiceRegistryStateKey(
SERVICE_STATUS_HANDLE serviceStatusHandle, SERVICE_REGISTRY_STATE_TYPE stateType, int accessMask, Pointer< onecorePointer< serviceStateKey) → intNativeType> > - Returns a handle for a registry key for a service to read and/or write state to.
- Returns a path for a per-service filesystem location for a service and associated programs to read and/or write state to.
- Returns a handle for a registry key for a service and associated programs to read and/or write state to.
-
IsApiSetImplemented(
PCSTR contract) → bool onecore - Tests if a specified API set is present on the computer.
-
OpenCommPort(
int uPortNumber, int dwDesiredAccess, int dwFlagsAndAttributes) → HANDLE onecore - Attempts to open a communication device.