shlwapi topic
Shell Lightweight Utility Library
Contains a collection of functions that provide support for various shell operations, such as file and folder manipulation, user interface elements, and internet-related tasks.
Contains a collection of functions that provide support for various shell operations, such as file and folder manipulation, user interface elements, and internet-related tasks.