struct topic
Structs
Structs used in the Win32 API.
Classes
- ACCEL struct
- Defines an accelerator key used in an accelerator table.
- ACCENT_POLICY struct
- Determines how a window's background is rendered.
- ACL struct
- Header of an access control list (ACL).
- ACTCTX struct
- Used by the CreateActCtx function to create the activation context.
- ADDJOB_INFO_1 struct
- Identifies a print job as well as the directory and file in which an application can store that job.
- ADDRINFO struct
- Used by the GetAddrInfoW function to hold host address information.
- ALTTABINFO struct
- Contains status information for the application-switching (ALT+TAB) window.
- APPX_PACKAGE_SETTINGS struct
- Represents package settings used to create a package.
- ARRAYDESC struct
- Describes an array, its element type, and its dimension.
- ASSEMBLYMETADATA struct
- AudioClientProperties struct
- Used to set the parameters that describe the properties of the client's audio stream.
- BIND_OPTS struct
- Contains parameters used during a moniker-binding operation.
- BITMAP struct
- Defines the type, width, height, color format, and bit values of a bitmap.
- BITMAPFILEHEADER struct
- Contains information about the type, size, and layout of a file that contains a DIB.
- BITMAPINFO struct
- Defines the dimensions and color information for a DIB.
- BITMAPINFOHEADER struct
- Contains information about the dimensions and color format of a device-independent bitmap (DIB).
- BITMAPV5HEADER struct
- The bitmap information header file.
- BLENDFUNCTION struct
- Controls blending by specifying the blending functions for source and destination bitmaps.
- BLOB struct
- Contains information about a block of data.
- BLUETOOTH_ADDRESS struct
- BLUETOOTH_AUTHENTICATE_RESPONSE struct
- Contains information passed in response to a BTH_REMOTE_AUTHENTICATE_REQUEST event.
- BLUETOOTH_AUTHENTICATION_CALLBACK_PARAMS struct
- Contains specific configuration information about the Bluetooth device responding to an authentication request.
- BLUETOOTH_COD_PAIRS struct
- Provides for specification and retrieval of Bluetooth Class Of Device (COD) information.
- BLUETOOTH_DEVICE_INFO struct
- BLUETOOTH_DEVICE_SEARCH_PARAMS struct
- Specifies search criteria for Bluetooth device searches.
- BLUETOOTH_FIND_RADIO_PARAMS struct
- Facilitates enumerating installed Bluetooth radios.
- BLUETOOTH_GATT_VALUE_CHANGED_EVENT struct
- Describes a changed attribute value.
- BLUETOOTH_GATT_VALUE_CHANGED_EVENT_REGISTRATION struct
- Describes one or more characteristics that have changed.
- BLUETOOTH_NUMERIC_COMPARISON_INFO struct
- Contains the numeric value used for authentication via numeric comparison.
- BLUETOOTH_OOB_DATA_INFO struct
- Contains data used to authenticate prior to establishing an Out-of-Band device pairing.
- BLUETOOTH_PASSKEY_INFO struct
- Contains a passkey value used for authentication.
- BLUETOOTH_PIN_INFO struct
- Contains information used for authentication via PIN.
- BLUETOOTH_RADIO_INFO struct
- Contains information about a Bluetooth radio.
- BLUETOOTH_SELECT_DEVICE_PARAMS struct
- Facilitates and manages the visibility, authentication, and selection of Bluetooth devices and services.
- BROWSEINFO struct
- Contains parameters for the SHBrowseForFolder function and receives information about the folder selected by the user.
- BSMINFO struct
- Contains information about a window that denied a request from BroadcastSystemMessageEx.
- BSTRBLOB struct
- BTH_DEVICE_INFO struct
- Stores information about a Bluetooth device.
- BTH_HCI_EVENT_INFO struct
- Used in connection with obtaining WM_DEVICECHANGE messages for Bluetooth.
- BTH_L2CAP_EVENT_INFO struct
- Contains data about events associated with an L2CAP channel.
- BTH_LE_GATT_CHARACTERISTIC struct
- Describes a Bluetooth Low Energy (LE) generic attribute (GATT) profile characteristic.
- BTH_LE_GATT_CHARACTERISTIC_VALUE struct
- Describes a Bluetooth Low Energy (LE) generic attribute (GATT) profile characteristic value.
- BTH_LE_GATT_DESCRIPTOR struct
- Describes a Bluetooth Low Energy (LE) generic attribute (GATT) profile descriptor.
- BTH_LE_GATT_DESCRIPTOR_VALUE struct
- Describes a parent characteristic.
- BTH_LE_GATT_DESCRIPTOR_VALUE_0_0 struct
- BTH_LE_GATT_DESCRIPTOR_VALUE_0_1 struct
- BTH_LE_GATT_DESCRIPTOR_VALUE_0_2 struct
- BTH_LE_GATT_DESCRIPTOR_VALUE_0_3 struct
- BTH_LE_GATT_SERVICE struct
- Describes a Bluetooth Low Energy (LE) generic attribute (GATT) profile service.
- BTH_LE_UUID struct
- Contains information about a Bluetooth Low Energy (LE) Universally Unique Identifier (UUID).
- BTH_QUERY_DEVICE struct
- Used when querying for the presence of a Bluetooth device.
- BTH_QUERY_SERVICE struct
- Used to query a Bluetooth service.
- BTH_RADIO_IN_RANGE struct
- Stores data about Bluetooth devices within communication range.
- BTH_SET_SERVICE struct
- Provides service information for the specified Bluetooth service.
- BY_HANDLE_FILE_INFORMATION struct
- Contains information that the GetFileInformationByHandle function retrieves.
- CABOOL struct
- CABSTR struct
- CABSTRBLOB struct
- CAC struct
- CACHE_DESCRIPTOR struct
- Describes the cache attributes.
- CACLIPDATA struct
- CACLSID struct
- CACY struct
- CADATE struct
- CADBL struct
- CAFILETIME struct
- CAFLT struct
- CAH struct
- CAI struct
- CAL struct
- CALPSTR struct
- CALPWSTR struct
- CAPROPVARIANT struct
- CASCODE struct
- CAUB struct
- CAUH struct
- CAUI struct
- CAUL struct
- CBT_CREATEWND struct
- Contains information passed to a WH_CBT hook procedure, CBTProc, before a window is created.
- CBTACTIVATESTRUCT struct
- Contains information passed to a WH_CBT hook procedure, CBTProc, before a window is activated.
- CERT_CONTEXT struct
- Contains both the encoded and decoded representations of a certificate.
- CERT_EXTENSION struct
- Contains the extension information for a certificate, Certificate Revocation List (CRL) or Certificate Trust List (CTL).
- CERT_INFO struct
- Contains the information of a certificate.
- CERT_PUBLIC_KEY_INFO struct
- Contains a public key and its algorithm.
- CHANGEFILTERSTRUCT struct
- Contains extended result information obtained by calling the ChangeWindowMessageFilterEx function.
- CHAR_INFO struct
- Specifies a Unicode or ANSI character and its attributes.
- CHOOSECOLOR struct
- Contains information the ChooseColor function uses to initialize the Color dialog box.
- CHOOSEFONT struct
- Contains information that the ChooseFont function uses to initialize the Font dialog box.
- CIEXYZ struct
- Contains the x,y, and z coordinates of a specific color in a specified color space.
- CIEXYZTRIPLE struct
- Contains the x,y, and z coordinates of the three colors that correspond to the red, green, and blue endpoints for a specified logical color space.
- CLIENT_ID struct
- CLIPDATA struct
- COLORADJUSTMENT struct
- Defines the color adjustment values used by the StretchBlt and StretchDIBits functions when the stretch mode is HALFTONE.
- COMDLG_FILTERSPEC struct
- Used generically to filter elements.
- COMMCONFIG struct
- Contains information about the configuration state of a communications device.
- COMMPROP struct
- Contains information about a communications driver.
- COMMTIMEOUTS struct
- Contains the time-out parameters for a communications device.
- COMSTAT struct
- Contains information about a communications device.
- CONDITION_VARIABLE struct
- CONNECTDATA struct
- Describes a connection that exists to a given connection point.
- CONSOLE_CURSOR_INFO struct
- Contains the size and visibility information about the about the console cursor.
- CONSOLE_READCONSOLE_CONTROL struct
- Contains information for a console read operation.
- CONSOLE_SCREEN_BUFFER_INFO struct
- Contains information about a console screen buffer.
- CONSOLE_SELECTION_INFO struct
- Contains information for a console selection.
- COORD struct
- Defines the coordinates of a character cell in a console screen buffer.
- COR_FIELD_OFFSET struct
- CREATEFILE2_EXTENDED_PARAMETERS struct
- Contains optional extended parameters for CreateFile2.
- CREATESTRUCT struct
- Defines the initialization parameters passed to the window procedure of an application.
- CREDENTIAL struct
- Contains an individual credential.
- CREDENTIAL_ATTRIBUTE struct
- Contains an application-defined attribute of the credential.
- CRYPT_ALGORITHM_IDENTIFIER struct
- Specifies an algorithm used to encrypt a private key.
- CRYPT_BIT_BLOB struct
- Contains a set of bits represented by an array of bytes.
- CRYPT_INTEGER_BLOB struct
- Used for an arbitrary array of bytes.
- CRYPTPROTECT_PROMPTSTRUCT struct
- Provides the text of a prompt and information about when and where that prompt is to be displayed when using the CryptProtectData and CryptUnprotectData functions.
- CURSORINFO struct
- Contains global cursor information.
- CWPRETSTRUCT struct
- Defines the message parameters passed to a WH_CALLWNDPROCRET hook procedure, CallWndRetProc.
- CWPSTRUCT struct
- Defines the message parameters passed to a WH_CALLWNDPROC hook procedure, CallWndProc.
- CY_0 struct
- DCB struct
- Defines the control setting for a serial communications device.
- DEBUGHOOKINFO struct
- Contains debugging information passed to a WH_DEBUG hook procedure, DebugProc.
- DECIMAL struct
- Represents a decimal data type that provides a sign and scale for a number.
- DECIMAL_0_0 struct
- DECIMAL_1_0 struct
- DESIGNVECTOR struct
- Used by an application to specify values for the axes of a multiple master font.
- DEV_BROADCAST_DEVICEINTERFACE struct
- Contains information about a class of devices.
- DEV_BROADCAST_HDR struct
- Serves as a standard header for information related to a device event reported through the WM_DEVICECHANGE message.
- DEV_BROADCAST_VOLUME struct
- Contains information about a logical volume.
- DEVMODE struct
- Used for specifying characteristics of display and print devices in the Unicode (wide) character set.
- DEVMODE_0_0 struct
- DEVMODE_0_1 struct
- DEVPROPKEY struct
- DIBSECTION struct
- Contains information about a DIB created by calling the CreateDIBSection function.
- DISK_EXTENT struct
- Represents a disk extent.
- DISK_GEOMETRY struct
- Describes the geometry of disk devices and media.
- DISK_GEOMETRY_EX struct
- Describes the extended geometry of disk devices and media.
- DISPLAY_DEVICE struct
- Receives information about the display device specified by the iDevNum parameter of the EnumDisplayDevices function.
- DISPLAYCONFIG_2DREGION struct
- Represents a point or an offset in a two-dimensional space.
- DISPLAYCONFIG_DESKTOP_IMAGE_INFO struct
- Contains information about the image displayed on the desktop.
- DISPLAYCONFIG_DEVICE_INFO_HEADER struct
- Contains display information about the device.
- DISPLAYCONFIG_MODE_INFO struct
- Contains either source mode or target mode information.
- DISPLAYCONFIG_PATH_INFO struct
- Used to describe a single path from a target to a source.
- DISPLAYCONFIG_PATH_SOURCE_INFO struct
- Contains source information for a single path.
- DISPLAYCONFIG_PATH_SOURCE_INFO_0_0 struct
- DISPLAYCONFIG_PATH_TARGET_INFO struct
- Contains target information for a single path.
- DISPLAYCONFIG_PATH_TARGET_INFO_0_0 struct
- DISPLAYCONFIG_RATIONAL struct
- Describes a fractional value that represents vertical and horizontal frequencies of a video mode (that is, vertical sync and horizontal sync).
- DISPLAYCONFIG_SOURCE_MODE struct
- Represents a point or an offset in a two-dimensional space.
- DISPLAYCONFIG_TARGET_MODE struct
- Describes a display path target mode.
- DISPLAYCONFIG_VIDEO_SIGNAL_INFO struct
- Contains information about the video signal for a display.
- DISPLAYCONFIG_VIDEO_SIGNAL_INFO_0_0 struct
- DISPPARAMS struct
- Contains the arguments passed to a method or property.
- DLGITEMTEMPLATE struct
- Defines the dimensions and style of a control in a dialog box.
- DLGTEMPLATE struct
- Defines the dimensions and style of a dialog box.
- DLLVERSIONINFO struct
- Receives DLL-specific version information.
- DOC_INFO_1 struct
- Describes a document that will be printed.
- DOT11_AUTH_CIPHER_PAIR struct
- Defines a pair of 802.11 authentication and cipher algorithms that can be enabled at the same time on the 802.11 station.
- DOT11_BSSID_LIST struct
- Contains a list of basic service set (BSS) identifiers.
- DOT11_NETWORK struct
- Contains information about an available wireless network.
- DOT11_NETWORK_LIST struct
- Contains a list of 802.11 wireless networks.
- DOT11_SSID struct
- Contains the SSID of an interface.
- DRAWTEXTPARAMS struct
- Contains extended formatting options for the DrawTextEx function.
- DROPFILES struct
- Defines the CF_HDROP clipboard format.
- DSREG_JOIN_INFO struct
- Contains information about how a device is joined to Microsoft Azure Active Directory.
- DSREG_USER_INFO struct
- Contains information about a user account that is used to join a device to Microsoft Azure Active Directory.
- DTBGOPTS struct
- Defines the options for the DrawThemeBackgroundEx function.
- DTTOPTS struct
- Defines the options for the DrawThemeTextEx function.
- DWM_BLURBEHIND struct
- Specifies Desktop Window Manager (DWM) blur-behind properties.
- EAP_METHOD_TYPE struct
- Contains type, identification, and author information about an EAP method.
- EAP_TYPE struct
- Contains type and vendor identification information for an EAP method.
- ELEMDESC struct
- Contains the type description and process-transfer information for a variable, a function, or a function parameter.
- ENUM_PAGE_FILE_INFORMATION struct
- Contains information about a pagefile.
- ENUM_SERVICE_STATUS struct
- Contains the name of a service in a service control manager database and information about that service.
- ENUM_SERVICE_STATUS_PROCESS struct
- Contains the name of a service in a service control manager database and information about the service.
- ENUMLOGFONTEX struct
- Contains information about an enumerated font.
- EVENTMSG struct
- Contains information about a hardware message sent to the system message queue.
- EVT_RPC_LOGIN struct
- Contains the information used to connect to a remote computer.
- EVT_VARIANT struct
- Contains event data or property values.
- EXCEPINFO struct
- Describes an exception that occurred during IDispatch::Invoke.
- ExtendedProperty struct
- Represents a Microsoft-extended property.
- FD_SET struct
- Used by Windows Sockets (Winsock) functions and service providers to place sockets into a set.
- FILETIME struct
- Holds an unsigned 64-bit date and time value for a file.
- FINDREPLACE struct
- Contains information that the FindText and ReplaceText functions use to initialize the Find and Replace dialog boxes.
- FOCUS_EVENT_RECORD struct
- Describes a focus event in a console INPUT_RECORD structure.
- FUNCDESC struct
- Describes a function.
- GESTURECONFIG struct
- Gets and sets the configuration for enabling gesture messages and the type of this configuration.
- GESTUREINFO struct
- Stores information about a gesture.
- GESTURENOTIFYSTRUCT struct
- When transmitted with WM_GESTURENOTIFY messages, passes information about a gesture.
- GUID struct
- A native representation of a Windows GUID (Globally Unique Identifier).
- GUITHREADINFO struct
- Contains information about a GUI thread.
- HARDWAREINPUT struct
- Contains information about a simulated message generated by an input device other than a keyboard or mouse.
- HOSTENT struct
- Used by functions to store information about a given host, such as host name, IPv4 address, and so forth.
- ICONINFO struct
- Contains information about an icon or a cursor.
- ICONINFOEX struct
- Contains information about an icon or a cursor.
- IDLDESC struct
- IN_ADDR struct
- Represents an IPv4 address.
- IN_ADDR_0_0 struct
- IN_ADDR_0_1 struct
- INIT_ONCE struct
- INITCOMMONCONTROLSEX struct
- Carries information used to load common control classes from the dynamic-link library (DLL).
- INPUT struct
- Used by SendInput to store information for synthesizing input events such as keystrokes, mouse movement, and mouse clicks.
- INPUT_RECORD struct
- Describes an input event in the console input buffer.
- INPUT_TRANSFORM struct
- Defines the matrix that represents a transform on a message consumer.
- INPUT_TRANSFORM_0_0 struct
- IP_ADAPTER_ADDRESSES_LH struct
- The header node for a linked list of addresses for a particular adapter.
- IP_ADAPTER_ADDRESSES_LH_0_0 struct
- IP_ADAPTER_ADDRESSES_LH_1_0 struct
- IP_ADAPTER_ANYCAST_ADDRESS_XP struct
- Stores a single anycast IP address in a linked list of addresses for a particular adapter.
- IP_ADAPTER_ANYCAST_ADDRESS_XP_0_0 struct
- IP_ADAPTER_DNS_SERVER_ADDRESS_XP struct
- Stores a single DNS server address in a linked list of DNS server addresses for a particular adapter.
- IP_ADAPTER_DNS_SERVER_ADDRESS_XP_0_0 struct
- IP_ADAPTER_DNS_SUFFIX struct
- Stores a DNS suffix in a linked list of DNS suffixes for a particular adapter.
- IP_ADAPTER_GATEWAY_ADDRESS_LH struct
- Stores a single gateway address in a linked list of gateway addresses for a particular adapter.
- IP_ADAPTER_GATEWAY_ADDRESS_LH_0_0 struct
- IP_ADAPTER_INDEX_MAP struct
- Stores the interface index associated with a network adapter with IPv4 enabled together with the name of the network adapter.
- IP_ADAPTER_MULTICAST_ADDRESS_XP struct
- Stores a single multicast address in a linked-list of addresses for a particular adapter.
- IP_ADAPTER_MULTICAST_ADDRESS_XP_0_0 struct
- IP_ADAPTER_PREFIX_XP struct
- Stores an IP address prefix.
- IP_ADAPTER_PREFIX_XP_0_0 struct
- IP_ADAPTER_UNICAST_ADDRESS_LH struct
- Stores a single unicast IP address in a linked list of IP addresses for a particular adapter.
- IP_ADAPTER_UNICAST_ADDRESS_LH_0_0 struct
- IP_ADAPTER_WINS_SERVER_ADDRESS_LH struct
- Stores a single Windows Internet Name Service (WINS) server address in a linked list of WINS server addresses for a particular adapter.
- IP_ADAPTER_WINS_SERVER_ADDRESS_LH_0_0 struct
- IP_ADDR_STRING struct
- Represents a node in a linked-list of IPv4 addresses.
- IP_ADDRESS_STRING struct
- Stores an IPv4 address in dotted decimal notation.
- IP_INTERFACE_INFO struct
- Contains a list of the network interface adapters with IPv4 enabled on the local system.
- IP_PER_ADAPTER_INFO_W2KSP1 struct
- Contains information specific to a particular adapter.
- ITEMIDLIST struct
- Contains a list of item identifiers.
- JOB_INFO_1 struct
- Specifies print-job information such as the job-identifier value, the name of the printer for which the job is spooled, the name of the machine that created the print job, the name of the user that owns the print job, and so on.
- JOBOBJECT_IO_RATE_CONTROL_INFORMATION struct
- Contains information used to control the I/O rate for a job.
- KBDLLHOOKSTRUCT struct
- Contains information about a low-level keyboard input event.
- KEY_EVENT_RECORD struct
- Describes a keyboard input event in a console INPUT_RECORD structure.
- KEYBDINPUT struct
- Contains information about a simulated keyboard event.
- KNOWNFOLDER_DEFINITION struct
- Defines the specifics of a known folder.
- L2_NOTIFICATION_DATA struct
- Used by the IHV Extensions DLL to send notifications to any service or applications that has registered for the notification.
- LASTINPUTINFO struct
- Contains the time of the last input.
- LOGBRUSH struct
- Defines the style, color, and pattern of a physical brush.
- LOGFONT struct
- Defines the attributes of a font.
- LOGPALETTE struct
- Defines a logical palette.
- LUID struct
- An opaque structure that specifies an identifier that is guaranteed to be unique on the local machine.
- MAGCOLOREFFECT struct
- Describes a color transformation matrix that a magnifier control uses to apply a color effect to magnified screen content.
- MAGIMAGEHEADER struct
- Describes an image format.
- MAGTRANSFORM struct
- Describes a transformation matrix that a magnifier control uses to magnify screen content.
- MARGINS struct
- Returned by the GetThemeMargins function to define the margins of windows that have visual styles applied.
- MCI_OPEN_PARMS struct
- Contains information for the MCI_OPEN command.
- MCI_PLAY_PARMS struct
- Contains positioning information for the MCI_PLAY command.
- MCI_SEEK_PARMS struct
- Contains positioning information for the MCI_SEEK command.
- MCI_STATUS_PARMS struct
- Contains information for the MCI_STATUS command.
- MEMORY_BASIC_INFORMATION struct
- Contains information about a range of pages in the virtual address space of a process.
- MEMORYSTATUSEX struct
- Contains information about the current state of both physical and virtual memory, including extended memory.
- MENU_EVENT_RECORD struct
- Describes a menu event in a console INPUT_RECORD structure.
- MENUBARINFO struct
- Contains menu bar information.
- MENUINFO struct
- Contains information about a menu.
- MENUITEMINFO struct
- Contains information about a menu item.
- MENUITEMTEMPLATE struct
- Defines a menu item in a menu template.
- MENUITEMTEMPLATEHEADER struct
- Defines the header for a menu template.
- METAFILEPICT struct
- Defines the metafile picture format used for exchanging metafile data through the clipboard.
- MIDIEVENT struct
- Describes a MIDI event in a stream buffer.
- MIDIHDR struct
- Defines the header used to identify a MIDI system-exclusive or stream buffer.
- MIDIINCAPS struct
- Describes the capabilities of a MIDI input device.
- MIDIOUTCAPS struct
- Describes the capabilities of a MIDI output device.
- MIDIPROPTEMPO struct
- Contains the tempo property for a stream.
- MIDIPROPTIMEDIV struct
- Contains the time division property for a stream.
- MIDISTRMBUFFVER struct
- Contains version information for a long MIDI event of the MEVT_VERSION type.
- MINMAXINFO struct
- Contains information about a window's maximized size and position and its minimum and maximum tracking size.
- MMTIME struct
- MMTIME_0_0 struct
- MMTIME_0_1 struct
- MODEMDEVCAPS struct
- Contains information about the capabilities of a modem.
- MODEMSETTINGS struct
- Contains information about a modem's configuration.
- MODLOAD_DATA struct
- Contains module data.
- MODULEINFO struct
- Contains the module load address, size, and entry point.
- MONITORINFO struct
- Contains information about a display monitor.
- MONITORINFOEX struct
- Contains information about a display monitor.
- MOUSE_EVENT_RECORD struct
- Describes a mouse input event in a console INPUT_RECORD structure.
- MOUSEHOOKSTRUCT struct
- Contains information about a mouse event passed to a WH_MOUSE hook procedure, MouseProc.
- MOUSEHOOKSTRUCTEX struct
- Contains information about a mouse event passed to a WH_MOUSE hook procedure, MouseProc.
- MOUSEINPUT struct
- Contains information about a simulated mouse event.
- MOUSEMOVEPOINT struct
- Contains information about the mouse's location in screen coordinates.
- MSG struct
- Contains message information from a thread's message queue.
- MSLLHOOKSTRUCT struct
- Contains information about a low-level mouse input event.
- NCCALCSIZE_PARAMS struct
- Contains information that an application can use while processing the WM_NCCALCSIZE message to calculate the size, position, and valid contents of the client area of a window.
- NDIS_OBJECT_HEADER struct
- Packages the object type, version, and size information that is required in many NDIS 6.0 structures.
- NET_LUID_LH_0 struct
- NEWTEXTMETRIC struct
- Contains data that describes a physical font.
- NLM_SIMULATED_PROFILE_INFO struct
- Used to specify values that are used by SetSimulatedProfileInfo to override current internet connection profile values in an RDP Child Session to support the simulation of specific metered internet connection conditions.
- NONCLIENTMETRICS struct
- Contains the scalable metrics associated with the nonclient area of a nonminimized window.
- NOTIFYICONDATA struct
- Contains information that the system needs to display notifications in the notification area.
- OPENCARD_SEARCH_CRITERIA struct
- Used by the SCardUIDlgSelectCard function in order to recognize cards that meet the requirements set forth by the caller.
- OPENCARDNAME struct
- Contains the information that the GetOpenCardName function uses to initialize a smart card Select Card dialog box.
- OPENCARDNAME_EX struct
- Contains the information that the SCardUIDlgSelectCard function uses to initialize a smart card Select Card dialog box.
- OPENFILENAME struct
- Contains information that the GetOpenFileName and GetSaveFileName functions use to initialize an Open or Save As dialog box.
- OSINFO struct
- OSVERSIONINFO struct
- Contains operating system version information.
- OSVERSIONINFOEX struct
- Contains operating system version information.
- OVERLAPPED struct
- Contains information used in asynchronous (or overlapped) input and output (I/O).
- OVERLAPPED_0_0 struct
- OVERLAPPED_ENTRY struct
- Contains the information returned by a call to the GetQueuedCompletionStatusEx function.
- PAINTSTRUCT struct
- Contains information for an application.
- PALETTEENTRY struct
- Specifies the color and usage of an entry in a logical palette.
- PARAMDESC struct
- Contains information needed for transferring a structure element, parameter, or function return value between processes.
- PARAMDESCEX struct
- Contains information about the default value of a parameter.
- PERFORMANCE_INFORMATION struct
- Contains performance information.
- PHYSICAL_MONITOR struct
- Contains a handle and text description corresponding to a physical monitor.
- POINT struct
- Defines the x- and y-coordinates of a point.
- POINTER_INFO struct
- Contains basic pointer information common to all pointer types.
- POINTER_PEN_INFO struct
- Defines basic pen information common to all pointer types.
- POINTER_TOUCH_INFO struct
- Defines basic touch information common to all pointer types.
- POINTL struct
- Defines the x- and y-coordinates of a point.
- POINTS struct
- Defines the x- and y-coordinates of a point.
- POLYTEXT struct
- Describes how the PolyTextOut function should draw a string of text.
- PORT_INFO_1 struct
- Identifies a supported printer port.
- PORT_INFO_2 struct
- Identifies a supported printer port.
- POWERBROADCAST_SETTING struct
- Sent with a power setting event and contains data about the specific change.
- PRINT_EXECUTION_DATA struct
- Contains the execution context of the printer driver that calls GetPrintExecutionData.
- PRINTER_DEFAULTS struct
- Specifies the default data type, environment, initialization data, and access rights for a printer.
- PRINTER_INFO_1 struct
- Specifies general printer information.
- PRINTER_INFO_2 struct
- Specifies detailed printer information.
- PRINTER_INFO_3 struct
- Specifies printer security information.
- PRINTER_INFO_4 struct
- Specifies general printer information.
- PRINTER_INFO_5 struct
- Specifies detailed printer information.
- PRINTER_INFO_6 struct
- Specifies the status value of a printer.
- PRINTER_NOTIFY_INFO struct
- Contains printer information returned by the FindNextPrinterChangeNotification function.
- PRINTER_NOTIFY_INFO_DATA struct
- Identifies a job or printer information field and provides the current data for that field.
- PRINTER_NOTIFY_INFO_DATA_0_0 struct
- PRINTER_OPTIONS struct
- Represents printer options.
- PROCESS_HEAP_ENTRY struct
- Contains information about a heap element.
- PROCESS_HEAP_ENTRY_0_0 struct
- PROCESS_HEAP_ENTRY_0_1 struct
- PROCESS_INFORMATION struct
- Contains information about a newly created process and its primary thread.
- PROCESS_MEMORY_COUNTERS struct
- Contains the memory statistics for a process.
- PROPERTYKEY struct
- Specifies the FMTID/PID identifier that programmatically identifies a property.
- PROPSPEC struct
- Used by many of the methods of IPropertyStorage to specify a property either by its property identifier (ID) or the associated string name.
- PROPVARIANT struct
- Used in the ReadMultiple and WriteMultiple methods of IPropertyStorage to define the type tag and the value of a property in a property set.
- PROPVARIANT_0_0 struct
- PROTOENT struct
- Contains the name and protocol numbers that correspond to a given protocol name.
- QUERY_SERVICE_CONFIG struct
- Contains configuration information for an installed service.
- QUERY_SERVICE_LOCK_STATUS struct
- Contains information about the lock status of a service control manager database.
- RAWHID struct
- Describes the format of the raw input from a Human Interface Device (HID).
- RAWINPUT struct
- Contains the raw input from a device.
- RAWINPUTDEVICE struct
- Defines information for the raw input devices.
- RAWINPUTDEVICELIST struct
- Contains information about a raw input device.
- RAWINPUTHEADER struct
- Contains the header information that is part of the raw input data.
- RAWKEYBOARD struct
- Contains information about the state of the keyboard.
- RAWMOUSE struct
- Contains information about the state of the mouse.
- RAWMOUSE_0_0 struct
- RECT struct
- Defines a rectangle by the coordinates of its upper-left and lower-right corners.
- RECTL struct
- Defines a rectangle by the coordinates of its upper-left and lower-right corners.
- RGBQUAD struct
- Describes a color consisting of relative intensities of red, green, and blue.
- SAFEARRAY struct
- Represents a safe array.
- SAFEARRAYBOUND struct
- Represents the bounds of one dimension of the array.
- SC_ACTION struct
- Represents an action that the service control manager can perform.
- SCARD_ATRMASK struct
- Used by the SCardLocateCardsByATR function to locate cards.
- SCARD_IO_REQUEST struct
- Begins a protocol control information structure.
- SCARD_READERSTATE struct
- Used by functions for tracking smart cards within readers.
- SCROLLBARINFO struct
- Contains scroll bar information.
- SCROLLINFO struct
- Contains scroll bar parameters to be set by the SetScrollInfo function (or SBM_SETSCROLLINFO message), or retrieved by the GetScrollInfo function (or SBM_GETSCROLLINFO message).
- SDP_ELEMENT_DATA struct
- Stores SDP element data.
- SDP_ELEMENT_DATA_0_0 struct
- SDP_ELEMENT_DATA_0_1 struct
- SDP_ELEMENT_DATA_0_2 struct
- SDP_ELEMENT_DATA_0_3 struct
- SDP_LARGE_INTEGER_16 struct
- SDP_STRING_TYPE_DATA struct
- Stores information about SDP string types.
- SDP_ULARGE_INTEGER_16 struct
- SdpAttributeRange struct
- Used in a Bluetooth query to constrain the set of attributes to return in the query.
- SdpQueryUuid struct
- Facilitates searching for UUIDs.
- SECURITY_ATTRIBUTES struct
- Contains the security descriptor for an object and specifies whether the handle retrieved by specifying this structure is inheritable.
- SECURITY_DESCRIPTOR struct
- Contains the security information associated with an object.
- SERVENT struct
- Used to store or return the name and service number for a given service name.
- SERVICE_CONTROL_STATUS_REASON_PARAMS struct
- Contains service control parameters.
- SERVICE_DELAYED_AUTO_START_INFO struct
- Contains the delayed auto-start setting of an auto-start service.
- SERVICE_DESCRIPTION struct
- Contains a service description.
- SERVICE_FAILURE_ACTIONS struct
- Represents the action the service controller should take on each failure of a service.
- SERVICE_FAILURE_ACTIONS_FLAG struct
- Contains the failure actions flag setting of a service.
- SERVICE_LAUNCH_PROTECTED_INFO struct
- Indicates a service protection type.
- SERVICE_NOTIFY_2 struct
- Represents service status notification information.
- SERVICE_PREFERRED_NODE_INFO struct
- Represents the preferred node on which to run a service.
- SERVICE_PRESHUTDOWN_INFO struct
- Contains preshutdown settings.
- SERVICE_REQUIRED_PRIVILEGES_INFO struct
- Represents the required privileges for a service.
- SERVICE_SID_INFO struct
- Represents a service security identifier (SID).
- SERVICE_STATUS struct
- Contains status information for a service.
- SERVICE_STATUS_PROCESS struct
- Contains process status information for a service.
- SERVICE_TABLE_ENTRY struct
- Specifies the ServiceMain function for a service that can run in the calling process.
- SERVICE_TIMECHANGE_INFO struct
- Contains system time change settings.
- SERVICE_TRIGGER struct
- Represents a service trigger event.
- SERVICE_TRIGGER_INFO struct
- Contains trigger event information for a service.
- SERVICE_TRIGGER_SPECIFIC_DATA_ITEM struct
- Contains trigger-specific data for a service trigger event.
- SHELL_ITEM_RESOURCE struct
- Defines Shell item resource.
- SHELLEXECUTEINFO struct
- Contains information used by ShellExecuteEx.
- SHFILEINFO struct
- Contains information about a file object.
- SHFILEOPSTRUCT struct
- Contains information that the SHFileOperation function uses to perform file operations.
- SHITEMID struct
- Defines an item identifier.
- SHQUERYRBINFO struct
- Contains the size and item count information retrieved by the SHQueryRecycleBin function.
- SID_IDENTIFIER_AUTHORITY struct
- SID_IDENTIFIER_AUTHORITY IDL Definition.
- SIZE struct
- Defines the width and height of a rectangle.
- SMALL_RECT struct
- Defines the coordinates of the upper left and lower right corners of a rectangle.
- SOCKADDR struct
- Varies depending on the protocol selected.
- SOCKADDR_BTH struct
- Used in conjunction with Bluetooth socket operations, defined by address family AF_BTH.
- SOCKET_ADDRESS struct
- Stores protocol-specific address information.
- SOLE_AUTHENTICATION_SERVICE struct
- Identifies an authentication service that a server is willing to use to communicate to a client.
- SP_DEVICE_INTERFACE_DATA struct
- Defines a device interface in a device information set.
- SP_DEVICE_INTERFACE_DETAIL_DATA struct
- Contains the path for a device interface.
- SP_DEVINFO_DATA struct
- Defines a device instance that is a member of a device information set.
- SPEVENT struct
- SPEVENTSOURCEINFO struct
- SPVOICESTATUS struct
- SRWLOCK struct
- STARTUPINFO struct
- Specifies the window station, desktop, standard handles, and appearance of the main window for a process at creation time.
- STARTUPINFOEX struct
- Specifies the window station, desktop, standard handles, and attributes for a new process.
- STATPROPSETSTG struct
- Contains information about a property set.
- STATPROPSTG struct
- Contains data about a single property in a property set.
- STATSTG struct
- Contains statistical data about an open storage, stream, or byte-array object.
- STORAGE_DEVICE_NUMBER struct
- Contains information about a device.
- STRRET struct
- Contains strings returned from the IShellFolder interface methods.
- STYLESTRUCT struct
- Contains the styles for a window.
- SYMBOL_INFO struct
- Contains symbol information.
- SYSTEM_BASIC_INFORMATION struct
- SYSTEM_BATTERY_STATE struct
- Contains information about the current state of the system battery.
- SYSTEM_CODEINTEGRITY_INFORMATION struct
- SYSTEM_EXCEPTION_INFORMATION struct
- SYSTEM_INFO struct
- Contains information about the current computer system.
- SYSTEM_INFO_0_0 struct
- SYSTEM_INTERRUPT_INFORMATION struct
- SYSTEM_LOGICAL_PROCESSOR_INFORMATION struct
- Describes the relationship between the specified processor set.
- SYSTEM_LOGICAL_PROCESSOR_INFORMATION_0_0 struct
- SYSTEM_LOGICAL_PROCESSOR_INFORMATION_0_1 struct
- SYSTEM_LOOKASIDE_INFORMATION struct
- SYSTEM_PERFORMANCE_INFORMATION struct
- SYSTEM_POLICY_INFORMATION struct
- SYSTEM_POWER_STATUS struct
- Contains information about the power status of the system.
- SYSTEM_PROCESS_INFORMATION struct
- SYSTEM_PROCESSOR_PERFORMANCE_INFORMATION struct
- SYSTEM_REGISTRY_QUOTA_INFORMATION struct
- SYSTEM_THREAD_INFORMATION struct
- SYSTEM_TIMEOFDAY_INFORMATION struct
- SYSTEMTIME struct
- Specifies a date and time, using individual members for the month, day, year, weekday, hour, minute, second, and millisecond.
- TASKDIALOG_BUTTON struct
- Contains information used to display a button in a task dialog.
- TASKDIALOGCONFIG struct
- Contains information used to display a task dialog.
- TEXTMETRIC struct
- Contains basic information about a physical font.
- TIMEVAL struct
- Used to specify a time interval.
- TITLEBARINFO struct
- Contains title bar information.
- TITLEBARINFOEX struct
- Expands on the information described in the TITLEBARINFO structure by including the coordinates of each element of the title bar.
- TLIBATTR struct
- Contains information about a type library.
- TOKEN_APPCONTAINER_INFORMATION struct
- Specifies all the information in a token that is necessary for an app container.
- TOKEN_ELEVATION struct
- Indicates whether a token has elevated privileges.
- TOUCHINPUT struct
- Encapsulates data for touch input.
- TOUCHPREDICTIONPARAMETERS struct
- Contains hardware input details that can be used to predict touch targets and help compensate for hardware latency when processing touch and gesture input that contains distance and velocity data.
- TPMPARAMS struct
- Contains extended parameters for the TrackPopupMenuEx function.
- TYPEATTR struct
- Contains attributes of a type.
- TYPEDESC struct
- Describes the type of a variable, the return type of a function, or the type of a function parameter.
- UiaChangeInfo struct
- Contains data about a UI Automation change that occurred.
- UNICODE_STRING struct
- Used by various Local Security Authority (LSA) functions to specify a Unicode string.
- UNSIGNED_RATIO struct
- Defines a data type used by the Desktop Window Manager (DWM) APIs.
- UPDATELAYEREDWINDOWINFO struct
- Used by UpdateLayeredWindowIndirect to provide position, size, shape, content, and translucency information for a layered window.
- USB_DEVICE_STATUS_0 struct
- VALENT struct
- Contains information about a registry value.
- VARDESC struct
- Describes a variable, constant, or data member.
- VARIANT struct
- A container for a large union that carries many types of data.
- VARIANT_0_0 struct
- VARIANT_0_0_0_0 struct
- VERSIONEDSTREAM struct
- VOLUME_DISK_EXTENTS struct
- Represents a physical location on a disk.
- VS_FIXEDFILEINFO struct
- Contains version information for a file.
- WAVEFORMATEX struct
- Defines the format of waveform-audio data.
- WAVEFORMATEXTENSIBLE struct
- Defines the format of waveform-audio data for formats having more than two channels or higher sample resolutions than allowed by WAVEFORMATEX.
- WAVEHDR struct
- Defines the header used to identify a waveform-audio buffer.
- WAVEINCAPS struct
- Describes the capabilities of a waveform-audio input device.
- WAVEOUTCAPS struct
- Describes the capabilities of a waveform-audio output device.
- WIN32_FILE_ATTRIBUTE_DATA struct
- Contains attribute information for a file or directory.
- WIN32_FIND_DATA struct
- Contains information about the file that is found by the FindFirstFile, FindFirstFileEx, or FindNextFile function.
- WINDOW_BUFFER_SIZE_RECORD struct
- Describes a change in the size of the console screen buffer.
- WINDOWCOMPOSITIONATTRIBDATA struct
- Describes a key/value pair that specifies a window composition attribute and its value.
- WINDOWINFO struct
- Contains window information.
- WINDOWPLACEMENT struct
- Contains information about the placement of a window on the screen.
- WINDOWPOS struct
- Contains information about the size and position of a window.
- WLAN_ASSOCIATION_ATTRIBUTES struct
- Contains association attributes for a connection.
- WLAN_AUTH_CIPHER_PAIR_LIST struct
- Contains a list of authentication and cipher algorithm pairs.
- WLAN_AVAILABLE_NETWORK struct
- Contains information about an available wireless network.
- WLAN_AVAILABLE_NETWORK_LIST struct
- Contains an array of information about available networks.
- WLAN_BSS_ENTRY struct
- Contains information about a basic service set (BSS).
- WLAN_BSS_LIST struct
- Contains a list of basic service set (BSS) entries.
- WLAN_CONNECTION_ATTRIBUTES struct
- Defines the attributes of a wireless connection.
- WLAN_CONNECTION_NOTIFICATION_DATA struct
- Contains information about connection related notifications.
- WLAN_CONNECTION_PARAMETERS struct
- Specifies the parameters used when using the WlanConnect function.
- WLAN_COUNTRY_OR_REGION_STRING_LIST struct
- Contains a list of supported country or region strings.
- WLAN_DEVICE_SERVICE_GUID_LIST struct
- Contains an array of device service GUIDs.
- WLAN_DEVICE_SERVICE_NOTIFICATION_DATA struct
- A structure that represents a device service notification.
- WLAN_HOSTED_NETWORK_CONNECTION_SETTINGS struct
- Contains information about the connection settings on the wireless Hosted Network.
- WLAN_HOSTED_NETWORK_DATA_PEER_STATE_CHANGE struct
- Contains information about a network state change for a data peer on the wireless Hosted Network.
- WLAN_HOSTED_NETWORK_PEER_STATE struct
- Contains information about the peer state for a peer on the wireless Hosted Network.
- WLAN_HOSTED_NETWORK_RADIO_STATE struct
- Contains information about the radio state on the wireless Hosted Network.
- WLAN_HOSTED_NETWORK_SECURITY_SETTINGS struct
- Contains information about the security settings on the wireless Hosted Network.
- WLAN_HOSTED_NETWORK_STATE_CHANGE struct
- Contains information about a network state change on the wireless Hosted Network.
- WLAN_HOSTED_NETWORK_STATUS struct
- Contains information about the status of the wireless Hosted Network.
- WLAN_INTERFACE_CAPABILITY struct
- Contains information about the capabilities of an interface.
- WLAN_INTERFACE_INFO struct
- Contains information about a wireless LAN interface.
- WLAN_INTERFACE_INFO_LIST struct
- Array of NIC interface information.
- WLAN_MAC_FRAME_STATISTICS struct
- Contains information about sent and received MAC frames.
- WLAN_MSM_NOTIFICATION_DATA struct
- Contains information about media specific module (MSM) connection related notifications.
- WLAN_PHY_FRAME_STATISTICS struct
- Contains information about sent and received PHY frames.
- WLAN_PHY_RADIO_STATE struct
- Specifies the radio state.
- WLAN_PROFILE_INFO struct
- Basic information about a profile.
- WLAN_PROFILE_INFO_LIST struct
- Contains a list of wireless profile information.
- WLAN_RADIO_STATE struct
- Specifies the radio state on a list of physical layer (PHY) types.
- WLAN_RATE_SET struct
- The set of supported data rates.
- WLAN_RAW_DATA struct
- Contains raw data in the form of a blob that is used by some Native Wifi functions.
- WLAN_RAW_DATA_LIST struct
- Contains raw data in the form of an array of data blobs that are used by some Native Wifi functions.
- WLAN_RAW_DATA_LIST_0 struct
- WLAN_SECURITY_ATTRIBUTES struct
- Defines the security attributes for a wireless connection.
- WLAN_STATISTICS struct
- Assorted statistics about an interface.
- WNDCLASS struct
- Contains the window class attributes that are registered by the RegisterClass function.
- WNDCLASSEX struct
- Contains window class information.
- WTA_OPTIONS struct
- Defines options that are used to set window visual style attributes.
- XFORM struct
- Specifies a world-space to page-space transformation.
- XINPUT_BATTERY_INFORMATION struct
- Contains information on battery type and charge state.
- XINPUT_CAPABILITIES struct
- Describes the capabilities of a connected controller.
- XINPUT_GAMEPAD struct
- Describes the current state of the Xbox 360 Controller.
- XINPUT_KEYSTROKE struct
- Specifies keystroke data returned by XInputGetKeystroke.
- XINPUT_STATE struct
- Represents the state of a controller.
- XINPUT_VIBRATION struct
- Specifies motor speed levels for the vibration function of a controller.