version topic
Version Information APIs
The version information functions enable applications to query a version resource for file information and present the information in a clear format. This information includes the file's purpose, author, version number, and so on.
Functions
-
GetFileVersionInfo(
PCWSTR lptstrFilename, int dwLen, Pointer< versionNativeType> lpData) → Win32Result<bool> - Retrieves version information for the specified file.
-
GetFileVersionInfoEx(
GET_FILE_VERSION_INFO_FLAGS dwFlags, PCWSTR lpwstrFilename, int dwLen, Pointer< versionNativeType> lpData) → Win32Result<bool> - Retrieves version information for the specified file.
-
GetFileVersionInfoSize(
PCWSTR lptstrFilename, Pointer< versionUint32> ? lpdwHandle) → Win32Result<int> - Determines whether the operating system can retrieve version information for a specified file.
-
GetFileVersionInfoSizeEx(
GET_FILE_VERSION_INFO_FLAGS dwFlags, PCWSTR lpwstrFilename, Pointer< versionUint32> lpdwHandle) → Win32Result<int> - Determines whether the operating system can retrieve version information for a specified file.
-
VerFindFile(
VER_FIND_FILE_FLAGS uFlags, PCWSTR szFileName, PCWSTR? szWinDir, PCWSTR szAppDir, PWSTR szCurDir, Pointer< versionUint32> puCurDirLen, PWSTR szDestDir, Pointer<Uint32> puDestDirLen) → VER_FIND_FILE_STATUS - Determines where to install a file based on whether it locates another version of the file in the system.
-
VerInstallFile(
VER_INSTALL_FILE_FLAGS uFlags, PCWSTR szSrcFileName, PCWSTR szDestFileName, PCWSTR szSrcDir, PCWSTR szDestDir, PCWSTR szCurDir, PWSTR szTmpFile, Pointer< versionUint32> puTmpFileLen) → VER_INSTALL_FILE_STATUS - Installs the specified file based on information returned from the VerFindFile function.
-
VerQueryValue(
Pointer< versionNativeType> pBlock, PCWSTR lpSubBlock, Pointer<Pointer< lplpBuffer, Pointer<NativeType> >Uint32> puLen) → bool - Retrieves specified version information from the specified version-information resource.