winmm topic

Windows Multimedia API

Microsoft Windows multimedia support enables applications to use sound and video.

Functions

mciGetDeviceID(Pointer<Utf16> pszDevice) → int winmm
The mciGetDeviceID function retrieves the device identifier corresponding to the name of an open device.
mciGetDeviceIDFromElementID(int dwElementID, Pointer<Utf16> lpstrType) → int winmm
The mciGetDeviceIDFromElementID function retrieves the MCI device identifier corresponding to an element identifier.
mciGetErrorString(int mcierr, Pointer<Utf16> pszText, int cchText) → int winmm
The mciGetErrorString function retrieves a string that describes the specified MCI error code.
mciSendCommand(int mciId, int uMsg, int dwParam1, int dwParam2) → int winmm
The mciSendCommand function sends a command message to the specified MCI device.
mciSendString(Pointer<Utf16> lpstrCommand, Pointer<Utf16> lpstrReturnString, int uReturnLength, int hwndCallback) → int winmm
The mciSendString function sends a command string to an MCI device. The device that the command is sent to is specified in the command string.
midiConnect(int hmi, int hmo, Pointer<NativeType> pReserved) → int winmm
The midiConnect function connects a MIDI input device to a MIDI thru or output device, or connects a MIDI thru device to a MIDI output device.
midiDisconnect(int hmi, int hmo, Pointer<NativeType> pReserved) → int winmm
The midiDisconnect function disconnects a MIDI input device from a MIDI thru or output device, or disconnects a MIDI thru device from a MIDI output device.
midiInAddBuffer(int hmi, Pointer<MIDIHDR> pmh, int cbmh) → int winmm
The midiInAddBuffer function sends an input buffer to a specified opened MIDI input device. This function is used for system-exclusive messages.
midiInClose(int hmi) → int winmm
The midiInClose function closes the specified MIDI input device.
midiInGetDevCaps(int uDeviceID, Pointer<MIDIINCAPS> pmic, int cbmic) → int winmm
The midiInGetDevCaps function determines the capabilities of a specified MIDI input device.
midiInGetErrorText(int mmrError, Pointer<Utf16> pszText, int cchText) → int winmm
The midiInGetErrorText function retrieves a textual description for an error identified by the specified error code.
midiInGetID(int hmi, Pointer<Uint32> puDeviceID) → int winmm
The midiInGetID function gets the device identifier for the given MIDI input device.
midiInGetNumDevs() → int winmm
The midiInGetNumDevs function retrieves the number of MIDI input devices in the system.
midiInMessage(int hmi, int uMsg, int dw1, int dw2) → int winmm
The midiInMessage function sends a message to the MIDI device driver.
midiInOpen(Pointer<IntPtr> phmi, int uDeviceID, int dwCallback, int dwInstance, int fdwOpen) → int winmm
The midiInOpen function opens a specified MIDI input device.
midiInPrepareHeader(int hmi, Pointer<MIDIHDR> pmh, int cbmh) → int winmm
The midiInPrepareHeader function prepares a buffer for MIDI input.
midiInReset(int hmi) → int winmm
The midiInReset function stops input on a given MIDI input device.
midiInStart(int hmi) → int winmm
The midiInStart function starts MIDI input on the specified MIDI input device.
midiInStop(int hmi) → int winmm
The midiInStop function stops MIDI input on the specified MIDI input device.
midiInUnprepareHeader(int hmi, Pointer<MIDIHDR> pmh, int cbmh) → int winmm
The midiInUnprepareHeader function cleans up the preparation performed by the midiInPrepareHeader function.
midiOutCacheDrumPatches(int hmo, int uPatch, Pointer<Uint16> pwkya, int fuCache) → int winmm
The midiOutCacheDrumPatches function requests that an internal MIDI synthesizer device preload and cache a specified set of key-based percussion patches.
midiOutCachePatches(int hmo, int uBank, Pointer<Uint16> pwpa, int fuCache) → int winmm
The midiOutCachePatches function requests that an internal MIDI synthesizer device preload and cache a specified set of patches.
midiOutClose(int hmo) → int winmm
The midiOutClose function closes the specified MIDI output device.
midiOutGetDevCaps(int uDeviceID, Pointer<MIDIOUTCAPS> pmoc, int cbmoc) → int winmm
The midiOutGetDevCaps function queries a specified MIDI output device to determine its capabilities.
midiOutGetErrorText(int mmrError, Pointer<Utf16> pszText, int cchText) → int winmm
The midiOutGetErrorText function retrieves a textual description for an error identified by the specified error code.
midiOutGetID(int hmo, Pointer<Uint32> puDeviceID) → int winmm
The midiOutGetID function retrieves the device identifier for the given MIDI output device.
midiOutGetNumDevs() → int winmm
The midiOutGetNumDevs function retrieves the number of MIDI output devices present in the system.
midiOutGetVolume(int hmo, Pointer<Uint32> pdwVolume) → int winmm
The midiOutGetVolume function retrieves the current volume setting of a MIDI output device.
midiOutLongMsg(int hmo, Pointer<MIDIHDR> pmh, int cbmh) → int winmm
The midiOutLongMsg function sends a system-exclusive MIDI message to the specified MIDI output device.
midiOutMessage(int hmo, int uMsg, int dw1, int dw2) → int winmm
The midiOutMessage function sends a message to the MIDI device drivers. This function is used only for driver-specific messages that are not supported by the MIDI API.
midiOutOpen(Pointer<IntPtr> phmo, int uDeviceID, int dwCallback, int dwInstance, int fdwOpen) → int winmm
The midiOutOpen function opens a MIDI output device for playback.
midiOutPrepareHeader(int hmo, Pointer<MIDIHDR> pmh, int cbmh) → int winmm
The midiOutPrepareHeader function prepares a MIDI system-exclusive or stream buffer for output.
midiOutReset(int hmo) → int winmm
The midiOutReset function turns off all notes on all MIDI channels for the specified MIDI output device.
midiOutSetVolume(int hmo, int dwVolume) → int winmm
The midiOutSetVolume function sets the volume of a MIDI output device.
midiOutShortMsg(int hmo, int dwMsg) → int winmm
The midiOutShortMsg function sends a short MIDI message to the specified MIDI output device.
midiOutUnprepareHeader(int hmo, Pointer<MIDIHDR> pmh, int cbmh) → int winmm
The midiOutUnprepareHeader function cleans up the preparation performed by the midiOutPrepareHeader function.
PlaySound(Pointer<Utf16> pszSound, int hmod, int fdwSound) → int winmm
The PlaySound function plays a sound specified by the given file name, resource, or system event.
waveInAddBuffer(int hwi, Pointer<WAVEHDR> pwh, int cbwh) → int winmm
The waveInAddBuffer function sends an input buffer to the given waveform-audio input device. When the buffer is filled, the application is notified.
waveInClose(int hwi) → int winmm
The waveInClose function closes the given waveform-audio input device.
waveInGetDevCaps(int uDeviceID, Pointer<WAVEINCAPS> pwic, int cbwic) → int winmm
The waveInGetDevCaps function retrieves the capabilities of a given waveform-audio input device.
waveInGetErrorText(int mmrError, Pointer<Utf16> pszText, int cchText) → int winmm
The waveInGetErrorText function retrieves a textual description of the error identified by the given error number.
waveInGetID(int hwi, Pointer<Uint32> puDeviceID) → int winmm
The waveInGetID function gets the device identifier for the given waveform-audio input device.
waveInGetNumDevs() → int winmm
The waveInGetNumDevs function returns the number of waveform-audio input devices present in the system.
waveInGetPosition(int hwi, Pointer<MMTIME> pmmt, int cbmmt) → int winmm
The waveInGetPosition function retrieves the current input position of the given waveform-audio input device.
waveInMessage(int hwi, int uMsg, int dw1, int dw2) → int winmm
The waveInMessage function sends messages to the waveform-audio input device drivers.
waveInOpen(Pointer<IntPtr> phwi, int uDeviceID, Pointer<WAVEFORMATEX> pwfx, int dwCallback, int dwInstance, int fdwOpen) → int winmm
The waveInOpen function opens the given waveform-audio input device for recording.
waveInPrepareHeader(int hwi, Pointer<WAVEHDR> pwh, int cbwh) → int winmm
The waveInPrepareHeader function prepares a buffer for waveform-audio input.
waveInReset(int hwi) → int winmm
The waveInReset function stops input on the given waveform-audio input device and resets the current position to zero.
waveInStart(int hwi) → int winmm
The waveInStart function starts input on the given waveform-audio input device.
waveInStop(int hwi) → int winmm
The waveInStop function stops waveform-audio input.
waveInUnprepareHeader(int hwi, Pointer<WAVEHDR> pwh, int cbwh) → int winmm
The waveInUnprepareHeader function cleans up the preparation performed by the waveInPrepareHeader function. This function must be called after the device driver fills a buffer and returns it to the application. You must call this function before freeing the buffer.
waveOutClose(int hwo) → int winmm
The waveOutClose function closes the given waveform-audio output device.
waveOutGetDevCaps(int uDeviceID, Pointer<WAVEOUTCAPS> pwoc, int cbwoc) → int winmm
The waveOutGetDevCaps function retrieves the capabilities of a given waveform-audio output device.
waveOutGetErrorText(int mmrError, Pointer<Utf16> pszText, int cchText) → int winmm
The waveOutGetErrorText function retrieves a textual description of the error identified by the given error number.
waveOutGetID(int hwo, Pointer<Uint32> puDeviceID) → int winmm
The waveOutGetID function retrieves the device identifier for the given waveform-audio output device.
waveOutGetNumDevs() → int winmm
The waveOutGetNumDevs function retrieves the number of waveform-audio output devices present in the system.
waveOutGetPitch(int hwo, Pointer<Uint32> pdwPitch) → int winmm
The waveOutGetPitch function retrieves the current pitch setting for the specified waveform-audio output device.
waveOutGetPlaybackRate(int hwo, Pointer<Uint32> pdwRate) → int winmm
The waveOutGetPlaybackRate function retrieves the current playback rate for the specified waveform-audio output device.
waveOutGetPosition(int hwo, Pointer<MMTIME> pmmt, int cbmmt) → int winmm
The waveOutGetPosition function retrieves the current playback position of the given waveform-audio output device.
waveOutGetVolume(int hwo, Pointer<Uint32> pdwVolume) → int winmm
The waveOutGetVolume function retrieves the current volume level of the specified waveform-audio output device.
waveOutMessage(int hwo, int uMsg, int dw1, int dw2) → int winmm
The waveOutMessage function sends messages to the waveform-audio output device drivers.
waveOutOpen(Pointer<IntPtr> phwo, int uDeviceID, Pointer<WAVEFORMATEX> pwfx, int dwCallback, int dwInstance, int fdwOpen) → int winmm
The waveOutOpen function opens the given waveform-audio output device for playback.
waveOutPause(int hwo) → int winmm
The waveOutPause function pauses playback on the given waveform-audio output device. The current position is saved. Use the waveOutRestart function to resume playback from the current position.
waveOutPrepareHeader(int hwo, Pointer<WAVEHDR> pwh, int cbwh) → int winmm
The waveOutPrepareHeader function prepares a waveform-audio data block for playback.
waveOutReset(int hwo) → int winmm
The waveOutReset function stops playback on the given waveform-audio output device and resets the current position to zero. All pending playback buffers are marked as done (WHDR_DONE) and returned to the application.
waveOutRestart(int hwo) → int winmm
The waveOutRestart function resumes playback on a paused waveform-audio output device.
waveOutSetPitch(int hwo, int dwPitch) → int winmm
The waveOutSetPitch function sets the pitch for the specified waveform-audio output device.
waveOutSetPlaybackRate(int hwo, int dwRate) → int winmm
The waveOutSetPlaybackRate function sets the playback rate for the specified waveform-audio output device.
waveOutSetVolume(int hwo, int dwVolume) → int winmm
The waveOutSetVolume function sets the volume level of the specified waveform-audio output device.
waveOutUnprepareHeader(int hwo, Pointer<WAVEHDR> pwh, int cbwh) → int winmm
The waveOutUnprepareHeader function cleans up the preparation performed by the waveOutPrepareHeader function. This function must be called after the device driver is finished with a data block. You must call this function before freeing the buffer.
waveOutWrite(int hwo, Pointer<WAVEHDR> pwh, int cbwh) → int winmm
The waveOutWrite function sends a data block to the given waveform-audio output device.