winrt topic

Windows Runtime API

The Windows Runtime provides the latest generation of Windows APIs to apps running on Windows 8 or later. WinRT is an evolution of COM and the flat Win32 APIs that came before it, and is designed for projection into a variety of languages.

Functions

convertFromHString(int hstring) → String winrt
Takes a HSTRING (a WinRT String handle), and converts it to a Dart String.
convertToHString(String string) → int winrt
Takes a Dart String and converts it to an HSTRING (a WinRT String), returning an integer handle.
GetRestrictedErrorInfo(Pointer<Pointer<COMObject>> ppRestrictedErrorInfo) → int winrt
Gets the restricted error information object set by a previous call to SetRestrictedErrorInfo in the current logical thread.
MetaDataGetDispenser(Pointer<GUID> rclsid, Pointer<GUID> riid, Pointer<Pointer<NativeType>> ppv) → int winrt
Creates a dispenser class.
RoActivateInstance(int activatableClassId, Pointer<Pointer<COMObject>> instance) → int winrt
Activates the specified Windows Runtime class.
RoGetActivationFactory(int activatableClassId, Pointer<GUID> iid, Pointer<Pointer<NativeType>> factory) → int winrt
Gets the activation factory for the specified runtime class.
RoGetApartmentIdentifier(Pointer<Uint64> apartmentIdentifier) → int winrt
Gets a unique identifier for the current apartment.
RoGetMetaDataFile(int name, Pointer<COMObject> metaDataDispenser, Pointer<IntPtr> metaDataFilePath, Pointer<Pointer<COMObject>> metaDataImport, Pointer<Uint32> typeDefToken) → int winrt
Locates and retrieves the metadata file that describes the Application Binary Interface (ABI) for the specified typename.
RoInitialize(int initType) → int winrt
Initializes the Windows Runtime on the current thread with the specified concurrency model.
RoIsApiContractMajorVersionPresent(Pointer<Utf16> name, int majorVersion, Pointer<Int32> present) → int winrt
Returns true or false to indicate whether the API contract with the specified name and major version number is present.
RoIsApiContractPresent(Pointer<Utf16> name, int majorVersion, int minorVersion, Pointer<Int32> present) → int winrt
Returns true or false to indicate whether the API contract with the specified name and major and minor version number is present.
RoUninitialize() → void winrt
Closes the Windows Runtime on the current thread.
WindowsCompareStringOrdinal(int string1, int string2, Pointer<Int32> result) → int winrt
Compares two specified HSTRING objects and returns an integer that indicates their relative position in a sort order.
WindowsConcatString(int string1, int string2, Pointer<IntPtr> newString) → int winrt
Concatenates two specified strings.
WindowsCreateString(Pointer<Utf16> sourceString, int length, Pointer<IntPtr> string) → int winrt
Creates a new HSTRING based on the specified source string.
WindowsDeleteString(int string) → int winrt
Decrements the reference count of a string buffer.
WindowsDeleteStringBuffer(int bufferHandle) → int winrt
Discards a preallocated string buffer if it was not promoted to an HSTRING.
WindowsDuplicateString(int string, Pointer<IntPtr> newString) → int winrt
Creates a copy of the specified string.
WindowsGetStringLen(int string) → int winrt
Gets the length, in Unicode characters, of the specified string.
WindowsGetStringRawBuffer(int string, Pointer<Uint32> length) → Pointer<Utf16> winrt
Retrieves the backing buffer for the specified string.
WindowsIsStringEmpty(int string) → int winrt
Indicates whether the specified string is the empty string.
WindowsPreallocateStringBuffer(int length, Pointer<Pointer<Uint16>> charBuffer, Pointer<IntPtr> bufferHandle) → int winrt
Allocates a mutable character buffer for use in HSTRING creation.
WindowsPromoteStringBuffer(int bufferHandle, Pointer<IntPtr> string) → int winrt
Creates an HSTRING from the specified HSTRING_BUFFER.
WindowsReplaceString(int string, int stringReplaced, int stringReplaceWith, Pointer<IntPtr> newString) → int winrt
Replaces all occurrences of a set of characters in the specified string with another set of characters to create a new string.
WindowsStringHasEmbeddedNull(int string, Pointer<Int32> hasEmbedNull) → int winrt
Indicates whether the specified string has embedded null characters.
WindowsSubstring(int string, int startIndex, Pointer<IntPtr> newString) → int winrt
Retrieves a substring from the specified string. The substring starts at the specified character position.
WindowsSubstringWithSpecifiedLength(int string, int startIndex, int length, Pointer<IntPtr> newString) → int winrt
Retrieves a substring from the specified string. The substring starts at a specified character position and has a specified length.
WindowsTrimStringEnd(int string, int trimString, Pointer<IntPtr> newString) → int winrt
Removes all trailing occurrences of a specified set of characters from the source string.
WindowsTrimStringStart(int string, int trimString, Pointer<IntPtr> newString) → int winrt
Removes all leading occurrences of a specified set of characters from the source string.