wlanapi topic
Wireless LAN API
The Native Wifi application programming interface (API) functions have two purposes: to manage wireless network profiles and to manage wireless network connections. The API elements are exposed by the Auto Configuration Module (ACM). The exposed connection and disconnection API elements can be used to override the automatic configuration logic.
Functions
-
WlanAllocateMemory(
int dwMemorySize) → Win32Result< wlanapiPointer< NativeType> > - Allocates memory.
-
WlanCloseHandle(
HANDLE hClientHandle) → int wlanapi - Closes a connection to the server.
-
WlanConnect(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, Pointer<WLAN_CONNECTION_PARAMETERS> pConnectionParameters) → int - Attempts to connect to a specific network.
-
WlanDeleteProfile(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, PCWSTR strProfileName) → int - Deletes a wireless profile for a wireless interface on the local computer.
-
WlanDeviceServiceCommand(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, Pointer<GUID> pDeviceServiceGuid, int dwOpCode, int dwInBufferSize, Pointer<NativeType> ? pInBuffer, int dwOutBufferSize, Pointer<NativeType> ? pOutBuffer, Pointer<Uint32> pdwBytesReturned) → int - Allows an OEM or IHV component to communicate with a device service on a particular wireless LAN interface.
-
WlanDisconnect(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid) → int - Disconnects an interface from its current network.
-
WlanEnumInterfaces(
HANDLE hClientHandle, Pointer< wlanapiPointer< ppInterfaceList) → intWLAN_INTERFACE_INFO_LIST> > - Enumerates all of the wireless LAN interfaces currently enabled on the local computer.
-
WlanExtractPsdIEDataList(
HANDLE hClientHandle, int dwIeDataSize, Pointer< wlanapiUint8> pRawIeData, PCWSTR strFormat, Pointer<Pointer< ppPsdIEDataList) → intWLAN_RAW_DATA_LIST> > - Extracts the proximity service discovery (PSD) information element (IE) data list from raw IE data included in a beacon.
-
WlanFreeMemory(
Pointer< wlanapiNativeType> pMemory) → void - Frees memory.
-
WlanGetAvailableNetworkList(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, int dwFlags, Pointer<Pointer< ppAvailableNetworkList) → intWLAN_AVAILABLE_NETWORK_LIST> > - Retrieves the list of available networks on a wireless LAN interface.
-
WlanGetFilterList(
HANDLE hClientHandle, WLAN_FILTER_LIST_TYPE wlanFilterListType, Pointer< wlanapiPointer< ppNetworkList) → intDOT11_NETWORK_LIST> > - Retrieves a group policy or user permission list.
-
WlanGetInterfaceCapability(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, Pointer<Pointer< ppCapability) → intWLAN_INTERFACE_CAPABILITY> > - Retrieves the capabilities of an interface.
-
WlanGetNetworkBssList(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, Pointer<DOT11_SSID> ? pDot11Ssid, DOT11_BSS_TYPE dot11BssType, bool bSecurityEnabled, Pointer<Pointer< ppWlanBssList) → intWLAN_BSS_LIST> > - Retrieves a list of the basic service set (BSS) entries of the wireless network or networks on a given wireless LAN interface.
-
WlanGetProfile(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, PCWSTR strProfileName, Pointer<Pointer< pstrProfileXml, Pointer<Utf16> >Uint32> ? pdwFlags, Pointer<Uint32> ? pdwGrantedAccess) → int - Retrieves all information about a specified wireless profile.
-
WlanGetProfileCustomUserData(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, PCWSTR strProfileName, Pointer<Uint32> pdwDataSize, Pointer<Pointer< ppData) → intUint8> > - Gets the custom user data associated with a wireless profile.
-
WlanGetProfileList(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, Pointer<Pointer< ppProfileList) → intWLAN_PROFILE_INFO_LIST> > - Retrieves the list of profiles.
-
WlanGetSecuritySettings(
HANDLE hClientHandle, WLAN_SECURABLE_OBJECT securableObject, Pointer< wlanapiInt32> ? pValueType, Pointer<Pointer< pstrCurrentSDDL, Pointer<Utf16> >Uint32> pdwGrantedAccess) → int - Gets the security settings associated with a configurable object.
-
WlanGetSupportedDeviceServices(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, Pointer<Pointer< ppDevSvcGuidList) → intWLAN_DEVICE_SERVICE_GUID_LIST> > - Retrieves a list of the supported device services on a given wireless LAN interface.
-
WlanHostedNetworkForceStart(
HANDLE hClientHandle, Pointer< wlanapiInt32> ? pFailReason) → int - Transitions the wireless Hosted Network to the wlan_hosted_network_active state without associating the request with the application's calling handle.
-
WlanHostedNetworkForceStop(
HANDLE hClientHandle, Pointer< wlanapiInt32> ? pFailReason) → int - Transitions the wireless Hosted Network to the wlan_hosted_network_idle without associating the request with the application's calling handle.
-
WlanHostedNetworkInitSettings(
HANDLE hClientHandle, Pointer< wlanapiInt32> ? pFailReason) → int - Configures and persists to storage the network connection settings (SSID and maximum number of peers, for example) on the wireless Hosted Network if these settings are not already configured.
-
WlanHostedNetworkQueryProperty(
HANDLE hClientHandle, WLAN_HOSTED_NETWORK_OPCODE opCode, Pointer< wlanapiUint32> pdwDataSize, Pointer<Pointer< ppvData, Pointer<NativeType> >Int32> pWlanOpcodeValueType) → int - Queries the current static properties of the wireless Hosted Network.
-
WlanHostedNetworkQuerySecondaryKey(
HANDLE hClientHandle, Pointer< wlanapiUint32> pdwKeyLength, Pointer<Pointer< ppucKeyData, Pointer<Uint8> >Int32> pbIsPassPhrase, Pointer<Int32> pbPersistent, Pointer<Int32> ? pFailReason) → int - Queries the secondary security key that is configured to be used by the wireless Hosted Network.
-
WlanHostedNetworkQueryStatus(
HANDLE hClientHandle, Pointer< wlanapiPointer< ppWlanHostedNetworkStatus) → intWLAN_HOSTED_NETWORK_STATUS> > - Queries the current status of the wireless Hosted Network.
-
WlanHostedNetworkRefreshSecuritySettings(
HANDLE hClientHandle, Pointer< wlanapiInt32> ? pFailReason) → int - Refreshes the configurable and auto-generated parts of the wireless Hosted Network security settings.
-
WlanHostedNetworkSetProperty(
HANDLE hClientHandle, WLAN_HOSTED_NETWORK_OPCODE opCode, int dwDataSize, Pointer< wlanapiNativeType> pvData, Pointer<Int32> ? pFailReason) → int - Sets static properties of the wireless Hosted Network.
-
WlanHostedNetworkSetSecondaryKey(
HANDLE hClientHandle, int dwKeyLength, Pointer< wlanapiUint8> pucKeyData, bool bIsPassPhrase, bool bPersistent, Pointer<Int32> ? pFailReason) → int - Configures the secondary security key that will be used by the wireless Hosted Network.
-
WlanHostedNetworkStartUsing(
HANDLE hClientHandle, Pointer< wlanapiInt32> ? pFailReason) → int - Starts the wireless Hosted Network.
-
WlanHostedNetworkStopUsing(
HANDLE hClientHandle, Pointer< wlanapiInt32> ? pFailReason) → int - Stops the wireless Hosted Network.
-
WlanIhvControl(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, WLAN_IHV_CONTROL_TYPE type, int dwInBufferSize, Pointer<NativeType> pInBuffer, int dwOutBufferSize, Pointer<NativeType> ? pOutBuffer, Pointer<Uint32> pdwBytesReturned) → int - Provides a mechanism for independent hardware vendor (IHV) control of WLAN drivers or services.
-
WlanOpenHandle(
int dwClientVersion, Pointer< wlanapiUint32> pdwNegotiatedVersion, Pointer<Pointer< phClientHandle) → intNativeType> > - Opens a connection to the server.
-
WlanQueryAutoConfigParameter(
HANDLE hClientHandle, WLAN_AUTOCONF_OPCODE opCode, Pointer< wlanapiUint32> pdwDataSize, Pointer<Pointer< ppData, Pointer<NativeType> >Int32> ? pWlanOpcodeValueType) → int - Queries for the parameters of the auto configuration service.
-
WlanQueryInterface(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, WLAN_INTF_OPCODE opCode, Pointer<Uint32> pdwDataSize, Pointer<Pointer< ppData, Pointer<NativeType> >Int32> ? pWlanOpcodeValueType) → int - Queries various parameters of a specified interface.
-
WlanReasonCodeToString(
int dwReasonCode, int dwBufferSize, PCWSTR pStringBuffer) → int wlanapi - Retrieves a string that describes a specified reason code.
-
WlanRegisterDeviceServiceNotification(
HANDLE hClientHandle, Pointer< wlanapiWLAN_DEVICE_SERVICE_GUID_LIST> ? pDevSvcGuidList) → int - Allows user mode clients with admin privileges, or User-Mode Driver Framework (UMDF) drivers, to register for unsolicited notifications corresponding to device services that they're interested in.
-
WlanRegisterNotification(
HANDLE hClientHandle, WLAN_NOTIFICATION_SOURCES dwNotifSource, bool bIgnoreDuplicate, Pointer< wlanapiNativeFunction< ? funcCallback, Pointer<WLAN_NOTIFICATION_CALLBACK> >NativeType> ? pCallbackContext, Pointer<Uint32> ? pdwPrevNotifSource) → int - Used to register and unregister notifications on all wireless interfaces.
-
WlanRegisterVirtualStationNotification(
HANDLE hClientHandle, bool bRegister) → int wlanapi - Used to register and unregister notifications on a virtual station.
-
WlanRenameProfile(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, PCWSTR strOldProfileName, PCWSTR strNewProfileName) → int - Renames the specified profile.
-
WlanSaveTemporaryProfile(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, PCWSTR strProfileName, PCWSTR? strAllUserProfileSecurity, int dwFlags, bool bOverWrite) → int - Saves a temporary profile to the profile store.
-
WlanScan(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, Pointer<DOT11_SSID> ? pDot11Ssid, Pointer<WLAN_RAW_DATA> ? pIeData) → int - Requests a scan for available networks on the indicated interface.
-
WlanSetAutoConfigParameter(
HANDLE hClientHandle, WLAN_AUTOCONF_OPCODE opCode, int dwDataSize, Pointer< wlanapiNativeType> pData) → int - Sets parameters for the automatic configuration service.
-
WlanSetFilterList(
HANDLE hClientHandle, WLAN_FILTER_LIST_TYPE wlanFilterListType, Pointer< wlanapiDOT11_NETWORK_LIST> ? pNetworkList) → int - Sets the permit/deny list.
-
WlanSetInterface(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, WLAN_INTF_OPCODE opCode, int dwDataSize, Pointer<NativeType> pData) → int - Sets user-configurable parameters.
-
WlanSetProfile(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, int dwFlags, PCWSTR strProfileXml, PCWSTR? strAllUserProfileSecurity, bool bOverwrite, Pointer<Uint32> pdwReasonCode) → int - Sets the content of a specific profile.
-
WlanSetProfileCustomUserData(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, PCWSTR strProfileName, int dwDataSize, Pointer<Uint8> pData) → int - Sets the custom user data associated with a profile.
-
WlanSetProfileEapUserData(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, PCWSTR strProfileName, EAP_METHOD_TYPE eapType, WLAN_SET_EAPHOST_FLAGS dwFlags, int dwEapUserDataSize, Pointer<Uint8> ? pbEapUserData) → int - Sets the Extensible Authentication Protocol (EAP) user credentials as specified by raw EAP data.
-
WlanSetProfileEapXmlUserData(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, PCWSTR strProfileName, WLAN_SET_EAPHOST_FLAGS dwFlags, PCWSTR strEapXmlUserData) → int - Sets the Extensible Authentication Protocol (EAP) user credentials as specified by an XML string.
-
WlanSetProfileList(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, int dwItems, Pointer<Pointer< strProfileNames) → intUtf16> > - Sets the preference order of profiles.
-
WlanSetProfilePosition(
HANDLE hClientHandle, Pointer< wlanapiGUID> pInterfaceGuid, PCWSTR strProfileName, int dwPosition) → int - Sets the position of a single, specified profile in the preference list.
-
WlanSetPsdIEDataList(
HANDLE hClientHandle, PCWSTR? strFormat, Pointer< wlanapiWLAN_RAW_DATA_LIST> ? pPsdIEDataList) → int - Sets the proximity service discovery (PSD) information element (IE) data list.
-
WlanSetSecuritySettings(
HANDLE hClientHandle, WLAN_SECURABLE_OBJECT securableObject, PCWSTR strModifiedSDDL) → int wlanapi - Sets the security settings for a configurable object.