AddFontResourceEx function gdi32
Adds the font resource from the specified file to the system.
Fonts added with the AddFontResourceEx function can be marked as private and not enumerable.
To learn more, see learn.microsoft.com/windows/win32/api/wingdi/nf-wingdi-addfontresourceexw.
Implementation
@pragma('vm:prefer-inline')
int AddFontResourceEx(PCWSTR name, FONT_RESOURCE_CHARACTERISTICS fl) =>
_AddFontResourceEx(name, fl, nullptr);