Describes a pointer.
To learn more, see learn.microsoft.com/windows/win32/api/oaidl/ns-oaidl-bindptr.
- Inheritance
- Implemented types
- Available extensions
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the UnionAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
lpfuncdesc
↔ Pointer<
FUNCDESC> -
Pointer to a function.
getter/setter pair
- lptcomp ↔ ITypeComp?
-
The ITypeComp
that binds the pointer.
getter/setter pair
-
lpvardesc
↔ Pointer<
VARDESC> -
Pointer to a variable, constant, or data member.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< BINDPTR> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited