Contains parameters used during a moniker-binding operation.
To learn more, see learn.microsoft.com/windows/win32/api/objidl/ns-objidl-bind_opts.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - cbStruct ↔ int
-
The size of this structure, in bytes.
getter/setter pair
- dwTickCountDeadline ↔ int
-
The clock time by which the caller would like the binding operation to be
completed, in milliseconds.
getter/setter pair
- grfFlags ↔ int
-
Flags that control aspects of moniker binding operations.
getter/setter pair
- grfMode ↔ int
-
Flags that should be used when opening the file that contains the object
identified by the moniker.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< BIND_OPTS> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited