Describes one or more characteristics that have changed.
To learn more, see learn.microsoft.com/windows/win32/api/bthledef/ns-bthledef-bluetooth_gatt_value_changed_event_registration.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
Characteristics
↔ Array<
BTH_LE_GATT_CHARACTERISTIC> -
Array of characteristics to monitor for incoming events.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- NumCharacteristics ↔ int
-
The number of characteristics that follow this member in memory.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< BLUETOOTH_GATT_VALUE_CHANGED_EVENT_REGISTRATION> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited