Contains information about a Bluetooth Low Energy (LE) Universally Unique Identifier (UUID).
To learn more, see learn.microsoft.com/windows/win32/api/bthledef/ns-bthledef-bth_le_uuid.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- IsShortUuid ↔ bool
-
Indicates if the Low Energy (LE) UUID a 16-bit shortened value, or if it
is the long 128-bit value.
getter/setter pair
- LongUuid ↔ GUID
-
Available on BTH_LE_UUID, provided by the BTH_LE_UUID_0_Extension extension
getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ShortUuid ↔ int
-
Available on BTH_LE_UUID, provided by the BTH_LE_UUID_0_Extension extension
getter/setter pair - Value ↔ BTH_LE_UUID_0
-
The value of the UUID.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< BTH_LE_UUID> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited