Contains information that the GetFileInformationByHandle function retrieves.
To learn more, see learn.microsoft.com/windows/win32/api/fileapi/ns-fileapi-by_handle_file_information.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - dwFileAttributes ↔ int
-
The file attributes.
getter/setter pair
- dwVolumeSerialNumber ↔ int
-
The serial number of the volume that contains a file.
getter/setter pair
- ftCreationTime ↔ FILETIME
-
A
FILETIMEstructure that specifies when a file or directory is created.getter/setter pair - ftLastAccessTime ↔ FILETIME
-
A
FILETIMEstructure.getter/setter pair - ftLastWriteTime ↔ FILETIME
-
A
FILETIMEstructure.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- nFileIndexHigh ↔ int
-
The high-order part of a unique identifier that is associated with a file.
getter/setter pair
- nFileIndexLow ↔ int
-
The low-order part of a unique identifier that is associated with a file.
getter/setter pair
- nFileSizeHigh ↔ int
-
The high-order part of the file size.
getter/setter pair
- nFileSizeLow ↔ int
-
The low-order part of the file size.
getter/setter pair
- nNumberOfLinks ↔ int
-
The number of links to this file.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< BY_HANDLE_FILE_INFORMATION> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited