Contains information passed to a WH_CBT hook procedure, CBTProc, before a window is created.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-cbt_createwndw.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hwndInsertAfter ↔ HWND
-
A handle to the window whose position in the Z order precedes that of the
window being created.
getter/setter pair
-
lpcs
↔ Pointer<
CREATESTRUCT> -
A pointer to a
CREATESTRUCTstructure that contains initialization parameters for the window about to be created.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< CBT_CREATEWND> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited