Contains optional extended parameters for CreateFile2.
To learn more, see learn.microsoft.com/windows/win32/api/fileapi/ns-fileapi-createfile2_extended_parameters.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - dwFileAttributes ↔ int
-
The file or device attributes and flags, FILE_ATTRIBUTE_NORMAL being
the most common default value for files.
getter/setter pair
- dwFileFlags ↔ int
-
This parameter can contain combinations of flags (FILE_FLAG_*) for
control of file or device caching behavior, access modes, and other
special-purpose flags.
getter/setter pair
- dwSecurityQosFlags ↔ int
-
The dwSecurityQosFlags parameter specifies SQOS information.
getter/setter pair
- dwSize ↔ int
-
Contains the size of this structure,
sizeOf<CREATEFILE2_EXTENDED_PARAMETERS>().getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- hTemplateFile ↔ HANDLE
-
A valid handle to a template file with the GENERIC_READ access right.
getter/setter pair
-
lpSecurityAttributes
↔ Pointer<
SECURITY_ATTRIBUTES> -
A pointer to a
SECURITY_ATTRIBUTESstructure that contains two separate but related data members: an optional security descriptor, and a Boolean value that determines whether the returned handle can be inherited by child processes.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< CREATEFILE2_EXTENDED_PARAMETERS> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited