Defines the initialization parameters passed to the window procedure of an application.
These members are identical to the parameters of the CreateWindowEx function.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-createstructw.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - cx ↔ int
-
The width of the new window, in pixels.
getter/setter pair
- cy ↔ int
-
The height of the new window, in pixels.
getter/setter pair
- dwExStyle ↔ WINDOW_EX_STYLE
-
The extended window style for the new window.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hInstance ↔ HINSTANCE
-
A handle to the module that owns the new window.
getter/setter pair
- hMenu ↔ HMENU
-
A handle to the menu to be used by the new window.
getter/setter pair
- hwndParent ↔ HWND
-
A handle to the parent window, if the window is a child window.
getter/setter pair
-
lpCreateParams
↔ Pointer<
NativeType> -
Contains additional data which may be used to create the window.
getter/setter pair
- lpszClass ↔ PWSTR
-
A pointer to a null-terminated string or an atom that specifies the class
name of the new window.
getter/setter pair
- lpszName ↔ PWSTR
-
The name of the new window.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style ↔ WINDOW_STYLE
-
The style for the new window.
getter/setter pair
- x ↔ int
-
The x-coordinate of the upper left corner of the new window.
getter/setter pair
- y ↔ int
-
The y-coordinate of the upper left corner of the new window.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< CREATESTRUCT> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited