Useful for calculations involving money, or for any fixed-point calculation where accuracy is particularly important.
To learn more, see learn.microsoft.com/windows/win32/api/wtypes/ns-wtypes-cy~r1.
- Inheritance
- Implemented types
- Available extensions
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the UnionAddress extension
The memory address of the underlying data.no setter - Anonymous ↔ CY_0
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- Hi ↔ int
-
Available on CY, provided by the CY_0_Extension extension
getter/setter pair - int64 ↔ int
-
getter/setter pair
- Lo ↔ int
-
Available on CY, provided by the CY_0_Extension extension
getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< CY> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited