Base interface for all COM types that participate in the companion system.
This abstraction enables type-safe COM activation and casting by associating Dart interface types with metadata and construction logic at runtime.
Each COM interface type is paired with a ComCompanion, which provides:
- The interface IID
- A constructor that wraps a raw vtable pointer
Companions may be either:
- Predefined by the library (for built-in Win32 / COM interfaces)
- Registered by user code for custom or third-party interfaces
This system is used by functions such as:
createInstance<T>()CoCreateInstance<T>()CoGetClassObject<T>()
- Implementers
- IAccessible
- IAgileObject
- IApplicationActivationManager
- IAppxBlockMapBlock
- IAppxBlockMapBlocksEnumerator
- IAppxBlockMapFile
- IAppxBlockMapFilesEnumerator
- IAppxBlockMapReader
- IAppxFactory
- IAppxFile
- IAppxFilesEnumerator
- IAppxManifestApplication
- IAppxManifestApplicationsEnumerator
- IAppxManifestCapabilitiesEnumerator
- IAppxManifestDeviceCapabilitiesEnumerator
- IAppxManifestDriverConstraint
- IAppxManifestDriverConstraintsEnumerator
- IAppxManifestDriverDependenciesEnumerator
- IAppxManifestDriverDependency
- IAppxManifestHostRuntimeDependenciesEnumerator
- IAppxManifestHostRuntimeDependency
- IAppxManifestHostRuntimeDependency2
- IAppxManifestMainPackageDependenciesEnumerator
- IAppxManifestMainPackageDependency
- IAppxManifestOptionalPackageInfo
- IAppxManifestOSPackageDependenciesEnumerator
- IAppxManifestOSPackageDependency
- IAppxManifestPackageDependenciesEnumerator
- IAppxManifestPackageDependency
- IAppxManifestPackageId
- IAppxManifestProperties
- IAppxManifestQualifiedResource
- IAppxManifestQualifiedResourcesEnumerator
- IAppxManifestReader
- IAppxManifestReader2
- IAppxManifestReader3
- IAppxManifestReader4
- IAppxManifestReader5
- IAppxManifestReader6
- IAppxManifestReader7
- IAppxManifestResourcesEnumerator
- IAppxManifestTargetDeviceFamiliesEnumerator
- IAppxManifestTargetDeviceFamily
- IAppxPackageReader
- IAppxPackageWriter
- IAudioCaptureClient
- IAudioClient
- IAudioClient2
- IAudioClient3
- IAudioClientDuckingControl
- IAudioClock
- IAudioClock2
- IAudioClockAdjustment
- IAudioRenderClient
- IAudioSessionControl
- IAudioSessionControl2
- IAudioSessionEnumerator
- IAudioSessionEvents
- IAudioSessionManager
- IAudioSessionManager2
- IAudioSessionNotification
- IAudioStreamVolume
- IAudioVolumeDuckNotification
- IBindCtx
- IChannelAudioVolume
- IClassFactory
- IConnectionPoint
- IConnectionPointContainer
- IDesktopWallpaper
- IDispatch
- IEnumConnectionPoints
- IEnumConnections
- IEnumIDList
- IEnumMoniker
- IEnumNetworkConnections
- IEnumNetworks
- IEnumResources
- IEnumShellItems
- IEnumSpellingError
- IEnumSpObjectTokens
- IEnumSTATSTG
- IEnumString
- IEnumVARIANT
- IEnumWbemClassObject
- IErrorInfo
- IFileDialog
- IFileDialog2
- IFileDialogCustomize
- IFileDialogEvents
- IFileIsInUse
- IFileOpenDialog
- IFileOperationProgressSink
- IFileSaveDialog
- IInitializeWithWindow
- IInspectable
- IKnownFolder
- IKnownFolderManager
- IMalloc
- IMetaDataAssemblyImport
- IMetaDataDispenser
- IMetaDataDispenserEx
- IMetaDataImport
- IMetaDataImport2
- IMetaDataTables
- IMetaDataTables2
- IMMDevice
- IMMDeviceCollection
- IMMDeviceEnumerator
- IMMEndpoint
- IMMNotificationClient
- IModalWindow
- IMoniker
- INetwork
- INetworkConnection
- INetworkListManager
- INetworkListManagerEvents
- IOptionDescription
- IPersist
- IPersistFile
- IPersistMemory
- IPersistStream
- IPortableDeviceKeyCollection
- IPortableDevicePropVariantCollection
- IPortableDeviceValues
- IPortableDeviceValuesCollection
- IPropertyDescriptionList
- IPropertyStore
- IProvideClassInfo
- IRawElementProviderSimple
- IRecordInfo
- IRestrictedErrorInfo
- IRunningObjectTable
- ISensor
- ISensorCollection
- ISensorDataReport
- ISensorEvents
- ISensorManager
- ISensorManagerEvents
- ISequentialStream
- IShellFolder
- IShellItem
- IShellItem2
- IShellItemArray
- IShellItemFilter
- IShellItemImageFactory
- IShellItemResources
- IShellLink
- IShellLinkDataList
- IShellLinkDual
- IShellService
- ISimpleAudioVolume
- ISpDataKey
- ISpeechAudioFormat
- ISpeechBaseStream
- ISpeechDataKey
- ISpeechObjectToken
- ISpeechObjectTokenCategory
- ISpeechObjectTokens
- ISpeechVoice
- ISpeechVoiceStatus
- ISpeechWaveFormatEx
- ISpellChecker
- ISpellChecker2
- ISpellCheckerChangedEventHandler
- ISpellCheckerFactory
- ISpellingError
- ISpEventSource
- ISpNotifySink
- ISpNotifySource
- ISpObjectToken
- ISpObjectTokenCategory
- ISpStreamFormat
- ISpVoice
- IStorage
- IStream
- ISupportErrorInfo
- ITypeComp
- ITypeInfo
- ITypeLib
- IUIAutomation
- IUIAutomation2
- IUIAutomation3
- IUIAutomation4
- IUIAutomation5
- IUIAutomation6
- IUIAutomationActiveTextPositionChangedEventHandler
- IUIAutomationAndCondition
- IUIAutomationAnnotationPattern
- IUIAutomationBoolCondition
- IUIAutomationCacheRequest
- IUIAutomationChangesEventHandler
- IUIAutomationCondition
- IUIAutomationCustomNavigationPattern
- IUIAutomationDockPattern
- IUIAutomationDragPattern
- IUIAutomationDropTargetPattern
- IUIAutomationElement
- IUIAutomationElement2
- IUIAutomationElement3
- IUIAutomationElement4
- IUIAutomationElement5
- IUIAutomationElement6
- IUIAutomationElement7
- IUIAutomationElement8
- IUIAutomationElement9
- IUIAutomationElementArray
- IUIAutomationEventHandler
- IUIAutomationEventHandlerGroup
- IUIAutomationExpandCollapsePattern
- IUIAutomationFocusChangedEventHandler
- IUIAutomationGridItemPattern
- IUIAutomationGridPattern
- IUIAutomationInvokePattern
- IUIAutomationItemContainerPattern
- IUIAutomationLegacyIAccessiblePattern
- IUIAutomationMultipleViewPattern
- IUIAutomationNotCondition
- IUIAutomationNotificationEventHandler
- IUIAutomationObjectModelPattern
- IUIAutomationOrCondition
- IUIAutomationPropertyChangedEventHandler
- IUIAutomationPropertyCondition
- IUIAutomationProxyFactory
- IUIAutomationProxyFactoryEntry
- IUIAutomationProxyFactoryMapping
- IUIAutomationRangeValuePattern
- IUIAutomationScrollItemPattern
- IUIAutomationScrollPattern
- IUIAutomationSelectionItemPattern
- IUIAutomationSelectionPattern
- IUIAutomationSelectionPattern2
- IUIAutomationSpreadsheetItemPattern
- IUIAutomationSpreadsheetPattern
- IUIAutomationStructureChangedEventHandler
- IUIAutomationStylesPattern
- IUIAutomationSynchronizedInputPattern
- IUIAutomationTableItemPattern
- IUIAutomationTablePattern
- IUIAutomationTextChildPattern
- IUIAutomationTextEditPattern
- IUIAutomationTextEditTextChangedEventHandler
- IUIAutomationTextPattern
- IUIAutomationTextPattern2
- IUIAutomationTextRange
- IUIAutomationTextRange2
- IUIAutomationTextRange3
- IUIAutomationTextRangeArray
- IUIAutomationTogglePattern
- IUIAutomationTransformPattern
- IUIAutomationTransformPattern2
- IUIAutomationTreeWalker
- IUIAutomationValuePattern
- IUIAutomationVirtualizedItemPattern
- IUIAutomationWindowPattern
- IUnknown
- IUri
- IVirtualDesktopManager
- IWbemCallResult
- IWbemClassObject
- IWbemConfigureRefresher
- IWbemContext
- IWbemHiPerfEnum
- IWbemLocator
- IWbemObjectAccess
- IWbemObjectSink
- IWbemQualifierSet
- IWbemRefresher
- IWbemServices
- IWebAuthenticationCoreManagerInterop
- IWinHttpRequest
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
register<
T extends ComInterface> (ComCompanion< T> companion) → void -
Registers a ComCompanion for the COM interface type
T. -
unregister<
T extends ComInterface> () → void -
Unregisters the companion associated with the COM interface type
T.