Contains information about a class of devices.
To learn more, see learn.microsoft.com/windows/win32/api/dbt/ns-dbt-dev_broadcast_deviceinterface_w.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - dbcc_classguid ↔ GUID
-
The GUID for the interface device class.
getter/setter pair
- dbcc_devicetype ↔ int
-
Set to DBT_DEVTYP_DEVICEINTERFACE.
getter/setter pair
- dbcc_name ↔ String
-
A string that specifies the name of the device.
getter/setter pair
- dbcc_reserved ↔ int
-
getter/setter pair
- dbcc_size ↔ int
-
The size of this structure, in bytes.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< DEV_BROADCAST_DEVICEINTERFACE> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited