Contains display information about the device.
To learn more, see learn.microsoft.com/windows/win32/api/wingdi/ns-wingdi-displayconfig_device_info_header.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
- adapterId ↔ LUID
-
A locally unique identifier (LUID) that identifies the adapter that the
device information packet refers to.
getter/setter pair
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int
-
The source or target identifier to get or set the device information for.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size ↔ int
-
The size, in bytes, of the device information that is retrieved or set.
getter/setter pair
- type ↔ DISPLAYCONFIG_DEVICE_INFO_TYPE
-
A DISPLAYCONFIG_DEVICE_INFO_TYPE
enumerated value that determines the type of device information to
retrieve or set.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< DISPLAYCONFIG_DEVICE_INFO_HEADER> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited