DISPLAYCONFIG_PATH_INFO class base struct

The DISPLAYCONFIG_PATH_INFO structure is used to describe a single path from a target to a source.

Inheritance
Implemented types
Available extensions

Constructors

DISPLAYCONFIG_PATH_INFO()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
flags ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceInfo ↔ DISPLAYCONFIG_PATH_SOURCE_INFO
getter/setter pair
targetInfo ↔ DISPLAYCONFIG_PATH_TARGET_INFO
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited