Contains target information for a single path.
To learn more, see learn.microsoft.com/windows/win32/api/wingdi/ns-wingdi-displayconfig_path_target_info.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
- adapterId ↔ LUID
-
The identifier of the adapter that the path is on.
getter/setter pair
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - Anonymous ↔ DISPLAYCONFIG_PATH_TARGET_INFO_0
-
getter/setter pair
- Anonymous ↔ DISPLAYCONFIG_PATH_TARGET_INFO_0_0
-
Available on DISPLAYCONFIG_PATH_TARGET_INFO, provided by the DISPLAYCONFIG_PATH_TARGET_INFO_0_Extension extension
getter/setter pair - bitfield ↔ int
-
Available on DISPLAYCONFIG_PATH_TARGET_INFO, provided by the DISPLAYCONFIG_PATH_TARGET_INFO_0_0_Extension extension
getter/setter pair - desktopModeInfoIdx ↔ int
-
Available on DISPLAYCONFIG_PATH_TARGET_INFO, provided by the DISPLAYCONFIG_PATH_TARGET_INFO_0_0_Extension extension
getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int
-
The target identifier on the specified adapter that this path relates to.
getter/setter pair
- modeInfoIdx ↔ int
-
Available on DISPLAYCONFIG_PATH_TARGET_INFO, provided by the DISPLAYCONFIG_PATH_TARGET_INFO_0_Extension extension
getter/setter pair - outputTechnology ↔ DISPLAYCONFIG_VIDEO_OUTPUT_TECHNOLOGY
-
The target's connector type.
getter/setter pair
- refreshRate ↔ DISPLAYCONFIG_RATIONAL
-
A
DISPLAYCONFIG_RATIONALstructure that specifies the refresh rate of the target.getter/setter pair - rotation ↔ DISPLAYCONFIG_ROTATION
-
A value that specifies the rotation of the target.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaling ↔ DISPLAYCONFIG_SCALING
-
A value that specifies how the source image is scaled to the target.
getter/setter pair
- scanLineOrdering ↔ DISPLAYCONFIG_SCANLINE_ORDERING
-
A value that specifies the scan-line ordering of the output on the target.
getter/setter pair
- statusFlags ↔ int
-
A bitwise OR of flag values that indicates the status of the target.
getter/setter pair
- targetAvailable ↔ bool
-
A Boolean value that specifies whether the target is available.
getter/setter pair
- targetModeInfoIdx ↔ int
-
Available on DISPLAYCONFIG_PATH_TARGET_INFO, provided by the DISPLAYCONFIG_PATH_TARGET_INFO_0_0_Extension extension
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< DISPLAYCONFIG_PATH_TARGET_INFO> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited