Describes a document that will be printed.
To learn more, see learn.microsoft.com/windows/win32/printdocs/doc-info-1.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- pDatatype ↔ PWSTR
-
Pointer to a null-terminated string that identifies the type of data used
to record the document.
getter/setter pair
- pDocName ↔ PWSTR
-
Pointer to a null-terminated string that specifies the name of the
document.
getter/setter pair
- pOutputFile ↔ PWSTR
-
Pointer to a null-terminated string that specifies the name of an output
file.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< DOC_INFO_1> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited