DestroyCursor function user32
Destroys a cursor and frees any memory the cursor occupied.
Do not use this function to destroy a shared cursor.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-destroycursor.
Implementation
Win32Result<bool> DestroyCursor(HCURSOR hCursor) {
final result_ = DestroyCursor_Wrapper(hCursor);
return Win32Result(value: result_.value.i32 != FALSE, error: result_.error);
}