DragDetect function user32
Captures the mouse and tracks its movement until the user releases the left button, presses the ESC key, or moves the mouse outside the drag rectangle around the specified point.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-dragdetect.
Implementation
@pragma('vm:prefer-inline')
bool DragDetect(HWND hwnd, POINT pt) => _DragDetect(hwnd, pt) != FALSE;