DrawAnimatedRects function user32
Animates the caption of a window to indicate the opening of an icon or the minimizing or maximizing of a window.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-drawanimatedrects.
Implementation
@pragma('vm:prefer-inline')
bool DrawAnimatedRects(
HWND? hwnd,
int idAni,
Pointer<RECT> lprcFrom,
Pointer<RECT> lprcTo,
) => _DrawAnimatedRects(hwnd ?? nullptr, idAni, lprcFrom, lprcTo) != FALSE;