DrawText function user32
Draws formatted text in the specified rectangle.
It formats the text according to the specified method (expanding tabs, justifying characters, breaking lines, and so forth).
To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-drawtextw.
Implementation
@pragma('vm:prefer-inline')
int DrawText(
HDC hdc,
PCWSTR lpchText,
int cchText,
Pointer<RECT> lprc,
DRAW_TEXT_FORMAT format,
) => _DrawText(hdc, lpchText, cchText, lprc, format);