DwmInvalidateIconicBitmaps function dwmapi
Called by an application to indicate that all previously provided iconic bitmaps from a window, both thumbnails and peek representations, should be refreshed.
Throws a WindowsException on failure.
To learn more, see learn.microsoft.com/windows/win32/api/dwmapi/nf-dwmapi-dwminvalidateiconicbitmaps.
Implementation
@pragma('vm:prefer-inline')
void DwmInvalidateIconicBitmaps(HWND hwnd) {
final hr$ = HRESULT(_DwmInvalidateIconicBitmaps(hwnd));
if (hr$.isError) throw WindowsException(hr$);
}