Contains type and vendor identification information for an EAP method.
To learn more, see learn.microsoft.com/windows/win32/api/eaptypes/ns-eaptypes-eap_type.
- Inheritance
- Implemented types
- Available extensions
Constructors
- EAP_TYPE()
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - dwVendorId ↔ int
-
The vendor ID for the EAP method.
getter/setter pair
- dwVendorType ↔ int
-
The numeric type code for the vendor of this EAP method.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ int
-
The numeric type code for this EAP method.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< EAP_TYPE> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited