Contains the name of a service in a service control manager database and information about the service.
It is used by the EnumServicesStatusEx function.
To learn more, see learn.microsoft.com/windows/win32/api/winsvc/ns-winsvc-enum_service_status_processw.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- lpDisplayName ↔ PWSTR
-
A display name that can be used by service control programs, such as
Services in Control Panel, to identify the service.
getter/setter pair
- lpServiceName ↔ PWSTR
-
The name of a service in the service control manager database.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ServiceStatusProcess ↔ SERVICE_STATUS_PROCESS
-
A
SERVICE_STATUS_PROCESSstructure that contains status information for the lpServiceName service.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< ENUM_SERVICE_STATUS_PROCESS> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited