EnableNonClientDpiScaling function user32
In high-DPI displays, enables automatic display scaling of the non-client area portions of the specified top-level window.
Must be called during the initialization of that window.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-enablenonclientdpiscaling.
Implementation
Win32Result<bool> EnableNonClientDpiScaling(HWND hwnd) {
final result_ = EnableNonClientDpiScaling_Wrapper(hwnd);
return Win32Result(value: result_.value.i32 != FALSE, error: result_.error);
}