EnumFontFamiliesEx function gdi32
int
EnumFontFamiliesEx(
- HDC hdc,
- Pointer<
LOGFONT> lpLogfont, - Pointer<
NativeFunction< lpProc,FONTENUMPROC> > - LPARAM lParam,
- int dwFlags,
Enumerates all uniquely-named fonts in the system that match the font characteristics specified by the LOGFONT structure.
EnumFontFamiliesEx enumerates fonts based on typeface name, character set, or both.
To learn more, see learn.microsoft.com/windows/win32/api/wingdi/nf-wingdi-enumfontfamiliesexw.
Implementation
@pragma('vm:prefer-inline')
int EnumFontFamiliesEx(
HDC hdc,
Pointer<LOGFONT> lpLogfont,
Pointer<NativeFunction<FONTENUMPROC>> lpProc,
LPARAM lParam,
int dwFlags,
) => _EnumFontFamiliesEx(hdc, lpLogfont, lpProc, lParam, dwFlags);