ExcludeUpdateRgn function user32
Prevents drawing within invalid areas of a window by excluding an updated region in the window from a clipping region.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-excludeupdatergn.
Implementation
@pragma('vm:prefer-inline')
int ExcludeUpdateRgn(HDC hDC, HWND hWnd) => _ExcludeUpdateRgn(hDC, hWnd);