Contains information that the FindText and ReplaceText functions use to initialize the Find and Replace dialog boxes.
To learn more, see learn.microsoft.com/windows/win32/api/commdlg/ns-commdlg-findreplacew.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - Flags ↔ FINDREPLACE_FLAGS
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hInstance ↔ HINSTANCE
-
If the FR_ENABLETEMPLATEHANDLE flag is set in the Flags,
hInstance is a handle to a memory object containing a dialog box
template.
getter/setter pair
- hwndOwner ↔ HWND
-
A handle to the window that owns the dialog box.
getter/setter pair
- lCustData ↔ LPARAM
-
Application-defined data that the system passes to the hook procedure
identified by the lpfnHook member.
getter/setter pair
-
lpfnHook
↔ Pointer<
NativeFunction< LPFRHOOKPROC> > -
A pointer to an
FRHookProchook procedure that can process messages intended for the dialog box.getter/setter pair - lpstrFindWhat ↔ PWSTR
-
The search string that the user typed in the Find What edit
control.
getter/setter pair
- lpstrReplaceWith ↔ PWSTR
-
The replacement string that the user typed in the Replace With edit
control.
getter/setter pair
- lpTemplateName ↔ PWSTR
-
The name of the dialog box template resource in the module identified by
the hInstance member.
getter/setter pair
- lStructSize ↔ int
-
The length, in bytes, of the structure.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wFindWhatLen ↔ int
-
The length, in bytes, of the buffer pointed to by the lpstrFindWhat
member.
getter/setter pair
- wReplaceWithLen ↔ int
-
The length, in bytes, of the buffer pointed to by the
lpstrReplaceWith member.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< FINDREPLACE> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited