FillConsoleOutputAttribute function kernel32
Sets the character attributes for a specified number of character cells, beginning at the specified coordinates in a screen buffer.
To learn more, see learn.microsoft.com/windows/console/fillconsoleoutputattribute.
Implementation
Win32Result<bool> FillConsoleOutputAttribute(
HANDLE hConsoleOutput,
int wAttribute,
int nLength,
COORD dwWriteCoord,
Pointer<Uint32> lpNumberOfAttrsWritten,
) {
resolveGetLastError();
final result_ = _FillConsoleOutputAttribute(
hConsoleOutput,
wAttribute,
nLength,
dwWriteCoord,
lpNumberOfAttrsWritten,
);
return .new(value: result_ != FALSE, error: GetLastError());
}