FillConsoleOutputCharacter function kernel32
Writes a character to the console screen buffer a specified number of times, beginning at the specified coordinates.
To learn more, see learn.microsoft.com/windows/console/fillconsoleoutputcharacter.
Implementation
Win32Result<bool> FillConsoleOutputCharacter(
HANDLE hConsoleOutput,
int cCharacter,
int nLength,
COORD dwWriteCoord,
Pointer<Uint32> lpNumberOfCharsWritten,
) {
final result_ = FillConsoleOutputCharacterW_Wrapper(
hConsoleOutput,
cCharacter,
nLength,
dwWriteCoord,
lpNumberOfCharsWritten,
);
return .new(value: result_.value.i32 != FALSE, error: result_.error);
}