FillPath function gdi32
Closes any open figures in the current path and fills the path's interior by using the current brush and polygon-filling mode.
To learn more, see learn.microsoft.com/windows/win32/api/wingdi/nf-wingdi-fillpath.
Implementation
@pragma('vm:prefer-inline')
bool FillPath(HDC hdc) => _FillPath(hdc) != FALSE;