FindFirstPrinterChangeNotification function winspool
FINDPRINTERCHANGENOTIFICATION_HANDLE
FindFirstPrinterChangeNotification(
- PRINTER_HANDLE hPrinter,
- int fdwFilter,
- int fdwOptions,
- Pointer<
NativeType> ? pPrinterNotifyOptions,
Creates a change notification object and returns a handle to the object.
You can then use this handle in a call to one of the wait functions to monitor changes to the printer or print server.
To learn more, see learn.microsoft.com/windows/win32/printdocs/findfirstprinterchangenotification.
Implementation
@pragma('vm:prefer-inline')
FINDPRINTERCHANGENOTIFICATION_HANDLE FindFirstPrinterChangeNotification(
PRINTER_HANDLE hPrinter,
int fdwFilter,
int fdwOptions,
Pointer? pPrinterNotifyOptions,
) => FINDPRINTERCHANGENOTIFICATION_HANDLE(
_FindFirstPrinterChangeNotification(
hPrinter,
fdwFilter,
fdwOptions,
pPrinterNotifyOptions ?? nullptr,
),
);