FindText function comdlg32
Creates a system-defined modeless Find dialog box that lets the user specify a string to search for and options to use when searching for text in a document.
To learn more, see learn.microsoft.com/windows/win32/api/commdlg/nf-commdlg-findtextw.
Implementation
@pragma('vm:prefer-inline')
HWND FindText(Pointer<FINDREPLACE> param0) => HWND(_FindText(param0));