Stores information about a gesture.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-gestureinfo.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - cbExtraArgs ↔ int
-
The size, in bytes, of extra arguments that accompany this gesture.
getter/setter pair
- cbSize ↔ int
-
The size of the struct in bytes.
getter/setter pair
- dwFlags ↔ int
-
The state of the gesture.
getter/setter pair
- dwID ↔ int
-
The identifier of the gesture command.
getter/setter pair
- dwInstanceID ↔ int
-
An internally used identifier for the structure.
getter/setter pair
- dwSequenceID ↔ int
-
An internally used identifier for the sequence.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hwndTarget ↔ HWND
-
A handle to the window that is targeted by this gesture.
getter/setter pair
- ptsLocation ↔ POINTS
-
A POINTS structure containing the coordinates associated with the
gesture.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ullArguments ↔ int
-
A 64-bit unsigned integer that contains the arguments for gestures that
fit into 8 bytes.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< GESTUREINFO> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited