GetClipboardFormatName function user32

Win32Result<int> GetClipboardFormatName(
  1. int format,
  2. PWSTR lpszFormatName,
  3. int cchMaxCount
)

Retrieves from the clipboard the name of the specified registered format.

The function copies the name to the specified buffer.

To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-getclipboardformatnamew.

Implementation

Win32Result<int> GetClipboardFormatName(
  int format,
  PWSTR lpszFormatName,
  int cchMaxCount,
) {
  final result_ = GetClipboardFormatNameW_Wrapper(
    format,
    lpszFormatName,
    cchMaxCount,
  );
  return Win32Result(value: result_.value.i32, error: result_.error);
}