GetDialogBaseUnits function user32
Retrieves the system's dialog base units, which are the average width and height of characters in the system font.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-getdialogbaseunits.
Implementation
@pragma('vm:prefer-inline')
int GetDialogBaseUnits() => _GetDialogBaseUnits();