GetFileVersionInfoSize function version
Determines whether the operating system can retrieve version information for a specified file.
If version information is available, GetFileVersionInfoSize returns the size, in bytes, of that information.
To learn more, see learn.microsoft.com/windows/win32/api/winver/nf-winver-getfileversioninfosizew.
Implementation
Win32Result<int> GetFileVersionInfoSize(
PCWSTR lptstrFilename,
Pointer<Uint32>? lpdwHandle,
) {
final result_ = GetFileVersionInfoSizeW_Wrapper(
lptstrFilename,
lpdwHandle ?? nullptr,
);
return Win32Result(value: result_.value.u32, error: result_.error);
}