GetFocus function user32
Retrieves the handle to the window that has the keyboard focus, if the window is attached to the calling thread's message queue.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-getfocus.
Implementation
@pragma('vm:prefer-inline')
HWND GetFocus() => HWND(_GetFocus());