GetLocaleInfoEx function kernel32
Retrieves information about a locale specified by name.
Note: The application should call this function in preference to GetLocaleInfo if designed to run only on Windows Vista and later. Note: This function can retrieve data that changes between releases, for example, due to a custom locale. If your application must persist or transmit data, see Using Persistent Locale Data.
To learn more, see learn.microsoft.com/windows/win32/api/winnls/nf-winnls-getlocaleinfoex.
Implementation
Win32Result<int> GetLocaleInfoEx(
PCWSTR? lpLocaleName,
int lCType,
PWSTR? lpLCData,
int cchData,
) {
final result_ = GetLocaleInfoEx_Wrapper(
lpLocaleName ?? nullptr,
lCType,
lpLCData ?? nullptr,
cchData,
);
return Win32Result(value: result_.value.i32, error: result_.error);
}