GetPath function gdi32
Retrieves the coordinates defining the endpoints of lines and the control points of curves found in the path that is selected into the specified device context.
To learn more, see learn.microsoft.com/windows/win32/api/wingdi/nf-wingdi-getpath.
Implementation
@pragma('vm:prefer-inline')
int GetPath(HDC hdc, Pointer<POINT>? apt, Pointer<Uint8>? aj, int cpt) =>
_GetPath(hdc, apt ?? nullptr, aj ?? nullptr, cpt);