GetSystemMenu function user32
Enables the application to access the window menu (also known as the system menu or the control menu) for copying and modifying.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-getsystemmenu.
Implementation
@pragma('vm:prefer-inline')
HMENU GetSystemMenu(HWND hWnd, bool bRevert) =>
HMENU(_GetSystemMenu(hWnd, bRevert ? TRUE : FALSE));