GetSystemTimeAdjustment function kernel32
Determines whether the system is applying periodic time adjustments to its time-of-day clock, and obtains the value and period of any such adjustments.
To learn more, see learn.microsoft.com/windows/win32/api/sysinfoapi/nf-sysinfoapi-getsystemtimeadjustment.
Implementation
Win32Result<bool> GetSystemTimeAdjustment(
Pointer<Uint32> lpTimeAdjustment,
Pointer<Uint32> lpTimeIncrement,
Pointer<Int32> lpTimeAdjustmentDisabled,
) {
final result_ = GetSystemTimeAdjustment_Wrapper(
lpTimeAdjustment,
lpTimeIncrement,
lpTimeAdjustmentDisabled,
);
return Win32Result(value: result_.value.i32 != FALSE, error: result_.error);
}