GetUpdateRgn function user32
Retrieves the update region of a window by copying it into the specified region.
The coordinates of the update region are relative to the upper-left corner of the window (that is, they are client coordinates).
To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-getupdatergn.
Implementation
@pragma('vm:prefer-inline')
GDI_REGION_TYPE GetUpdateRgn(HWND hWnd, HRGN hRgn, bool bErase) =>
GDI_REGION_TYPE(_GetUpdateRgn(hWnd, hRgn, bErase ? TRUE : FALSE));