IApplicationActivationManager class com
Provides methods which activate Windows Store apps for the Launch, File, and Protocol extensions.
You will normally use this interface in debuggers and design tools.
To learn more, see learn.microsoft.com/windows/win32/api/shobjidl_core/nn-shobjidl_core-iapplicationactivationmanager.
- Inheritance
- Implemented types
Constructors
- IApplicationActivationManager(VTablePointer ptr)
- Creates a new instance of IApplicationActivationManager from a VTablePointer.
- IApplicationActivationManager.from(IUnknown interface)
-
Creates a new instance of IApplicationActivationManager from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
activateApplication(
PCWSTR appUserModelId, PCWSTR arguments, ACTIVATEOPTIONS options) → int - Activates the specified Windows Store app for the generic launch contract (Windows.Launch) in the current session.
-
activateForFile(
PCWSTR appUserModelId, IShellItemArray? itemArray, PCWSTR verb) → int - Activates the specified Windows Store app for the file contract (Windows.File).
-
activateForProtocol(
PCWSTR appUserModelId, IShellItemArray? itemArray) → int - Activates the specified Windows Store app for the protocol contract (Windows.Protocol).
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited