IAppxBlockMapBlock class com

Provides a read-only object that represents an individual block within a file contained in the block map file (AppxBlockMap.xml) for the App package.

To learn more, see learn.microsoft.com/windows/win32/api/appxpackaging/nn-appxpackaging-iappxblockmapblock.

Inheritance
Implemented types

Constructors

IAppxBlockMapBlock(VTablePointer ptr)
Creates a new instance of IAppxBlockMapBlock from a VTablePointer.
IAppxBlockMapBlock.from(IUnknown interface)
Creates a new instance of IAppxBlockMapBlock from an existing interface.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ptr VTablePointer
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() int
Increments the reference count of this COM object.
inherited
getCompressedSize() int
Retrieves compressed size of the block.
getHash(Pointer<Uint32> bufferSize, Pointer<Pointer<Uint8>> buffer) → void
Retrieves the hash value of the block.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface<T extends IUnknown>() → T
Queries this COM object for a specific interface defined by the type parameter T.
inherited
release() int
Decrements the reference count of this COM object.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited