IAppxFile class com
Retrieves information about a payload or footprint file in a package.
To learn more, see learn.microsoft.com/windows/win32/api/appxpackaging/nn-appxpackaging-iappxfile.
- Inheritance
- Implemented types
Constructors
- IAppxFile(VTablePointer ptr)
- Creates a new instance of IAppxFile from a VTablePointer.
- IAppxFile.from(IUnknown interface)
-
Creates a new instance of IAppxFile from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
getCompressionOption(
) → APPX_COMPRESSION_OPTION - Retrieves the compression option that is used to store the file in the package.
-
getContentType(
) → PWSTR - Retrieves the content type of the file.
-
getName(
) → PWSTR - Retrieves the name of the file, including its path relative to the package root directory.
-
getSize(
) → int - Retrieves the uncompressed size of the file.
-
getStream(
) → IStream? - Gets a read-only stream that contains the uncompressed content of the file.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited