IAppxManifestPackageDependency class com
Describes the dependency of one package on another package.
To learn more, see learn.microsoft.com/windows/win32/api/appxpackaging/nn-appxpackaging-iappxmanifestpackagedependency.
- Inheritance
- Implemented types
Constructors
- IAppxManifestPackageDependency(VTablePointer ptr)
- Creates a new instance of IAppxManifestPackageDependency from a VTablePointer.
- IAppxManifestPackageDependency.from(IUnknown interface)
-
Creates a new instance of IAppxManifestPackageDependency from an
existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
getMinVersion(
) → int - Gets the minimum version of the package on which the current package has a dependency.
-
getName(
) → PWSTR - Gets the name of the package on which the current package has a dependency.
-
getPublisher(
) → PWSTR - Gets the name of the publisher that produced the package on which the current package depends.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited