IAudioClientDuckingControl class com
Provides a method, SetDuckingOptionsForCurrentStream, that allows an app to specify that the system shouldn't duck the audio of other streams when the app's audio render stream is active.
To learn more, see learn.microsoft.com/windows/win32/api/audioclient/nn-audioclient-iaudioclientduckingcontrol.
- Inheritance
- Implemented types
Constructors
- IAudioClientDuckingControl(VTablePointer ptr)
- Creates a new instance of IAudioClientDuckingControl from a VTablePointer.
- IAudioClientDuckingControl.from(IUnknown interface)
-
Creates a new instance of IAudioClientDuckingControl from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
setDuckingOptionsForCurrentStream(
AUDIO_DUCKING_OPTIONS options) → void - Sets the audio ducking options for an audio render stream.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited