IBindCtx class com
Provides access to a bind context, which is an object that stores information about a particular moniker binding operation.
To learn more, see learn.microsoft.com/windows/win32/api/objidl/nn-objidl-ibindctx.
- Inheritance
- Implemented types
Constructors
- IBindCtx(VTablePointer ptr)
- Creates a new instance of IBindCtx from a VTablePointer.
- IBindCtx.from(IUnknown interface)
-
Creates a new instance of IBindCtx from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
enumObjectParam(
) → IEnumString? - Retrieves a pointer to an interface that can be used to enumerate the keys of the bind context's string-keyed table of pointers.
-
getBindOptions(
Pointer< BIND_OPTS> pbindopts) → void - Retrieves the binding options stored in this bind context.
-
getObjectParam(
PCWSTR pszKey) → IUnknown? - Retrieves an interface pointer to the object associated with the specified key in the bind context's string-keyed table of pointers.
-
getRunningObjectTable(
) → IRunningObjectTable? - Retrieves an interface pointer to the running object table (ROT) for the computer on which this bind context is running.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
registerObjectBound(
IUnknown? punk) → void - Registers an object with the bind context to ensure that the object remains active until the bind context is released.
-
registerObjectParam(
PCWSTR pszKey, IUnknown? punk) → void - Associates an object with a string key in the bind context's string-keyed table of pointers.
-
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
releaseBoundObjects(
) → void - Releases all pointers to all objects that were previously registered by calls to RegisterObjectBound.
-
revokeObjectBound(
IUnknown? punk) → void - Removes the object from the bind context, undoing a previous call to RegisterObjectBound.
-
revokeObjectParam(
PCWSTR pszKey) → void - Removes the specified key and its associated pointer from the bind context's string-keyed table of objects.
-
setBindOptions(
Pointer< BIND_OPTS> pbindopts) → void - Sets new values for the binding parameters stored in the bind context.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited