IBindCtx class com

Provides access to a bind context, which is an object that stores information about a particular moniker binding operation.

Inheritance

Constructors

IBindCtx(Pointer<COMObject> ptr)
IBindCtx.from(IUnknown interface)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
ptr ↔ Pointer<COMObject>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() → int
Increments the reference count for an interface pointer to a COM object.
inherited
detach() → void
Detaches the object from the Finalizer.
inherited
enumObjectParam(Pointer<Pointer<COMObject>> ppenum) → int
getBindOptions(Pointer<BIND_OPTS> pbindopts) → int
getObjectParam(Pointer<Utf16> pszKey, Pointer<Pointer<COMObject>> ppunk) → int
getRunningObjectTable(Pointer<Pointer<COMObject>> pprot) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface(Pointer<GUID> riid, Pointer<Pointer<NativeType>> ppvObject) → int
Queries a COM object for a pointer to one of its interface; identifying the interface by a reference to its interface identifier (IID).
inherited
registerObjectBound(Pointer<COMObject> punk) → int
registerObjectParam(Pointer<Utf16> pszKey, Pointer<COMObject> punk) → int
release() → int
Decrements the reference count for an interface on a COM object.
inherited
releaseBoundObjects() → int
revokeObjectBound(Pointer<COMObject> punk) → int
revokeObjectParam(Pointer<Utf16> pszKey) → int
setBindOptions(Pointer<BIND_OPTS> pbindopts) → int
toInterface(String iid) → Pointer<COMObject>
Cast an existing COM object to a specified interface.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited