IEnumConnectionPoints class com
Enumerates connection points.
To learn more, see learn.microsoft.com/windows/win32/api/ocidl/nn-ocidl-ienumconnectionpoints.
- Inheritance
- Implemented types
Constructors
- IEnumConnectionPoints(VTablePointer ptr)
- Creates a new instance of IEnumConnectionPoints from a VTablePointer.
- IEnumConnectionPoints.from(IUnknown interface)
-
Creates a new instance of IEnumConnectionPoints from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
clone(
) → IEnumConnectionPoints? - Creates a new enumerator that contains the same enumeration state as the current one.
-
next(
int cConnections, Pointer< VTablePointer> ppCP, Pointer<Uint32> pcFetched) → HRESULT - Retrieves the specified number of items in the enumeration sequence.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
reset(
) → void - Resets the enumeration sequence to the beginning.
-
skip(
int cConnections) → void - Skips over the specified number of items in the enumeration sequence.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited