IEnumString class com
Enumerates strings.
LPWSTR is the type that indicates a pointer to a zero-terminated string of wide, or Unicode, characters.
To learn more, see learn.microsoft.com/windows/win32/api/objidlbase/nn-objidlbase-ienumstring.
- Inheritance
- Implemented types
Constructors
- IEnumString(VTablePointer ptr)
- Creates a new instance of IEnumString from a VTablePointer.
- IEnumString.from(IUnknown interface)
-
Creates a new instance of IEnumString from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
clone(
) → IEnumString? - Creates a new enumerator that contains the same enumeration state as the current one.
-
next(
int celt, Pointer< Pointer< rgelt, Pointer<Utf16> >Uint32> ? pceltFetched) → HRESULT - Retrieves the specified number of items in the enumeration sequence.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
reset(
) → void - Resets the enumeration sequence to the beginning.
-
skip(
int celt) → HRESULT - Skips over the specified number of items in the enumeration sequence.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited