IErrorInfo class com
Provides detailed contextual error information.
To learn more, see learn.microsoft.com/windows/win32/api/oaidl/nn-oaidl-ierrorinfo.
- Inheritance
- Implemented types
Constructors
- IErrorInfo(VTablePointer ptr)
- Creates a new instance of IErrorInfo from a VTablePointer.
- IErrorInfo.from(IUnknown interface)
-
Creates a new instance of IErrorInfo from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
getDescription(
) → BSTR - Returns a textual description of the error.
-
getGUID(
) → Pointer< GUID> - Returns the globally unique identifier (GUID) of the interface that defined the error.
-
getHelpContext(
) → int - Returns the Help context identifier (ID) for the error.
-
getHelpFile(
) → BSTR - Returns the path of the Help file that describes the error.
-
getSource(
) → BSTR - Returns the language-dependent programmatic ID (ProgID) for the class or application that raised the error.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited