IInspectable class com
Provides functionality required for all Windows Runtime classes.
To learn more, see learn.microsoft.com/windows/win32/api/inspectable/nn-inspectable-iinspectable.
- Inheritance
- Implemented types
- Implementers
Constructors
- IInspectable(VTablePointer ptr)
- Creates a new instance of IInspectable from a VTablePointer.
- IInspectable.from(IUnknown interface)
-
Creates a new instance of IInspectable from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
getIids(
Pointer< Uint32> iidCount, Pointer<Pointer< iids) → voidGUID> > - Gets the interfaces that are implemented by the current Windows Runtime class.
-
getRuntimeClassName(
) → HSTRING - Gets the fully qualified name of the current Windows Runtime object.
-
getTrustLevel(
) → TrustLevel - Gets the trust level of the current Windows Runtime object.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited