IKnownFolder class com
Exposes methods that allow an application to retrieve information about a known folder's category, type, GUID, pointer to an item identifier list (PIDL) value, redirection capabilities, and definition.
To learn more, see learn.microsoft.com/windows/win32/api/shobjidl_core/nn-shobjidl_core-iknownfolder.
- Inheritance
- Implemented types
Constructors
- IKnownFolder(VTablePointer ptr)
- Creates a new instance of IKnownFolder from a VTablePointer.
- IKnownFolder.from(IUnknown interface)
-
Creates a new instance of IKnownFolder from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
getCategory(
) → KF_CATEGORY - Retrieves the category—virtual, fixed, common, or per-user—of the selected folder.
-
getFolderDefinition(
) → Pointer< KNOWNFOLDER_DEFINITION> - Retrieves a structure that contains the defining elements of a known folder, which includes the folder's category, name, path, description, tooltip, icon, and other properties.
-
getFolderType(
) → Pointer< GUID> - Retrieves the folder type.
-
getId(
) → Pointer< GUID> - Gets the ID of the selected folder.
-
getIDList(
int dwFlags) → Pointer< ITEMIDLIST> - Gets the location of the Shell namespace folder in the IDList (ITEMIDLIST) form.
-
getPath(
int dwFlags) → PWSTR - Retrieves the path of a known folder as a string.
-
getRedirectionCapabilities(
) → int - Gets a value that states whether the known folder can have its path set to a new value or what specific restrictions or prohibitions are placed on that redirection.
-
getShellItem<
T extends IUnknown> (int dwFlags) → T - Retrieves the location of a known folder in the Shell namespace in the form of a Shell item (IShellItem or derived interface).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
setPath(
int dwFlags, PCWSTR pszPath) → void - Assigns a new path to a known folder.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited