IMMDeviceEnumerator class com
Provides methods for enumerating multimedia device resources.
To learn more, see learn.microsoft.com/windows/win32/api/mmdeviceapi/nn-mmdeviceapi-immdeviceenumerator.
- Inheritance
- Implemented types
Constructors
- IMMDeviceEnumerator(VTablePointer ptr)
- Creates a new instance of IMMDeviceEnumerator from a VTablePointer.
- IMMDeviceEnumerator.from(IUnknown interface)
-
Creates a new instance of IMMDeviceEnumerator from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
enumAudioEndpoints(
EDataFlow dataFlow, DEVICE_STATE dwStateMask) → IMMDeviceCollection? - Generates a collection of audio endpoint devices that meet the specified criteria.
-
getDefaultAudioEndpoint(
EDataFlow dataFlow, ERole role) → IMMDevice? - Retrieves the default audio endpoint for the specified data-flow direction and role.
-
getDevice(
PCWSTR pwstrId) → IMMDevice? - Retrieves an audio endpoint device that is identified by an endpoint ID string.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
registerEndpointNotificationCallback(
IMMNotificationClient? pClient) → void - Registers a client's notification callback interface.
-
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
unregisterEndpointNotificationCallback(
IMMNotificationClient? pClient) → void -
Deletes the registration of a notification interface that the client
registered in a previous call to the
IMMDeviceEnumerator.registerEndpointNotificationCallbackmethod.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited