IMMNotificationClient class com
Provides notifications when an audio endpoint device is added or removed, when the state or properties of an endpoint device change, or when there is a change in the default role assigned to an endpoint device.
To learn more, see learn.microsoft.com/windows/win32/api/mmdeviceapi/nn-mmdeviceapi-immnotificationclient.
- Inheritance
- Implemented types
Constructors
- IMMNotificationClient(VTablePointer ptr)
- Creates a new instance of IMMNotificationClient from a VTablePointer.
- IMMNotificationClient.from(IUnknown interface)
-
Creates a new instance of IMMNotificationClient from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDefaultDeviceChanged(
EDataFlow flow, ERole role, PCWSTR? pwstrDefaultDeviceId) → void - Notifies the client that the default audio endpoint device for a particular device role has changed.
-
onDeviceAdded(
PCWSTR pwstrDeviceId) → void - Indicates that a new audio endpoint device has been added.
-
onDeviceRemoved(
PCWSTR pwstrDeviceId) → void - Indicates that an audio endpoint device has been removed.
-
onDeviceStateChanged(
PCWSTR pwstrDeviceId, DEVICE_STATE dwNewState) → void - Indicates that the state of an audio endpoint device has changed.
-
onPropertyValueChanged(
PCWSTR pwstrDeviceId, PROPERTYKEY key) → void - Indicates that the value of a property belonging to an audio endpoint device has changed.
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited