IMetaDataDispenserEx class com
Extends the IMetaDataDispenser interface to provide the capability to control how the metadata APIs operate on the current metadata scope.
To learn more, see learn.microsoft.com/windows/win32/api/rometadataapi/nn-rometadataapi-imetadatadispenserex.
- Inheritance
-
- Object
- IUnknown
- IMetaDataDispenser
- IMetaDataDispenserEx
- Implemented types
Constructors
- IMetaDataDispenserEx(VTablePointer ptr)
- Creates a new instance of IMetaDataDispenserEx from a VTablePointer.
- IMetaDataDispenserEx.from(IUnknown interface)
-
Creates a new instance of IMetaDataDispenserEx from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
defineScope(
Pointer< GUID> rclsid, int dwCreateFlags, Pointer<GUID> riid) → IUnknown? -
Creates a new area in memory in which you can create new metadata.
inherited
-
findAssembly(
PCWSTR szAppBase, PCWSTR szPrivateBin, PCWSTR szGlobalBin, PCWSTR szAssemblyName, PCWSTR szName, int cchName, Pointer< Uint32> pcName) → void - Gets the name of the assembly.
-
findAssemblyModule(
PCWSTR szAppBase, PCWSTR szPrivateBin, PCWSTR szGlobalBin, PCWSTR szAssemblyName, PCWSTR szModuleName, PWSTR? szName, int cchName, Pointer< Uint32> pcName) → void - Finds the name of the assembly module.
-
getCORSystemDirectory(
PWSTR? szBuffer, int cchBuffer, Pointer< Uint32> pchBuffer) → void - Gets the directory that holds the current common language runtime (CLR).
-
getOption(
Pointer< GUID> optionid, Pointer<VARIANT> pvalue) → void - Gets the value of the specified option for the current metadata scope.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openScope(
PCWSTR szScope, int dwOpenFlags, Pointer< GUID> riid) → IUnknown? -
Opens an existing file from disk, and maps its metadata into memory for
reading.
inherited
-
openScopeOnITypeInfo(
ITypeInfo? pITI, int dwOpenFlags, Pointer< GUID> riid) → IUnknown? - Opens the specified scope type.
-
openScopeOnMemory(
Pointer< NativeType> pData, int cbData, int dwOpenFlags, Pointer<GUID> riid) → IUnknown? -
Opens an area of memory that contains existing metadata.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
setOption(
Pointer< GUID> optionid, Pointer<VARIANT> value) → void - Sets the specified option to a given value for the current metadata scope.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited