getMethodSemantics method
Gets flags indicating the relationship between the method referenced by the specified MethodDef token and the paired property and event referenced by the specified EventProp token.
Throws a WindowsException on failure.
To learn more, see learn.microsoft.com/windows/win32/api/rometadataapi/nf-rometadataapi-imetadataimport-getmethodsemantics.
Implementation
@pragma('vm:prefer-inline')
void getMethodSemantics(
int mb,
int tkEventProp,
Pointer<Uint32> pdwSemanticsFlags,
) {
final hr$ = HRESULT(
_GetMethodSemanticsFn(ptr, mb, tkEventProp, pdwSemanticsFlags),
);
if (hr$.isError) throw WindowsException(hr$);
}