IMetaDataTables class com
Provides methods for the storage and retrieval of metadata information in tables.
To learn more, see learn.microsoft.com/windows/win32/api/rometadataapi/nn-rometadataapi-imetadatatables.
- Inheritance
- Implemented types
- Implementers
Constructors
- IMetaDataTables(VTablePointer ptr)
- Creates a new instance of IMetaDataTables from a VTablePointer.
- IMetaDataTables.from(IUnknown interface)
-
Creates a new instance of IMetaDataTables from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
getBlob(
int ixBlob, Pointer< Uint32> pcbData, Pointer<Pointer< ppData) → voidNativeType> > - Gets a pointer to the binary large object (BLOB) at the specified column index.
-
getBlobHeapSize(
Pointer< Uint32> pcbBlobs) → void - A pointer to a pointer to the binary data retrieved.
-
getCodedTokenInfo(
int ixCdTkn, Pointer< Uint32> pcTokens, Pointer<Pointer< ppTokens, Pointer<Uint32> >Pointer< ppName) → voidInt8> > - Gets a pointer to an array of tokens associated with the specified row index.
-
getColumn(
int ixTbl, int ixCol, int rid, Pointer< Uint32> pVal) → void - Gets a pointer to the value contained in the cell of the specified column and row in the given table.
-
getColumnInfo(
int ixTbl, int ixCol, Pointer< Uint32> poCol, Pointer<Uint32> pcbCol, Pointer<Uint32> pType, Pointer<Pointer< ppName) → voidInt8> > - Gets data about the specified column in the specified table.
-
getGuid(
int ixGuid, Pointer< Pointer< ppGUID) → voidGUID> > - Gets a GUID from the row at the specified index.
-
getGuidHeapSize(
Pointer< Uint32> pcbGuids) → void - Gets the size, in bytes, of the GUID heap.
-
getNextBlob(
int ixBlob, Pointer< Uint32> pNext) → void - Gets the index of the next binary large object (BLOB) in the table.
-
getNextGuid(
int ixGuid, Pointer< Uint32> pNext) → void - Gets the index of the next GUID value in the current table column.
-
getNextString(
int ixString, Pointer< Uint32> pNext) → void - Gets the index of the next string in the current table column.
-
getNextUserString(
int ixUserString, Pointer< Uint32> pNext) → void - Gets the index of the row that contains the next hard-coded string in the current table column.
-
getNumTables(
Pointer< Uint32> pcTables) → void - Gets the number of tables in the scope of the current IMetaDataTables instance.
-
getRow(
int ixTbl, int rid, Pointer< Pointer< ppRow) → voidNativeType> > - Gets the row at the specified row index, in the table at the specified table index.
-
getString(
int ixString, Pointer< Pointer< ppString) → voidInt8> > - Gets the string at the specified index from the table column in the current reference scope.
-
getStringHeapSize(
Pointer< Uint32> pcbStrings) → void - Gets the size, in bytes, of the string heap.
-
getTableIndex(
int token, Pointer< Uint32> pixTbl) → void - Gets the index for the table referenced by the specified token.
-
getTableInfo(
int ixTbl, Pointer< Uint32> pcbRow, Pointer<Uint32> pcRows, Pointer<Uint32> pcCols, Pointer<Uint32> piKey, Pointer<Pointer< ppName) → voidInt8> > - Gets the name, row size, number of rows, number of columns, and key column index of the specified table.
-
getUserString(
int ixUserString, Pointer< Uint32> pcbData, Pointer<Pointer< ppData) → voidNativeType> > - Gets the hard-coded string at the specified index in the string column in the current scope.
-
getUserStringHeapSize(
Pointer< Uint32> pcbBlobs) → void - Gets the size, in bytes, of the user string heap.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited