INetworkConnection class com
Represents a single network connection.
To learn more, see learn.microsoft.com/windows/win32/api/netlistmgr/nn-netlistmgr-inetworkconnection.
- Inheritance
- Implemented types
Constructors
- INetworkConnection(VTablePointer ptr)
- Creates a new instance of INetworkConnection from a VTablePointer.
- INetworkConnection.from(IUnknown interface)
-
Creates a new instance of INetworkConnection from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnected → bool
-
Specifies if the associated network connection has network connectivity.
no setter
- isConnectedToInternet → bool
-
Specifies if the associated network connection has internet connectivity.
no setter
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
getAdapterId(
) → Pointer< GUID> - Returns the ID of the network adapter used by this connection.
-
getConnectionId(
) → Pointer< GUID> - Returns the Connection ID associated with this network connection.
-
getConnectivity(
) → NLM_CONNECTIVITY - Returns the connectivity state of the network connection.
-
getDomainType(
) → NLM_DOMAIN_TYPE - Returns the domain type of the network connection.
-
getIDsOfNames(
Pointer< GUID> riid, Pointer<Pointer< rgszNames, int cNames, int lcid, Pointer<Utf16> >Int32> rgDispId) → void -
Maps a single member and an optional set of argument names to a
corresponding set of integer DISPIDs, which can be used on subsequent
calls to Invoke.
inherited
-
getNetwork(
) → INetwork? - Returns the network associated with the connection.
-
getTypeInfo(
int iTInfo, int lcid) → ITypeInfo? -
Retrieves the type information for an object, which can then be used to
get the type information for an interface.
inherited
-
getTypeInfoCount(
) → int -
Retrieves the number of type information interfaces that an object
provides (either 0 or 1).
inherited
-
invoke(
int dispIdMember, Pointer< GUID> riid, int lcid, DISPATCH_FLAGS wFlags, Pointer<DISPPARAMS> pDispParams, Pointer<VARIANT> ? pVarResult, Pointer<EXCEPINFO> ? pExcepInfo, Pointer<Uint32> ? puArgErr) → void -
Provides access to properties and methods exposed by an object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited