INetworkListManager class com
Provides a set of methods to perform network list management functions.
To learn more, see learn.microsoft.com/windows/win32/api/netlistmgr/nn-netlistmgr-inetworklistmanager.
- Inheritance
- Implemented types
Constructors
- INetworkListManager(VTablePointer ptr)
- Creates a new instance of INetworkListManager from a VTablePointer.
- INetworkListManager.from(IUnknown interface)
-
Creates a new instance of INetworkListManager from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnected → bool
-
Specifies if the local machine has network connectivity.
no setter
- isConnectedToInternet → bool
-
Specifies if the local machine has internet connectivity.
no setter
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
clearSimulatedProfileInfo(
) → void - Clears the connection profile values previously applied to the internet connection profile by SetSimulatedProfileInfo.
-
getConnectivity(
) → NLM_CONNECTIVITY - Returns the overall connectivity state of the machine.
-
getIDsOfNames(
Pointer< GUID> riid, Pointer<Pointer< rgszNames, int cNames, int lcid, Pointer<Utf16> >Int32> rgDispId) → void -
Maps a single member and an optional set of argument names to a
corresponding set of integer DISPIDs, which can be used on subsequent
calls to Invoke.
inherited
-
getNetwork(
GUID gdNetworkId) → INetwork? - Retrieves a network based on a supplied network ID.
-
getNetworkConnection(
GUID gdNetworkConnectionId) → INetworkConnection? - Retrieves a network based on a supplied Network Connection ID.
-
getNetworkConnections(
) → IEnumNetworkConnections? - Enumerates a complete list of the network connections that have been made.
-
getNetworks(
NLM_ENUM_NETWORK flags) → IEnumNetworks? - Retrieves the list of networks available on the local machine.
-
getTypeInfo(
int iTInfo, int lcid) → ITypeInfo? -
Retrieves the type information for an object, which can then be used to
get the type information for an interface.
inherited
-
getTypeInfoCount(
) → int -
Retrieves the number of type information interfaces that an object
provides (either 0 or 1).
inherited
-
invoke(
int dispIdMember, Pointer< GUID> riid, int lcid, DISPATCH_FLAGS wFlags, Pointer<DISPPARAMS> pDispParams, Pointer<VARIANT> ? pVarResult, Pointer<EXCEPINFO> ? pExcepInfo, Pointer<Uint32> ? puArgErr) → void -
Provides access to properties and methods exposed by an object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
setSimulatedProfileInfo(
Pointer< NLM_SIMULATED_PROFILE_INFO> pSimulatedInfo) → void - Applies a specific set of connection profile values to the internet connection profile in support of the simulation of specific metered internet connection conditions.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited