IOCTL_STORAGE_FIRMWARE_DOWNLOAD top-level constant
int
const IOCTL_STORAGE_FIRMWARE_DOWNLOAD
Windows applications can use this control code to download a firmware image to the target device, but not activate it.
To learn more, see learn.microsoft.com/windows/win32/api/winioctl/ni-winioctl-ioctl_storage_firmware_download.
Implementation
const IOCTL_STORAGE_FIRMWARE_DOWNLOAD = 3005444;