Stores an IP address prefix.
To learn more, see learn.microsoft.com/windows/win32/api/iptypes/ns-iptypes-ip_adapter_prefix_xp.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
- Address ↔ SOCKET_ADDRESS
-
getter/setter pair
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - Alignment ↔ int
-
Available on IP_ADAPTER_PREFIX_XP, provided by the IP_ADAPTER_PREFIX_XP_0_Extension extension
getter/setter pair - Anonymous ↔ IP_ADAPTER_PREFIX_XP_0
-
getter/setter pair
- Anonymous ↔ IP_ADAPTER_PREFIX_XP_0_0
-
Available on IP_ADAPTER_PREFIX_XP, provided by the IP_ADAPTER_PREFIX_XP_0_Extension extension
getter/setter pair - Flags ↔ int
-
Available on IP_ADAPTER_PREFIX_XP, provided by the IP_ADAPTER_PREFIX_XP_0_0_Extension extension
getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- Length ↔ int
-
Available on IP_ADAPTER_PREFIX_XP, provided by the IP_ADAPTER_PREFIX_XP_0_0_Extension extension
getter/setter pair -
Next
↔ Pointer<
IP_ADAPTER_PREFIX_XP> -
getter/setter pair
- PrefixLength ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< IP_ADAPTER_PREFIX_XP> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited