Represents a node in a linked-list of IPv4 addresses.
To learn more, see learn.microsoft.com/windows/win32/api/iptypes/ns-iptypes-ip_addr_string.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - Context ↔ int
-
A network table entry (NTE).
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- IpAddress ↔ IP_ADDRESS_STRING
-
A value that specifies a structure type with a single member,
String.
getter/setter pair
- IpMask ↔ IP_ADDRESS_STRING
-
A value that specifies a structure type with a single member,
String.
getter/setter pair
-
Next
↔ Pointer<
IP_ADDR_STRING> -
A pointer to the next IP_ADDR_STRING structure in the list.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< IP_ADDR_STRING> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited