IPersistFile class com

Enables an object to be loaded from or saved to a disk file, rather than a storage object or stream. Because the information needed to open a file varies greatly from one application to another, the implementation of IPersistFile::Loadon the object must also open its disk file.

Inheritance

Constructors

IPersistFile(Pointer<COMObject> ptr)
IPersistFile.from(IUnknown interface)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
ptr ↔ Pointer<COMObject>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRef() → int
Increments the reference count for an interface pointer to a COM object.
inherited
detach() → void
Detaches the object from the Finalizer.
inherited
getClassID(Pointer<GUID> pClassID) → int
inherited
getCurFile(Pointer<Pointer<Utf16>> ppszFileName) → int
isDirty() → int
load(Pointer<Utf16> pszFileName, int dwMode) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInterface(Pointer<GUID> riid, Pointer<Pointer<NativeType>> ppvObject) → int
Queries a COM object for a pointer to one of its interface; identifying the interface by a reference to its interface identifier (IID).
inherited
release() → int
Decrements the reference count for an interface on a COM object.
inherited
save(Pointer<Utf16> pszFileName, int fRemember) → int
saveCompleted(Pointer<Utf16> pszFileName) → int
toInterface(String iid) → Pointer<COMObject>
Cast an existing COM object to a specified interface.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited