IRunningObjectTable class com
Manages access to the running object table (ROT), a globally accessible look-up table on each workstation.
To learn more, see learn.microsoft.com/windows/win32/api/objidl/nn-objidl-irunningobjecttable.
- Inheritance
- Implemented types
Constructors
- IRunningObjectTable(VTablePointer ptr)
- Creates a new instance of IRunningObjectTable from a VTablePointer.
- IRunningObjectTable.from(IUnknown interface)
-
Creates a new instance of IRunningObjectTable from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
enumRunning(
) → IEnumMoniker? - Creates and returns a pointer to an enumerator that can list the monikers of all the objects currently registered in the running object table (ROT).
-
getObject(
IMoniker? pmkObjectName) → IUnknown? - Determines whether the object identified by the specified moniker is running, and if it is, retrieves a pointer to that object.
-
getTimeOfLastChange(
IMoniker? pmkObjectName) → Pointer< FILETIME> - Retrieves the time that an object was last modified.
-
isRunning(
IMoniker? pmkObjectName) → void - Determines whether the object identified by the specified moniker is currently running.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
noteChangeTime(
int dwRegister, Pointer< FILETIME> pfiletime) → void - Records the time that a running object was last modified.
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
register(
ROT_FLAGS grfFlags, IUnknown? punkObject, IMoniker? pmkObjectName) → int -
Registers an object and its identifying moniker in the running object
table (ROT).
override
-
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
revoke(
int dwRegister) → void -
Removes an entry from the running object table (ROT) that was previously
registered by a call to
IRunningObjectTable.register. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited