ISensor class com
Represents a sensor.
To learn more, see learn.microsoft.com/windows/win32/api/sensorsapi/nn-sensorsapi-isensor.
- Inheritance
- Implemented types
Constructors
- ISensor(VTablePointer ptr)
- Creates a new instance of ISensor from a VTablePointer.
- ISensor.from(IUnknown interface)
-
Creates a new instance of ISensor from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
getCategory(
) → Pointer< GUID> - Retrieves the identifier of the sensor category.
-
getData(
) → ISensorDataReport? - Retrieves the most recent sensor data report.
-
getEventInterest(
Pointer< Pointer< ppValues, Pointer<GUID> >Uint32> pCount) → void - Retrieves the current event interest settings.
-
getFriendlyName(
) → BSTR - Retrieves the sensor name that is intended to be seen by the user.
-
getID(
) → Pointer< GUID> - Retrieves the unique identifier of the sensor.
-
getProperties(
IPortableDeviceKeyCollection? pKeys) → IPortableDeviceValues? - Retrieves multiple sensor properties.
-
getProperty(
Pointer< PROPERTYKEY> key) → Pointer<PROPVARIANT> - Retrieves a property value.
-
getState(
) → SensorState - Retrieves the current operational state of the sensor.
-
getSupportedDataFields(
) → IPortableDeviceKeyCollection? - Retrieves a set of PROPERTYKEYs that represent the data fields the sensor can provide.
-
getType(
) → Pointer< GUID> - Retrieves the sensor type ID.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
setEventInterest(
Pointer< GUID> ? pValues, int count) → void - Specifies the list of sensor events to receive.
-
setEventSink(
ISensorEvents? pEvents) → void - Specifies the interface through which to receive sensor event notifications.
-
setProperties(
IPortableDeviceValues? pProperties) → IPortableDeviceValues? - Specifies sensor properties.
-
supportsDataField(
Pointer< PROPERTYKEY> key) → bool - Indicates whether the sensor supports the specified data field.
-
supportsEvent(
Pointer< GUID> eventGuid) → bool - Indicates whether the sensor supports the specified event.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited