ISensorCollection class com
Represents a collection of sensors, such as all the sensors connected to a computer.
To learn more, see learn.microsoft.com/windows/win32/api/sensorsapi/nn-sensorsapi-isensorcollection.
- Inheritance
- Implemented types
Constructors
- ISensorCollection(VTablePointer ptr)
- Creates a new instance of ISensorCollection from a VTablePointer.
- ISensorCollection.from(IUnknown interface)
-
Creates a new instance of ISensorCollection from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
ISensor? pSensor) → void - Adds a sensor to the collection.
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
clear(
) → void - Empties the sensor collection.
-
getAt(
int ulIndex) → ISensor? - Retrieves the sensor at the specified index in the collection.
-
getCount(
) → int - Retrieves the count of sensors in the collection.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
remove(
ISensor? pSensor) → void - Removes a sensor from the collection.
-
removeByID(
Pointer< GUID> sensorID) → void - Removes a sensor from the collection.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited