ISensorDataReport class com
Represents a sensor data report.
Sensor data reports contain data field values generated by a sensor and a time stamp that indicates when the data report was created.
To learn more, see learn.microsoft.com/windows/win32/api/sensorsapi/nn-sensorsapi-isensordatareport.
- Inheritance
- Implemented types
Constructors
- ISensorDataReport(VTablePointer ptr)
- Creates a new instance of ISensorDataReport from a VTablePointer.
- ISensorDataReport.from(IUnknown interface)
-
Creates a new instance of ISensorDataReport from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
getSensorValue(
Pointer< PROPERTYKEY> pKey) → Pointer<PROPVARIANT> - Retrieves a single data field value from the data report.
-
getSensorValues(
IPortableDeviceKeyCollection? pKeys) → IPortableDeviceValues? - Retrieves a collection of data field values.
-
getTimestamp(
) → Pointer< SYSTEMTIME> - Retrieves the time at which the data report was created.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited