ISequentialStream class com
Supports simplified sequential access to stream objects.
The IStream interface inherits its Read and Write methods from ISequentialStream.
To learn more, see learn.microsoft.com/windows/win32/api/objidl/nn-objidl-isequentialstream.
- Inheritance
- Implemented types
- Implementers
Constructors
- ISequentialStream(VTablePointer ptr)
- Creates a new instance of ISequentialStream from a VTablePointer.
- ISequentialStream.from(IUnknown interface)
-
Creates a new instance of ISequentialStream from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
read(
Pointer< NativeType> pv, int cb, Pointer<Uint32> ? pcbRead) → HRESULT - Reads a specified number of bytes from the stream object into memory, starting at the current seek pointer.
-
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
write(
Pointer< NativeType> pv, int cb, Pointer<Uint32> ? pcbWritten) → HRESULT - Writes a specified number of bytes into the stream object starting at the current seek pointer.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited