IShellItem2 class com
Extends IShellItem with methods that retrieve various property values of the item.
IShellItem and IShellItem2 are the preferred representations of items in any new code.
To learn more, see learn.microsoft.com/windows/win32/api/shobjidl_core/nn-shobjidl_core-ishellitem2.
- Inheritance
-
- Object
- IUnknown
- IShellItem
- IShellItem2
- Implemented types
Constructors
- IShellItem2(VTablePointer ptr)
- Creates a new instance of IShellItem2 from a VTablePointer.
- IShellItem2.from(IUnknown interface)
-
Creates a new instance of IShellItem2 from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
bindToHandler<
T extends IUnknown> (IBindCtx? pbc, Pointer< GUID> bhid) → T -
Binds to a handler for an item as specified by the handler ID value
(BHID).
inherited
-
compare(
IShellItem? psi, int hint) → int -
Compares two IShellItem objects.
inherited
-
getAttributes(
SFGAO_FLAGS sfgaoMask) → SFGAO_FLAGS -
Gets a requested set of attributes of the IShellItem object.
inherited
-
getBool(
Pointer< PROPERTYKEY> key) → bool - Gets the boolean value of a specified property key.
-
getCLSID(
Pointer< PROPERTYKEY> key) → Pointer<GUID> - Gets the class identifier (CLSID) value of specified property key.
-
getDisplayName(
SIGDN sigdnName) → PWSTR -
Gets the display name of the IShellItem object.
inherited
-
getFileTime(
Pointer< PROPERTYKEY> key) → Pointer<FILETIME> - Gets the date and time value of a specified property key.
-
getInt32(
Pointer< PROPERTYKEY> key) → int - Gets the Int32 value of specified property key.
-
getParent(
) → IShellItem? -
Gets the parent of an IShellItem object.
inherited
-
getProperty(
Pointer< PROPERTYKEY> key) → Pointer<PROPVARIANT> - Gets a PROPVARIANT structure from a specified property key.
-
getPropertyDescriptionList<
T extends IUnknown> (Pointer< PROPERTYKEY> keyType) → T - Gets a property description list object given a reference to a property key.
-
getPropertyStore<
T extends IUnknown> (GETPROPERTYSTOREFLAGS flags) → T - Gets a property store object for specified property store flags.
-
getPropertyStoreForKeys<
T extends IUnknown> (Pointer< PROPERTYKEY> rgKeys, int cKeys, GETPROPERTYSTOREFLAGS flags) → T - Gets property store object for specified property keys.
-
getPropertyStoreWithCreateObject<
T extends IUnknown> (GETPROPERTYSTOREFLAGS flags, IUnknown? punkCreateObject) → T - Uses the specified ICreateObject instead of CoCreateInstance to create an instance of the property handler associated with the Shell item on which this method is called.
-
getString(
Pointer< PROPERTYKEY> key) → PWSTR - Gets the string value of a specified property key.
-
getUInt32(
Pointer< PROPERTYKEY> key) → int - Gets the UInt32 value of a specified property key.
-
getUInt64(
Pointer< PROPERTYKEY> key) → int - Gets the UInt64 value of a specified property key.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
update(
IBindCtx? pbc) → void - Ensures that any cached information in this item is updated.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited