ISpEventSource class com
Provides the mechanism to filter and queue events.
To learn more, see learn.microsoft.com/previous-versions/windows/desktop/ms717848(v=vs.85).
- Inheritance
-
- Object
- IUnknown
- ISpNotifySource
- ISpEventSource
- Implemented types
- Implementers
Constructors
- ISpEventSource(VTablePointer ptr)
- Creates a new instance of ISpEventSource from a VTablePointer.
- ISpEventSource.from(IUnknown interface)
-
Creates a new instance of ISpEventSource from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
getEvents(
int ulCount, Pointer< SPEVENT> pEventArray, Pointer<Uint32> pulFetched) → void - Throws a WindowsException on failure.
-
getInfo(
Pointer< SPEVENTSOURCEINFO> pInfo) → void - Throws a WindowsException on failure.
-
getNotifyEventHandle(
) → HANDLE -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
setInterest(
int ullEventInterest, int ullQueuedInterest) → void - Throws a WindowsException on failure.
-
setNotifyCallbackFunction(
Pointer< Pointer< pfnCallback, WPARAM wParam, LPARAM lParam) → voidNativeFunction< >SPNOTIFYCALLBACK> > -
Throws a WindowsException on failure.
inherited
-
setNotifyCallbackInterface(
ISpNotifyCallback? pSpCallback, WPARAM wParam, LPARAM lParam) → void -
Throws a WindowsException on failure.
inherited
-
setNotifySink(
ISpNotifySink? pNotifySink) → void -
Throws a WindowsException on failure.
inherited
-
setNotifyWin32Event(
) → void -
Throws a WindowsException on failure.
inherited
-
setNotifyWindowMessage(
HWND hWnd, int msg, WPARAM wParam, LPARAM lParam) → void -
Throws a WindowsException on failure.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
waitForNotifyEvent(
int dwMilliseconds) → void -
Throws a WindowsException on failure.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited