ISpellChecker2 class com
Represents a particular spell checker for a particular language, with the added ability to remove words from the added words dictionary, or from the ignore list.
To learn more, see learn.microsoft.com/windows/win32/api/spellcheck/nn-spellcheck-ispellchecker2.
- Inheritance
-
- Object
- IUnknown
- ISpellChecker
- ISpellChecker2
- Implemented types
Constructors
- ISpellChecker2(VTablePointer ptr)
- Creates a new instance of ISpellChecker2 from a VTablePointer.
- ISpellChecker2.from(IUnknown interface)
-
Creates a new instance of ISpellChecker2 from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → PWSTR
-
Gets the identifier for this spell checker.
no setterinherited
- languageTag → PWSTR
-
Gets the BCP47 language tag this instance of the spell checker supports.
no setterinherited
- localizedName → PWSTR
-
Gets text, suitable to display to the user, that describes this spell
checker.
no setterinherited
- optionIds → IEnumString?
-
Gets all of the declared option identifiers.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
PCWSTR word) → void -
Treats the provided word as though it were part of the original
dictionary.
inherited
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
addSpellCheckerChanged(
ISpellCheckerChangedEventHandler? handler) → int -
Adds an event handler (ISpellCheckerChangedEventHandler) for the
SpellCheckerChanged event.
inherited
-
autoCorrect(
PCWSTR from, PCWSTR to) → void -
Causes occurrences of one word to be replaced by another.
inherited
-
check(
PCWSTR text) → IEnumSpellingError? -
Checks the spelling of the supplied text and returns a collection of
spelling errors.
inherited
-
comprehensiveCheck(
PCWSTR text) → IEnumSpellingError? -
Checks the spelling of the supplied text in a more thorough manner than
ISpellChecker.check, and returns a collection of spelling errors.inherited -
getOptionDescription(
PCWSTR optionId) → IOptionDescription? -
Retrieves the information (id, description, heading and labels) of a
specific option.
inherited
-
getOptionValue(
PCWSTR optionId) → int -
Retrieves the value associated with the given option.
inherited
-
ignore(
PCWSTR word) → void -
Ignores the provided word for the rest of this session.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
remove(
PCWSTR word) → void - Removes a word that was previously added by ISpellChecker.Add, or set by ISpellChecker.Ignore to be ignored.
-
removeSpellCheckerChanged(
int eventCookie) → void -
Removes an event handler (ISpellCheckerChangedEventHandler) that has been
added for the SpellCheckerChanged event.
inherited
-
suggest(
PCWSTR word) → IEnumString? -
Retrieves spelling suggestions for the supplied text.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited