ITypeComp class com
Provides a fast way to access information that compilers need when binding to and instantiating structures and interfaces.
To learn more, see learn.microsoft.com/windows/win32/api/oaidl/nn-oaidl-itypecomp.
- Inheritance
- Implemented types
Constructors
- ITypeComp(VTablePointer ptr)
- Creates a new instance of ITypeComp from a VTablePointer.
- ITypeComp.from(IUnknown interface)
-
Creates a new instance of ITypeComp from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
bind(
PCWSTR szName, int lHashVal, int wFlags, Pointer< VTablePointer> ppTInfo, Pointer<Int32> pDescKind, Pointer<BINDPTR> pBindPtr) → void - Maps a name to a member of a type, or binds global variables and functions contained in a type library.
-
bindType(
PCWSTR szName, int lHashVal, Pointer< VTablePointer> ppTInfo, Pointer<VTablePointer> ppTComp) → void - Binds to the type descriptions contained within a type library.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited