IUIAutomationCacheRequest class com
Exposes properties and methods of a cache request.
Client applications use this interface to specify the properties and control patterns to be cached when a Microsoft UI Automation element is obtained.
To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationcacherequest.
- Inheritance
- Implemented types
Constructors
- IUIAutomationCacheRequest(VTablePointer ptr)
- Creates a new instance of IUIAutomationCacheRequest from a VTablePointer.
- IUIAutomationCacheRequest.from(IUnknown interface)
-
Creates a new instance of IUIAutomationCacheRequest from an existing
interface.factory
Properties
- automationElementMode ↔ AutomationElementMode
-
Indicates whether returned elements contain full references to the
underlying UI, or only cached information.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- treeFilter ↔ IUIAutomationCondition?
-
Specifies the view of the UI Automation element tree that is used when
caching.
getter/setter pair
- treeScope ↔ TreeScope
-
Specifies the scope of caching.
getter/setter pair
Methods
-
addPattern(
UIA_PATTERN_ID patternId) → void - Adds a control pattern to the cache request.
-
addProperty(
UIA_PROPERTY_ID propertyId) → void - Adds a property to the cache request.
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
clone(
) → IUIAutomationCacheRequest? - Creates a copy of the cache request.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited