IUIAutomationChangesEventHandler class com
Exposes a method to handle one or more Microsoft UI Automation change events.
To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationchangeseventhandler.
- Inheritance
- Implemented types
Constructors
- IUIAutomationChangesEventHandler(VTablePointer ptr)
- Creates a new instance of IUIAutomationChangesEventHandler from a VTablePointer.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
handleChangesEvent(
IUIAutomationElement? sender, Pointer< UiaChangeInfo> uiaChanges, int changesCount) → void - Handles one or more Microsoft UI Automation change events.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited