IUIAutomationElement class com
Exposes methods and properties for a UI Automation element, which represents a UI item.
To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationelement.
- Inheritance
- Implemented types
- Implementers
Constructors
- IUIAutomationElement(VTablePointer ptr)
- Creates a new instance of IUIAutomationElement from a VTablePointer.
- IUIAutomationElement.from(IUnknown interface)
-
Creates a new instance of IUIAutomationElement from an existing
interface.factory
Properties
- cachedAcceleratorKey → BSTR
-
Retrieves the cached accelerator key for the element.
no setter
- cachedAccessKey → BSTR
-
Retrieves the cached access key character for the element.
no setter
- cachedAriaProperties → BSTR
-
Retrieves the cached Accessible Rich Internet Applications (ARIA)
properties of the element.
no setter
- cachedAriaRole → BSTR
-
Retrieves the cached Accessible Rich Internet Applications (ARIA) role of
the element.
no setter
- cachedAutomationId → BSTR
-
Retrieves the cached Microsoft UI Automation identifier of the element.
no setter
-
cachedBoundingRectangle
→ Pointer<
RECT> -
Retrieves the cached coordinates of the rectangle that completely encloses
the element.
no setter
- cachedClassName → BSTR
-
Retrieves the cached class name of the element.
no setter
- cachedControllerFor → IUIAutomationElementArray?
-
Retrieves a cached array of UI Automation elements for which this element
serves as the controller.
no setter
- cachedControlType → UIA_CONTROLTYPE_ID
-
Retrieves a cached value that indicates the control type of the element.
no setter
- cachedCulture → int
-
Retrieves a cached value that indicates the culture associated with the
element.
no setter
- cachedDescribedBy → IUIAutomationElementArray?
-
Retrieves a cached array of elements that describe this element.
no setter
- cachedFlowsTo → IUIAutomationElementArray?
-
Retrieves a cached array of elements that indicate the reading order after
the current element.
no setter
- cachedFrameworkId → BSTR
-
Retrieves the cached name of the underlying UI framework associated with
the element.
no setter
- cachedHasKeyboardFocus → bool
-
A cached value that indicates whether the element has keyboard focus.
no setter
- cachedHelpText → BSTR
-
Retrieves the cached help text for the element.
no setter
- cachedIsContentElement → bool
-
A cached value that indicates whether the element is a content element.
no setter
- cachedIsControlElement → bool
-
Retrieves a cached value that indicates whether the element is a control
element.
no setter
- cachedIsDataValidForForm → bool
-
Retrieves a cached value that indicates whether the element contains valid
data for the form.
no setter
- cachedIsEnabled → bool
-
Retrieves a cached value that indicates whether the element is enabled.
no setter
- cachedIsKeyboardFocusable → bool
-
Retrieves a cached value that indicates whether the element can accept
keyboard focus.
no setter
- cachedIsOffscreen → bool
-
Retrieves a cached value that indicates whether the element is off-screen.
no setter
- cachedIsPassword → bool
-
Retrieves a cached value that indicates whether the element contains a
disguised password.
no setter
- cachedIsRequiredForForm → bool
-
Retrieves a cached value that indicates whether the element is required to
be filled out on a form.
no setter
- cachedItemStatus → BSTR
-
Retrieves a cached description of the status of an item within an element.
no setter
- cachedItemType → BSTR
-
Retrieves a cached string that describes the type of item represented by
the element.
no setter
- cachedLabeledBy → IUIAutomationElement?
-
Retrieves the cached element that contains the text label for this
element.
no setter
- cachedLocalizedControlType → BSTR
-
Retrieves the cached localized description of the control type of the
element.
no setter
- cachedName → BSTR
-
Retrieves the cached name of the element.
no setter
- cachedNativeWindowHandle → HWND
-
Retrieves the cached window handle of the element.
no setter
- cachedOrientation → OrientationType
-
Retrieves a cached value that indicates the orientation of the element.
no setter
- cachedProcessId → int
-
Retrieves the cached ID of the process that hosts the element.
no setter
- cachedProviderDescription → BSTR
-
Retrieves a cached description of the provider for this element.
no setter
- currentAcceleratorKey → BSTR
-
Retrieves the accelerator key for the element.
no setter
- currentAccessKey → BSTR
-
Retrieves the access key character for the element.
no setter
- currentAriaProperties → BSTR
-
Retrieves the Accessible Rich Internet Applications (ARIA) properties of
the element.
no setter
- currentAriaRole → BSTR
-
Retrieves the Accessible Rich Internet Applications (ARIA) role of the
element.
no setter
- currentAutomationId → BSTR
-
Retrieves the Microsoft UI Automation identifier of the element.
no setter
-
currentBoundingRectangle
→ Pointer<
RECT> -
Retrieves the coordinates of the rectangle that completely encloses the
element.
no setter
- currentClassName → BSTR
-
Retrieves the class name of the element.
no setter
- currentControllerFor → IUIAutomationElementArray?
-
Retrieves an array of elements for which this element serves as the
controller.
no setter
- currentControlType → UIA_CONTROLTYPE_ID
-
Retrieves the control type of the element.
no setter
- currentCulture → int
-
Retrieves the culture identifier for the element.
no setter
- currentDescribedBy → IUIAutomationElementArray?
-
Retrieves an array of elements that describe this element.
no setter
- currentFlowsTo → IUIAutomationElementArray?
-
Retrieves an array of elements that indicates the reading order after the
current element.
no setter
- currentFrameworkId → BSTR
-
Retrieves the name of the underlying UI framework.
no setter
- currentHasKeyboardFocus → bool
-
Indicates whether the element has keyboard focus.
no setter
- currentHelpText → BSTR
-
Retrieves the help text for the element.
no setter
- currentIsContentElement → bool
-
Indicates whether the element is a content element.
no setter
- currentIsControlElement → bool
-
Indicates whether the element is a control element.
no setter
- currentIsDataValidForForm → bool
-
Indicates whether the element contains valid data for a form.
no setter
- currentIsEnabled → bool
-
Indicates whether the element is enabled.
no setter
- currentIsKeyboardFocusable → bool
-
Indicates whether the element can accept keyboard focus.
no setter
- currentIsOffscreen → bool
-
Indicates whether the element is off-screen.
no setter
- currentIsPassword → bool
-
Indicates whether the element contains a disguised password.
no setter
- currentIsRequiredForForm → bool
-
Indicates whether the element is required to be filled out on a form.
no setter
- currentItemStatus → BSTR
-
Retrieves the description of the status of an item in an element.
no setter
- currentItemType → BSTR
-
Retrieves a description of the type of UI item represented by the element.
no setter
- currentLabeledBy → IUIAutomationElement?
-
Retrieves the element that contains the text label for this element.
no setter
- currentLocalizedControlType → BSTR
-
Retrieves a localized description of the control type of the element.
no setter
- currentName → BSTR
-
Retrieves the name of the element.
no setter
- currentNativeWindowHandle → HWND
-
Retrieves the window handle of the element.
no setter
- currentOrientation → OrientationType
-
Retrieves a value that indicates the orientation of the element.
no setter
- currentProcessId → int
-
Retrieves the identifier of the process that hosts the element.
no setter
- currentProviderDescription → BSTR
-
Retrieves a description of the provider for this element.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
buildUpdatedCache(
IUIAutomationCacheRequest? cacheRequest) → IUIAutomationElement? - Retrieves a new UI Automation element with an updated cache.
-
findAll(
TreeScope scope, IUIAutomationCondition? condition) → IUIAutomationElementArray? - Returns all UI Automation elements that satisfy the specified condition.
-
findAllBuildCache(
TreeScope scope, IUIAutomationCondition? condition, IUIAutomationCacheRequest? cacheRequest) → IUIAutomationElementArray? - Returns all UI Automation elements that satisfy the specified condition, prefetches the requested properties and control patterns, and stores the prefetched items in the cache.
-
findFirst(
TreeScope scope, IUIAutomationCondition? condition) → IUIAutomationElement? - Retrieves the first child or descendant element that matches the specified condition.
-
findFirstBuildCache(
TreeScope scope, IUIAutomationCondition? condition, IUIAutomationCacheRequest? cacheRequest) → IUIAutomationElement? - Retrieves the first child or descendant element that matches the specified condition, prefetches the requested properties and control patterns, and stores the prefetched items in the cache.
-
getCachedChildren(
) → IUIAutomationElementArray? - Retrieves the cached child elements of this UI Automation element.
-
getCachedParent(
) → IUIAutomationElement? - Retrieves from the cache the parent of this UI Automation element.
-
getCachedPattern(
UIA_PATTERN_ID patternId) → IUnknown? - Retrieves from the cache the IUnknown interface of the specified control pattern of this UI Automation element.
-
getCachedPatternAs<
T extends IUnknown> (UIA_PATTERN_ID patternId) → T - Retrieves the control pattern interface of the specified pattern from the cache of this UI Automation element.
-
getCachedPropertyValue(
UIA_PROPERTY_ID propertyId) → Pointer< VARIANT> - Retrieves a property value from the cache for this UI Automation element.
-
getCachedPropertyValueEx(
UIA_PROPERTY_ID propertyId, bool ignoreDefaultValue) → Pointer< VARIANT> - Retrieves a property value from the cache for this UI Automation element, optionally ignoring any default value.
-
getClickablePoint(
Pointer< POINT> clickable, Pointer<Int32> gotClickable) → void - Retrieves a point on the element that can be clicked.
-
getCurrentPattern(
UIA_PATTERN_ID patternId) → IUnknown? - Retrieves the IUnknown interface of the specified control pattern on this UI Automation element.
-
getCurrentPatternAs<
T extends IUnknown> (UIA_PATTERN_ID patternId) → T - Retrieves the control pattern interface of the specified pattern on this UI Automation element.
-
getCurrentPropertyValue(
UIA_PROPERTY_ID propertyId) → Pointer< VARIANT> - Retrieves the current value of a property for this UI Automation element.
-
getCurrentPropertyValueEx(
UIA_PROPERTY_ID propertyId, bool ignoreDefaultValue) → Pointer< VARIANT> - Retrieves a property value for this UI Automation element, optionally ignoring any default value.
-
getRuntimeId(
) → Pointer< SAFEARRAY> - Retrieves the unique identifier assigned to the UI element.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
setFocus(
) → void - Sets the keyboard focus to this UI Automation element.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited