cachedLiveSetting property
LiveSetting
get
cachedLiveSetting
Retrieves a cached value that indicates the type of notifications, if any, that the element sends when the content of the element changes.
To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nf-uiautomationclient-iuiautomationelement2-get_cachedlivesetting.
Implementation
LiveSetting get cachedLiveSetting {
final retVal = adaptiveCalloc<Int32>();
final hr$ = HRESULT(_get_CachedLiveSettingFn(ptr, retVal));
if (hr$.isError) {
free(retVal);
throw WindowsException(hr$);
}
final result$ = retVal.value;
free(retVal);
return .new(result$);
}