IUIAutomationElement4 class com
Extends the IUIAutomationElement3 interface.
To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationelement4.
- Inheritance
-
- Object
- IUnknown
- IUIAutomationElement
- IUIAutomationElement2
- IUIAutomationElement3
- IUIAutomationElement4
- Implemented types
- Implementers
Constructors
- IUIAutomationElement4(VTablePointer ptr)
- Creates a new instance of IUIAutomationElement4 from a VTablePointer.
- IUIAutomationElement4.from(IUnknown interface)
-
Creates a new instance of IUIAutomationElement4 from an existing
interface.factory
Properties
- cachedAcceleratorKey → BSTR
-
Retrieves the cached accelerator key for the element.
no setterinherited
- cachedAccessKey → BSTR
-
Retrieves the cached access key character for the element.
no setterinherited
- cachedAnnotationObjects → IUIAutomationElementArray?
-
Returns the cached list of annotation objects associated with this
element, such as comment, header, footer, and so on.
no setter
-
cachedAnnotationTypes
→ Pointer<
SAFEARRAY> -
Returns the cached list of annotation types associated with this element,
such as comment, header, footer, and so on.
no setter
- cachedAriaProperties → BSTR
-
Retrieves the cached Accessible Rich Internet Applications (ARIA)
properties of the element.
no setterinherited
- cachedAriaRole → BSTR
-
Retrieves the cached Accessible Rich Internet Applications (ARIA) role of
the element.
no setterinherited
- cachedAutomationId → BSTR
-
Retrieves the cached Microsoft UI Automation identifier of the element.
no setterinherited
-
cachedBoundingRectangle
→ Pointer<
RECT> -
Retrieves the cached coordinates of the rectangle that completely encloses
the element.
no setterinherited
- cachedClassName → BSTR
-
Retrieves the cached class name of the element.
no setterinherited
- cachedControllerFor → IUIAutomationElementArray?
-
Retrieves a cached array of UI Automation elements for which this element
serves as the controller.
no setterinherited
- cachedControlType → UIA_CONTROLTYPE_ID
-
Retrieves a cached value that indicates the control type of the element.
no setterinherited
- cachedCulture → int
-
Retrieves a cached value that indicates the culture associated with the
element.
no setterinherited
- cachedDescribedBy → IUIAutomationElementArray?
-
Retrieves a cached array of elements that describe this element.
no setterinherited
- cachedFlowsFrom → IUIAutomationElementArray?
-
Retrieves a cached array of elements that indicate the reading order
before the current element.
no setterinherited
- cachedFlowsTo → IUIAutomationElementArray?
-
Retrieves a cached array of elements that indicate the reading order after
the current element.
no setterinherited
- cachedFrameworkId → BSTR
-
Retrieves the cached name of the underlying UI framework associated with
the element.
no setterinherited
- cachedHasKeyboardFocus → bool
-
A cached value that indicates whether the element has keyboard focus.
no setterinherited
- cachedHelpText → BSTR
-
Retrieves the cached help text for the element.
no setterinherited
- cachedIsContentElement → bool
-
A cached value that indicates whether the element is a content element.
no setterinherited
- cachedIsControlElement → bool
-
Retrieves a cached value that indicates whether the element is a control
element.
no setterinherited
- cachedIsDataValidForForm → bool
-
Retrieves a cached value that indicates whether the element contains valid
data for the form.
no setterinherited
- cachedIsEnabled → bool
-
Retrieves a cached value that indicates whether the element is enabled.
no setterinherited
- cachedIsKeyboardFocusable → bool
-
Retrieves a cached value that indicates whether the element can accept
keyboard focus.
no setterinherited
- cachedIsOffscreen → bool
-
Retrieves a cached value that indicates whether the element is off-screen.
no setterinherited
- cachedIsPassword → bool
-
Retrieves a cached value that indicates whether the element contains a
disguised password.
no setterinherited
- cachedIsPeripheral → bool
-
Retrieves the cached peripheral UI indicator for the element.
no setterinherited
- cachedIsRequiredForForm → bool
-
Retrieves a cached value that indicates whether the element is required to
be filled out on a form.
no setterinherited
- cachedItemStatus → BSTR
-
Retrieves a cached description of the status of an item within an element.
no setterinherited
- cachedItemType → BSTR
-
Retrieves a cached string that describes the type of item represented by
the element.
no setterinherited
- cachedLabeledBy → IUIAutomationElement?
-
Retrieves the cached element that contains the text label for this
element.
no setterinherited
- cachedLevel → int
-
Returns the cached 1-based integer for the level (hierarchy) for the
element.
no setter
- cachedLiveSetting → LiveSetting
-
Retrieves a cached value that indicates the type of notifications, if any,
that the element sends when the content of the element changes.
no setterinherited
- cachedLocalizedControlType → BSTR
-
Retrieves the cached localized description of the control type of the
element.
no setterinherited
- cachedName → BSTR
-
Retrieves the cached name of the element.
no setterinherited
- cachedNativeWindowHandle → HWND
-
Retrieves the cached window handle of the element.
no setterinherited
- cachedOptimizeForVisualContent → bool
-
Retrieves a cached value that indicates whether the provider exposes only
elements that are visible.
no setterinherited
- cachedOrientation → OrientationType
-
Retrieves a cached value that indicates the orientation of the element.
no setterinherited
- cachedPositionInSet → int
-
Returns the cached 1-based integer for the ordinal position in the set for
the element.
no setter
- cachedProcessId → int
-
Retrieves the cached ID of the process that hosts the element.
no setterinherited
- cachedProviderDescription → BSTR
-
Retrieves a cached description of the provider for this element.
no setterinherited
- cachedSizeOfSet → int
-
Returns the cached 1-based integer for the size of the set where the
element is located.
no setter
- currentAcceleratorKey → BSTR
-
Retrieves the accelerator key for the element.
no setterinherited
- currentAccessKey → BSTR
-
Retrieves the access key character for the element.
no setterinherited
- currentAnnotationObjects → IUIAutomationElementArray?
-
Returns the current list of annotation objects associated with this
element, such as comment, header, footer, and so on.
no setter
-
currentAnnotationTypes
→ Pointer<
SAFEARRAY> -
Returns the current list of annotation types associated with this element,
such as comment, header, footer, and so on.
no setter
- currentAriaProperties → BSTR
-
Retrieves the Accessible Rich Internet Applications (ARIA) properties of
the element.
no setterinherited
- currentAriaRole → BSTR
-
Retrieves the Accessible Rich Internet Applications (ARIA) role of the
element.
no setterinherited
- currentAutomationId → BSTR
-
Retrieves the Microsoft UI Automation identifier of the element.
no setterinherited
-
currentBoundingRectangle
→ Pointer<
RECT> -
Retrieves the coordinates of the rectangle that completely encloses the
element.
no setterinherited
- currentClassName → BSTR
-
Retrieves the class name of the element.
no setterinherited
- currentControllerFor → IUIAutomationElementArray?
-
Retrieves an array of elements for which this element serves as the
controller.
no setterinherited
- currentControlType → UIA_CONTROLTYPE_ID
-
Retrieves the control type of the element.
no setterinherited
- currentCulture → int
-
Retrieves the culture identifier for the element.
no setterinherited
- currentDescribedBy → IUIAutomationElementArray?
-
Retrieves an array of elements that describe this element.
no setterinherited
- currentFlowsFrom → IUIAutomationElementArray?
-
Retrieves an array of elements that indicates the reading order before the
current element.
no setterinherited
- currentFlowsTo → IUIAutomationElementArray?
-
Retrieves an array of elements that indicates the reading order after the
current element.
no setterinherited
- currentFrameworkId → BSTR
-
Retrieves the name of the underlying UI framework.
no setterinherited
- currentHasKeyboardFocus → bool
-
Indicates whether the element has keyboard focus.
no setterinherited
- currentHelpText → BSTR
-
Retrieves the help text for the element.
no setterinherited
- currentIsContentElement → bool
-
Indicates whether the element is a content element.
no setterinherited
- currentIsControlElement → bool
-
Indicates whether the element is a control element.
no setterinherited
- currentIsDataValidForForm → bool
-
Indicates whether the element contains valid data for a form.
no setterinherited
- currentIsEnabled → bool
-
Indicates whether the element is enabled.
no setterinherited
- currentIsKeyboardFocusable → bool
-
Indicates whether the element can accept keyboard focus.
no setterinherited
- currentIsOffscreen → bool
-
Indicates whether the element is off-screen.
no setterinherited
- currentIsPassword → bool
-
Indicates whether the element contains a disguised password.
no setterinherited
- currentIsPeripheral → bool
-
Retrieves the current peripheral UI indicator for the element.
no setterinherited
- currentIsRequiredForForm → bool
-
Indicates whether the element is required to be filled out on a form.
no setterinherited
- currentItemStatus → BSTR
-
Retrieves the description of the status of an item in an element.
no setterinherited
- currentItemType → BSTR
-
Retrieves a description of the type of UI item represented by the element.
no setterinherited
- currentLabeledBy → IUIAutomationElement?
-
Retrieves the element that contains the text label for this element.
no setterinherited
- currentLevel → int
-
Returns the current 1-based integer for the level (hierarchy) for the
element.
no setter
- currentLiveSetting → LiveSetting
-
Indicates the type of notifications, if any, that the element sends when
the content of the element changes.
no setterinherited
- currentLocalizedControlType → BSTR
-
Retrieves a localized description of the control type of the element.
no setterinherited
- currentName → BSTR
-
Retrieves the name of the element.
no setterinherited
- currentNativeWindowHandle → HWND
-
Retrieves the window handle of the element.
no setterinherited
- currentOptimizeForVisualContent → bool
-
Indicates whether the provider exposes only elements that are visible.
no setterinherited
- currentOrientation → OrientationType
-
Retrieves a value that indicates the orientation of the element.
no setterinherited
- currentPositionInSet → int
-
Returns the current 1-based integer for the ordinal position in the set
for the element.
no setter
- currentProcessId → int
-
Retrieves the identifier of the process that hosts the element.
no setterinherited
- currentProviderDescription → BSTR
-
Retrieves a description of the provider for this element.
no setterinherited
- currentSizeOfSet → int
-
Returns the current 1-based integer for the size of the set where the
element is located.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
buildUpdatedCache(
IUIAutomationCacheRequest? cacheRequest) → IUIAutomationElement? -
Retrieves a new UI Automation element with an updated cache.
inherited
-
findAll(
TreeScope scope, IUIAutomationCondition? condition) → IUIAutomationElementArray? -
Returns all UI Automation elements that satisfy the specified condition.
inherited
-
findAllBuildCache(
TreeScope scope, IUIAutomationCondition? condition, IUIAutomationCacheRequest? cacheRequest) → IUIAutomationElementArray? -
Returns all UI Automation elements that satisfy the specified condition,
prefetches the requested properties and control patterns, and stores the
prefetched items in the cache.
inherited
-
findFirst(
TreeScope scope, IUIAutomationCondition? condition) → IUIAutomationElement? -
Retrieves the first child or descendant element that matches the specified
condition.
inherited
-
findFirstBuildCache(
TreeScope scope, IUIAutomationCondition? condition, IUIAutomationCacheRequest? cacheRequest) → IUIAutomationElement? -
Retrieves the first child or descendant element that matches the specified
condition, prefetches the requested properties and control patterns, and
stores the prefetched items in the cache.
inherited
-
getCachedChildren(
) → IUIAutomationElementArray? -
Retrieves the cached child elements of this UI Automation element.
inherited
-
getCachedParent(
) → IUIAutomationElement? -
Retrieves from the cache the parent of this UI Automation element.
inherited
-
getCachedPattern(
UIA_PATTERN_ID patternId) → IUnknown? -
Retrieves from the cache the IUnknown interface of the specified control
pattern of this UI Automation element.
inherited
-
getCachedPatternAs<
T extends IUnknown> (UIA_PATTERN_ID patternId) → T -
Retrieves the control pattern interface of the specified pattern from the
cache of this UI Automation element.
inherited
-
getCachedPropertyValue(
UIA_PROPERTY_ID propertyId) → Pointer< VARIANT> -
Retrieves a property value from the cache for this UI Automation element.
inherited
-
getCachedPropertyValueEx(
UIA_PROPERTY_ID propertyId, bool ignoreDefaultValue) → Pointer< VARIANT> -
Retrieves a property value from the cache for this UI Automation element,
optionally ignoring any default value.
inherited
-
getClickablePoint(
Pointer< POINT> clickable, Pointer<Int32> gotClickable) → void -
Retrieves a point on the element that can be clicked.
inherited
-
getCurrentPattern(
UIA_PATTERN_ID patternId) → IUnknown? -
Retrieves the IUnknown interface of the specified control pattern on this
UI Automation element.
inherited
-
getCurrentPatternAs<
T extends IUnknown> (UIA_PATTERN_ID patternId) → T -
Retrieves the control pattern interface of the specified pattern on this
UI Automation element.
inherited
-
getCurrentPropertyValue(
UIA_PROPERTY_ID propertyId) → Pointer< VARIANT> -
Retrieves the current value of a property for this UI Automation element.
inherited
-
getCurrentPropertyValueEx(
UIA_PROPERTY_ID propertyId, bool ignoreDefaultValue) → Pointer< VARIANT> -
Retrieves a property value for this UI Automation element, optionally
ignoring any default value.
inherited
-
getRuntimeId(
) → Pointer< SAFEARRAY> -
Retrieves the unique identifier assigned to the UI element.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
setFocus(
) → void -
Sets the keyboard focus to this UI Automation element.
inherited
-
showContextMenu(
) → void -
Programmatically invokes a context menu on the target element.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited