IUIAutomationSelectionPattern2 class com
Extends the IUIAutomationSelectionPattern interface to provide information about selected items.
To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationselectionpattern2.
- Inheritance
-
- Object
- IUnknown
- IUIAutomationSelectionPattern
- IUIAutomationSelectionPattern2
- Implemented types
Constructors
- IUIAutomationSelectionPattern2(VTablePointer ptr)
- Creates a new instance of IUIAutomationSelectionPattern2 from a VTablePointer.
- IUIAutomationSelectionPattern2.from(IUnknown interface)
-
Creates a new instance of IUIAutomationSelectionPattern2 from an
existing
interface.factory
Properties
- cachedCanSelectMultiple → bool
-
Retrieves a cached value that indicates whether more than one item in the
container can be selected at one time.
no setterinherited
- cachedCurrentSelectedItem → IUIAutomationElement?
-
Gets a cached IUIAutomationElement object representing the currently
selected item.
no setter
- cachedFirstSelectedItem → IUIAutomationElement?
-
Gets a cached IUIAutomationElement object representing the first item in a
group of selected items.
no setter
- cachedIsSelectionRequired → bool
-
Retrieves a cached value that indicates whether at least one item must be
selected at all times.
no setterinherited
- cachedItemCount → int
-
Gets a cached integer value indicating the number of selected items.
no setter
- cachedLastSelectedItem → IUIAutomationElement?
-
Gets a cached IUIAutomationElement object representing the last item in a
group of selected items.
no setter
- currentCanSelectMultiple → bool
-
Indicates whether more than one item in the container can be selected at
one time.
no setterinherited
- currentCurrentSelectedItem → IUIAutomationElement?
-
Gets an IUIAutomationElement object representing the currently selected
item.
no setter
- currentFirstSelectedItem → IUIAutomationElement?
-
Gets an IUIAutomationElement object representing the first item in a group
of selected items.
no setter
- currentIsSelectionRequired → bool
-
Indicates whether at least one item must be selected at all times.
no setterinherited
- currentItemCount → int
-
Gets an integer value indicating the number of selected items.
no setter
- currentLastSelectedItem → IUIAutomationElement?
-
Gets an IUIAutomationElement object representing the last item in a group
of selected items.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
getCachedSelection(
) → IUIAutomationElementArray? -
Retrieves the cached selected elements in the container.
inherited
-
getCurrentSelection(
) → IUIAutomationElementArray? -
Retrieves the selected elements in the container.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited