IUIAutomationSpreadsheetItemPattern class com
Enables a client application to retrieve information about an item (cell) in a spreadsheet.
To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationspreadsheetitempattern.
- Inheritance
- Implemented types
Constructors
- IUIAutomationSpreadsheetItemPattern(VTablePointer ptr)
- Creates a new instance of IUIAutomationSpreadsheetItemPattern from a VTablePointer.
- IUIAutomationSpreadsheetItemPattern.from(IUnknown interface)
-
Creates a new instance of IUIAutomationSpreadsheetItemPattern from an
existing
interface.factory
Properties
- cachedFormula → BSTR
-
Retrieves the cached formula for this cell.
no setter
- currentFormula → BSTR
-
Retrieves the formula for this cell.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
getCachedAnnotationObjects(
) → IUIAutomationElementArray? - Retrieves a cached array of elements representing the annotations associated with this spreadsheet cell.
-
getCachedAnnotationTypes(
) → Pointer< SAFEARRAY> - Retrieves a cached array of annotation type identifiers indicating the types of annotations that are associated with this spreadsheet cell.
-
getCurrentAnnotationObjects(
) → IUIAutomationElementArray? - Retrieves an array of elements representing the annotations associated with this spreadsheet cell.
-
getCurrentAnnotationTypes(
) → Pointer< SAFEARRAY> - Retrieves an array of annotation type identifiers indicating the types of annotations that are associated with this spreadsheet cell.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited