IUIAutomationSynchronizedInputPattern class com
Provides access to the keyboard or mouse input of a control.
To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationsynchronizedinputpattern.
- Inheritance
- Implemented types
Constructors
- IUIAutomationSynchronizedInputPattern(VTablePointer ptr)
- Creates a new instance of IUIAutomationSynchronizedInputPattern from a VTablePointer.
- IUIAutomationSynchronizedInputPattern.from(IUnknown interface)
-
Creates a new instance of IUIAutomationSynchronizedInputPattern from an
existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
cancel(
) → void - Causes the Microsoft UI Automation provider to stop listening for mouse or keyboard input.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
startListening(
SynchronizedInputType inputType) → void - Causes the Microsoft UI Automation provider to start listening for mouse or keyboard input.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited