IUIAutomationTreeWalker class com
Exposes properties and methods that UI Automation client applications use to view and navigate the UI Automation elements on the desktop.
To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationtreewalker.
- Inheritance
- Implemented types
Constructors
- IUIAutomationTreeWalker(VTablePointer ptr)
- Creates a new instance of IUIAutomationTreeWalker from a VTablePointer.
- IUIAutomationTreeWalker.from(IUnknown interface)
-
Creates a new instance of IUIAutomationTreeWalker from an existing
interface.factory
Properties
- condition → IUIAutomationCondition?
-
Retrieves the condition that defines the view of the UI Automation tree.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
getFirstChildElement(
IUIAutomationElement? element) → IUIAutomationElement? - Retrieves the first child element of the specified UI Automation element.
-
getFirstChildElementBuildCache(
IUIAutomationElement? element, IUIAutomationCacheRequest? cacheRequest) → IUIAutomationElement? - Retrieves the first child element of the specified UI Automation element, and caches properties and control patterns.
-
getLastChildElement(
IUIAutomationElement? element) → IUIAutomationElement? - Retrieves the last child element of the specified UI Automation element.
-
getLastChildElementBuildCache(
IUIAutomationElement? element, IUIAutomationCacheRequest? cacheRequest) → IUIAutomationElement? - Retrieves the last child element of the specified UI Automation element, and caches properties and control patterns.
-
getNextSiblingElement(
IUIAutomationElement? element) → IUIAutomationElement? - Retrieves the next sibling element of the specified UI Automation element.
-
getNextSiblingElementBuildCache(
IUIAutomationElement? element, IUIAutomationCacheRequest? cacheRequest) → IUIAutomationElement? - Retrieves the next sibling element of the specified UI Automation element, and caches properties and control patterns.
-
getParentElement(
IUIAutomationElement? element) → IUIAutomationElement? - Retrieves the parent element of the specified UI Automation element.
-
getParentElementBuildCache(
IUIAutomationElement? element, IUIAutomationCacheRequest? cacheRequest) → IUIAutomationElement? - Retrieves the parent element of the specified UI Automation element, and caches properties and control patterns.
-
getPreviousSiblingElement(
IUIAutomationElement? element) → IUIAutomationElement? - Retrieves the previous sibling element of the specified UI Automation element.
-
getPreviousSiblingElementBuildCache(
IUIAutomationElement? element, IUIAutomationCacheRequest? cacheRequest) → IUIAutomationElement? - Retrieves the previous sibling element of the specified UI Automation element, and caches properties and control patterns.
-
normalizeElement(
IUIAutomationElement? element) → IUIAutomationElement? - Retrieves the ancestor element nearest to the specified Microsoft UI Automation element in the tree view.
-
normalizeElementBuildCache(
IUIAutomationElement? element, IUIAutomationCacheRequest? cacheRequest) → IUIAutomationElement? - Retrieves the ancestor element nearest to the specified Microsoft UI Automation element in the tree view, prefetches the requested properties and control patterns, and stores the prefetched items in the cache.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited