IUIAutomationValuePattern class com
Provides access to a control that contains a value that does not span a range and that can be represented as a string.
To learn more, see learn.microsoft.com/windows/win32/api/uiautomationclient/nn-uiautomationclient-iuiautomationvaluepattern.
- Inheritance
- Implemented types
Constructors
- IUIAutomationValuePattern(VTablePointer ptr)
- Creates a new instance of IUIAutomationValuePattern from a VTablePointer.
- IUIAutomationValuePattern.from(IUnknown interface)
-
Creates a new instance of IUIAutomationValuePattern from an existing
interface.factory
Properties
- cachedIsReadOnly → bool
-
Retrieves a cached value that indicates whether the value of the element
is read-only.
no setter
- cachedValue → BSTR
-
Retrieves the cached value of the element.
no setter
- currentIsReadOnly → bool
-
Indicates whether the value of the element is read-only.
no setter
- currentValue → BSTR
-
Retrieves the value of the element.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
setValue(
BSTR val) → void - Sets the value of the element.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited