IUnknown class com
The foundational COM interface that provides methods for querying other interfaces and managing the lifecycle of a COM object.
All COM interfaces directly or indirectly inherit from IUnknown. As such, the three methods defined by IUnknown (queryInterface, addRef, and release) are always the first entries in the VTable for any COM interface.
To learn more, see learn.microsoft.com/windows/win32/api/unknwn/nn-unknwn-iunknown.
- Implemented types
- Implementers
- IAgileObject
- IApplicationActivationManager
- IAppxBlockMapBlock
- IAppxBlockMapBlocksEnumerator
- IAppxBlockMapFile
- IAppxBlockMapFilesEnumerator
- IAppxBlockMapReader
- IAppxFactory
- IAppxFile
- IAppxFilesEnumerator
- IAppxManifestApplication
- IAppxManifestApplicationsEnumerator
- IAppxManifestCapabilitiesEnumerator
- IAppxManifestDeviceCapabilitiesEnumerator
- IAppxManifestDriverConstraint
- IAppxManifestDriverConstraintsEnumerator
- IAppxManifestDriverDependenciesEnumerator
- IAppxManifestDriverDependency
- IAppxManifestHostRuntimeDependenciesEnumerator
- IAppxManifestHostRuntimeDependency
- IAppxManifestHostRuntimeDependency2
- IAppxManifestMainPackageDependenciesEnumerator
- IAppxManifestMainPackageDependency
- IAppxManifestOptionalPackageInfo
- IAppxManifestOSPackageDependenciesEnumerator
- IAppxManifestOSPackageDependency
- IAppxManifestPackageDependenciesEnumerator
- IAppxManifestPackageDependency
- IAppxManifestPackageId
- IAppxManifestProperties
- IAppxManifestQualifiedResource
- IAppxManifestQualifiedResourcesEnumerator
- IAppxManifestReader
- IAppxManifestReader5
- IAppxManifestReader6
- IAppxManifestReader7
- IAppxManifestResourcesEnumerator
- IAppxManifestTargetDeviceFamiliesEnumerator
- IAppxManifestTargetDeviceFamily
- IAppxPackageReader
- IAppxPackageWriter
- IAudioCaptureClient
- IAudioClient
- IAudioClientDuckingControl
- IAudioClock
- IAudioClock2
- IAudioClockAdjustment
- IAudioRenderClient
- IAudioSessionControl
- IAudioSessionEnumerator
- IAudioSessionEvents
- IAudioSessionManager
- IAudioSessionNotification
- IAudioStreamVolume
- IAudioVolumeDuckNotification
- IBindCtx
- IChannelAudioVolume
- IClassFactory
- IConnectionPoint
- IConnectionPointContainer
- IDesktopWallpaper
- IDispatch
- IEnumConnectionPoints
- IEnumConnections
- IEnumIDList
- IEnumMoniker
- IEnumResources
- IEnumShellItems
- IEnumSpellingError
- IEnumSpObjectTokens
- IEnumSTATSTG
- IEnumString
- IEnumVARIANT
- IEnumWbemClassObject
- IErrorInfo
- IFileDialogCustomize
- IFileDialogEvents
- IFileIsInUse
- IFileOperationProgressSink
- IInitializeWithWindow
- IInspectable
- IKnownFolder
- IKnownFolderManager
- IMalloc
- IMetaDataAssemblyImport
- IMetaDataDispenser
- IMetaDataImport
- IMetaDataTables
- IMMDevice
- IMMDeviceCollection
- IMMDeviceEnumerator
- IMMEndpoint
- IMMNotificationClient
- IModalWindow
- INetworkListManagerEvents
- IOptionDescription
- IPersist
- IPortableDeviceKeyCollection
- IPortableDevicePropVariantCollection
- IPortableDeviceValues
- IPortableDeviceValuesCollection
- IPropertyDescriptionList
- IPropertyStore
- IProvideClassInfo
- IRawElementProviderSimple
- IRecordInfo
- IRestrictedErrorInfo
- IRunningObjectTable
- ISensor
- ISensorCollection
- ISensorDataReport
- ISensorEvents
- ISensorManager
- ISensorManagerEvents
- ISequentialStream
- IShellFolder
- IShellItem
- IShellItemArray
- IShellItemFilter
- IShellItemImageFactory
- IShellItemResources
- IShellLink
- IShellLinkDataList
- IShellService
- ISimpleAudioVolume
- ISpDataKey
- ISpellChecker
- ISpellCheckerChangedEventHandler
- ISpellCheckerFactory
- ISpellingError
- ISpNotifySink
- ISpNotifySource
- IStorage
- ISupportErrorInfo
- ITypeComp
- ITypeInfo
- ITypeLib
- IUIAutomation
- IUIAutomationActiveTextPositionChangedEventHandler
- IUIAutomationAnnotationPattern
- IUIAutomationCacheRequest
- IUIAutomationChangesEventHandler
- IUIAutomationCondition
- IUIAutomationCustomNavigationPattern
- IUIAutomationDockPattern
- IUIAutomationDragPattern
- IUIAutomationDropTargetPattern
- IUIAutomationElement
- IUIAutomationElementArray
- IUIAutomationEventHandler
- IUIAutomationEventHandlerGroup
- IUIAutomationExpandCollapsePattern
- IUIAutomationFocusChangedEventHandler
- IUIAutomationGridItemPattern
- IUIAutomationGridPattern
- IUIAutomationInvokePattern
- IUIAutomationItemContainerPattern
- IUIAutomationLegacyIAccessiblePattern
- IUIAutomationMultipleViewPattern
- IUIAutomationNotificationEventHandler
- IUIAutomationObjectModelPattern
- IUIAutomationPropertyChangedEventHandler
- IUIAutomationProxyFactory
- IUIAutomationProxyFactoryEntry
- IUIAutomationProxyFactoryMapping
- IUIAutomationRangeValuePattern
- IUIAutomationScrollItemPattern
- IUIAutomationScrollPattern
- IUIAutomationSelectionItemPattern
- IUIAutomationSelectionPattern
- IUIAutomationSpreadsheetItemPattern
- IUIAutomationSpreadsheetPattern
- IUIAutomationStructureChangedEventHandler
- IUIAutomationStylesPattern
- IUIAutomationSynchronizedInputPattern
- IUIAutomationTableItemPattern
- IUIAutomationTablePattern
- IUIAutomationTextChildPattern
- IUIAutomationTextEditTextChangedEventHandler
- IUIAutomationTextPattern
- IUIAutomationTextRange
- IUIAutomationTextRangeArray
- IUIAutomationTogglePattern
- IUIAutomationTransformPattern
- IUIAutomationTreeWalker
- IUIAutomationValuePattern
- IUIAutomationVirtualizedItemPattern
- IUIAutomationWindowPattern
- IUri
- IVirtualDesktopManager
- IWbemCallResult
- IWbemClassObject
- IWbemConfigureRefresher
- IWbemContext
- IWbemHiPerfEnum
- IWbemLocator
- IWbemObjectSink
- IWbemQualifierSet
- IWbemRefresher
- IWbemServices
Constructors
- IUnknown(VTablePointer ptr)
- Creates a new instance of IUnknown from a VTablePointer.
- IUnknown.from(IUnknown interface)
-
Creates a new instance of IUnknown from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int - Increments the reference count of this COM object.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T. -
release(
) → int - Decrements the reference count of this COM object.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited