IVirtualDesktopManager class com
Exposes methods that enable an application to interact with groups of windows that form virtual workspaces.
To learn more, see learn.microsoft.com/windows/win32/api/shobjidl_core/nn-shobjidl_core-ivirtualdesktopmanager.
- Inheritance
- Implemented types
Constructors
- IVirtualDesktopManager(VTablePointer ptr)
- Creates a new instance of IVirtualDesktopManager from a VTablePointer.
- IVirtualDesktopManager.from(IUnknown interface)
-
Creates a new instance of IVirtualDesktopManager from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
getWindowDesktopId(
HWND topLevelWindow) → Pointer< GUID> - Gets the identifier for the virtual desktop hosting the provided top-level window.
-
isWindowOnCurrentVirtualDesktop(
HWND topLevelWindow) → bool - Indicates whether the provided window is on the currently active virtual desktop.
-
moveWindowToDesktop(
HWND topLevelWindow, Pointer< GUID> desktopId) → void - Moves a window to the specified virtual desktop.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited