IWbemCallResult class com
Used for semisynchronous calls of the IWbemServices interface.
When making such calls, the called IWbemServices method returns immediately, along with an IWbemCallResult object.
To learn more, see learn.microsoft.com/windows/win32/api/wbemcli/nn-wbemcli-iwbemcallresult.
- Inheritance
- Implemented types
Constructors
- IWbemCallResult(VTablePointer ptr)
- Creates a new instance of IWbemCallResult from a VTablePointer.
- IWbemCallResult.from(IUnknown interface)
-
Creates a new instance of IWbemCallResult from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
getCallStatus(
int lTimeout) → int - Returns to the user the status of the current outstanding semisynchronous call.
-
getResultObject(
int lTimeout) → IWbemClassObject? -
Attempts to retrieve an object from a previous semisynchronous call to
IWbemServices.getObjectorIWbemServices.execMethod. -
getResultServices(
int lTimeout) → IWbemServices? -
Retrieves the IWbemServices pointer, which results from a semisynchronous
call to
IWbemServices.openNamespacewhen it becomes available. -
getResultString(
int lTimeout) → BSTR -
Returns the assigned object path of an instance newly created by
IWbemServices.putInstance. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited