IWbemClassObject class com
Contains and manipulates both class definitions and class object instances.
To learn more, see learn.microsoft.com/windows/win32/api/wbemcli/nn-wbemcli-iwbemclassobject.
- Inheritance
- Implemented types
- Implementers
Constructors
- IWbemClassObject(VTablePointer ptr)
- Creates a new instance of IWbemClassObject from a VTablePointer.
- IWbemClassObject.from(IUnknown interface)
-
Creates a new instance of IWbemClassObject from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
beginEnumeration(
int lEnumFlags) → void - Resets an enumeration back to the beginning of the enumeration.
-
beginMethodEnumeration(
int lEnumFlags) → void -
Use the
IWbemClassObject.beginMethodEnumerationmethod call to begin an enumeration of the methods available for the object. -
clone(
) → IWbemClassObject? - Returns a new object that is a complete clone of the current object.
-
compareTo(
WBEM_COMPARISON_FLAG lFlags, IWbemClassObject? pCompareTo) → void - Compares an object to another Windows Management object.
-
delete(
PCWSTR wszName) → void - Deletes the specified property from a CIM class definition and all of its qualifiers.
-
deleteMethod(
PCWSTR wszName) → void -
Use the
IWbemClassObject.deleteMethodmethod to delete a method. -
endEnumeration(
) → void -
Terminates an enumeration sequence started with
IWbemClassObject.beginEnumeration. -
endMethodEnumeration(
) → void -
Used to terminate a method enumeration sequence started with
IWbemClassObject.beginMethodEnumeration. -
get(
PCWSTR wszName, int lFlags, Pointer< VARIANT> pVal, Pointer<Int32> ? pType, Pointer<Int32> ? plFlavor) → void - Retrieves the specified property value, if it exists.
-
getMethod(
PCWSTR wszName, int lFlags, Pointer< VTablePointer> ppInSignature, Pointer<VTablePointer> ppOutSignature) → void - Returns information about the requested method.
-
getMethodOrigin(
PCWSTR wszMethodName) → BSTR - Used to determine the class for which a method was declared.
-
getMethodQualifierSet(
PCWSTR wszMethod) → IWbemQualifierSet? -
The
IWbemClassObject.getMethodQualifierSetis used to retrieve the qualifier set for a particular method. -
getNames(
PCWSTR wszQualifierName, WBEM_CONDITION_FLAG_TYPE lFlags, Pointer< VARIANT> pQualifierVal) → Pointer<SAFEARRAY> - Retrieves the names of the properties in the object.
-
getObjectText(
int lFlags) → BSTR - Returns a textual rendering of the object in the MOF syntax.
-
getPropertyOrigin(
PCWSTR wszName) → BSTR - Retrieves the name of the class in which a particular property was introduced.
-
getPropertyQualifierSet(
PCWSTR wszProperty) → IWbemQualifierSet? - Gets the qualifier set for a particular property in the class object.
-
getQualifierSet(
) → IWbemQualifierSet? - Returns an interface pointer that allows read and write operations on the set of qualifiers for the entire class object, whether the object is an instance or a class definition.
-
inheritsFrom(
PCWSTR strAncestor) → void - Determines if the current class or instance derives from a specified parent class.
-
next(
int lFlags, Pointer< Pointer< strName, Pointer<Utf16> >VARIANT> pVal, Pointer<Int32> pType, Pointer<Int32> plFlavor) → void -
Retrieves the next property in an enumeration that started with
IWbemClassObject.beginEnumeration. -
nextMethod(
int lFlags, Pointer< Pointer< pstrName, Pointer<Utf16> >VTablePointer> ppInSignature, Pointer<VTablePointer> ppOutSignature) → void -
Used to retrieve the next method in a method enumeration sequence that
starts with a call to
IWbemClassObject.beginMethodEnumeration. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
put(
PCWSTR wszName, int lFlags, Pointer< VARIANT> pVal, int type) → void - Sets a named property to a new value.
-
putMethod(
PCWSTR wszName, int lFlags, IWbemClassObject? pInSignature, IWbemClassObject? pOutSignature) → void - Used to create a method.
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
spawnDerivedClass(
int lFlags) → IWbemClassObject? -
Use the
IWbemClassObject.spawnDerivedClassmethod to create a newly derived class object from the current object. -
spawnInstance(
int lFlags) → IWbemClassObject? -
Use the
IWbemClassObject.spawnInstancemethod to create a new instance of a class. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited