IWbemQualifierSet class com
Acts as a container for the entire set of named qualifiers for a single property or entire object (a class or instance).
To learn more, see learn.microsoft.com/windows/win32/api/wbemcli/nn-wbemcli-iwbemqualifierset.
- Inheritance
- Implemented types
Constructors
- IWbemQualifierSet(VTablePointer ptr)
- Creates a new instance of IWbemQualifierSet from a VTablePointer.
- IWbemQualifierSet.from(IUnknown interface)
-
Creates a new instance of IWbemQualifierSet from an existing
interface.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ptr → VTablePointer
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRef(
) → int -
Increments the reference count of this COM object.
inherited
-
beginEnumeration(
int lFlags) → void - Resets before there is an enumeration of all the qualifiers in the object.
-
delete(
PCWSTR wszName) → void - Deletes the specified qualifier by name.
-
endEnumeration(
) → void -
Call the
IWbemQualifierSet.endEnumerationmethod when you plan to terminate enumerations initiated withIWbemQualifierSet.beginEnumerationandIWbemQualifierSet.next. -
get(
PCWSTR wszName, int lFlags, Pointer< VARIANT> pVal, Pointer<Int32> plFlavor) → void - Gets the specified named qualifier, if found.
-
getNames(
int lFlags) → Pointer< SAFEARRAY> - Retrieves the names of all of the qualifiers available from the current object or property.
-
next(
int lFlags, Pointer< Pointer< pstrName, Pointer<Utf16> >VARIANT> pVal, Pointer<Int32> plFlavor) → void -
Retrieves the next qualifier in an enumeration that started with
IWbemQualifierSet.beginEnumeration. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
put(
PCWSTR wszName, Pointer< VARIANT> pVal, int lFlavor) → void - Writes the named qualifier and value.
-
queryInterface<
T extends IUnknown> () → T -
Queries this COM object for a specific interface defined by the type
parameter
T.inherited -
release(
) → int -
Decrements the reference count of this COM object.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited