InitCommonControlsEx function comctl32
Ensures that the common control DLL (Comctl32.dll) is loaded, and registers specific common control classes from the DLL.
An application must call this function before creating a common control.
To learn more, see learn.microsoft.com/windows/win32/api/commctrl/nf-commctrl-initcommoncontrolsex.
Implementation
@pragma('vm:prefer-inline')
bool InitCommonControlsEx(Pointer<INITCOMMONCONTROLSEX> picce) =>
_InitCommonControlsEx(picce) != FALSE;