IsValidLocaleName function kernel32
Determines if the specified locale name is valid for a locale that is installed or supported on the operating system.
Note: An application running only on Windows Vista and later should call this function in preference to IsValidLocale to determine the validity of a supplemental locale.
To learn more, see learn.microsoft.com/windows/win32/api/winnls/nf-winnls-isvalidlocalename.
Implementation
@pragma('vm:prefer-inline')
bool IsValidLocaleName(PCWSTR lpLocaleName) =>
_IsValidLocaleName(lpLocaleName) != FALSE;