Used by the IHV Extensions DLL to send notifications to any service or applications that has registered for the notification.
To learn more, see learn.microsoft.com/windows/win32/api/l2cmn/ns-l2cmn-l2_notification_data.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - dwDataSize ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- InterfaceGuid ↔ GUID
-
getter/setter pair
- NotificationCode ↔ int
-
getter/setter pair
- NotificationSource ↔ WLAN_NOTIFICATION_SOURCES
-
getter/setter pair
-
pData
↔ Pointer<
NativeType> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< L2_NOTIFICATION_DATA> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited