LOCK_EXCLUSIVE top-level constant
LOCKTYPE
const LOCK_EXCLUSIVE
If this lock is granted, writing to the specified range of bytes is prohibited except by the owner that was granted this lock.
Implementation
const LOCK_EXCLUSIVE = LOCKTYPE(2);