LOGPALETTE class base struct

Defines a logical palette.

To learn more, see learn.microsoft.com/windows/win32/api/wingdi/ns-wingdi-logpalette.

Inheritance
Implemented types
Available extensions

Constructors

LOGPALETTE()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
palNumEntries int
The number of entries in the logical palette.
getter/setter pair
palPalEntry Array<PALETTEENTRY>
Specifies an array of PALETTEENTRY structures that define the color and usage of each entry in the logical palette.
getter/setter pair
palVersion int
The version number of the system.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<LOGPALETTE>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited