Contains information about the current state of both physical and virtual memory, including extended memory.
To learn more, see learn.microsoft.com/windows/win32/api/sysinfoapi/ns-sysinfoapi-memorystatusex.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - dwLength ↔ int
-
The size of the structure, in bytes.
getter/setter pair
- dwMemoryLoad ↔ int
-
A number between 0 and 100 that specifies the approximate percentage of
physical memory that is in use (0 indicates no memory use and 100
indicates full memory use).
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ullAvailExtendedVirtual ↔ int
-
Reserved.
getter/setter pair
- ullAvailPageFile ↔ int
-
The maximum amount of memory the current process can commit, in bytes.
getter/setter pair
- ullAvailPhys ↔ int
-
The amount of physical memory currently available, in bytes.
getter/setter pair
- ullAvailVirtual ↔ int
-
The amount of unreserved and uncommitted memory currently in the user-mode
portion of the virtual address space of the calling process, in bytes.
getter/setter pair
- ullTotalPageFile ↔ int
-
The current committed memory limit for the system or the current process,
whichever is smaller, in bytes.
getter/setter pair
- ullTotalPhys ↔ int
-
The amount of actual physical memory, in bytes.
getter/setter pair
- ullTotalVirtual ↔ int
-
The size of the user-mode portion of the virtual address space of the
calling process, in bytes.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< MEMORYSTATUSEX> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited