Defines a menu item in a menu template.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-menuitemtemplate.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- mtID ↔ int
-
The menu item identifier of a command item; a command item sends a command
message to its owner window.
getter/setter pair
- mtOption ↔ int
-
One or more of the following predefined menu options that control the
appearance of the menu item as shown in the following table.
getter/setter pair
- mtString ↔ String
-
The menu item.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< MENUITEMTEMPLATE> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited