MagGetInputTransform function magnification
Retrieves the current input transformation for pen and touch input, represented as a source rectangle and a destination rectangle.
To learn more, see learn.microsoft.com/windows/win32/api/magnification/nf-magnification-maggetinputtransform.
Implementation
@pragma('vm:prefer-inline')
bool MagGetInputTransform(
Pointer<Int32> pfEnabled,
Pointer<RECT> pRectSource,
Pointer<RECT> pRectDest,
) => _MagGetInputTransform(pfEnabled, pRectSource, pRectDest) != FALSE;