MonitorFromRect function user32
Retrieves a handle to the display monitor that has the largest area of intersection with a specified rectangle.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-monitorfromrect.
Implementation
@pragma('vm:prefer-inline')
HMONITOR MonitorFromRect(Pointer<RECT> lprc, MONITOR_FROM_FLAGS dwFlags) =>
HMONITOR(_MonitorFromRect(lprc, dwFlags));