Used to specify values that are used by SetSimulatedProfileInfo to override current internet connection profile values in an RDP Child Session to support the simulation of specific metered internet connection conditions.
To learn more, see learn.microsoft.com/windows/win32/api/netlistmgr/ns-netlistmgr-nlm_simulated_profile_info.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - cost ↔ NLM_CONNECTION_COST
-
The network cost.
getter/setter pair
- DataLimitInMegabytes ↔ int
-
The data limit of the plan.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- ProfileName ↔ String
-
Name for the simulated profile.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- UsageInMegabytes ↔ int
-
The data usage.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< NLM_SIMULATED_PROFILE_INFO> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited