Contains the scalable metrics associated with the nonclient area of a nonminimized window.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-nonclientmetricsw.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - cbSize ↔ int
-
The size of the struct in bytes.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- iBorderWidth ↔ int
-
The thickness of the sizing border, in pixels.
getter/setter pair
- iCaptionHeight ↔ int
-
The height of caption buttons, in pixels.
getter/setter pair
- iCaptionWidth ↔ int
-
The width of caption buttons, in pixels.
getter/setter pair
- iMenuHeight ↔ int
-
The height of a menu bar, in pixels.
getter/setter pair
- iMenuWidth ↔ int
-
The width of menu-bar buttons, in pixels.
getter/setter pair
- iPaddedBorderWidth ↔ int
-
The thickness of the padded border, in pixels.
getter/setter pair
- iScrollHeight ↔ int
-
The height of a standard horizontal scroll bar, in pixels.
getter/setter pair
- iScrollWidth ↔ int
-
The width of a standard vertical scroll bar, in pixels.
getter/setter pair
- iSmCaptionHeight ↔ int
-
The height of small captions, in pixels.
getter/setter pair
- iSmCaptionWidth ↔ int
-
The width of small caption buttons, in pixels.
getter/setter pair
- lfCaptionFont ↔ LOGFONT
-
A
LOGFONTstructure that contains information about the caption font.getter/setter pair - lfMenuFont ↔ LOGFONT
-
A
LOGFONTstructure that contains information about the font used in menu bars.getter/setter pair - lfMessageFont ↔ LOGFONT
-
A
LOGFONTstructure that contains information about the font used in message boxes.getter/setter pair - lfSmCaptionFont ↔ LOGFONT
-
A
LOGFONTstructure that contains information about the small caption font.getter/setter pair - lfStatusFont ↔ LOGFONT
-
A
LOGFONTstructure that contains information about the font used in status bars and tooltips.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< NONCLIENTMETRICS> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited