NotificationKind_ItemRemoved top-level constant
NotificationKind
const NotificationKind_ItemRemoved
The current element has had something removed from inside of it that should be presented to the user.
Implementation
const NotificationKind_ItemRemoved = NotificationKind(1);