OSVERSIONINFO class base struct

Contains operating system version information.

To learn more, see learn.microsoft.com/windows/win32/api/winnt/ns-winnt-osversioninfow.

Inheritance
Implemented types
Available extensions

Constructors

OSVERSIONINFO()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
dwBuildNumber int
The build number of the operating system.
getter/setter pair
dwMajorVersion int
The major version number of the operating system.
getter/setter pair
dwMinorVersion int
The minor version number of the operating system.
getter/setter pair
dwOSVersionInfoSize int
The size of this data structure, in bytes.
getter/setter pair
dwPlatformId int
The operating system platform.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
szCSDVersion String
A string, such as "Service Pack 3", that indicates the latest Service Pack installed on the system.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative({Allocator allocator = adaptiveCalloc}) Pointer<OSVERSIONINFO>
Allocates native memory and copies the contents of this struct into it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited