Contains information for an application.
This information can be used to paint the client area of a window owned by that application.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-paintstruct.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - fErase ↔ bool
-
Indicates whether the background must be erased.
getter/setter pair
- fIncUpdate ↔ bool
-
Reserved; used internally by the system.
getter/setter pair
- fRestore ↔ bool
-
Reserved; used internally by the system.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hdc ↔ HDC
-
A handle to the display DC to be used for painting.
getter/setter pair
- rcPaint ↔ RECT
-
A
RECTstructure that specifies the upper left and lower right corners of the rectangle in which the painting is requested, in device units relative to the upper-left corner of the client area.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< PAINTSTRUCT> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited