PAINTSTRUCT class base struct

The PAINTSTRUCT structure contains information for an application. This information can be used to paint the client area of a window owned by that application.

Inheritance
Implemented types
Available extensions

Constructors

PAINTSTRUCT()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
fErase ↔ int
getter/setter pair
fIncUpdate ↔ int
getter/setter pair
fRestore ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hdc ↔ int
getter/setter pair
rcPaint ↔ RECT
getter/setter pair
rgbReserved ↔ Array<Uint8>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited