Describes how the PolyTextOut function should draw a string of text.
To learn more, see learn.microsoft.com/windows/win32/api/wingdi/ns-wingdi-polytextw.
- Inheritance
- Implemented types
- Available extensions
Constructors
- POLYTEXT()
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- lpstr ↔ PWSTR
-
Pointer to a string of text to be drawn by the PolyTextOut
function.
getter/setter pair
- n ↔ int
-
The length
of the string pointed to by lpstr.
getter/setter pair
-
pdx
↔ Pointer<
Int32> -
Pointer to an array containing the width value for each character in the
string.
getter/setter pair
- rcl ↔ RECT
-
A rectangle structure that contains the dimensions of the opaquing or
clipping rectangle.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uiFlags ↔ int
-
getter/setter pair
- x ↔ int
-
The horizontal reference point for the string.
getter/setter pair
- y ↔ int
-
The vertical reference point for the string.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< POLYTEXT> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited