Contains printer information returned by the FindNextPrinterChangeNotification function.
The function returns this information after a wait operation on a printer change notification object has been satisfied.
To learn more, see learn.microsoft.com/windows/win32/printdocs/printer-notify-info.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
aData
↔ Array<
PRINTER_NOTIFY_INFO_DATA> -
An array of
PRINTER_NOTIFY_INFO_DATAstructures.getter/setter pair -
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - Count ↔ int
-
The number of
PRINTER_NOTIFY_INFO_DATAelements in the aData array.getter/setter pair - Flags ↔ int
-
A bit flag that indicates the state of the notification structure.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- Version ↔ int
-
The version of this structure.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< PRINTER_NOTIFY_INFO> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited