Identifies a job or printer information field and provides the current data for that field.
To learn more, see learn.microsoft.com/windows/win32/printdocs/printer-notify-info-data.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
adwData
↔ Array<
Uint32> -
Available on PRINTER_NOTIFY_INFO_DATA, provided by the PRINTER_NOTIFY_INFO_DATA_0_Extension extension
getter/setter pair - cbBuf ↔ int
-
Available on PRINTER_NOTIFY_INFO_DATA, provided by the PRINTER_NOTIFY_INFO_DATA_0_0_Extension extension
getter/setter pair - Data ↔ PRINTER_NOTIFY_INFO_DATA_0_0
-
Available on PRINTER_NOTIFY_INFO_DATA, provided by the PRINTER_NOTIFY_INFO_DATA_0_Extension extension
getter/setter pair - Field ↔ int
-
Indicates the field that changed.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- Id ↔ int
-
Indicates the job identifier if the Type member specifies
JOB_NOTIFY_TYPE.
getter/setter pair
- NotifyData ↔ PRINTER_NOTIFY_INFO_DATA_0
-
A union of data information based on the Type and Field members.
getter/setter pair
-
pBuf
↔ Pointer<
NativeType> -
Available on PRINTER_NOTIFY_INFO_DATA, provided by the PRINTER_NOTIFY_INFO_DATA_0_0_Extension extension
getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- Type ↔ int
-
Indicates the type of information provided.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< PRINTER_NOTIFY_INFO_DATA> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited