Contains the memory statistics for a process.
To learn more, see learn.microsoft.com/windows/win32/api/psapi/ns-psapi-process_memory_counters.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - cb ↔ int
-
The size of the structure, in bytes.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- PageFaultCount ↔ int
-
The number of page faults.
getter/setter pair
- PagefileUsage ↔ int
-
The Commit Charge value in bytes for this process.
getter/setter pair
- PeakPagefileUsage ↔ int
-
The peak value in bytes of the Commit Charge during the lifetime of this
process.
getter/setter pair
- PeakWorkingSetSize ↔ int
-
The peak working set size, in bytes.
getter/setter pair
- QuotaNonPagedPoolUsage ↔ int
-
The current nonpaged pool usage, in bytes.
getter/setter pair
- QuotaPagedPoolUsage ↔ int
-
The current paged pool usage, in bytes.
getter/setter pair
- QuotaPeakNonPagedPoolUsage ↔ int
-
The peak nonpaged pool usage, in bytes.
getter/setter pair
- QuotaPeakPagedPoolUsage ↔ int
-
The peak paged pool usage, in bytes.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- WorkingSetSize ↔ int
-
The current working set size, in bytes.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< PROCESS_MEMORY_COUNTERS> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited