Contains the name and protocol numbers that correspond to a given protocol name.
To learn more, see learn.microsoft.com/windows/win32/api/winsock/ns-winsock-protoent.
- Inheritance
- Implemented types
- Available extensions
Constructors
- PROTOENT()
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
p_aliases
↔ Pointer<
Pointer< Int8> > -
Null-terminated array of alternate names.
getter/setter pair
- p_name ↔ PSTR
-
Official name of the protocol.
getter/setter pair
- p_proto ↔ int
-
Protocol number, in host byte order.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< PROTOENT> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited