PostQuitMessage function user32
Indicates to the system that a thread has made a request to terminate (quit).
It is typically used in response to a WM_DESTROY message.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-postquitmessage.
Implementation
@pragma('vm:prefer-inline')
void PostQuitMessage(int nExitCode) => _PostQuitMessage(nExitCode);