RegRestoreKey function advapi32
Reads the registry information in a specified file and copies it over the specified key.
This registry information may be in the form of a key and multiple levels of subkeys.
To learn more, see learn.microsoft.com/windows/win32/api/winreg/nf-winreg-regrestorekeyw.
Implementation
@pragma('vm:prefer-inline')
WIN32_ERROR RegRestoreKey(
HKEY hKey,
PCWSTR lpFile,
REG_RESTORE_KEY_FLAGS dwFlags,
) => WIN32_ERROR(_RegRestoreKey(hKey, lpFile, dwFlags));