SCardGetAttrib function winscard
Retrieves the current reader attributes for the given handle.
It does not affect the state of the reader, driver, or card.
To learn more, see learn.microsoft.com/windows/win32/api/winscard/nf-winscard-scardgetattrib.
Implementation
@pragma('vm:prefer-inline')
int SCardGetAttrib(
int hCard,
int dwAttrId,
Pointer<Uint8>? pbAttr,
Pointer<Uint32> pcbAttrLen,
) => _SCardGetAttrib(hCard, dwAttrId, pbAttr ?? nullptr, pcbAttrLen);