Used to store or return the name and service number for a given service name.
To learn more, see learn.microsoft.com/windows/win32/api/winsock/ns-winsock-servent.
- Inheritance
- Implemented types
- Available extensions
Constructors
- SERVENT()
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
s_aliases
↔ Pointer<
Pointer< Int8> > -
A NULL-terminated array of alternate names.
getter/setter pair
- s_name ↔ PSTR
-
The official name of the service.
getter/setter pair
- s_port ↔ int
-
The port number at which the service can be contacted.
getter/setter pair
- s_proto ↔ PSTR
-
The name of the protocol to use when contacting the service.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< SERVENT> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited