Represents the action the service controller should take on each failure of a service.
A service is considered failed when it terminates without reporting a status of SERVICE_STOPPED to the service controller.
To learn more, see learn.microsoft.com/windows/win32/api/winsvc/ns-winsvc-service_failure_actionsw.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - cActions ↔ int
-
The number of elements in the lpsaActions array.
getter/setter pair
- dwResetPeriod ↔ int
-
The time after which to reset the failure count to zero if there are no
failures, in seconds.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- lpCommand ↔ PWSTR
-
The command line of the process for the CreateProcess
function to execute in response to the SC_ACTION_RUN_COMMAND
service controller action.
getter/setter pair
- lpRebootMsg ↔ PWSTR
-
The message to be broadcast to server users before rebooting in response
to the SC_ACTION_REBOOT service controller action.
getter/setter pair
-
lpsaActions
↔ Pointer<
SC_ACTION> -
A pointer to an array of SC_ACTION
structures.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< SERVICE_FAILURE_ACTIONS> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited