Specifies a date and time, using individual members for the month, day, year, weekday, hour, minute, second, and millisecond.
The time is either in coordinated universal time (UTC) or local time, depending on the function that is being called.
To learn more, see learn.microsoft.com/windows/win32/api/minwinbase/ns-minwinbase-systemtime.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wDay ↔ int
-
The day of the month.
getter/setter pair
- wDayOfWeek ↔ int
-
getter/setter pair
- wHour ↔ int
-
The hour.
getter/setter pair
- wMilliseconds ↔ int
-
The millisecond.
getter/setter pair
- wMinute ↔ int
-
The minute.
getter/setter pair
- wMonth ↔ int
-
getter/setter pair
- wSecond ↔ int
-
The second.
getter/setter pair
- wYear ↔ int
-
The year.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDateTime(
{bool isUtc = true}) → DateTime -
Available on SYSTEMTIME, provided by the SYSTEMTIMEToDateTimeConversion extension
Converts this SYSTEMTIME to a Dart DateTime. -
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< SYSTEMTIME> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited