Contains information about the current state of the system battery.
To learn more, see learn.microsoft.com/windows/win32/api/winnt/ns-winnt-system_battery_state.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
- AcOnLine ↔ bool
-
If this member is TRUE, the system battery charger is currently
operating on external power.
getter/setter pair
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - BatteryPresent ↔ bool
-
If this member is TRUE, at least one battery is present in the system.
getter/setter pair
- Charging ↔ bool
-
If this member is TRUE, a battery is currently charging.
getter/setter pair
- DefaultAlert1 ↔ int
-
The manufacturer's suggestion of a capacity, in mWh, at which a low
battery alert should occur.
getter/setter pair
- DefaultAlert2 ↔ int
-
The manufacturer's suggestion of a capacity, in mWh, at which a warning
battery alert should occur.
getter/setter pair
- Discharging ↔ bool
-
If this member is TRUE, a battery is currently discharging.
getter/setter pair
- EstimatedTime ↔ int
-
The estimated time remaining on the battery, in seconds.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- MaxCapacity ↔ int
-
The theoretical capacity of the battery when new.
getter/setter pair
- Rate ↔ int
-
The current rate of discharge of the battery, in mW.
getter/setter pair
- RemainingCapacity ↔ int
-
The estimated remaining capacity of the battery.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Spare1
↔ Array<
Uint8> -
Reserved.
getter/setter pair
- Tag ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< SYSTEM_BATTERY_STATE> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited