Describes the relationship between the specified processor set.
This structure is used with the GetLogicalProcessorInformation function.
To learn more, see learn.microsoft.com/windows/win32/api/winnt/ns-winnt-system_logical_processor_information.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - Anonymous ↔ SYSTEM_LOGICAL_PROCESSOR_INFORMATION_0
-
getter/setter pair
- Cache ↔ CACHE_DESCRIPTOR
-
Available on SYSTEM_LOGICAL_PROCESSOR_INFORMATION, provided by the SYSTEM_LOGICAL_PROCESSOR_INFORMATION_0_Extension extension
getter/setter pair - Flags ↔ int
-
Available on SYSTEM_LOGICAL_PROCESSOR_INFORMATION, provided by the SYSTEM_LOGICAL_PROCESSOR_INFORMATION_0_0_Extension extension
getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- NodeNumber ↔ int
-
Available on SYSTEM_LOGICAL_PROCESSOR_INFORMATION, provided by the SYSTEM_LOGICAL_PROCESSOR_INFORMATION_0_1_Extension extension
getter/setter pair - NumaNode ↔ SYSTEM_LOGICAL_PROCESSOR_INFORMATION_0_1
-
Available on SYSTEM_LOGICAL_PROCESSOR_INFORMATION, provided by the SYSTEM_LOGICAL_PROCESSOR_INFORMATION_0_Extension extension
getter/setter pair - ProcessorCore ↔ SYSTEM_LOGICAL_PROCESSOR_INFORMATION_0_0
-
Available on SYSTEM_LOGICAL_PROCESSOR_INFORMATION, provided by the SYSTEM_LOGICAL_PROCESSOR_INFORMATION_0_Extension extension
getter/setter pair - ProcessorMask ↔ int
-
The processor mask identifying the processors described by this structure.
getter/setter pair
- Relationship ↔ LOGICAL_PROCESSOR_RELATIONSHIP
-
The relationship between the processors identified by the value of the
ProcessorMask member.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< SYSTEM_LOGICAL_PROCESSOR_INFORMATION> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited