ScrollAmount_LargeDecrement top-level constant
ScrollAmount
const ScrollAmount_LargeDecrement
Scrolling is done in large decrements, equivalent to pressing the PAGE UP key or clicking on a blank part of a scroll bar.
Implementation
const ScrollAmount_LargeDecrement = ScrollAmount(0);