ScrollAmount_SmallIncrement top-level constant
ScrollAmount
const ScrollAmount_SmallIncrement
Scrolling is done in small increments, equivalent to pressing an arrow key or clicking the arrow button on a scroll bar.
Implementation
const ScrollAmount_SmallIncrement = ScrollAmount(4);