SetJob function winspool
Pauses, resumes, cancels, or restarts a print job on a specified printer.
You can also use the SetJob function to set print job parameters, such as the print job priority and the document name.
To learn more, see learn.microsoft.com/windows/win32/printdocs/setjob.
Implementation
@pragma('vm:prefer-inline')
bool SetJob(PRINTER_HANDLE hPrinter, int jobId, int level, int command) =>
_SetJob(hPrinter, jobId, level, nullptr, command) != FALSE;