SetPrinterDataEx function winspool
Sets the configuration data for a printer or print server.
The function stores the configuration data under the printers registry key.
To learn more, see learn.microsoft.com/windows/win32/printdocs/setprinterdataex.
Implementation
@pragma('vm:prefer-inline')
int SetPrinterDataEx(
PRINTER_HANDLE hPrinter,
PCWSTR pKeyName,
PCWSTR pValueName,
int type,
Pointer<Uint8> pData,
int cbData,
) => _SetPrinterDataEx(hPrinter, pKeyName, pValueName, type, pData, cbData);