SetRect function user32
Sets the coordinates of the specified rectangle.
This is equivalent to assigning the left, top, right, and bottom arguments to the appropriate members of the RECT structure.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-setrect.
Implementation
@pragma('vm:prefer-inline')
bool SetRect(
Pointer<RECT> lprc,
int xLeft,
int yTop,
int xRight,
int yBottom,
) => _SetRect(lprc, xLeft, yTop, xRight, yBottom) != FALSE;