SetSystemCursor function user32
Enables an application to customize the system cursors.
It replaces the contents of the system cursor specified by the id parameter with the contents of the cursor specified by the hcur parameter and then destroys hcur.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/nf-winuser-setsystemcursor.
Implementation
Win32Result<bool> SetSystemCursor(HCURSOR hcur, SYSTEM_CURSOR_ID id) {
final result_ = SetSystemCursor_Wrapper(hcur, id);
return .new(value: result_.value.i32 != FALSE, error: result_.error);
}