SetWindowExtEx function gdi32
Sets the horizontal and vertical extents of the window for a device context by using the specified values.
To learn more, see learn.microsoft.com/windows/win32/api/wingdi/nf-wingdi-setwindowextex.
Implementation
@pragma('vm:prefer-inline')
bool SetWindowExtEx(HDC hdc, int x, int y, Pointer<SIZE>? lpsz) =>
_SetWindowExtEx(hdc, x, y, lpsz ?? nullptr) != FALSE;