SysReAllocString function oleaut32
Reallocates a previously allocated string to be the size of a second string and copies the second string into the reallocated memory.
To learn more, see learn.microsoft.com/windows/win32/api/oleauto/nf-oleauto-sysreallocstring.
Implementation
@pragma('vm:prefer-inline')
int SysReAllocString(Pointer<Pointer<Utf16>> pbstr, PCWSTR? psz) =>
_SysReAllocString(pbstr, psz ?? nullptr);