SysReleaseString function oleaut32
Decreases the pinning reference count for the specified string by one.
When that count reaches 0, the memory for that string is no longer prevented from being freed.
To learn more, see learn.microsoft.com/windows/win32/api/oleauto/nf-oleauto-sysreleasestring.
Implementation
@pragma('vm:prefer-inline')
void SysReleaseString(BSTR bstrString) => _SysReleaseString(bstrString);