Contains information about a type library.
Information from this structure is used to identify the type library and to provide national language support for member names.
To learn more, see learn.microsoft.com/windows/win32/api/oaidl/ns-oaidl-tlibattr.
- Inheritance
- Implemented types
- Available extensions
Constructors
- TLIBATTR()
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - guid ↔ GUID
-
The globally unique identifier.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- lcid ↔ int
-
The locale identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- syskind ↔ SYSKIND
-
The target hardware platform.
getter/setter pair
- wLibFlags ↔ int
-
The library flags.
getter/setter pair
- wMajorVerNum ↔ int
-
The major version number.
getter/setter pair
- wMinorVerNum ↔ int
-
The minor version number.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< TLIBATTR> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited