Contains window information.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-windowinfo.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - atomWindowType ↔ int
-
The window class atom (see RegisterClass).
getter/setter pair
- cbSize ↔ int
-
The size of the struct in bytes.
getter/setter pair
- cxWindowBorders ↔ int
-
The width of the window border, in pixels.
getter/setter pair
- cyWindowBorders ↔ int
-
The height of the window border, in pixels.
getter/setter pair
- dwExStyle ↔ WINDOW_EX_STYLE
-
The extended window styles.
getter/setter pair
- dwStyle ↔ WINDOW_STYLE
-
The window styles.
getter/setter pair
- dwWindowStatus ↔ int
-
The window status.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- rcClient ↔ RECT
-
The coordinates of the client area.
getter/setter pair
- rcWindow ↔ RECT
-
The coordinates of the window.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wCreatorVersion ↔ int
-
The Windows version of the application that created the window.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< WINDOWINFO> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited