Contains information about an available wireless network.
To learn more, see learn.microsoft.com/windows/win32/api/wlanapi/ns-wlanapi-wlan_available_network.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - bMorePhyTypes ↔ bool
-
Specifies if there are more than WLAN_MAX_PHY_TYPE_NUMBER PHY types
supported.
getter/setter pair
- bNetworkConnectable ↔ bool
-
Indicates whether the network is connectable or not.
getter/setter pair
- bSecurityEnabled ↔ bool
-
Indicates whether security is enabled on the network.
getter/setter pair
- dot11BssType ↔ DOT11_BSS_TYPE
-
A DOT11_BSS_TYPE
value that specifies whether the network is infrastructure or ad hoc.
getter/setter pair
- dot11DefaultAuthAlgorithm ↔ DOT11_AUTH_ALGORITHM
-
A DOT11_AUTH_ALGORITHM
value that indicates the default authentication algorithm used to join
this network for the first time.
getter/setter pair
- dot11DefaultCipherAlgorithm ↔ DOT11_CIPHER_ALGORITHM
-
A DOT11_CIPHER_ALGORITHM
value that indicates the default cipher algorithm to be used when joining
this network.
getter/setter pair
-
dot11PhyTypes
↔ Array<
Int32> -
Contains an array of DOT11_PHY_TYPE
values that represent the PHY types supported by the available networks.
getter/setter pair
- dot11Ssid ↔ DOT11_SSID
-
A
DOT11_SSIDstructure that contains the SSID of the visible wireless network.getter/setter pair - dwFlags ↔ int
-
Contains various flags for the network.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strProfileName ↔ String
-
Contains the profile name associated with the network.
getter/setter pair
- uNumberOfBssids ↔ int
-
Indicates the number of BSSIDs in the network.
getter/setter pair
- uNumberOfPhyTypes ↔ int
-
The number of PHY types supported on available networks.
getter/setter pair
- wlanNotConnectableReason ↔ int
-
A WLAN_REASON_CODE value that indicates why a network cannot be connected
to.
getter/setter pair
- wlanSignalQuality ↔ int
-
A percentage value that represents the signal quality of the network.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< WLAN_AVAILABLE_NETWORK> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited