Contains information about a network state change on the wireless Hosted Network.
To learn more, see learn.microsoft.com/windows/win32/api/wlanapi/ns-wlanapi-wlan_hosted_network_state_change.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- NewState ↔ WLAN_HOSTED_NETWORK_STATE
-
The current network state on the wireless Hosted Network.
getter/setter pair
- OldState ↔ WLAN_HOSTED_NETWORK_STATE
-
The previous network state on the wireless Hosted Network.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- StateChangeReason ↔ WLAN_HOSTED_NETWORK_REASON
-
The reason for the network state change.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< WLAN_HOSTED_NETWORK_STATE_CHANGE> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited