Contains information about sent and received MAC frames.
To learn more, see learn.microsoft.com/windows/win32/api/wlanapi/ns-wlanapi-wlan_mac_frame_statistics.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ullCCMPDecryptErrors ↔ int
-
Contains the number of received fragments discarded by the CCMP decryption
algorithm.
getter/setter pair
- ullCCMPReplays ↔ int
-
Contains the number of received unicast fragments discarded by the replay
mechanism.
getter/setter pair
- ullDecryptFailureCount ↔ int
-
Contains the number of encrypted packets that the NIC has failed to
decrypt.
getter/setter pair
- ullDecryptSuccessCount ↔ int
-
Contains the number of encrypted packets that the NIC has successfully
decrypted.
getter/setter pair
- ullReceivedFrameCount ↔ int
-
Contains the number of successfully received MSDU/MMPDUs.
getter/setter pair
- ullTKIPICVErrorCount ↔ int
-
Contains the number of TKIP protected packets that the NIC failed to
decrypt.
getter/setter pair
- ullTKIPLocalMICFailures ↔ int
-
Contains the number of MIC failures encountered while checking the
integrity of packets received from the AP or peer station.
getter/setter pair
- ullTKIPReplays ↔ int
-
Contains the number of TKIP replay errors detected.
getter/setter pair
- ullTransmittedFrameCount ↔ int
-
Contains the number of successfully transmitted MSDU/MMPDUs.
getter/setter pair
- ullWEPExcludedCount ↔ int
-
Contains the number of frames discarded due to having a "Protected" status
indicated in the frame control field.
getter/setter pair
- ullWEPICVErrorCount ↔ int
-
Contains the number of WEP protected packets the NIC failed to decrypt.
getter/setter pair
- ullWEPUndecryptableCount ↔ int
-
Contains the number of WEP protected packets received for which a
decryption key was not available on the NIC.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< WLAN_MAC_FRAME_STATISTICS> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited