bFirstPeer property
bool
get
bFirstPeer
Indicates whether the peer is the first to join the ad hoc network created by the machine.
Implementation
bool get bFirstPeer => _bFirstPeer != FALSE;
set
bFirstPeer
(bool value)
Implementation
set bFirstPeer(bool value) => _bFirstPeer = value ? TRUE : FALSE;