WM_CHAR top-level constant
int
const WM_CHAR
Posted to the window with the keyboard focus when a WM_KEYDOWN message is translated by the TranslateMessage function.
The WM_CHAR message contains the character code of the key that was pressed.
To learn more, see learn.microsoft.com/windows/win32/inputdev/wm-char.
Implementation
const WM_CHAR = 258;