WM_ERASEBKGND top-level constant
int
const WM_ERASEBKGND
Sent when the window background must be erased (for example, when a window is resized).
The message is sent to prepare an invalidated portion of a window for painting.
To learn more, see learn.microsoft.com/windows/win32/winmsg/wm-erasebkgnd.
Implementation
const WM_ERASEBKGND = 20;