WM_GETDPISCALEDSIZE top-level constant
int
const WM_GETDPISCALEDSIZE
This message tells the operating system that the window will be sized to dimensions other than the default.
To learn more, see learn.microsoft.com/windows/win32/hidpi/wm-getdpiscaledsize.
Implementation
const WM_GETDPISCALEDSIZE = 740;