WM_KEYDOWN top-level constant
int
const WM_KEYDOWN
Posted to the window with the keyboard focus when a nonsystem key is pressed.
A nonsystem key is a key that is pressed when the ALT key is not pressed.
To learn more, see learn.microsoft.com/windows/win32/inputdev/wm-keydown.
Implementation
const WM_KEYDOWN = 256;