WM_NCRBUTTONUP top-level constant
int
const WM_NCRBUTTONUP
Posted when the user releases the right mouse button while the cursor is within the nonclient area of a window.
This message is posted to the window that contains the cursor. If a window has captured the mouse, this message is not posted.
To learn more, see learn.microsoft.com/windows/win32/inputdev/wm-ncrbuttonup.
Implementation
const WM_NCRBUTTONUP = 165;