Contains window class information.
To learn more, see learn.microsoft.com/windows/win32/api/winuser/ns-winuser-wndclassexw.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - cbClsExtra ↔ int
-
The number of extra bytes to allocate following the window-class
structure.
getter/setter pair
- cbSize ↔ int
-
The size of the struct in bytes.
getter/setter pair
- cbWndExtra ↔ int
-
The number of extra bytes to allocate following the window instance.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hbrBackground ↔ HBRUSH
-
A handle to the class background brush.
getter/setter pair
- hCursor ↔ HCURSOR
-
A handle to the class cursor.
getter/setter pair
- hIcon ↔ HICON
-
A handle to the class icon.
getter/setter pair
- hIconSm ↔ HICON
-
A handle to a small icon that is associated with the window class.
getter/setter pair
- hInstance ↔ HINSTANCE
-
A handle to the instance that contains the window procedure for the class.
getter/setter pair
-
lpfnWndProc
↔ Pointer<
NativeFunction< WNDPROC> > -
A pointer to the window procedure.
getter/setter pair
- lpszClassName ↔ PWSTR
-
A pointer to a null-terminated string or is an atom.
getter/setter pair
- lpszMenuName ↔ PWSTR
-
Pointer to a null-terminated character string that specifies the resource
name of the class menu, as the name appears in the resource file.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style ↔ WNDCLASS_STYLES
-
The class style(s).
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
{Allocator allocator = adaptiveCalloc}) → Pointer< WNDCLASSEX> - Allocates native memory and copies the contents of this struct into it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited