WlanRegisterDeviceServiceNotification function wlanapi
int
WlanRegisterDeviceServiceNotification(
- HANDLE hClientHandle,
- Pointer<
WLAN_DEVICE_SERVICE_GUID_LIST> ? pDevSvcGuidList
Allows user mode clients with admin privileges, or User-Mode Driver Framework (UMDF) drivers, to register for unsolicited notifications corresponding to device services that they're interested in.
To learn more, see learn.microsoft.com/windows/win32/api/wlanapi/nf-wlanapi-wlanregisterdeviceservicenotification.
Implementation
@pragma('vm:prefer-inline')
int WlanRegisterDeviceServiceNotification(
HANDLE hClientHandle,
Pointer<WLAN_DEVICE_SERVICE_GUID_LIST>? pDevSvcGuidList,
) => _WlanRegisterDeviceServiceNotification(
hClientHandle,
pDevSvcGuidList ?? nullptr,
);