XInputGetAudioDeviceIds function xinput
Retrieves the sound rendering and sound capture audio device IDs that are associated with the headset connected to the specified controller.
To learn more, see learn.microsoft.com/windows/win32/api/xinput/nf-xinput-xinputgetaudiodeviceids.
Implementation
@pragma('vm:prefer-inline')
int XInputGetAudioDeviceIds(
int dwUserIndex,
PWSTR? pRenderDeviceId,
Pointer<Uint32>? pRenderCount,
PWSTR? pCaptureDeviceId,
Pointer<Uint32>? pCaptureCount,
) => _XInputGetAudioDeviceIds(
dwUserIndex,
pRenderDeviceId ?? nullptr,
pRenderCount ?? nullptr,
pCaptureDeviceId ?? nullptr,
pCaptureCount ?? nullptr,
);